(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   4229830,      79853]
NotebookOptionsPosition[   4196213,      79292]
NotebookOutlinePosition[   4196607,      79309]
CellTagsIndexPosition[   4196564,      79306]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Information and copyright", "Title"]], "Subtitle",
 CellChangeTimes->{{3.793911408292458*^9, 
  3.793911410460486*^9}},ExpressionUUID->"2ff7685d-4431-4733-a6dc-\
eb03aac664d6"],

Cell["\<\
Simulation code associated with \[OpenCurlyDoubleQuote]Projecting the \
transmission dynamics of SARS-CoV-2 through the post-pandemic period\
\[CloseCurlyDoubleQuote], \[LineSeparator]by S.M. Kissler*, C. Tedijanto*, E. \
Goldstein, Y.H. Grad, and M. Lipsitch
* denotes equal contribution
Correspondence: skissler@hsph.harvard.edu

Last modified: 22 March 2020

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.\
\>", "Text",
 CellChangeTimes->{{3.7939114128222847`*^9, 
  3.7939114553573427`*^9}},ExpressionUUID->"b60253c1-3dc2-4619-afc5-\
5c60a11ee2de"]
}, Closed]],

Cell[CellGroupData[{

Cell["Three-strain model", "Title",
 CellChangeTimes->{{3.7946560544449577`*^9, 
  3.794656056806396*^9}},ExpressionUUID->"fe9183ad-39dc-4baf-afff-\
e7d104581afe"],

Cell["Define forcing functions:", "Subtitle",
 CellChangeTimes->{{3.791023334159409*^9, 
  3.7910233367272177`*^9}},ExpressionUUID->"04b0bacc-6ba0-4a28-8587-\
c64867cea39d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Seasonality", " ", "function"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"betaval", "[", 
     RowBox[{
     "t_", ",", "amplitude_", ",", "baseline_", ",", "phival_", ",", 
      "gammaval_"}], "]"}], ":=", 
    RowBox[{"gammaval", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"amplitude", "/", "2"}], "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t", "-", "phival"}], ")"}], "/", "52"}]}], "]"}]}], "+", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{"amplitude", "/", "2"}], "+", "baseline"}], ")"}]}], 
      ")"}]}]}], "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Function", " ", "for", " ", "simulating", " ", "importation", " ", "of", 
     " ", "strain", " ", "1"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p1", "[", 
     RowBox[{
     "t_", ",", "kappaval_", ",", "importtime1_", ",", "importlength_"}], 
     "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"t", ">", "importtime1"}], "&&", " ", 
       RowBox[{"t", "\[LessEqual]", 
        RowBox[{"(", 
         RowBox[{"importtime1", "+", "importlength"}], ")"}]}]}], ",", 
      "kappaval", ",", "0"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Function", " ", "for", " ", "simulating", " ", "importation", " ", "of", 
     " ", "strain", " ", "2"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"p2", "[", 
     RowBox[{
     "t_", ",", "kappaval_", ",", "importtime2_", ",", "importlength_"}], 
     "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"t", ">", "importtime2"}], "&&", " ", 
       RowBox[{"t", "\[LessEqual]", 
        RowBox[{"(", 
         RowBox[{"importtime2", "+", "importlength"}], ")"}]}]}], ",", 
      "kappaval", ",", "0"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Function", " ", "for", " ", "simulating", " ", "importation", " ", "of", 
     " ", "strain", " ", "3"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"p3", "[", 
     RowBox[{
     "t_", ",", "kappaval_", ",", "importtime3_", ",", "importlength_"}], 
     "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"t", ">", "importtime3"}], "&&", " ", 
       RowBox[{"t", "\[LessEqual]", 
        RowBox[{"(", 
         RowBox[{"importtime3", "+", "importlength"}], ")"}]}]}], ",", 
      "kappaval", ",", "0"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7909370320251226`*^9, 3.7909370583715*^9}, {
  3.79093766968883*^9, 3.7909376697924356`*^9}, {3.7909384651341467`*^9, 
  3.790938471061796*^9}, {3.790954063164301*^9, 3.7909540729079037`*^9}, {
  3.793911473673235*^9, 3.793911490651181*^9}},
 CellLabel->
  "In[1517]:=",ExpressionUUID->"141cf336-bfaa-438f-9303-4191553821ed"],

Cell[CellGroupData[{

Cell["Define model functions:", "Subtitle",
 CellChangeTimes->{{3.791023359023484*^9, 
  3.791023361073688*^9}},ExpressionUUID->"25b7a628-1f53-4321-a8c8-\
c9a691798dde"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"S1S2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi31val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi31val"}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi32val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi32val"}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1S2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi31val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi31val"}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi32val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi32val"}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1S2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi31val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi31val"}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi32val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1S2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi32val"}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1S2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1S2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"S1S2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi21val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1E2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi21val"}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1E2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1E2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi23val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1E2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi23val"}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1E2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1E2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1E2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1E2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1E2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1E2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1E2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1E2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"S1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi21val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1I2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi21val"}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1I2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1I2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi23val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1I2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi23val"}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1I2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1I2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1I2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1I2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1I2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1I2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1I2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1I2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"S1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi21val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1R2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi21val"}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1R2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"S1R2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi23val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1R2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi23val"}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1R2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1R2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1R2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"S1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"S1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1R2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1R2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"S1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"S1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"S1R2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi21val", ",", "chi31val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p1", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime1", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"S1R2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"S1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S1R2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"S1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1S2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi12val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi12val"}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi13val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi13val"}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1S2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1S2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1S2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1S2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1S2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1S2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1S2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1S2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1S2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1S2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1S2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1S2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"E1S2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1E2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1E2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1E2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"E1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1I2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1I2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1I2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1I2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1I2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"E1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1R2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"E1R2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"E1R2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"E1R2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"E1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"E1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"E1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"E1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"E1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"E1R2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"E1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1S2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi12val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi12val"}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi13val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi13val"}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1S2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1S2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1S2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1S2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1S2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1S2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1S2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1S2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1S2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1S2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1S2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1S2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"I1S2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1E2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1E2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1E2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1E2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1E2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"I1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1I2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1I2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1I2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"I1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1R2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"I1R2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"I1R2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"I1R2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"I1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"I1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"I1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"I1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"I1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1R2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"I1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1S2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi12val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi12val"}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi13val"}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1S2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "chi13val"}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1S2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1S2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1S2E3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1S2E3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1S2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1S2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1S2I3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1S2I3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1S2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1S2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{
      "t", ",", "amplitude", ",", "baseline", ",", "phival", ",", 
       "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1S2R3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi12val", ",", "chi32val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p2", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime2", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1S2R3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1S2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"R1S2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1E2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1E2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1E2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1E2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1E2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1E2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1E2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"R1E2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1I2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1I2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1I2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1I2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1I2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1I2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1I2R3c3", "[", "t", "]"}], ":=", 
   RowBox[{"sigma3val", "*", 
    RowBox[{"R1I2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2S3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1R2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2S3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"R1R2S3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2S3c3", "[", "t", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"betaval", "[", 
      RowBox[{"t", ",", 
       RowBox[{"f", "*", "amplitude"}], ",", 
       RowBox[{"baseline", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "f"}], ")"}], "*", "amplitude"}]}], ",", "phival",
        ",", "gammaval"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
       RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}], "*", 
     RowBox[{"R1R2S3", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Max", "[", 
        RowBox[{"chi13val", ",", "chi23val"}], "]"}]}], ")"}], "*", 
     RowBox[{"p3", "[", 
      RowBox[{"t", ",", "kappaval", ",", "importtime3", ",", "importlength"}],
       "]"}], "*", 
     RowBox[{"R1R2S3", "[", "t", "]"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2E3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2E3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"R1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2E3c3", "[", "t", "]"}], ":=", 
   RowBox[{"nuval", "*", 
    RowBox[{"R1R2E3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2I3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2I3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"R1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2I3c3", "[", "t", "]"}], ":=", 
   RowBox[{"gammaval", "*", 
    RowBox[{"R1R2I3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2R3c1", "[", "t", "]"}], ":=", 
   RowBox[{"sigma1val", "*", 
    RowBox[{"R1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"R1R2R3c2", "[", "t", "]"}], ":=", 
   RowBox[{"sigma2val", "*", 
    RowBox[{"R1R2R3", "[", "t", "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R1R2R3c3", "[", "t", "]"}], ":=", 
  RowBox[{"sigma3val", "*", 
   RowBox[{"R1R2R3", "[", "t", "]"}]}]}], "\n"}], "Input",
 CellChangeTimes->{{3.7915567531636257`*^9, 3.791556753165571*^9}},
 CellLabel->
  "In[1521]:=",ExpressionUUID->"378d2fa8-8139-4363-8401-833ea9e62283"]
}, Closed]],

Cell[CellGroupData[{

Cell["Define model solver:", "Subtitle",
 CellChangeTimes->{{3.794654783806251*^9, 
  3.7946547909258537`*^9}},ExpressionUUID->"bae8e1ce-7076-471c-8e09-\
82f688cb58b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"runmodel3strain", "[", "]"}], " ", ":=", " ", 
   RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"S1S2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1S2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1S2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1S2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1S2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1R2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1S2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1S2S3", "[", "t", "]"}]}], "+", "muval"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1S2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1S2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1S2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1S2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1R2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1S2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1S2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1S2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1S2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1S2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1S2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1S2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1R2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1S2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1S2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1S2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1S2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1S2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1S2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1S2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1R2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1S2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1S2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1E2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1E2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1E2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1E2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1E2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1S2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1E2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1E2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1E2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1E2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1E2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1E2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1S2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1E2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1E2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1E2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1E2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1E2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1E2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1E2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1S2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1E2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1E2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1E2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1E2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1E2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1E2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1E2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1S2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1E2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1E2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1I2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1I2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1I2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1I2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1I2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1I2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1I2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1I2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1I2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1I2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1I2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1I2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1I2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1I2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1I2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1I2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1I2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1I2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1I2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1I2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1I2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1I2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1I2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1I2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1I2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1I2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1I2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1R2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1R2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1R2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1R2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1R2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1I2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1R2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1R2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1R2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1R2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1R2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1R2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1R2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1I2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1R2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1R2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1R2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1R2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1R2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1R2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1R2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1I2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1R2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1R2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"S1R2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"S1R2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"S1R2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"S1R2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1R2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1I2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1R2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"S1R2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1S2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1S2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1S2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1S2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1S2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1S2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1S2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1S2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1S2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1S2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1S2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1S2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1S2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1S2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1S2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1S2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1S2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1S2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1S2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1S2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1S2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1S2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1S2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1S2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1S2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1S2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1S2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1E2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1E2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1E2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1E2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1E2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1S2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1E2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1E2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1E2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1E2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1E2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1S2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1E2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1E2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1E2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1E2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1E2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1E2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1S2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1E2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1E2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1E2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1E2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1E2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1E2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1S2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1E2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1I2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1I2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1I2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1I2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1I2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1I2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1I2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1I2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1I2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1I2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1I2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1I2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1I2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1I2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1I2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1I2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1I2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1I2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1I2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1I2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1I2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1I2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1I2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1I2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1I2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1I2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1I2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1R2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1R2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1R2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1R2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1R2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1R2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1R2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1R2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1R2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1R2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1R2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1R2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1R2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1R2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1R2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1R2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1R2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1R2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1R2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1R2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1R2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"E1R2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"E1R2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"E1R2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"E1R2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1R2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1R2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"E1R2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1S2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1S2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1S2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1S2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1S2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1R2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1S2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1S2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1S2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1S2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1S2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1S2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1R2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1S2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1S2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1S2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1S2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1S2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1S2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1S2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1R2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1S2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1S2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1S2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1S2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1S2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1S2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1S2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1R2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1S2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1S2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1E2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1E2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1E2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1E2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1E2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1S2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1E2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1E2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1E2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1E2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1E2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1S2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1E2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1E2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1E2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1E2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1E2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1E2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1S2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1E2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1E2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1E2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1E2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1E2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1E2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1S2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1E2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1I2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1I2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1I2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1I2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1I2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1I2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1I2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1I2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1I2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1I2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1I2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1I2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1I2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1I2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1I2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1I2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1I2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1I2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1I2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1I2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1I2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1I2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1I2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1I2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1I2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1I2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1I2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1R2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1R2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1R2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1R2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1R2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1I2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1R2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1R2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1R2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1R2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1R2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1R2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1R2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1I2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1R2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1R2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1R2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1R2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1R2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1R2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1R2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1I2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1R2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1R2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"I1R2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"I1R2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"I1R2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"I1R2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1R2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"I1I2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1R2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"I1R2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1S2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1S2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1S2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1S2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1S2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1R2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1S2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1S2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1S2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1S2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1S2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1S2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1R2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1S2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1S2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1S2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1S2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1S2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1S2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1S2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1R2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1S2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1S2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1S2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1S2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1S2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1S2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1S2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1R2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1S2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1S2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1E2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1E2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1E2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1E2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1E2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1S2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1E2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1E2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1E2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1E2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1E2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1S2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1E2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1E2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1E2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1E2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1E2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1E2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1S2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1E2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1E2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1E2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1E2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1E2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1E2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1S2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1E2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1I2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1I2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1I2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1I2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1I2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1I2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1I2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1I2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1I2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1I2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1I2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1I2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1I2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1I2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1I2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1I2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1I2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1I2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1I2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1I2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1I2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1I2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1I2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1I2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1I2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1I2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1I2R3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1R2S3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1R2S3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1R2S3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1R2S3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1R2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1I2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1R2R3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1R2S3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1R2E3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1R2E3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1R2E3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1R2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1R2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1I2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1R2S3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1R2E3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1R2I3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1R2I3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1R2I3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1R2I3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1R2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1I2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1R2E3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1R2I3", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"R1R2R3", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"R1R2R3c1", "[", "t", "]"}]}], "-", 
         RowBox[{"R1R2R3c2", "[", "t", "]"}], "-", 
         RowBox[{"R1R2R3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1R2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"R1I2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1R2I3c3", "[", "t", "]"}], "-", 
         RowBox[{"muval", "*", 
          RowBox[{"R1R2R3", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"cuminf", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"E1S2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1S2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1S2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1S2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1E2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1I2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2S3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2E3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2I3c1", "[", "t", "]"}], "+", 
         RowBox[{"E1R2R3c1", "[", "t", "]"}], "+", 
         RowBox[{"S1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"E1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"I1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2S3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2E3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2I3c2", "[", "t", "]"}], "+", 
         RowBox[{"R1E2R3c2", "[", "t", "]"}], "+", 
         RowBox[{"S1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"S1R2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"E1R2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"I1R2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1S2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1E2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1I2E3c3", "[", "t", "]"}], "+", 
         RowBox[{"R1R2E3c3", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{
        RowBox[{"S1S2S3", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"S1S2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1S2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1S2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1E2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1E2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1E2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1E2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1I2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1I2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1I2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1I2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1R2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1R2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1R2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"S1R2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1S2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1S2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1S2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1S2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1E2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1E2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1E2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1E2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1I2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1I2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1I2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1I2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1R2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1R2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1R2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"E1R2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1S2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1S2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1S2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1S2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1E2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1E2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1E2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1E2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1I2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1I2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1I2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1I2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1R2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1R2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1R2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"I1R2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1S2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1S2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1S2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1S2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1E2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1E2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1E2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1E2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1I2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1I2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1I2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1I2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1R2S3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1R2E3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1R2I3", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"R1R2R3", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
       RowBox[{
        RowBox[{"cuminf", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "S1S2S3", ",", "S1S2E3", ",", "S1S2I3", ",", "S1S2R3", ",", "S1E2S3", 
       ",", "S1E2E3", ",", "S1E2I3", ",", "S1E2R3", ",", "S1I2S3", ",", 
       "S1I2E3", ",", "S1I2I3", ",", "S1I2R3", ",", "S1R2S3", ",", "S1R2E3", 
       ",", "S1R2I3", ",", "S1R2R3", ",", "E1S2S3", ",", "E1S2E3", ",", 
       "E1S2I3", ",", "E1S2R3", ",", "E1E2S3", ",", "E1E2E3", ",", "E1E2I3", 
       ",", "E1E2R3", ",", "E1I2S3", ",", "E1I2E3", ",", "E1I2I3", ",", 
       "E1I2R3", ",", "E1R2S3", ",", "E1R2E3", ",", "E1R2I3", ",", "E1R2R3", 
       ",", "I1S2S3", ",", "I1S2E3", ",", "I1S2I3", ",", "I1S2R3", ",", 
       "I1E2S3", ",", "I1E2E3", ",", "I1E2I3", ",", "I1E2R3", ",", "I1I2S3", 
       ",", "I1I2E3", ",", "I1I2I3", ",", "I1I2R3", ",", "I1R2S3", ",", 
       "I1R2E3", ",", "I1R2I3", ",", "I1R2R3", ",", "R1S2S3", ",", "R1S2E3", 
       ",", "R1S2I3", ",", "R1S2R3", ",", "R1E2S3", ",", "R1E2E3", ",", 
       "R1E2I3", ",", "R1E2R3", ",", "R1I2S3", ",", "R1I2E3", ",", "R1I2I3", 
       ",", "R1I2R3", ",", "R1R2S3", ",", "R1R2E3", ",", "R1R2I3", ",", 
       "R1R2R3", ",", " ", "cuminf"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "tmax"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7946548138245173`*^9, 3.794654820265665*^9}},
 CellLabel->
  "In[1713]:=",ExpressionUUID->"714225f8-68cb-4304-94db-e5b60663193e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set default parameter values: ", "Subtitle",
 CellChangeTimes->{{3.7910239846377707`*^9, 
  3.791023988052266*^9}},ExpressionUUID->"53125f91-a9fe-44a5-b45c-\
bb5e343cd1b9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sigma1val", " ", "=", " ", 
    RowBox[{"1", "/", "40"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Waning", " ", "immunity", " ", "rate"}], ",", " ", 
    RowBox[{"strain", " ", "1"}], ",", " ", 
    RowBox[{"weeks", ";", " ", 
     RowBox[{"default", " ", 
      RowBox[{"1", "/", "40"}]}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sigma2val", " ", "=", " ", 
    RowBox[{"1", "/", "38"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Waning", " ", "immunity", " ", "rate"}], ",", " ", 
    RowBox[{"strain", " ", "1"}], ",", " ", 
    RowBox[{"weeks", ";", " ", 
     RowBox[{"default", " ", 
      RowBox[{"1", "/", "40"}]}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sigma3val", " ", "=", " ", 
    RowBox[{"1", "/", "104"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Waning", " ", "immunity", " ", "rate"}], ",", " ", 
    RowBox[{"strain", " ", "1"}], ",", " ", 
    RowBox[{"weeks", ";", " ", 
     RowBox[{"default", " ", 
      RowBox[{"1", "/", "40"}]}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nuval", " ", "=", " ", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"4.9", "/", "7"}], ")"}]}]}], ";", "  ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Rate", " ", "of", " ", "progression", " ", "to", " ", "infection"}], ",",
     " ", 
    RowBox[{"weeks", ";", " ", 
     RowBox[{"default", " ", 
      RowBox[{"1", "/", "1"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"gammaval", " ", "=", " ", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"4.8", "/", "7"}], ")"}]}]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Rate", " ", "of", " ", "recovery"}], ",", " ", 
    RowBox[{"weeks", ";", " ", 
     RowBox[{"default", " ", 
      RowBox[{"1", "/", "1"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"chi12val", " ", "=", " ", "0.74"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cross", " ", "immunity"}], ",", " ", 
    RowBox[{"strain", " ", "1", " ", "to", " ", "2"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"chi21val", " ", "=", " ", "0.5"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cross", " ", "immunity"}], ",", " ", 
    RowBox[{"strain", " ", "2", " ", "to", " ", "1"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"chi13val", "=", "0.0"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cross", " ", "immunity"}], ",", " ", 
    RowBox[{"strain", " ", "1", " ", "to", " ", "2"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"chi31val", "=", "0.7"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cross", " ", "immunity"}], ",", " ", 
    RowBox[{"strain", " ", "3", " ", "to", " ", "1"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"chi23val", "=", "0.0"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cross", " ", "immunity"}], ",", " ", 
    RowBox[{"strain", " ", "2", " ", "to", " ", "3"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"chi32val", "=", "0.7"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cross", " ", "immunity"}], ",", " ", 
    RowBox[{"strain", " ", "3", " ", "to", " ", "2"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"amplitude", "=", "0.66"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"Amplitude", " ", "of", " ", "seasonal", " ", "R0"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"baseline", "=", "1.4"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"Baseline", " ", "Ro", " ", "value"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"phival", "=", 
   RowBox[{"-", "3.8"}]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"Phase", " ", "shift", " ", "for", " ", "seasonal", " ", "R0", " ", 
    RowBox[{"(", "weeks", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"kappaval", " ", "=", " ", "0.01"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"Boost", " ", "from", " ", "importations"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"importtime1", " ", "=", " ", "0"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Importation", " ", "time", " ", "for", " ", "strain", " ", "1"}],
     ",", " ", "weeks"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"importtime2", " ", "=", " ", "52"}], ";", "  ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Importation", " ", "time", " ", "for", " ", "strain", " ", "2"}],
     ",", " ", "weeks"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"importtime3", "=", " ", 
   RowBox[{"52", "*", "100"}]}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"52", "*", "24"}], "+", "12"}], "*)"}], ";", "  ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Importation", " ", "time", " ", "for", " ", "strain", " ", "3"}],
     ",", " ", "weeks"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"importlength", " ", "=", " ", "0.5"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "How", " ", "long", " ", "does", " ", "an", " ", "importation", " ", 
     "boost", " ", "transmission"}], ",", " ", 
    RowBox[{"in", " ", 
     RowBox[{"weeks", "?"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"muval", " ", "=", " ", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"80", "*", "52"}], ")"}]}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"birth", " ", "rate"}], ",", " ", 
    RowBox[{"in", " ", "weeks"}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"f", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"Seasonality", " ", "factor", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", " ", "=", " ", 
       RowBox[{"full", " ", "seasonality"}]}], ",", " ", 
      RowBox[{"0", " ", "=", " ", 
       RowBox[{
       "no", " ", "seasonality", " ", "so", " ", "that", " ", "R0", " ", 
        "stays", " ", "fixed", " ", "at", " ", "its", " ", "maximal", " ", 
        "wintertime", " ", "value"}]}]}]}]}], "*)"}], 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.7893826216068077`*^9, 3.789382656206634*^9}, {
   3.789382771373292*^9, 3.789382810329616*^9}, 3.789382848558259*^9, {
   3.7893831265003138`*^9, 3.789383140681679*^9}, {3.789383535866098*^9, 
   3.789383604275647*^9}, {3.789383674181281*^9, 3.789383689217669*^9}, {
   3.789386570768784*^9, 3.789386576295244*^9}, {3.7893868720478373`*^9, 
   3.7893869009261293`*^9}, {3.78938703092451*^9, 3.7893870814114323`*^9}, {
   3.789387490795575*^9, 3.789387490850889*^9}, {3.7894945548936453`*^9, 
   3.789494554958658*^9}, {3.789494688780409*^9, 3.789494688842576*^9}, {
   3.789494765764986*^9, 3.7894947659418907`*^9}, {3.789494862456452*^9, 
   3.789494862505726*^9}, {3.7898385416303253`*^9, 3.7898386993599453`*^9}, {
   3.789846839591811*^9, 3.789846842212534*^9}, {3.789846887444832*^9, 
   3.789846915320219*^9}, {3.789846946204403*^9, 3.789846960273794*^9}, {
   3.7898609662258663`*^9, 3.789861183020906*^9}, {3.7898614257391577`*^9, 
   3.789861428287363*^9}, {3.78986167613214*^9, 3.789861678923402*^9}, {
   3.789861711255385*^9, 3.7898617890870857`*^9}, {3.7898618527744617`*^9, 
   3.78986186185503*^9}, {3.789861927488884*^9, 3.7898619287834263`*^9}, {
   3.789862100439152*^9, 3.789862182481927*^9}, {3.789862216272408*^9, 
   3.78986223977148*^9}, {3.789862486664744*^9, 3.78986249545652*^9}, 
   3.789862773216525*^9, {3.789908320786502*^9, 3.7899083387161083`*^9}, {
   3.789908427306974*^9, 3.789908455399016*^9}, {3.789909675809986*^9, 
   3.789909743047771*^9}, {3.78990977517432*^9, 3.7899098195598173`*^9}, {
   3.7899118767348127`*^9, 3.789911893699658*^9}, {3.789986555734662*^9, 
   3.789986637749013*^9}, {3.78998696191321*^9, 3.789986964999498*^9}, {
   3.789986995998123*^9, 3.78998700958105*^9}, {3.789987107257535*^9, 
   3.789987137039667*^9}, {3.7899872574638433`*^9, 3.7899872843481827`*^9}, {
   3.7899873384250393`*^9, 3.7899873386862793`*^9}, {3.7899875748641653`*^9, 
   3.789987587009626*^9}, 3.789987745408474*^9, 3.7899881319874983`*^9, 
   3.789988179024788*^9, {3.789988214832548*^9, 3.7899882241578503`*^9}, {
   3.789989445427074*^9, 3.789989548670764*^9}, {3.78998963827211*^9, 
   3.7899896507018623`*^9}, {3.7900798281386423`*^9, 
   3.7900798426283216`*^9}, {3.790079905141206*^9, 3.7900799328731813`*^9}, {
   3.7909371071519423`*^9, 3.790937229295066*^9}, {3.7909376509724503`*^9, 
   3.790937662301177*^9}, {3.790938822901424*^9, 3.7909388229991713`*^9}, {
   3.790938935517494*^9, 3.7909389741717873`*^9}, {3.7909390318143473`*^9, 
   3.790939036359186*^9}, {3.79095347465147*^9, 3.790953503107008*^9}, {
   3.791310603282024*^9, 3.791310613209457*^9}, {3.791310757466666*^9, 
   3.791310758164405*^9}, {3.7913109136968603`*^9, 3.791310916232502*^9}, {
   3.791464732674632*^9, 3.7914647988655148`*^9}, {3.791553223079227*^9, 
   3.7915532250626783`*^9}, {3.792330833400733*^9, 3.792330834406374*^9}, {
   3.793911499516836*^9, 3.7939115897740593`*^9}, {3.7946551350798597`*^9, 
   3.794655136859536*^9}},
 CellLabel->
  "In[1714]:=",ExpressionUUID->"888a48f1-5d01-4f63-9e78-19be0ed94d9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"scalingfactor", " ", "=", " ", "0.075"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Conversion", " ", "between", " ", "prevalence", " ", "and", " ", 
    RowBox[{"(", 
     RowBox[{"%", " ", "positive", " ", "*", " ", "%", " ", "ILI"}], ")"}]}], 
   " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.790941440214479*^9, 3.790941442279361*^9}, 
   3.7909535142434607`*^9, {3.793911591929694*^9, 3.793911612095974*^9}},
 CellLabel->
  "In[1718]:=",ExpressionUUID->"eb3d0e3b-d028-4079-ba6d-a325e738cd6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tmax", " ", "=", " ", 
    RowBox[{"52", "*", "30"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Simulation", " ", "timespan"}], ",", " ", "weeks"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7893826216068077`*^9, 3.789382656206634*^9}, {
   3.789382771373292*^9, 3.789382810329616*^9}, 3.789382848558259*^9, {
   3.7893831265003138`*^9, 3.789383140681679*^9}, {3.789383535866098*^9, 
   3.789383604275647*^9}, {3.789383674181281*^9, 3.789383689217669*^9}, {
   3.789386570768784*^9, 3.789386576295244*^9}, {3.7893868720478373`*^9, 
   3.7893869009261293`*^9}, {3.78938703092451*^9, 3.7893870814114323`*^9}, {
   3.789387490795575*^9, 3.789387490850889*^9}, {3.7894945548936453`*^9, 
   3.789494554958658*^9}, {3.789494688780409*^9, 3.789494688842576*^9}, {
   3.789494765764986*^9, 3.7894947659418907`*^9}, {3.789494862456452*^9, 
   3.789494862505726*^9}, {3.7898385416303253`*^9, 3.7898386993599453`*^9}, {
   3.789846839591811*^9, 3.789846842212534*^9}, {3.789846887444832*^9, 
   3.789846915320219*^9}, {3.789846946204403*^9, 3.789846960273794*^9}, {
   3.7898609662258663`*^9, 3.789861183020906*^9}, {3.7898614257391577`*^9, 
   3.789861428287363*^9}, {3.78986167613214*^9, 3.789861678923402*^9}, {
   3.789861711255385*^9, 3.7898617890870857`*^9}, {3.7898618527744617`*^9, 
   3.78986186185503*^9}, {3.789861927488884*^9, 3.7898619287834263`*^9}, {
   3.789862100439152*^9, 3.789862182481927*^9}, {3.789862216272408*^9, 
   3.78986223977148*^9}, {3.789862486664744*^9, 3.78986249545652*^9}, 
   3.789862773216525*^9, {3.789908320786502*^9, 3.7899083387161083`*^9}, {
   3.789908427306974*^9, 3.789908455399016*^9}, {3.789909675809986*^9, 
   3.789909743047771*^9}, {3.78990977517432*^9, 3.7899098195598173`*^9}, {
   3.7899118767348127`*^9, 3.789911893699658*^9}, {3.789986555734662*^9, 
   3.789986637749013*^9}, {3.78998696191321*^9, 3.789986964999498*^9}, {
   3.789986995998123*^9, 3.78998700958105*^9}, {3.789987107257535*^9, 
   3.789987137039667*^9}, {3.7899872574638433`*^9, 3.7899872843481827`*^9}, {
   3.7899873384250393`*^9, 3.7899873386862793`*^9}, {3.7899875748641653`*^9, 
   3.789987587009626*^9}, 3.789987745408474*^9, 3.7899881319874983`*^9, 
   3.789988179024788*^9, {3.789988214832548*^9, 3.7899882241578503`*^9}, {
   3.789989445427074*^9, 3.789989548670764*^9}, {3.78998963827211*^9, 
   3.7899896507018623`*^9}, {3.7900798281386423`*^9, 
   3.7900798426283216`*^9}, {3.790079905141206*^9, 3.7900799328731813`*^9}, {
   3.7909371071519423`*^9, 3.790937229295066*^9}, 3.791024700184856*^9},
 CellLabel->
  "In[1719]:=",ExpressionUUID->"c80e3ba9-d763-4994-92f1-51cc546a7d7f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"plotwindow", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"52", "*", "20.5"}], ",", " ", 
      RowBox[{"52", "*", "27.5"}]}], "}"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Time", " ", "span", " ", "for", " ", "plotting"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plotrangemax", " ", "=", " ", "0.8"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Max", " ", "plotting", " ", "value"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"importbarchar", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"Black", ",", " ", "Thick"}], "}"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "For", " ", "plotting", " ", "the", " ", "bar", " ", "marking", " ", "the",
     " ", "importation", " ", "time"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yearbarchar", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", " ", "Thin"}], "}"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"For", " ", "marking", " ", "years"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fs", " ", "=", " ", "18"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Plot", " ", "font", " ", "size"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"imsz", " ", "=", " ", "475"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"plot", " ", "image", " ", "size"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ncovticks", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"100", "*", "scalingfactor", "*", "#"}], ",", " ", 
       RowBox[{"ToString", "[", 
        RowBox[{"N", "[", 
         RowBox[{"1000", "*", "#"}], "]"}], "]"}]}], "}"}], "&"}], "/@", 
    RowBox[{"N", "[", 
     RowBox[{"FindDivisions", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"100", "*", "scalingfactor"}], ")"}]}], "*", 
          "plotrangemax"}]}], "}"}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"oc43char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Blue", ",", 
     RowBox[{"Thickness", "[", "0.008", "]"}], ",", " ", 
     RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Plotting", " ", "characteristics", " ", "for", " ", "HCoV"}], 
    "-", "OC43"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"hku1char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Red", ",", " ", 
     RowBox[{"Thickness", "[", "0.008", "]"}], ",", " ", 
     RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Plotting", " ", "characteristics", " ", "for", " ", "HCoV"}], 
    "-", "HKU1"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"ncovchar", "=", 
   RowBox[{"{", 
    RowBox[{"Black", ",", " ", 
     RowBox[{"Thickness", "[", "0.008", "]"}], ",", " ", 
     RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Plotting", " ", "characteristics", " ", "for", " ", "HCoV"}], 
    "-", "SARS", "-", "CoV", "-", "2"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"totalchar", "=", 
   RowBox[{"{", 
    RowBox[{"Black", ",", " ", 
     RowBox[{"Thickness", "[", "0.004", "]"}], ",", " ", 
     RowBox[{"Opacity", "[", "0.5", "]"}], ",", "Dashed"}], "}"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "Plotting", " ", "characteristics", " ", "for", " ", "the", " ", "total", 
    " ", "prevalence", " ", "curve"}], "*)"}], 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.791024717762186*^9, 3.791024805721538*^9}, {
  3.791024889143342*^9, 3.791024889320231*^9}, {3.7910249325264587`*^9, 
  3.791024950223687*^9}, {3.791239154707735*^9, 3.7912391821906557`*^9}, {
  3.793911615844095*^9, 3.793911679272488*^9}, {3.794655002166423*^9, 
  3.794655004011662*^9}},
 CellLabel->
  "In[1720]:=",ExpressionUUID->"7b51fd4b-e75f-474b-a781-4d9a463c0929"]
}, Closed]],

Cell[CellGroupData[{

Cell["Run some scenarios (Figure 3): ", "Subtitle",
 CellChangeTimes->{{3.791024028785932*^9, 3.791024045128837*^9}, {
  3.79465542406275*^9, 
  3.794655425213561*^9}},ExpressionUUID->"206007e1-e0d0-4f63-81a3-\
e3ea91d8bfdf"],

Cell[CellGroupData[{

Cell["70/0 | 104 | w4:", "Subsection",
 CellChangeTimes->{{3.791024299513517*^9, 3.791024333549387*^9}, 
   3.791024387646628*^9, 
   3.7910249962592897`*^9},ExpressionUUID->"0b9aab27-8667-40c4-9959-\
f6181b069508"],

Cell[CellGroupData[{

Cell["Define parameter values:", "Subsubsection",
 CellChangeTimes->{{3.791024353689595*^9, 
  3.7910243639133368`*^9}},ExpressionUUID->"bed0f23c-5785-46c2-9ac1-\
ebc6ce020d70"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi31val", "=", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi32val", " ", "=", " ", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi13val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi23val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma3val", " ", "=", " ", 
   RowBox[{"1", "/", "104"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"importtime3", " ", "=", " ", 
   RowBox[{
    RowBox[{"52", "*", "22"}], " ", "+", " ", "4"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.791024391785356*^9, 3.7910244703065147`*^9}, {
  3.791024832104692*^9, 3.791024893824339*^9}, {3.791025018882915*^9, 
  3.791025019096078*^9}},
 CellLabel->
  "In[1728]:=",ExpressionUUID->"65ee156e-f7eb-41a2-8633-db174b829f1b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the model: ", "Subsubsection",
 CellChangeTimes->{{3.791024365809227*^9, 
  3.791024367637371*^9}},ExpressionUUID->"c1237918-da52-42fd-a582-\
66e3b68e8cee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"runmodel3strain", "[", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.79465483624581*^9, 3.794654860545933*^9}},
 CellLabel->
  "In[1734]:=",ExpressionUUID->"98347448-fc9c-43b8-8e30-5d013a95309b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot output: ", "Subsubsection",
 CellChangeTimes->{{3.79102437504543*^9, 3.7910243813336277`*^9}, {
  3.7910245019903917`*^9, 
  3.791024504277298*^9}},ExpressionUUID->"a20696c8-180b-4a3c-9d0a-\
587612829b18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"figinvasion", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}]}], "}"}]}], "}"}], "/.",
         "sol"}], "]"}], "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "plotrangemax"}], "}"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "yearbarchar"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "0", ",", " ", "tmax", ",", " ", "52"}], 
             "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"importtime3", ",", "importbarchar"}], "}"}], "}"}]}], 
         "]"}], ",", "None"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicks", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ncovticks", ",", " ", "All"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"\"\<'\>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{
                 RowBox[{"i", "/", "52"}], "-", "2"}], "]"}]}]}], "}"}], ",", 
            " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "tmax", ",", "52"}], "}"}]}], "]"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Year\>\"", ",", "\"\<Prevalence per 1000 people\>\"", ",", " ", 
        "Automatic", ",", " ", "\"\<%Positive \[Times] %ILI\>\""}], "}"}]}], 
     ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "imsz"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<OC43\>\"", ",", "\"\<HKU1\>\"", ",", "\"\<SARS-CoV-2\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"oc43char", ",", " ", "hku1char", ",", "ncovchar"}], "}"}]}]}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7893824421170883`*^9, 3.7893826157339983`*^9}, {
   3.7893826664946747`*^9, 3.78938266695546*^9}, {3.789382731126128*^9, 
   3.789382731675748*^9}, {3.7893827767664127`*^9, 3.789382777444231*^9}, {
   3.789386619546466*^9, 3.789386631208551*^9}, {3.789387810394597*^9, 
   3.789388029020711*^9}, {3.789838710858089*^9, 3.789838717718485*^9}, {
   3.789842556270996*^9, 3.789842651382614*^9}, {3.7898426863790817`*^9, 
   3.7898427300803967`*^9}, {3.789842819806529*^9, 3.789842948950203*^9}, {
   3.7898429865388527`*^9, 3.789843021987234*^9}, {3.789843093799283*^9, 
   3.789843184820764*^9}, {3.78984336766575*^9, 3.7898436006321487`*^9}, {
   3.7898436712471724`*^9, 3.78984370597163*^9}, {3.789845657271617*^9, 
   3.78984565935472*^9}, {3.789845785029049*^9, 3.789845795524316*^9}, {
   3.7898458658704863`*^9, 3.789846118358913*^9}, {3.789846154006332*^9, 
   3.7898463664972258`*^9}, {3.789846403235764*^9, 3.789846484288625*^9}, {
   3.789846522317915*^9, 3.7898466387710238`*^9}, {3.789911908017222*^9, 
   3.789911994611348*^9}, {3.789987417920609*^9, 3.789987519668146*^9}, 
   3.78998766533955*^9, {3.7900151606852503`*^9, 3.790015162261084*^9}, {
   3.790017373012323*^9, 3.790017443684984*^9}, {3.7900174921119833`*^9, 
   3.7900178416947412`*^9}, {3.7900178781015577`*^9, 3.790018049008872*^9}, {
   3.790018143265133*^9, 3.7900182454606028`*^9}, {3.790080424619478*^9, 
   3.79008045222733*^9}, 3.790937591828598*^9, 3.790937628558119*^9, 
   3.790937755476927*^9, 3.790938168272998*^9, {3.790939252734089*^9, 
   3.790939274532484*^9}, {3.79093932502175*^9, 3.7909394034475937`*^9}, {
   3.790939491200864*^9, 3.790939533093276*^9}, {3.7909396652500963`*^9, 
   3.7909396778141613`*^9}, {3.7909397335725937`*^9, 3.790939735050262*^9}, 
   3.7909399443534927`*^9, {3.790940134103973*^9, 3.79094021526552*^9}, {
   3.790940254309019*^9, 3.790940255328331*^9}, {3.7909403051360607`*^9, 
   3.79094031494598*^9}, {3.7909404920878763`*^9, 3.7909404977980022`*^9}, {
   3.7909406269986343`*^9, 3.7909406299951353`*^9}, {3.790940726648095*^9, 
   3.790940771458849*^9}, {3.79094080944941*^9, 3.790940811632804*^9}, 
   3.7909409745994387`*^9, {3.7909413836357393`*^9, 3.790941469640398*^9}, {
   3.7909419009848537`*^9, 3.7909419011777773`*^9}, 3.790941934145125*^9, {
   3.7909429495176973`*^9, 3.790942950149515*^9}, 3.790943062385366*^9, {
   3.7909524619930143`*^9, 3.790952484646926*^9}, {3.790966313488199*^9, 
   3.7909663273901997`*^9}, 3.790966398007543*^9, {3.790986123275064*^9, 
   3.7909861516486263`*^9}, {3.7909862083701267`*^9, 3.790986209160791*^9}, {
   3.790986242927669*^9, 3.790986244031867*^9}, {3.790986294640409*^9, 
   3.7909863255150146`*^9}, {3.791024642180931*^9, 3.7910246434516687`*^9}, {
   3.7910247121220627`*^9, 3.791024713209406*^9}, {3.7910247441953907`*^9, 
   3.7910247453652563`*^9}, {3.7910247761867857`*^9, 3.791024874373518*^9}, 
   3.791024910533731*^9, {3.7910249449382544`*^9, 3.791024947047079*^9}, {
   3.791239027522357*^9, 3.7912390365135803`*^9}, 3.794655091073164*^9},
 CellLabel->
  "In[1735]:=",ExpressionUUID->"f1b05c94-8542-4b64-9433-61731956abe6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save output:", "Subsubsection",
 CellChangeTimes->{{3.791024505581291*^9, 3.7910245071250677`*^9}, {
  3.791311015004434*^9, 
  3.7913110162050247`*^9}},ExpressionUUID->"dfc40dac-1285-488a-9bc5-\
e74b12e325cc"],

Cell[CellGroupData[{

Cell[BoxData["figinvasion"], "Input",
 CellChangeTimes->{{3.790966344065854*^9, 3.79096634514146*^9}, {
  3.791024648443697*^9, 3.7910246488615093`*^9}},
 CellLabel->
  "In[1736]:=",ExpressionUUID->"1e5cadb8-3212-478d-a8b6-83a76ae2a7b2"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c81t8XAHAradAwMssqDcmIJH3OJYkGskmyd/ZKssmsZyChQsgmZBMy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          "]]}, 
        Annotation[#, "Charting`Private`Tag$63389#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c4ll8fAHAhlB8pGRklKrIyIqtzjpG9986eZSdJSEionoGE7GRkFNl7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          "]]}, 
        Annotation[#, "Charting`Private`Tag$63389#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJxM13c819/7OH5SlFCJMksqlBJSJLkO1dPeI9krlLI32ZQVnsPOKnuEZGav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          "]]}, Annotation[#, "Charting`Private`Tag$63389#1"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1066., 0}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, {{0., 
          FormBox["0", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.2, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.4, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.6, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.8, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.05, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.1, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.15, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.25, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.3, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.35, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.45, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.5, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.55, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.65, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.7, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.75, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {156, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {208, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {260, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {312, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {364, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {416, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {468, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {520, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {572, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {624, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {676, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {728, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {780, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {832, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {884, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {936, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {988, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1040, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1092, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1144, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1196, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1248, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1300, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1352, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1404, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1456, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1508, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1560, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1148, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{None, None}, {None, None}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1066., 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 1000 people\"", TraditionalForm], 
        FormBox["\"%Positive \[Times] %ILI\"", TraditionalForm]}, {
        FormBox["\"Year\"", TraditionalForm], 
        FormBox[
         TagBox["t", HoldForm], TraditionalForm]}}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, All}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1148, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 475, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{1066., 1430.}, {0, 0.8}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{None, None}, {None, None}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"OC43\"", "\"HKU1\"", "\"SARS-CoV-2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.79096634556618*^9, {3.790966425237339*^9, 3.790966454603299*^9}, {
   3.790966491150526*^9, 3.790966509642466*^9}, {3.790966583577635*^9, 
   3.790966594007172*^9}, 3.790966659549314*^9, 3.790966703393758*^9, {
   3.7909667383899107`*^9, 3.790966757715486*^9}, 3.790967166819141*^9, {
   3.790967206499619*^9, 3.79096727099717*^9}, {3.790967305889214*^9, 
   3.7909673423461*^9}, {3.790967440118722*^9, 3.7909674858629427`*^9}, 
   3.790967633111467*^9, {3.790967671807901*^9, 3.790967812899515*^9}, 
   3.790986120764835*^9, 3.790986154907075*^9, 3.790986213066638*^9, 
   3.7909862490280943`*^9, {3.790986298382011*^9, 3.7909863272991123`*^9}, {
   3.790986432124242*^9, 3.790986453558629*^9}, {3.790986576906382*^9, 
   3.7909866345433292`*^9}, 3.791024598576089*^9, 3.79102466009927*^9, 
   3.791024900351776*^9, 3.791024955991094*^9, 3.791025031840266*^9, 
   3.791238960765253*^9, 3.791239124941112*^9, {3.791239162745346*^9, 
   3.791239189172682*^9}, 3.7913110174043818`*^9, 3.791312911608612*^9, 
   3.791464823863011*^9, 3.791464894758128*^9, 3.793911361474633*^9, 
   3.794654867857441*^9, 3.794655108250066*^9, 3.794655374179044*^9, 
   3.794668106378087*^9, 3.794668503339221*^9},
 CellLabel->
  "Out[1736]=",ExpressionUUID->"c7f1edf9-a37f-427c-a364-0996e80352b8"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3E.pdf\>\"", ",", "figinvasion"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3E.png\>\"", ",", "figinvasion"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668427246479*^9, 3.7946684356350946`*^9}},
 CellLabel->
  "In[1737]:=",ExpressionUUID->"aae97602-f56b-4040-bd1d-ca8c0ac53634"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["70/0 | 104 | w26:", "Subsection",
 CellChangeTimes->{{3.791024299513517*^9, 3.791024333549387*^9}, 
   3.791024387646628*^9},ExpressionUUID->"f080211a-528f-4b6d-8ed8-\
24abfda161b8"],

Cell[CellGroupData[{

Cell["Define parameter values:", "Subsubsection",
 CellChangeTimes->{{3.791024353689595*^9, 
  3.7910243639133368`*^9}},ExpressionUUID->"a6b44300-d510-42e9-a59a-\
8d5adc429882"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi31val", "=", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi32val", " ", "=", " ", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi13val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi23val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma3val", " ", "=", " ", 
   RowBox[{"1", "/", "104"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"importtime3", " ", "=", " ", 
   RowBox[{
    RowBox[{"52", "*", "22"}], " ", "+", " ", "26"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.791024391785356*^9, 3.7910244703065147`*^9}, {
  3.791024832104692*^9, 3.791024893824339*^9}},
 CellLabel->
  "In[1739]:=",ExpressionUUID->"324a6c07-d025-4eb3-b7be-a7d9cc326c53"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the model: ", "Subsubsection",
 CellChangeTimes->{{3.791024365809227*^9, 3.791024367637371*^9}, {
  3.791311045138668*^9, 
  3.791311045664119*^9}},ExpressionUUID->"9d54a903-7aaa-46ce-aec0-\
e86751f6aeb6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"runmodel3strain", "[", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[1745]:=",ExpressionUUID->"506bbd7a-ac28-40eb-ba9f-682b1acc81ae"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot output: ", "Subsubsection",
 CellChangeTimes->{{3.79102437504543*^9, 3.7910243813336277`*^9}, {
  3.7910245019903917`*^9, 
  3.791024504277298*^9}},ExpressionUUID->"0685a7e7-2350-4d3c-84e3-\
f85d6ad559e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"figinvasion", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}]}], "}"}]}], "}"}], "/.",
         "sol"}], "]"}], "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "plotrangemax"}], "}"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "yearbarchar"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "0", ",", " ", "tmax", ",", " ", "52"}], 
             "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"importtime3", ",", "importbarchar"}], "}"}], "}"}]}], 
         "]"}], ",", "None"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicks", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ncovticks", ",", " ", "All"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"\"\<'\>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{
                 RowBox[{"i", "/", "52"}], "-", "2"}], "]"}]}]}], "}"}], ",", 
            " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "tmax", ",", "52"}], "}"}]}], "]"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Year\>\"", ",", "\"\<Prevalence per 1000 people\>\"", ",", " ", 
        "Automatic", ",", " ", "\"\<%Positive \[Times] %ILI\>\""}], "}"}]}], 
     ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "imsz"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<OC43\>\"", ",", "\"\<HKU1\>\"", ",", "\"\<SARS-CoV-2\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"oc43char", ",", " ", "hku1char", ",", "ncovchar"}], "}"}]}]}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7893824421170883`*^9, 3.7893826157339983`*^9}, {
   3.7893826664946747`*^9, 3.78938266695546*^9}, {3.789382731126128*^9, 
   3.789382731675748*^9}, {3.7893827767664127`*^9, 3.789382777444231*^9}, {
   3.789386619546466*^9, 3.789386631208551*^9}, {3.789387810394597*^9, 
   3.789388029020711*^9}, {3.789838710858089*^9, 3.789838717718485*^9}, {
   3.789842556270996*^9, 3.789842651382614*^9}, {3.7898426863790817`*^9, 
   3.7898427300803967`*^9}, {3.789842819806529*^9, 3.789842948950203*^9}, {
   3.7898429865388527`*^9, 3.789843021987234*^9}, {3.789843093799283*^9, 
   3.789843184820764*^9}, {3.78984336766575*^9, 3.7898436006321487`*^9}, {
   3.7898436712471724`*^9, 3.78984370597163*^9}, {3.789845657271617*^9, 
   3.78984565935472*^9}, {3.789845785029049*^9, 3.789845795524316*^9}, {
   3.7898458658704863`*^9, 3.789846118358913*^9}, {3.789846154006332*^9, 
   3.7898463664972258`*^9}, {3.789846403235764*^9, 3.789846484288625*^9}, {
   3.789846522317915*^9, 3.7898466387710238`*^9}, {3.789911908017222*^9, 
   3.789911994611348*^9}, {3.789987417920609*^9, 3.789987519668146*^9}, 
   3.78998766533955*^9, {3.7900151606852503`*^9, 3.790015162261084*^9}, {
   3.790017373012323*^9, 3.790017443684984*^9}, {3.7900174921119833`*^9, 
   3.7900178416947412`*^9}, {3.7900178781015577`*^9, 3.790018049008872*^9}, {
   3.790018143265133*^9, 3.7900182454606028`*^9}, {3.790080424619478*^9, 
   3.79008045222733*^9}, 3.790937591828598*^9, 3.790937628558119*^9, 
   3.790937755476927*^9, 3.790938168272998*^9, {3.790939252734089*^9, 
   3.790939274532484*^9}, {3.79093932502175*^9, 3.7909394034475937`*^9}, {
   3.790939491200864*^9, 3.790939533093276*^9}, {3.7909396652500963`*^9, 
   3.7909396778141613`*^9}, {3.7909397335725937`*^9, 3.790939735050262*^9}, 
   3.7909399443534927`*^9, {3.790940134103973*^9, 3.79094021526552*^9}, {
   3.790940254309019*^9, 3.790940255328331*^9}, {3.7909403051360607`*^9, 
   3.79094031494598*^9}, {3.7909404920878763`*^9, 3.7909404977980022`*^9}, {
   3.7909406269986343`*^9, 3.7909406299951353`*^9}, {3.790940726648095*^9, 
   3.790940771458849*^9}, {3.79094080944941*^9, 3.790940811632804*^9}, 
   3.7909409745994387`*^9, {3.7909413836357393`*^9, 3.790941469640398*^9}, {
   3.7909419009848537`*^9, 3.7909419011777773`*^9}, 3.790941934145125*^9, {
   3.7909429495176973`*^9, 3.790942950149515*^9}, 3.790943062385366*^9, {
   3.7909524619930143`*^9, 3.790952484646926*^9}, {3.790966313488199*^9, 
   3.7909663273901997`*^9}, 3.790966398007543*^9, {3.790986123275064*^9, 
   3.7909861516486263`*^9}, {3.7909862083701267`*^9, 3.790986209160791*^9}, {
   3.790986242927669*^9, 3.790986244031867*^9}, {3.790986294640409*^9, 
   3.7909863255150146`*^9}, {3.791024642180931*^9, 3.7910246434516687`*^9}, {
   3.7910247121220627`*^9, 3.791024713209406*^9}, {3.7910247441953907`*^9, 
   3.7910247453652563`*^9}, {3.7910247761867857`*^9, 3.791024874373518*^9}, 
   3.791024910533731*^9, {3.7910249449382544`*^9, 3.791024947047079*^9}, {
   3.7912390547184963`*^9, 3.791239057860058*^9}, 3.794655086703925*^9},
 CellLabel->
  "In[1746]:=",ExpressionUUID->"cb03dde3-40dc-424f-87c5-785506102ec3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save output:", "Subsubsection",
 CellChangeTimes->{{3.791024505581291*^9, 
  3.7910245071250677`*^9}},ExpressionUUID->"aa04129a-1173-4480-89e1-\
9aef4bc8f225"],

Cell[CellGroupData[{

Cell[BoxData["figinvasion"], "Input",
 CellChangeTimes->{{3.790966344065854*^9, 3.79096634514146*^9}, {
  3.791024648443697*^9, 3.7910246488615093`*^9}},
 CellLabel->
  "In[1747]:=",ExpressionUUID->"d152d2f1-5e0e-4818-bd8a-b8191bc3cede"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c8ll8bAHBlE4WMhIQSSUaEuK+DCCmyV7J3VkIqZFVIzyIhSXbIClnZ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$64589#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c8ll8bAHA7JSIjpBINCaFI0n0do+yVPTOzMkOSkKysnkWySfYqKgmR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          "]]}, 
        Annotation[#, "Charting`Private`Tag$64589#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJxM13c81t//OH67ErIzs6XIjqjOOVGyyUp2UYpEUqkkO7O4hozsTdlkJVz2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          "]]}, 
        Annotation[#, "Charting`Private`Tag$64589#1"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1066., 0}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, {{0., 
          FormBox["0", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.2, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.4, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.6, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.8, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.05, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.1, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.15, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.25, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.3, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.35, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.45, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.5, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.55, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.65, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.7, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.75, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {156, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {208, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {260, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {312, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {364, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {416, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {468, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {520, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {572, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {624, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {676, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {728, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {780, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {832, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {884, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {936, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {988, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1040, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1092, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1144, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1196, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1248, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1300, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1352, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1404, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1456, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1508, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1560, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1170, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{None, None}, {None, None}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1066., 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 1000 people\"", TraditionalForm], 
        FormBox["\"%Positive \[Times] %ILI\"", TraditionalForm]}, {
        FormBox["\"Year\"", TraditionalForm], 
        FormBox[
         TagBox["t", HoldForm], TraditionalForm]}}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, All}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1170, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 475, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{1066., 1430.}, {0, 0.8}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{None, None}, {None, None}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"OC43\"", "\"HKU1\"", "\"SARS-CoV-2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.79096634556618*^9, {3.790966425237339*^9, 3.790966454603299*^9}, {
   3.790966491150526*^9, 3.790966509642466*^9}, {3.790966583577635*^9, 
   3.790966594007172*^9}, 3.790966659549314*^9, 3.790966703393758*^9, {
   3.7909667383899107`*^9, 3.790966757715486*^9}, 3.790967166819141*^9, {
   3.790967206499619*^9, 3.79096727099717*^9}, {3.790967305889214*^9, 
   3.7909673423461*^9}, {3.790967440118722*^9, 3.7909674858629427`*^9}, 
   3.790967633111467*^9, {3.790967671807901*^9, 3.790967812899515*^9}, 
   3.790986120764835*^9, 3.790986154907075*^9, 3.790986213066638*^9, 
   3.7909862490280943`*^9, {3.790986298382011*^9, 3.7909863272991123`*^9}, {
   3.790986432124242*^9, 3.790986453558629*^9}, {3.790986576906382*^9, 
   3.7909866345433292`*^9}, 3.791024598576089*^9, 3.79102466009927*^9, 
   3.791024900351776*^9, 3.791024955991094*^9, 3.791238972144346*^9, 
   3.7912391260217037`*^9, {3.7912391640469723`*^9, 3.791239190491391*^9}, 
   3.791311057552409*^9, 3.791312913204534*^9, 3.791464919756754*^9, 
   3.7939113626383543`*^9, 3.794655109995174*^9, 3.794655375150844*^9, 
   3.7946681071424828`*^9, 3.794668505498087*^9},
 CellLabel->
  "Out[1747]=",ExpressionUUID->"d3a0da68-5073-480b-aadf-bbcf186e398d"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3F.pdf\>\"", ",", "figinvasion"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3F.png\>\"", ",", "figinvasion"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7946684520618553`*^9, 3.7946684527685223`*^9}},
 CellLabel->
  "In[1748]:=",ExpressionUUID->"9f03c8cd-381c-4723-baaf-e9e8ac0fe567"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["70/0 | \[Infinity] | w12:", "Subsection",
 CellChangeTimes->{{3.791024299513517*^9, 3.791024333549387*^9}, 
   3.791024387646628*^9, {3.791027963156403*^9, 3.791027968136772*^9}, {
   3.79102802686504*^9, 
   3.791028026929071*^9}},ExpressionUUID->"9b4127bf-4e95-447a-bffb-\
0aecdaec48a0"],

Cell[CellGroupData[{

Cell["Define parameter values:", "Subsubsection",
 CellChangeTimes->{{3.791024353689595*^9, 
  3.7910243639133368`*^9}},ExpressionUUID->"deb0762c-78a9-4c83-b511-\
a8ec53166dd3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi31val", "=", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi32val", " ", "=", " ", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi13val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi23val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma3val", " ", "=", " ", 
   RowBox[{"1", "/", "Infinity"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"importtime3", " ", "=", " ", 
   RowBox[{
    RowBox[{"52", "*", "22"}], " ", "+", " ", "12"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.791024391785356*^9, 3.7910244703065147`*^9}, {
  3.791024832104692*^9, 3.791024893824339*^9}, {3.791027983305586*^9, 
  3.791028012584515*^9}},
 CellLabel->
  "In[1750]:=",ExpressionUUID->"c2e4f71f-b111-457a-b1d5-15fddab351c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the model: ", "Subsubsection",
 CellChangeTimes->{{3.791024365809227*^9, 
  3.791024367637371*^9}},ExpressionUUID->"7f17ed78-19c5-43cb-aab4-\
aebf01b6c520"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"runmodel3strain", "[", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[1756]:=",ExpressionUUID->"6d5c02d0-3c4d-45db-bcae-f9700b08cdbf"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot output: ", "Subsubsection",
 CellChangeTimes->{{3.79102437504543*^9, 3.7910243813336277`*^9}, {
  3.7910245019903917`*^9, 
  3.791024504277298*^9}},ExpressionUUID->"49630a9b-99cc-4ab6-b92a-\
a57ff141c6c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"figinvasion", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}]}], "}"}]}], "}"}], "/.",
         "sol"}], "]"}], "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "plotrangemax"}], "}"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "yearbarchar"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "0", ",", " ", "tmax", ",", " ", "52"}], 
             "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"importtime3", ",", "importbarchar"}], "}"}], "}"}]}], 
         "]"}], ",", "None"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicks", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ncovticks", ",", " ", "All"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"\"\<'\>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{
                 RowBox[{"i", "/", "52"}], "-", "2"}], "]"}]}]}], "}"}], ",", 
            " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "tmax", ",", "52"}], "}"}]}], "]"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Year\>\"", ",", "\"\<Prevalence per 1000 people\>\"", ",", " ", 
        "Automatic", ",", " ", "\"\<%Positive \[Times] %ILI\>\""}], "}"}]}], 
     ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "imsz"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<OC43\>\"", ",", "\"\<HKU1\>\"", ",", "\"\<SARS-CoV-2\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"oc43char", ",", " ", "hku1char", ",", "ncovchar"}], "}"}]}]}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7893824421170883`*^9, 3.7893826157339983`*^9}, {
   3.7893826664946747`*^9, 3.78938266695546*^9}, {3.789382731126128*^9, 
   3.789382731675748*^9}, {3.7893827767664127`*^9, 3.789382777444231*^9}, {
   3.789386619546466*^9, 3.789386631208551*^9}, {3.789387810394597*^9, 
   3.789388029020711*^9}, {3.789838710858089*^9, 3.789838717718485*^9}, {
   3.789842556270996*^9, 3.789842651382614*^9}, {3.7898426863790817`*^9, 
   3.7898427300803967`*^9}, {3.789842819806529*^9, 3.789842948950203*^9}, {
   3.7898429865388527`*^9, 3.789843021987234*^9}, {3.789843093799283*^9, 
   3.789843184820764*^9}, {3.78984336766575*^9, 3.7898436006321487`*^9}, {
   3.7898436712471724`*^9, 3.78984370597163*^9}, {3.789845657271617*^9, 
   3.78984565935472*^9}, {3.789845785029049*^9, 3.789845795524316*^9}, {
   3.7898458658704863`*^9, 3.789846118358913*^9}, {3.789846154006332*^9, 
   3.7898463664972258`*^9}, {3.789846403235764*^9, 3.789846484288625*^9}, {
   3.789846522317915*^9, 3.7898466387710238`*^9}, {3.789911908017222*^9, 
   3.789911994611348*^9}, {3.789987417920609*^9, 3.789987519668146*^9}, 
   3.78998766533955*^9, {3.7900151606852503`*^9, 3.790015162261084*^9}, {
   3.790017373012323*^9, 3.790017443684984*^9}, {3.7900174921119833`*^9, 
   3.7900178416947412`*^9}, {3.7900178781015577`*^9, 3.790018049008872*^9}, {
   3.790018143265133*^9, 3.7900182454606028`*^9}, {3.790080424619478*^9, 
   3.79008045222733*^9}, 3.790937591828598*^9, 3.790937628558119*^9, 
   3.790937755476927*^9, 3.790938168272998*^9, {3.790939252734089*^9, 
   3.790939274532484*^9}, {3.79093932502175*^9, 3.7909394034475937`*^9}, {
   3.790939491200864*^9, 3.790939533093276*^9}, {3.7909396652500963`*^9, 
   3.7909396778141613`*^9}, {3.7909397335725937`*^9, 3.790939735050262*^9}, 
   3.7909399443534927`*^9, {3.790940134103973*^9, 3.79094021526552*^9}, {
   3.790940254309019*^9, 3.790940255328331*^9}, {3.7909403051360607`*^9, 
   3.79094031494598*^9}, {3.7909404920878763`*^9, 3.7909404977980022`*^9}, {
   3.7909406269986343`*^9, 3.7909406299951353`*^9}, {3.790940726648095*^9, 
   3.790940771458849*^9}, {3.79094080944941*^9, 3.790940811632804*^9}, 
   3.7909409745994387`*^9, {3.7909413836357393`*^9, 3.790941469640398*^9}, {
   3.7909419009848537`*^9, 3.7909419011777773`*^9}, 3.790941934145125*^9, {
   3.7909429495176973`*^9, 3.790942950149515*^9}, 3.790943062385366*^9, {
   3.7909524619930143`*^9, 3.790952484646926*^9}, {3.790966313488199*^9, 
   3.7909663273901997`*^9}, 3.790966398007543*^9, {3.790986123275064*^9, 
   3.7909861516486263`*^9}, {3.7909862083701267`*^9, 3.790986209160791*^9}, {
   3.790986242927669*^9, 3.790986244031867*^9}, {3.790986294640409*^9, 
   3.7909863255150146`*^9}, {3.791024642180931*^9, 3.7910246434516687`*^9}, {
   3.7910247121220627`*^9, 3.791024713209406*^9}, {3.7910247441953907`*^9, 
   3.7910247453652563`*^9}, {3.7910247761867857`*^9, 3.791024874373518*^9}, 
   3.791024910533731*^9, {3.7910249449382544`*^9, 3.791024947047079*^9}, {
   3.791239068869994*^9, 3.7912390727835817`*^9}, 3.794655082593767*^9},
 CellLabel->
  "In[1757]:=",ExpressionUUID->"9549ceea-cd30-44df-b002-ed6ba6d2f6bc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save output:", "Subsubsection",
 CellChangeTimes->{{3.791024505581291*^9, 
  3.7910245071250677`*^9}},ExpressionUUID->"98ec3e25-58e2-4978-aba7-\
72121cfec259"],

Cell[CellGroupData[{

Cell[BoxData["figinvasion"], "Input",
 CellChangeTimes->{{3.790966344065854*^9, 3.79096634514146*^9}, {
  3.791024648443697*^9, 3.7910246488615093`*^9}},
 CellLabel->
  "In[1758]:=",ExpressionUUID->"44095c16-072a-411b-bf29-c849a2e7739f"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwt13c4lt//AHAiiShEslIKlWQW4pwTykjI3tl7k52dyuoZyMree2WTXUYl
FCGjVKLkI5XM3/le169/ul7X87jv55zzXuekpZuWzT4KCopT1BQU//v/0701
SooiAvpmdmw3mOgGk17ya3timyj//EvicYPKrMZ5C9i8356mH610hRV53df7
iwnIetd9H8OkCzT//vfxlRICMpW5R2vq7QJZJIS+lWMT37JsvmRygX7dCTGk
UgISqbnw5pWuMzxP3z9NXUZAV5+GvJbddoIzWjsXfLEdnrxfup/vBBU+2gwb
l2PfoRXwpnCCjJSXWc9U4vepkhTOvnOAncpOto+xu9QXP30nOkBvQmbDwSoC
Ovv5Bf0JTQf4/gSt0Qp2gLbX3axRexhrJ1tqXk1AVFeuuU0n20NQ6b49gv2U
LkfP1Nwe5oH3GQ01BKTEnm5P88cO6kcxrJ6tJaAWsYc9HD12kO7V1avp2AVs
/xLUEuygm2nJp9A6Ajqx5azxXcYOnsqfkfiF/a2mdkSNyQ6OfWeOsnlKQHss
dKDymy2UCQoUVK0noHq4JWWWZQt/dFf6t2JbdGXtpgfbwiz6hQHhBgK6OMF2
qNvMFmpps3NlY1fdLPwyhGzh/jQ1F5ZGAsoX6w+vP20LGz+Gtt/Dvs5mPxRI
Zwsdzz09vIFdf9+tkn3NBnJ7fjN3bCKgQNbBYw+nbOBwE3fNNHanuu1/L/ps
YDilFpVGMwE1EOaUxmptoKRKlE4ndhnxultxjg1cJDTni7cQ0IKWoI4S2Qam
Tqz8yccuC4hILrtnA2/y8imztxLQrwrdmXF/G0hhr58SjU2TlP78uZsNrKmM
WdrGPvVO90+AnQ20+fvsilsbAWmxhhxaNbeB7HA9dh479OtSDL+JDRyIEpzR
biegxqlmXV5DG3j3lcnFPmxPLmfuWX0bKMJGDJV6RkAnmVtI1gY28KNp75sS
7LNnrG1qjGxgYv6/U9wdBLTVxndtwMwGKv+44P0Ie1uxfr7c2gZuSlj2UnYS
UNipiSUzZxtYHpTE5o3N/uzakdk7NtC8Z8DuC/bWV2ZdkTAbyHxor9Ggi4Dk
2hfEDeNtYK+2ON0gdqmyxsTtJzbQL83OWK6bgM7oG5aoVNjAc5/Syiqx7zQd
ZObqtIEfzg3vnOwhoGVo5zv91gYSPKk1ErD1m/3kCd9tIFF4Uu5ILwFRMjab
2B2whaSlSqFY7ItqrQVJ+HzJBfc4afvw/uzjYjqjaAsTLI3pIrHD9rFUn7C1
hYk8ov/2sD1mf/9KjLaFSZM0i4HPCWgx/8FIQrUtTNGq6fV6QUAyp15dMz9g
B1MZH9T9xF5dpR26fskOpg+Y5jr1E9C+aao33+zsYIb8wTCrAZyvnYbTKaN2
MHN3xm0Wm/2Rn/wggz3Maq4zMx4kIN2Zck7KG/YwR8xcVnuIgKTiuUJevbKH
uSuS519j00hekiSwOsC8EnqOGy8J6N03/vqS2w6w4FTDX/lXBNR3UN0d7DrA
wpnYL+3YnkwMcgtajrAo1fKtzGsCYthK6FQqdYQlzIy1YsMEpPnbu6jPzgmW
vvqUXYFNVzAjzDvkBMuimwjn3hCQhHR+ZJ2EM6zYZ+N6aoSAPnq2HaFncYG1
ay1nmccIiDtEdeU9rRusqyCyx2PTyjzbL052g/WOdgfo3hKQ7KpU1z0md5xP
zJ8p3xFQqseHr1vF7rApY3H0LvaDiKCUjk132GzU3vUP+2z686JadQ/YOuKQ
9d84AV2+lH0sncITtsXDRy4TON4sXjO/NPOE7aqswd+ww/+zG8vt8IQdXR3G
8+9xfHed7p965AV7ao4dezOF9+989ci4+R3Y6/pj/81pvN6s/17Hzd2Bfee6
119gX+Rkb5K28YEvclxHOj7genlbx/xqsC/sN1PslJ0hoP/6aAWoWfzgAAdH
VSP2t80a/ZhyP/iS1BtXNUtA5k4NhnPr/vCVelqQ0BwBLd3r4RHPCYDDdB5O
RdjdB+Z81PUC4Ug4l0rWPAGJn59/vzgaBN95elETPhEQ8226aylsoVDL4mUr
1QIBHY+L6CFGhsKXGgJ3fLErlXXvkf+Ewh6hqc9mnwnoc8+XesOvYRBySmaM
YBcSVDZ9bMNh88FHete/EFCzb63HjaVwWP1F/vmFrwQUXLioMEgRCYXepodk
Y7M7270cJUfCou4/l1kXCWi/ytsdHaF7MCOrpGgbm6faLTvDNQrGGjFHDy4R
0OnCJNs48BDSqjjLw2W8nh/M7yqoomHE5b7NGuz8Ld4KseFoGHA0wCn1O36e
j2W5b2gs/L1vjI/xB94f6ziTMes46P7fhekw7IMuaY3dt+Kh3at5NYcVfJ4x
fec1+AjwY+uV/R+w92SfnEguJECz0sQ2zZ8EpPddouKtCBHqPFARllrF9U6n
KmFFiwTl5asPH1gjoKarB8D2ZAJsF6F/EYCdxuHlaBKbCKVP2ISuYJsJ+P64
pZgERbbZ/3v7i4D4zCZUP714DEuXPItV1gkoovikxE5iMuR/P2TRhu2q8ys3
1zEFcteHjuT9xuufX61JPp8Gk/Mmo9n/EJD7nYUQB/Z0eJQsoRCLrc9fenyE
4Qmkc1+s9fpLQKO2//XFsWTCjbOaifL/CEjYRpys3Z8NvdhLbtZj2714Pctj
mwNXaKhpzm3i89vdJ2FOmws/f2rwYdoioOzNI9LzpnnQfITp4j1sp2EdO3em
fDjd4fR1A9s3P2WXaTAfjjw5YTC3TUCTxZ6Rp28VQvVY/yM6OwQ06Ezx5BN3
EewPGH3xHLvXrctZ/b8i2KF/X7pyl4Ccv8l715SVwHKmnxzBFESkcF+H0s2/
AiYoC8X/xPaLodejCqiEgSEOlBaURPTb8s3mX1QFVX58+qqwj4hOaDCcY9Gp
hp9fTNQdpCai5oHNvZeFtXBoj1UwENsoK41G/XodrL2knfYd23qf63DWYh0M
y3sZ9no/Ea3Z5G9WStVD7tAu9cQDRESIDGZT298EqRv2OmloiehXaXi/YWcT
XP4hK+mHPXWFdXcwtBk2GTdwGh8kIrO+u4sWB1uh7uWyRV56Ioos5GNSknsG
41YSw8sYiehAUQIjE2U39D4z+pv7MBH90JvKOe3WDY1Njjg8wi5JSmhn+dAN
zw5Ea3geIaI+IYegoYYe2JsfwiXFTESJVuJyslZ9sGy69VEx9pckhZixgT5I
Ztncx8lCRPd+DnDUijyHFmHe33awPx3RLXX48xzumDjUd7MS0RkpBvZ+q364
QC44K8mGn1dV/LSgoR8ODnxKL8DOWGhR5qUdgDWUJ4+wHyMi8cBvR6h1B2CK
lFnEQ2xqbq37fBkDMNQt7c8m9sVvD6S0Pg1Au4IJB2d2ItrPyqhjfXoQSh7V
1tQ4TkR0XuKKySmDkOsGobsDm9ZQ8obHy0FIFf7ykhgHEcWwDuxkbg/CpUa6
klxsIRFeRlqBIfjmpxI3KycRbWTOTT9SG4KN/PcIUdjnHC+cP+0yBDNNu6g2
sCfIRo9qHgzBqIQ9Hwcu/Pc5tDIXMoegy6Ds0iR2qUXrRkzVEMzx4dzS5SYi
T+LGV3LbEJw4uUn/BvuYsoJ+fM8QZHg5waXGQ0Q8p843BvcOQXm/hgvPsT8S
hficOoagH18SkD9BRG3J115ZPh2C5a+8NdqwFV7Z2PjkDcGP/trmUrxE9NNO
f6k1bgiynxHzqMU+2DPereUxBNWHj4QLnySiF086KfQ0hmBE4E9SMXbVyxDO
7wL/W9+r3NOniOj++9P7ZbcG4cqbsrpM7F8LpQPu/YOQ725MLwcffj6/4EgT
aRAaCDq+S8SW9jPTUtIfhN3BAhsxp4loVLbwPPXoAM5vmoMHzuDvX+czyI4e
gMJvF46HYz8xvNt9GwzA5PM5V/z4cby8dOIWSuuHrhNcIdaCRHQh+Z1VpsgL
mBex9WgWu1DZYuTt6+fwvfBkltFZInIx1dpkcHkOFe897tI8R0Th4TISzjl9
8LgYM42cEBG9tS4j/djtgeofVtkasSNagzKvJ/TAyAevBcQvENFRjb/PVM/2
wJWZWJWzwkQ0JCeUTa3dDXtiDsSxihDR3OoPck5xJ9y89OUJAXvojUlLF+qE
Fz/2VNCLEtGMENOrxokOmCoVPkwphp+fwHqQSN8B3T5vs6yIE1H9Eam51d1W
mEeYOu0ggeNTrpmvErbCySvNkgvYtJdomawjWqAiyVd/UpKIvntZn2A82gw5
4Fpq32UcbySJHHuTBqi5NFx6VYqI5ExH05bq6+G9xMrWVuxW/qzxyaP1cHXZ
eaZGmohSlB7XsUzVwd7kryczr+B60sAn8JlQA719VLeZZInopOirzr3DNfC0
Tvm7SGyHsklZOlI1jDzsFeMoR0TDQ+F33mZUQfmo3XVJSESHLHT3ddeVwzUr
i9dF2B50er6Kc2Uw52pPMScioqTrT3U5mcog5c5DM8qr2MSS3x7hJbDDi/XF
kDwROTPsuitnF0L3W345UIGIONKuOu2sF8ATF6eCarAZ2ntC1G8WwOClLNFk
RZwvzT40tvT5UM5CKM3qOhHJH1WX72jOgd/BozvvsDUU/92sFcmB6VxrGipK
eH3NMfbhJdlwe7yB+qIyET3qCjimX5wFm9UVXDdViKjAmd+5NucJdBQqUHZR
xfWDT8dY73k6PE53kG8Ou134Pbyxlgb9el+N994gIs2ZTzfDjFKhYK5ojZQa
Eb2GZV/dHqfAidCE2FLsW3kxZgyTyfCyrNFV4k283wHs55rdHsMvx9s4qdVx
vL7/OxzYlQST/p7444PdErDKr8uRBP/UfC4x0cD7v0bl3jWRAOvOehwVvEVE
tUd903tjSdD6wNhKKvZug4jHfWoSPPr5Uj+DFt7v0asCBqFE6JW1ffcXNpGw
eKg2ggBPBd82sNUmojKepiwqegIcMe4Se4892sFzd/78Iyh27MHXdh0imubl
dPB0joMf15c6RXWJ6Lohr1ZXUiwkjtxMz8PWIBB+Bz2PgatxLLei9Yho7MOE
ie+VaFhJndmsa0BEFKTxYxn292GFXq7YCHbO37p3cbVRsKyosETdkIiUa45c
dqKOgkVqValKRji+T731udAQCQsy6ph7sA1mqTuq2SNh3mpjNDLG9axQocQ2
JAJmJXQGSJvgenP8+7U243CY8aV37Sl29YF+90NvwmC61ICjmCmub/OWZl9V
w2Dy9IjReTMiCurqf156IxQSTi/IcJsTUZbk0WuiW0Ew3mexJgWbRjWUNMAf
BGNffD/HZkFEh9N+kM0MA+ED598chy2JaLNCbu7BiD+Mav9HisFeWpoTLGX3
h5FHdulorfB6zfN8v1j7wdA6mi0KayLKXrcMmmP0hcE09F53sUvI/SZXnH1g
kMHh5X/YD45Y5C2+ugP9to9NrdngeJQG+o9yvaG74tmWBTsc/3dn3ELueULX
pAviFvZE9Oen3O2PtJ7QeVG09AP246tu0IjgAe1jZdLeOeB4uPPearvEHdrO
ABZtRxx/dQpGn+TcobWIQsxrbCGvPJuGIjdoPnYj8IUTfp+J8hDrMVdoxq/5
S9GZiAT0Hn9gMHCBJn46Tp3Ykmal+1CmMzTgMjVudsHxpXVYnQCdoKa165Uy
NyIypOD5Se6yh+r1nrWC7kS0smuuwC1iD9Vofc/nYzO/LnzomWMHlctCODM8
8HxBZWvwMcEWXt+NIHN4EpHTxs+k8qO2UFHzAf1j7KgGGbHiZBuI1glbj7xw
vjRkUNSXWUNwPdHrkDcR/RfS+V+UrDWUTU5ZfoD9pX3M/OCwFZSSzZkKu4N/
713lijxKKygaWdvi5UtEXIt2Y5qxFjCVJ23lx/8cqWstIGUBqZvCT9r74fkg
SK312RdzOPHj1n0Tf/x+Dy+9pRvmUP6BdPM77Nz8tuu6+8xh6amTPzQDcH8I
oBq297kNg/VXta4F4vmIWd2Vyt4MLv43fu8Z9u+tedonX02hVuyzRukgIgql
cH6c6GQKz3TG8wjfJSLXApv8M6EmcOjchSW2EOxjaq5+E0bwUu9RbiK2Eb1F
76CvEcy8va1BH0pE767Cj1kcRtAzYfDpHvY2P1J0dTSE08K1i/5hRBTSMdcg
ecwQXu9P5VzHfprVNH36uQE8vusQthiO5633rA8uiRjA8ORbdZYRuB93P2KT
+KYPv4tJf53G/pM4F8CUrw877GhvvokkIjL7+tjJM/rw3L7VkBv38HxhzKMk
/k0PktPHa3qxHxB+lH+t1IO2bwrYm6OIyGd1P9f+a3pw2Cn+hsR9PM+wy7/W
ZtGDMjQ+wRXYDXGJa0cWdCHDlWsLOQ+IKH/xfXhOrC70eSt0jPshEcHZ3TRr
a10453ZU9TG2+pijgSvQhXV5nypjovH5Rgz+ufRPB/LAwY/7Y3B+8aX+WXiv
A++/r2ENxYbRVm8bW3Xgqleq8iZ2funRUyXZOtCIMTzQO5aIxLZXi2of6MCe
IoeKFez5qFXJUQ8dKKxwa94+DvdLGbsYalMdmPxB6ugn7Ke8jk4KqjqQ0o9X
yTQe13fEmBwjrQMdmWkDxrFBrv3oxDkdOFb2s+zWIyK6qxk/y8+jA4HS+Owg
9luXhWueLDqwaL6d+ToB5/9V4YOtdDqQOajgWgc2TUHbKWpqHRjIFu8nQyQi
4z1tMdU9bbhQdae0DnumumY8blsbqt8wnREmEdGHk2k1r7a0YeNnRaZi7Nra
V5aHdrThqVAhRT7y/+rFC9J1Ch0Yy3HU9wl235tds9D9OvB33VbxsQQietX7
Mq/9kA400/g0TcS+/Bko7GfTgS++DRw+lEhE/XvGxw1O6kCxyBr5KOyTn4Vp
WoR1YDpP6h2KJJzP1p2LokAHhi7v9/TEnpl7XhKmrgOtGz1cF7CnPvANFpjr
QOV7Hxz1HuPP7YRd87x1oJCWit0L7AetJ7RConXgkRNPrWSSiWj5xuBhhRwd
uL7Ma16GLRCv1fK3RQe23tswIKQQUYC0RM+t3zowS8tad18qETUWV7DSsOrC
yBPDt7yxuaYU5fov6UK1pkJVgzQiKn9E/TclVBeKRLEoDWDvHVe/W1+kC49q
hyjIpuN6wEP4QjmqC6e+68nyPsHz6rnG547CerC9qUuKhP04jFSSe1sP5kQJ
S1Jn4N+b31F4nawHHXlphBex+dnvG1Ps04fqPzzOGWXi/tOv91xUTh+KNX/g
H8K2pv/WsC9QH25qPz1RlUVEVGMbgi27+nCG9yTXqWwi2skmTg8pGsCuH7Hs
CdhR/OlUg3EGMPq+NZNfDhF1UswKzQoaQo4WFiqUR0Rhhgddy+4Zwd37IXvV
2AdOn5j2/mwEP+osb/HlE5HF6ZZvC8rGsGSla/1AARF5Rb1KEeE0gfEtwv/5
Y7MpOz6+Hm0CPR+k/ljGdt4bW/LbMYEypzy/vC4kIsrEaPnqVVPI8/PDx6tF
RIQYXwnu9zCD+1pVZmuxORBjEu0fMzige3LicTHuv8lEaHbAHBo+HO6/XYo/
H4/syIMWUFZPtu8Ndno4YWA0wQLy8hV1KZTh+88p7+3DPyzgYmtIi0A5EdVd
yP/IXmgJhx4uN6RgB9LZhHEctIJVevp19BW4nkdqPkh2tYJ+q8LlP7FfsHiO
khStoUlbarFFJe7XlJGS2k+tIYqmKRjFTkkJDmY/ZwNpT89kNFTh/IqYfiXH
awuT9eMIITV4HubWOx2tYA8HklPPbWGH6ed/K/hsD7ffF/b41BLRlRmtMIZ4
B2hh0rXhUkdED8vC3N6sOcKEJ69J37AryrjrWiudYN/MtJDNU3zfTV/oOeTt
DM9Z/DU3qcf96on0sx0WV2iSQ701jn3qouqj66uu8NEnpkTtBiKSPTzkKffW
Da7bCPWrNhKR1dEviRof3GGbo4WodDMRfeV2XZrd9YSrpa6Dddh5fW5NhxK9
4KkfgTYiLUTku3LkmLCoN4xyS0oRaCWihMqqKxpBd2BjVa54LnZ12JXV8fM+
cPm/qpc8bUSkLxbrbfHRB2p6D1KytRORfdvJ62QbPxj+dCKNiH2YvfzBpJg/
rPvzWZLhGa7XluxLBrQB8Lg/hSN1B+7PLEOD114Gwo93JUfWOono5XC1D2V/
CDz6TN7ZtYuIGH+z3PzlHgqVKDRplrCNkph3KanCYFm4o8x8NxERzt6+OikV
Dme6fcdMeogoTaWF/diHcHhk/z3XCWxdCuHK9/cj4J37mTmve3G/ahu4svVf
JCx6USZ7o4+IFNmu1cxV34OTB5vf9WFfOON32sA/CoLYMbr250TUrGX8nJv3
AaQlHvQq68f3mZ6tBre3MVBmhI1BcICI9lmm7YlOxkJnltOFudgCSk8lthbj
4JtEMJU6iOOPekxzi5kAqcdv3GEbIqLFdDF/lxICvMRueJiE/eXJlh9ZiQhT
U70UHr4kooF7tUwVZBIcmgr9QP0K14+Lwc/25MlwjyveNxT7DM1Sf9sGGVpn
FpX6vsbrPbP2TtIvEV7I+8Bi+wbHQ8NxodNDyXDymJvve2yBeplvl/NSYFQM
xZTaCD6/jikCZ0QqnPPkyxEfxfVa1vXrhG46JF11EKF8S0TCxr7dMmezIHi6
SfbGTnykXiVckwWXBWP/fsX+Im+ytgGyoeKRyvZX7/B8rh9VKmqdA//MrKul
T+D7k6j9ev2HPJijFVV1+D3er28TP7/fy4cafceORmDbsmpI0IsVwKJymSmH
STyvu93/OZlYCI2DQh0uT+N+wDZBoxyN71/HD0WNzOLfR/S5Wn+/CjrHPfl2
bQ7f514Xv5z6XQWPU1682YQ9Lx6U/Nu6Gnou3jqaNY/ja+Q4371rNfBMw+Mc
l0/4/FXk8i8dqoMj587SzGPLlIn9OhtcB4Mzmh10FohI1ZzN+MvPOjhx74PI
lc/4/nFRNvDAyFMYrcP3jPYr3g+XuluTMQ3w0ou6U0HYWeJvkun/NsBPV65H
/cRWXmZYjTNvhLJ8DjffLRJRh825sa4LTXAxabNK5Ruu14OC9qzEJphIF3u0
DTvq6evWjf+a4Mp/FVO5S/j7//ITm0qbYaoNgseWiYj3TmqaHHULVHr/Jica
u7lKCWUZtsCsjnUHj++4v7ld0Li92QJvSkS9XMB+Hx/10O1aK9wsPCZq8APf
NzXaBftiW6H2I5kNsILrkYhKbO/hNuh8o5KtClvI3VKWRbUNRh44LXnyJ55f
HHmkTUPbYHp3sjYJ+3fC+dX4mjZYF8LgSbVKRFeVfwQlzLXBoSvhBG9snks7
L8zo2uHC3z8Vn7GPXWC3nbvYDrdrnV7q/Yfj98NUJcOtdnjUfW75ObZn2rfZ
WZd2KCSkSye9hvP9w9ysZlQ7VFzsFyzBpvvHPG6a2g5N8oAS5y/8eS1f3YGS
dnjHvNYmFjtQdW9S42k7jOcSjNzBLncPoZBtbYcFE+k5ruu4PsrJ7Rtrb4ft
CUyds9jJegn9vG3t8J1m1Kzmbxx/9TnEiw3tcOXQ1k4ntv+hcifG8nZI0+/G
Jf4H30/9v999mdEOee4tyORhL/lusYXGtsPLVw0NWf8S0aRq3hdpn3aoufPS
Nwp7P+WaFpNJO7Rvkk/6i01X6OLBA9ph6J2GOvsNXP/evl7252qHyaJCo++x
L4qTfoC/bbDqR9Z/qv/wfZD0Ru7hqzb4opj1SCu2kolbwZ2cNvjv5J5axiaO
jy+0DhWoDTLPeDkd3sLxd/D8QWn6NngudfFhKPYPtvGCjyOt0Ih5pM9ym4io
OxcaWY1aoeer659HsW3DhR7PH2+F0dEtVNd2iGi1SWRHc7wFtuzLRwK7+L4q
qiabdaMFcv3ybV7ew/2dK744l7sZzoxyV3hTkVByXFgCY0QDtEx0SIyiIyE5
dgb9XIYa+KI35BYlPQk9bt1Z+1tdDS/+SWQIwl7/fO4Ch3413NbruudxiIRe
Ob7/s5tbBR+zc/qYMJLQUlzjcQ5yBdxVFhUbxw4pdXaTWS6H1v5KK7cOkxDF
eBBjxrVyKDbpZat0hISeXn63Y05ZBofShvTEmElIUJf0JD+hGIoNfWQux56c
phzn2yuCKdsbrwRYSKhBmUS36VQEbU3PKHEfJaHIKwGz42qFkPJE8GVaNhJK
t6WkGDmfDy/lXGSfOU5C3+Ns1Q+bZcP0kWtjBhwkVJH28tbflSxIRWVCGMWG
25H/zoZnwWGrB7T9nCQkL/LiU4lZJnQ6M79Ry01Cj1bGA6iU0+GI7t86YR4S
sg5wurwdmwalohg8irFrEs9SHnuXCmm+Sn/LOEFC8Tl/mz29U2BWEen9w5Mk
NDNoq/pvNgnSvC9KpD6F13Mta11GMQm6HHx2KwS74dEDxFmWCGUcl/u9+Uho
/uRn4p2oBPj2vGLz7TMkRHVY+mKnFQnKmhj5TGKnOBX6nv1EhDmx7mK6/CRU
HageUG5DhO4/0ktUBUiI9RvzyxdeBEhX+TtV8iwJz6tjnFI2cXCZicBbhD0p
6fdWPSsWDnmfK+A4R0L+apnq27MxMF7mdvUe9lFO4kKbczRk6nvxvF+IhKqK
syasm+7DNUGrm7IXSOgX5y/Rerb7cCRmZ6QC2zh4if6HbxRMuCU2QxYmobal
x6cbr92D7B/S1k1FSMhMqsov7VAE/AcvBQxj615/sPotKhxO5gzvyYuS0N1e
b8dw6nCYbr+fXlCMhEoH+jdVDobBE+uuJ9fEScim7/6tItdgSKF/sNBagoT+
hCuvnEi4C+eacoXGsV12ri/yPAuCOSETl1slScgoV4NX+kwg5KeXV4+6TEIx
z+7cLxD2gwdcp0c3sEOaGRu57/rCxWEfQycpEqKfvT0rOewDS5JKrTWlcfzk
K4vMR9yBF06xBnJcIaEIjQuZt3m8IOO9Soo47AGX6ZbjjzzhyleVqD1soWWD
m5VUnrCqPJi4IEtCqymUmywb7lBCerGwApDQacvN0h42V8iaHn7hJCShrvZT
jRdFXeCfXa5aMnbS7O2K3VvOsLHnVrsfIqGe/V8DLhY4QlnNljF5eRKKrXjh
2JNgB7lrdY2eYq98WlWUmrGFu6yrswIKJJRdZtj4XcgWdkydXj6kSELX36N2
8ntrqGAXTzl+Da+nwUROz9kSeoKB09rXSah/QDbHZtgC5rDSKL/Gzuj5RvCT
toAUPXfjnyuR0Fyqn+xxDnMoktZUraBMQnyirQc7Tt2Gtz1/jz3Dvtt/7Kws
hxls53XhbFQhIcdw39E/p0zgj79FQEKVhJQsxuXrxI0h1+sFiyrsk++e5N5W
M4KBd02Kim6Q0PbArU+xCQZQavKGZMpNEjK8XSu67a8L7arvG7Cq43xrtpsa
6daBSQ+6A4nYK+pG197j++3vS1e6HmqQUC71pHd5rxY8zej7eb8mCb14W/+a
S0AL6nyuoQ3HXqgO5NqOuwVryOc0Am6RkPRtGQcDJ00472jr+Qdb6fvPHxTd
GvCIfE6ipxYJ1cvOO080qkO31ePTjtokZABHYj8+U4NCNw86GOuSEOF6/ZOz
4irQ+PS12HHs88ElEZ5WyjB6K7RSW4+EzlbQOOymKsFvxRu/b+iTkIrQhOxX
nuuQPUzi+AvsLOHHt/odr0FlA3dZRQNc/yTOf99uVYQFNIvhsoY4vwqHnQK9
FODbD3wFjdi9xIxjRuPykPrp7X4JI/z+Fg+xp0geWlmNH75gjOtLZCMdF99V
yNvRl85tiust3SERXQUANR7v60jBHrfIv9JsIAeDXcEnVjMS4nBpEzH0kYUf
uOrPMt4moam9j3lH+2XgofX/1KKxTcUoM/J2pKHs4AV3GnOcf70pFZrS0jDV
P79+F9t84IT5r57LsF9z/n2ABQndExlWcj96GW4IcO/8wa47l/jpiOMlqP8u
QeGnJQn5MSbGvuOXhEfFI4dnrUnoTph72fM5MViplVthaIP7xcoGxV9TMajq
2RU7ir1NI0X/aFYUhlZTqDy3JSH1Q6rPdX+KQM43JwSu2pFQx2xNtfRdEVi/
Cva3YAuIMnOuMIrA5Yt3OyvsSWhRQFnAJ0AYRmmkZwo64HpmEVF/pvYC5HVr
uZuDvX586KrbmhDUq/gnneRIQs4MjarTEedhl5BPzV1nEipeJ9mf/C4ITdUS
CX+x/027e9/VFoQbTnWuHi4ktJbfMz70TAAKl66ds3HF+5FF20oo4If9A0wH
Z7HXqqQlqnn5ofWSyFcDNxJ6GLNlw5V5BqaedctVc8f1TiDJ/HLRaSipEh/W
h73AsWaZIXYaDtuX30YeeP9ERxifdfBBmqJlTglPnO/h7g5FX09BD377BE5v
EiLtbxPpNjkJD12/75mIHfkfj04C5UlYYFOgefgOXk8AhbhkMS+czls4ROVD
Qk5oZvs+BS/07aFaDsLe/vPyFKv5Cci8cKr/D/ai/0bSbjcPVOazuLfki/tB
96Ww2RRu+Ek+1Mraj4QYpDf17tNzw2DLzKsz2PODa6beYVywLvvDzht/EvKQ
fVr3yJ8T8vIa+TQF4v72tCRB4PFx2AL9dcSDSEhRf4T2hsBxqHc7WawcmzWF
kbOumR3GZrxbybpLQnT018a+LB2Df7m07R6E4Pw1+lXM7coGSbKe1/aFktCE
23ffHFY2KGRC5AvC7vutz1ryjBVapr2edQsjoRO6oo1/OVjhq+NqBvoReP8u
iF10+84CPzn93HuB7UxgPlNewgI32kiFMpE4HhPbf2U4skA+y/d/uO/h/ik8
Fub4kxn6ldgmLkSR0KGwtVM36Jlh3PZBOb37JMS18LRr7C0TzFEvX3iO/Sit
+V99NhMcWvslXvqAhH6y3ncylmOCJ6+EjXhEk1CT8vvnQhFH4KW40wGfsBeM
Hi/56B+BarPPT+rG4Pkimh2OCB2BPhGMHlKx+Dy0AlXknh6GA4Nph/fiSOhL
BbyeFMEIZ7lhg3s8CY1O+l8rv8II190+mn3EPnXi6CX/3wzwxNGzFb2PSOgW
q74hpSsD9DapV4slktBx+weq9z0OwYcVhus72OePUiTuSB6CGRQ7aW4kEpK0
9rMY3qKH/XkKy1pkXG9itDatY+ghz4/hh8cTcX9dl6+UaqKD4tBbNAb76tXs
zMj7dFCZeOz9NjYLKYfjsx4d9JQ0E5xLwv3uBF1F98ZB+Pzucl9BMglp32k9
wKZ8EE6/jndlTyEhn28qMgI8B+HaSTG2aOxrfPecmH7TQq4+PxuXVHwesY22
evm00J2RhloinYTylEiUS4y0kCOT92pnJj4/y7NKzJQHYLCNTZRsFgml/oC8
l2dp4Pz5ksEG7DGNm5I/22hgUaO4XkU2njfON3ZR3KWBl0auO6XlkpBq0zVu
CkoaqL3fJfFOIQlF/6KTbOPcD2Odmr6drcT97zJNh3IgFVwV3RXOx871Ftvb
saCC2hvy3rxVJOTq61lZp0wFOe4N7bJV4/6oUXiWg40KFmXMslDX4vxSePDb
rWof7H2zH8zUk1CA86vP63OUcPeyFonUjvsVT99kHB8FnBbhzN7/DMfvPa7e
zQMUsPnsQqUfNn/T5T/OE3vgDqfPS7MOvB+SNlwS9nvg+24K7fkuHH+zwkzn
I3bBVO98cHcvns/DpwUZCrdBo7aH0/oQjqdbjiw9VRsgSU0mwO4lrtfeOezX
3DaA9zWqh5PYyzeSPydf2AAilxMLOl7h9St9knpR/BcUcjTNxw7j+ec1pXd1
1h+QNE9hcGYM15umk4zLMevAy42gqDeF+1OgBPsb71WQNb25OoJdvy88j15k
FQyp2DzRmMb9XFOOUX38Jzh9WuaP8gcSsvtmZMf/YgWMTXwqvDKL572w9TfR
dd/BJfnL9Cc/kZA3yXii89kisKzMbniC7Xc40s3x+iKI5zpkzbFAQp+nJYa0
Xn0FX//MtbJ8xv0hNrd0a/4LSC6NdqX5is/br0fL7fhnsHl05s3yEp4/VZrV
egbnAX+4crD9Mgl5ZQWEpNvPA62fNec+Y7OuSIDfNPOgtP9+xMx3EiK+vl19
WnkOmASLSr5ZwfN9HbNed+MH8GA5bf7mT+yzguvKdB9AnQFN/AB2G7P2fx1m
04BBfOpL9yqOR2Py/ZwjU6D9a2Ry/RquB/aaktzJE2BJ56ei+C98n/A8E3Sd
cgKwdRn+V4n9Kew5902XceCWLqyKewviDl35MH7zHeC9NbGV9gevZ388rZPI
GFBrly9i/0tCIunFRzYrR4Hf+XKdROzH3n8qZMVGwfD+8PL4DRLaIHdWNYAR
ENZ8/nbYJglpCLhMhfkMA3Z3/74t7D6Syusnh4ZB1ZnnF3y28Hnow2lh1ddg
jmC57biN86GYn39f80uA7FJSdHZJKIjH6dSt1wNggusrxWtsqcuX6m1ODAD3
EQl7lT2c3x97WHK8+kGm3PAlQEFGk670tUqCL8Auy4ExgX1kdDVGZc25oxck
9etcycGueHrC9+3FXiAckpPDRUVG24fqqKZyeoDZkpwHEzUZVdasf/Yld4O2
Dm/Grf1ktGuVNUz3pBPo+HTduUNDRlE8NtvmAp3g+/kjH35ie+uLLD2r6wBc
j0tLFw6QkfuPY6FtVc9AkMtH5VcHyeiIs10kT0QrOMonUqVMR0aGTkfGJXpb
QNnE3WPd2Mn8ccG+h1rAtMLxLw30ZJRw0UbicEkTuMKhGZHNQEasbySp2Lnx
jr5+ssTJSEaNFFP8VZH1wPHe8q0kbAW/yRGv1acgdTWKN+YwGVVTLFw/P1YH
Nvva2ryZyOhVIZXE8YEaQAqiP/MT20bT9OKQZg04J2YY68BMRu/aaJv2T1UD
oyfrRmYsZCRtq8sv/68KNHmd31BiJaO2bNDAUVcBNM/63+7CduXMl6T4VQ4W
Z/r6ZNnIiJ29+F3A5XLArmqZKHqMjII9u+U7hkuBH2+KGOdxMkrx7lD3v1oM
ommdrOKwn3c8l0qpLQLpq7IJe9im175QWJwtAh0dc78/cZDR8TxTzqITheCg
hWBTGRcZAZcvtDqS+YBLZfMbDzcZCYgZeK115QFh0SEOIrbIw4G0Ru08oEXp
HnSHh4y+J+WzBQXngtTsBgh4yejMn+8dY3+yQdnDh+5V2Lw7aVLRadmg3cM4
+9RJMrKLVKt/Jp8NPl7d23fgFBmxKVha+iZngfMfr/e95iMjzSSrIqtnGQAM
sP+9ehqfn1xQ/t6FDKBZsyRQh62aa3D2VdYT4B0e/zD5DBndo2nbl05KB62n
3qlZCJDRl/P1cqo5qeAVXdHdUexrd+MkLYVTwdyaf8U1QTIiEMJDyG0pgLqb
+8i5s2RkbHzk2epCMrhpZTO6do6Mxlm75010HwPzG5epbc6TUTcd8TbNRhLw
FD8oOY59LYQplf9JEkiiKk9qESKjlt6RtviVRDCTu24YKUxGCxn7fztWJoDV
mL7oP9hHaqK/59gkgH3eyS32F/H5KHRJneBJAPyKstw3Rcio/cLX1cxEMpAS
YlR/hm1alvsjTIcMVI/OBYuK4vX/rjK3YiUDt4WIOVYxMvohajI4m04C4UO6
TA+w4270axtYkUBCnYD8JvaRoDPeMedJoDFyMHdGHMeXs0rGdAcRUJxhsSuU
JCMWmcD6tB0CMA+LkuS7hONN8vH0kyEC6PzwjyoT+660QaPMEwIIT5rLSrpM
RnnNgYrcCgTwcU3bjVkK769dg7oGOwEoaDyXi8cW2kyI/PbhEaCmrZi8J01G
b0O1xD6jR8Da+mQxpQyuD7LpZa5/4kFvR4LvXWyrB//MCRXxIMo/8OidK2S0
90h79iZ/PPjyduXjKvZgcJvmyOc4oCRmWe0sS0Zv3IcO7xbGAdplZXVrOVxf
/GbXeCTigL1SK9ccdnH03aCVnVjQn3tx2RiQ0Y76Z8PTA7Eg2oTtgTbE8frt
2pSvQyxYanyo9xqbqXViwU02Ftxg3Tl9A5HR/isODBFMseDQq0+d8lfxeqUa
oio7Y4DzOX1CO7ZWHaNcbnoMeBk1YCYjT0ZS7x5/sPWPAcKf5C7UYws+OZH2
VT8GxMPqLVEFMlo84FXELBUDVtJOD5Rj+zunqf07HgM0Nh4nn1UkI0sDZp/x
nWhwpDpY8uQ1MnIL7n9rOhgN3BnWqJ5gnzk8X7NeFw3eONiMsF8no3MXqjwt
s6KBWN9EVgL2n4gc+4y4aEA6peZ2RImMNtr5FjODosFa8DO5WGzDh5mKZi7R
QHtK7BCtMhkpx4e9Gb4dDeouF0xGYEv4S35c0Y4GRxOOF+9hh/7mH6hUiQbe
q7G+gSo4/io6p+muRoO3ahTX/2LTa3i4/JWOBpeKvY56qeL4C89+7SwRDZL2
f/24gu3+VtLGUiQa/LEwqna8QUaKFs3xny9EA/32lyFfsMd+z4lRYTdyXFW3
VCOjEy6Oyw3Y7L51XDPYzNnHtCjw3/uNCiwb3iSjAqdiivfi0eD9xbSmt9gz
BXMEgN8vE8v44JY6GZUKBadfQNEgdTFM7yX2yjv5thzlaLCp+Pu0igb+PORn
bKpWNDDOtv/Vg71OcS2fySwatO5MdSJNHC8S1FnUTtGAy0iD0Iqdt/6Dzd0/
GgTVd5lJ3SKjXxzduZoPo8EH5ksX6rBrwxTnclKjAXAr3rqoRUat+8Rtrcqj
QcYg10Apdny6rD+hMxrsCRCSBbRx/PWkhaLxaGAeSWWXi71mesLNfyUanJRb
okrTIaPYnIDzgSdjwPbgfBqjLhnVXVq9bHwlBrwzei8ejk0Udwl8oBcDYv1e
WDnokdFUTv7bTkIMsDvQsTWNfU7sTkR/ZQyQT2oga+rj9Vh7J7EOx4CN2oLu
ywZkFPjjLIfn0VgwKp9hXIr93Xz9ZLBULKh4k/iLx5CMXlaztfWaxgKrn5F8
NEZk9OxMzNRuaSx4dc4qYsyYjOZv6D39ZBAHipuMOJVNyOjhRTwN3I8Dkcpa
tS3Y7t+9X/M3xgFp26ufckxx/9Z6eUOSOx7kZZ9Q8LiNzzNwpsFzIx6EiByb
WsCuHpaNei72CBg9Y/QyMMf1oHP1ZajrI3D4w04OtCAjs/GfJPalRyCAfXof
oxWO71bxljd+BKBbOJoahv29WEnFI40ARC4Niv3GHuxN/9DcTgCftZstp63J
6EHz2x2lA0Sg+Si5q8SWjB79OGJ2IYsIzvMQjHjsyGg0v/U2xQsioCm/v0bE
Npa+ohaySgQtAz6n/O3xej06/D8rkAA/jW64kiOuz8Vd6VLrJECZqMbRgi3G
zs4HT5HBNJ9ijbATGSnNp146eIsMiFfFP7I6k1G6JlyZqyKD7SAm+QUXMupT
zt1z9k8Ao79eUoZ5kJFf3Viho1AS4Bgs0lnDfnaN+XCtdRIwz4kotPLE/cX9
48V03E++a0rfvO6F84VfYFWF6TGgqchLpr9DRlxM6vXf9x4DGfvAi0l+ZMQj
yS914F8Knr8FTUtDcP7PO3f7Xs0AX2qpqrhCyajD0E7w+YMMcCFmZl88du2J
kSXt4QzQLJ1Q5B6G69+j90Q280wwlrT3SzKCjPSdD5eVoCxw4Na76I4oMrL9
ocfIYJEN1AWrP4jeJ6OsLusfJZHZIGEvRiQX2+1B4DJvUTbgrbj67t4DMtra
8Z0OX8kGMvTlJ29EkxGtRErDE78c4Nob0fg2joyyZ+bDBPF8QMVEUawZj/fP
YzCtJTMXJJsEpQxi25ve2+vvyAWdv7wDOh+R0RLzuHwBZR44espWtpyI++vN
5Myhu3mg2OWjkCAJx4Ov9IRfWh4ATWbcudglheJ29xvzgL2m/m4yGefbofba
wtU80BKs3BGZiOtJzt/Lm/r5QHOgp2oP26j8gk67Wz5YYL2aHZCE87lwhPtJ
VD5gLJcOd39MRoUW6wtR1fkgd+Op5zI2Ie3SRkhvPpBSFLOyTSajiGbPBbeJ
fGA5dU7RJIWMctOtvI5s5YO//IUS49h2kx/OV9IVgFhPvjNaqfh9a9OLvMcL
AG97JutL7PJshacm/AXg6UEuGuU0HH/562mGYgVAVTf5Txc2X+tIIaNcAZjJ
OvpVLh33y5ABhbzrBcDrO2G8EXud8WCkqUYBoJVieCH+BM+XvZYVkvoF4EnE
w8YKbHBDQkvArACIvd5ffDaDjA6oTO4KWReAPo7wlDxsBbtqhasOBcDYdvfh
iUxcj9TZqsxcCsBqdUBAKrZFoc1oiHsBiNz548iaRUYqHNuymZ4F4LiKlzEB
e0zjUlCDVwGoSPh5gz6bjO6vuvN2YyvMOclGYS/n0Ta14u9PnF8UoszB8xmr
0dsM/DwXX2vuIOyFpU5qa/y+fd1zDH+x416mv6PBv+cxo+muRy4Z0dkqTYZZ
FQAho/cr37E/m/BkvjYpAB35urN2eWTUYBRct6RTAHT/e/P6I/a3Az3FL28U
gCVZ9Q7TfDzfMKgxel0tAMEPBqomsCeYvTzeShYAlrHr2doFuL52Jlr+FCwA
RSe6ia8K/lePjni0cBQAOScYrlJIRqgVCUnQF4CR+hbPHmw1w3A+nc18sH2z
Tru5COczdzmV91g+IKaIKEoWk1HYKUEh92f5gP9zmUQVtujF1v4LxflAIyif
taCEjE4XMxax+ON4e36S5mQpGYWHLlIp384HfiwZf9Kw1YxVm40U80FOSdI4
sQzH38q0szh9PqgWfEykLiejQ+ZKm0w/80BHweMbvthZK5P7D47kgZmc5Gcm
FWRkjfIVdRLzAEdaaqFAFY7/zg9c35jywNnjaRap2PqCRfqsP3OB1OM0ToZq
XJ9tlx3DBnOBHjn90Rp2jiL1C6HwXECOyfBtq8XxlJLEbvQ1B+QczBQVqcPf
7wOjjM9yQM39zOUc7M8RlR3nknLAcETW7QdPcTwQmedL5XPAoaAcJe0GnA97
v3+ZJGaDSOeCY9+a8fmHLMm/OJMFyEsFb4xbcP0LVavj/Z4JcuwLY15hX1rq
Pnk+JhN0WBft1bbieclaRuhobwbYMSn5GtxORgMLGo+lzz8BPjcrGo524fsj
2Tnqy0QKuDdY4XEfW/H8Q4p3LikgQaXy/Ca2f5HPxd/7UkDNtarM2W5cX9KC
OkWEk8GKXM39kl4yatYC6pkxScBOuF4f9eP5OGxxwDWADHp4DSpbsctsIjyr
j5HBKZZNGukBMmqyymeXaCCB6b9y9aKDZBRz6G3UvR0i0OrsPcr3Es9T+Zbq
B0sJAOi8fbP/DRl9XWjksroSC9Kv+54Nx578VVnyNzEG/JM6HraLnXtNb7xh
Fc9j3KYif0fIyPNXZPHdwofg3NeF+MUxPA+4SgV6nLgP2ALWbwxO4Prgancq
1ioceDsn5Sq9J6P8b2LbReNh4I2Z1FY3Nuje/bqlHgZiFYJKWidxvXrrRKJR
DgVLkjz7pKfweq1WAEwIAUqCHYZPsefsKuots4LBPgbqgxXTZLQ5MbKxbyQI
mO/lm5/7gPtLHL25/EYgaPtPqbEAO4cjyWxDIBD4vYuxy5zB+aWiYnwz3x+8
fXHhGecsGb14sZOR/8sPiLW8ZkvGZom2cmpT9QM/Mln6CHNkxCAevjzC6AtU
SU+5GeZxv1uu2dUI9AFFkfp3HmIvcmSKu67cAZYOaafDP+L3haV0xn71Bh3G
ckG72JNRJwIOuXgDbvXZ0YBP+D6Zp8kitOEFJsT4IrwW8Hl35Rao8HiBS2d6
J39iW5LlKJ43egLyMTsx58+43nJ6/vuo7wnUt0vmrb/g/VhJffg7xwOUrahJ
z2OrHzwQ6qTuAQ7OrxBMv+L8CtgZC95xBz29YkhvEdfvXT/DIBt3EEfRqDWM
/baGQVX4hDvQuyJno/oN98PFr2kD9W5gsUopGiyRkUEYnfJMnStgSDcZ4/9O
RgHfxoUTJpzBu3fzX7KwM+iCLP7ZOoMsJrt/HD/wvDJMdSjtjxMQu+/Bc3gF
53Oi2X9lx5yAnmeU/d+fZMT/Oed4i7YDOFFOH+ixSkb13H0CdTP2YPErIW4Z
+8t9hj1OO3tQfYoty+Y/HA/258sWV+1AgGlazSy2qLGh6IMHdkAhmbfXcA3X
L7qn52iE7cCh0fzxUeztT0/rSXO24C3D+aWbv3C/1B39ZZppCzKUq7afY5u/
jKRIdrAFdhGSh+XX8fk2Xd1yB7ZApL35ZCt2YVTYvuPctuDfBpS49JuMDua1
SHRQ24Iu8d7rVdi8IXZVSes2IMZV1fDcH1wv7m2Th5ZtgE7xa6c87CP8azvE
bzaAZ0EnmOcvzveXzw4d+2EDvvJMEpKxPyxNz8T8tgFVhrdzmTfwfW65g8S7
zxYEJCw8jcV+K/vp+n5mW6Dw2uEFzT8ycr7ZctzxtC04RPdzMhSbKqbjbIgU
Xp+i949N7BArx0Tvm3h9If/2vDfx+xRFAgMs8fqag5l/Yr9Kf/ivwwev7zfV
GYctMrrz/oew30O8vosPL3/CLrAfkx5OwetzZFQ13SYjjcY6qX8FtiAmn2wy
jq19iUaVr8oW6Myxu93awfGkiWKD62wBN2dG2CA2151J7iu1tuCLLl/CtV3c
z5jUuB+W2oJKQlHBM2zthEPFyem2wG/wQpP0Hp7/HcmzKfdswVWa2sFabBkq
g9lWG1tAd1Vq5gJFAjIZfNMnKmsLRgPbVguxz4j61QnS2oL0enmqU5QJKCyn
q+/NCxtg899z1nRsgzhBLtO7NkBY6KYg274E9Pj2ydHN0zZgw3ZEhoAtF3Wa
bqrdGnRm69+ko0pAn9yLZy+oWoPo6enbkdj7WPem1V5aAZ1jlp672PX61xMa
tazAl1jnx2vUCWj3ZuLt51aWgM4vbH6SJgHJBr8+ePexOVD/HN2mdiAByXj+
duIXNgdErYSUduxo6hxZGH0bsF8ovJVDm4AkqbZMtL+YgjMfhzod6BLQ69G/
Is5kI2Cv8e7JFLYFlBP52WQIylpn/W/SJ6ACDtRS88EAiD1eExU9lICKlQSW
bnDqA6TGnrPBkICmLnN++mepDSKbTgY7Miagi7vLvnV2WuA5/3mjaexOr6EI
TdtbQJ0SMHccxuvZN/h9M0MdEF2VVkSPJCBx3c8XXTzVwNiU5kAu9mU5DzWF
S6rAuN4q/D5TAvpIJbLTEnMNZPC5mP3DDtp/6EAlpwL4SPCRcWJOQJojpW8L
knFaOj1cU2dJQC2qzIYxZZfAVvfzaQbWBETx///+Dw4cWT4=
          "]], 
         LineBox[CompressedData["
1:eJxF1Hk01XkUAPBHMZbDRKRRScmMaVE02crtG4UozRQtiLKOfSdL2YZp7I/7
K9ST7SEZU5YZabGMnRdlafOYEHonKZkoYb5zzpwz95x77vn8d8+9594N9t5H
nYRZLJYVzX/rk357Z39TJKz/wuC+QbKGGRKBrX1gWaIO+EkvZS0eQlLS5Gym
1m4Jj8qCKzO+R/Koxm5TpI4HDDYUzkr+gMS/QN9oKckLBP19ehHUdurBHS1B
PiC8tLPe6SgS1TK5tfdf+oHmkbc8TQskAxe5pUf+Doa0qR/HO08gqbVrmL6s
GwXZyzI2k5NIzszo9E0MR0GJQotnBfUuzl5VicRoaNirOpN5ConI6XqZjfwY
mE55wXKxRjI+9V7LISgOju2wUhSyQ2Khy4qVdEiA9kSP1X7U7RGtqdozCWDw
6sKqEWr9op9Eh6ITQTMvX7bpDJKcjOo9UhlJULJYtULrLBLimBNjqpQMG6xb
pYuo+2Rs9vnkJsMKuUmJX+yRvFXcrj7MSYGLPktin6il9zz39ZNMBRZP5gt3
ByQj/HPJSkapMBWrteywI5LYz7fSf61KBedhE6H71NqhsbXuglQYBOsldSfa
72TeTsl1bHgwGzG/whnJmsotYQVhbDCySPsYRZ0j1sUOKWLDvZsFs9PUXse2
Bo91s6HUte19rwuS3+aDbErXp0HCc9nXGa5IyiQXBm7eTQNhHVWBuBuS6xa7
nriNpEEoak+EUsPFMfkG8XRwO2wzauNO5ze6df6NRTqY1HIHlD2RcKYzB7uH
06FuTfUzNrW0lMB22XIE7XPtT4S9kLy6wHVW3oTwtcZU7yh1c87jsrozCNlJ
Qj2W3kiUXscThfMIqwQrHzZT/9W08fPiZQSRfB1esQ+S7dYh6WptCOFLph1f
+SJZVx5Qpz+EMGN9ui2e2ukB73b8ewSPau+WeeqIhY1qH0UYGJWLbvLwQ6KY
JFvpt4oBG1/8k0891q4n+mITAz28wnpzfyQBy/VatmkwYLr5dm0tdcbPZdcM
djPQENdxb0cAki/ztHTEDRnQG+HfyaX2yvXRdTdhoHzv29uygUgcez6ZHTVj
YPNV4eoYak6s/+pi6tw5ud9nqLtFQoyPH2RgteU3lU5BSMpzr0cZ7Wcg9ZZu
eT/108J8b/s9DIhJH7ppHIxkwV6kJp32E+lmW1ZNzVPxFG9UYWCu2af023NI
PmiFiPJlGfBWiSnJoj4paDnVuogwFsEUS4YguZAwe8N7HMF2oKgwnLrfpZB7
txOhX6emYJJ6H89vKqMMwZzpzLMNReIpPq/xJhGh+d1gThe1qBtfvtAFQd/8
XTYJo/vRrzYsAYTl67l6d6hX9oR1LkkhtE+d7N8VjsRmoq8x63k6HGfXSW05
jyShS2IgKjAdvHpTwuUjkIS82BYdx02DbCt1K0E0vf+rklfmhNiw6Owuj/FI
nN39n76RSYS6iJcJ45lIZIf8Lyn5RAIrZt27U1lIDnxZUWTcEQEkzvJ4J3Xi
/DhfpeIC1Cc2Kd+6gqQrV3tRMiwcGjK5VaEcJClqUlmVs8EgzOErTlJ/ONgY
5twXBIY58pF22Ug8hLTX2lUEQmNhrOn+a0hcds8pDvn6Q1OF05BULhLhSzLa
LhJeIPoHZ38kNccseMF12B2MavquT1Ov15wzHq13hea6AwGP85DURHI8KrOc
QLTx/NOD+Ujixt1aGxkHMG6pgrvUnv7cG/VXzkIrT1U8twDJsJerwuvL1iD2
8LTXSi7df3dr5cLUCTDpZXpiqScCHhWrO1pA2zORbLdCJFfN+TG1hmbQPv5S
87tiJFLlyrrebAU44Kjv61v8/z/+B8yhshg=
          "]], 
         LineBox[CompressedData["
1:eJxF0mlIE2AcBvBp5FLyxivxWFppmc7VZib+eVVYzGO6y42lSEsrFVmUQmbL
jJQVHmVvqzQJtUSjTciJOFvTvOZcyUZKxhAPKjOc2YdIGdIbBD3w8PD7/tBk
cn6RM4VCiSL9u+rWYV/7EEaUf7m1FuDIeY3RqaXojNjIYPCVbe6YiRdCVJmm
8aPQMW9y4ugxUvYpMr36WGAwKqgpbzDqjuDyddpU4CKxm55YZY9BbZFssA3Q
3RMNGF3msdqZxRwojXPz6ifuNCw8/XIjE7a7VnzihzHye9RyzrckG5Shej81
cWvIRlOTNw8CVKrA6BGMAt09q1giPnS5Xwx+Tlyb/tWVXi2A47WcUNpbjAwu
ryzqRiGMOvbT2oh9KnvOL90UAb/cERE0ilGUlXrGIc2Fxe+zBx8QK9OoArq/
GORne6O9xzA6vGvZqukTw84nZUwDsTTVWtHDkEA9XxbnOo5R4TEfC69ZAsGm
JEYt8ZibrXLeIoEXKX5MpwmMaraLd1/6IYHEQXuCgriJ+WtP1roEjHTjyS3i
j3Zd0JNJCeR2tydXTGK0V/rTfPe6BD6HVaFN4tXuuYE8bwmUPxSmlRkxsnp0
yOOrxeDsGcv+Rpw33HgbTebCvToqp2gKI8X6XMvQqgjCdxYzloivmrQnPiwL
obdCx803YZR2R/Z7SCsAWL/PmyeeKNgnf5bPB3NhmVA0jVFijT/DYMuB0za2
2EKsYe1XV8m4sCYIl2aZMXIyKlc6telwZXorb4p4I3I2Xqphg0r3UjbyDqNr
Ddn9U/FJcIBRV5T8HiNRvaxAlMAAbU/BhUHiZsoRjUdsJKTSEkuZMxgVB8eF
6dNdoP/Q4+qSmf9/+wOW0R+A
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQ/TLj7RLZ21McGKBA4Ipc2L47UxzqhINnOvpp2knW
1SgZ3QXKz/JWn6dlYKekcevdUiD/fueW9CkLje1Maqa2996b4rBgJe+6lEAr
O1u1z8GM96c4sGiJ2/2utbVzuxCgUArkTxDlfXLQycEuQoVnZ8yDKQ6eK+Tf
F7I52yWey2y9AOTvTrL9Ze3gYpdVcTzQ5eEUBxG9wh7raFe7YiVVuR1Afmmc
44n4EDe7mjNNr7QfTXHYpTedL0PD3a617MG2+UC+mIfHXr5d7nZ9CnbNwo+n
OPwV2Hl2zVd3u+mnZvu3A/k85yWLuG+72y0o+Sn9G8hXPDHrzudMd7uVcuEv
8p5MceBwyrHXX+Rmt+nEli2PgPzGpn1n2ppd7XYXCTWGPZ3i4HH+4LbDvC52
R2QKfE8B+eZ5y/TXOzjZnT12VtLu2RQH7qVzMoVkHOyuFWg/2wjkaxWv1M21
t7a7L9W5SfX5FAehx38vnZxmavfiyLO6mUC+oree/6xqPbuPeS7evC+mOPzo
Xi0vnKFg90tikXgjkH+AZQpbjMs9249rL05vf4GIHwAZxcEt
          "]]}, 
        Annotation[#, "Charting`Private`Tag$65789#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwt13c8lt/7AHAiaYmKZGU0hGRnnnPsvUfZe++RJCurQnoGsgmZGYUIISOK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          "]], 
         LineBox[CompressedData["
1:eJxF1Xs01OkfB/AxJZdauWWpbKmlSCVsLvHxMJKmwmAYtxnzjZKUW0kiWlm/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          "]], 
         LineBox[CompressedData["
1:eJxF1HkwHFYYAHDHLoKNXSFLNMuqVVdINlSkfS/POUOT1BmklLiC1DEjjjgq
iCxJXPGIaqRDpaWSKtMQjIrEhrg3LHFTTLeyiCC6KvR1pjN9M9+8+f3xzXzf
N9987IAo12AZKSkpexL//icq7jgw2jGS+u8xi4s1DImzLBJ55R0NwDzTkcV+
ihFzqX0wSn0VPNvRZZcRl7rUimaOvwOul3c+1HyGUeupJymp+Ttg9rVQv4jY
Pjh5UeuMNIwKrDVkdGCkzZiRuHMocHc8yySHOKeqOaelTw7ecg0w28fHyLO+
natjuw9qdX/CzSS27Pgh0S1dCf5krW4h/RwjXtAHW5wsGrRqWrFMIe5lCa1C
XVRg19GukxJirzbr8NgIOjxXVQ5iOzGqk4swaaMz4KJ2Elojnn9o/0CSz4CX
77jbRnSR+iSV3BwxA8qomDr8SexvGqTwO1sVFlyXdwx+gdFYoU+cv5kq1Nmd
/WyOeCnyIj/6gCqsjW0+69uNkS/1S5jUy4BwudBljHjvrqaRyIsBe4Mi3D16
MNJIiRFoN9LhF5MOngLiekH2tlqPClxy0zl/ppfkn+0X6/BpMKFH4vOCmCt9
UcncWwnK2w752fdh1HVJTsS6pgCLmx8EtBMXNutpf+REhRzu9WDQj5Fm/KeH
uq1l4K/VfqFNxN/T5Yck9nvAhm11yWIAIwW2EdVzcBsISlQj64iho0ZDBnML
+NPF0UcGST0D8gJP+gZY4fFjqonvbpha19SugZS9e3EcAUZ2Qt58zfAqUI5P
uFJOHPKH5Fu/8GVQuuKSfPglRpslOulsRTEwDDFO/Ya4zzf0q/Ky1+DxFCVd
fQijq3XgWN5+MXDwmL5WQLxfkfZjqcMyEPY28mjDGPks2FTGmK2CILuCG9nE
v0zc3wsaewPetoTnUIUkf9uxU9/3LUg7bpefRvyebqc2ytwAN6bKfTaJ1XZX
WzYmN8Ft3p5B2AjZn0qmnUHbFqicaG53HsUIdB8IT2r4GzzM1MjtIFZWpdpE
N70HDWZx50+8wmiqtiaS82gPdGUcW9ceI/O3NSwDTdJQcCSvrZD4O35j9l/5
MnB8VHxTfhyjoLbWcZGrLJxPc/JKIr4a+HQ6Y1sWio2r9FaJZRZPL8AMCtwU
UtcCJki/8QtWeSKy76mBrSPEVafppkscKpQ3as92msRovMRThf8xFdKHWed+
I+7KtTYpOkiFml8n63KnMIq74DE08IQCdQ3GV+4Tr9secls6SoHGLy1bNKcx
8g5jbnsHyELz5CJeDnE9ZfggdpaBQH/dTXoGI5rj6BZtSwo6DDrrxBIrDjmP
XqnYBZ8n/iwWEZ/ilqWZPNoGXnrKTT6zGC2oV9xkHX4HLvSHZQ4Say1E3D4p
eAPCEzpd7ObIfZBjhYzkL4IYXQ7rMbHG83vur3oHQFZmde7G3P/34x/5vwRl

          "]]}, Annotation[#, "Charting`Private`Tag$65789#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJxN2Xc8ll/8P3BlZRZFkoQkDTIiReccykqytyK3VZE9M7K3uC6EVFZGspVZ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          "]], 
         LineBox[CompressedData["
1:eJxF1GlQk1cUBuAQAUEbNRJBg6ls5guJCMay+51e3FJxq1EiVLAIMqhDWQSx
xa1xA1Ra2quIGgtlLVRJWEIzxQ0MiiyyCSqgBEEFZBGLUsBob2c60zNz5szz
4/3z/jjWQRHSECaDwZCS/feWphrLTCowYvw3sesL/uAQl+Y2rBXbFNEnagqi
4olNpnEyXEN66bNrlKIJ4rYCd/PqxDG6aJUqrfM2RvO8GDvtAqdC+W2Vn1SL
kazowEjtMhY0eBWaVRKzuT0Hd51mwxBdFJ9fidFS9kVO7AYL0JcVefHuYFSo
Lm82sOTCJx7Fkz8S99+Q53o2zwdLTbGaeRcjY7uc7OC9C0DoUhKxj3hmuH6k
Y9wK3EtK7HuJFw0vXPa5vQ18IVZ3f1WFUU+y+NrfK23BV6W+XEc89qXpoTxv
OwhdXLoV3cPIn5+cOOK6ELRWvsprxDxGT3s1lw82ZhPG7tUY1ZRGT1LtfDhi
pNiuJrZovNjHjKWgY4wuXVKDkbytJNenlwKP/k5WAbFXAM+V6yiA8x3yEGEt
RhNdjhe8JQIYvW97PYcY/SWp1zkIQFpeybGtw0hp5X73+2cUqIpDw9KIQZO/
3TKFAlaOqdbyPkaR9wbSnbdRsCf1d8tUYme3jLybThRUnVofzanHyLDvm7N5
cyjgHxquTibuuvXmYLcJBccifrJhNWC0Nqv5cIApBbodS+MSicv3F6unmlMA
W1oajRox4lg5000OFChW77c/SvxQPul0dSMF427z5B+IXeR5VxLiKJCJyh7F
NWE0Z8qzmi1XKSjhBTiNEScMSPINXlIwe9bH+OhmjGqtDwcf4Qsggvlr5zBx
50nK7MYeAQhf9vzQ+wCjGfu+1oJeAAmPT77Y2YLRnrtL9YFr7OF5jQC6iF+3
G18yTLGHdFXY4ONWjHx0n8UkLxLCh4wZq2QPMdp5oeWFb4wQtp1TKZqILXIZ
DsEaIWjipaMbHmGkGPINShsTgnnc6NoaYiMfeYbeSQQxYSmZksckf2O+aXiw
CBq3u03eJp6Ycb9QlySCxZvapKgNI53ITbNKKYIzKw7mXyOuH9e7Jt0RQb/z
p0z3dtJXQMW63CYRSAS3/NTEmzwEs48TZ3GDCpd0EMc2ZZpVioDJMjQtIPZ/
G8xbnSeCwI/ZgcInGFkrjlycflgE10ckmhxi7cYqly3LRcDt6Ztp+xSjlFEd
a9ZbIXzbejo0jdg/PMzT8ZwQWqocblp2YhSbKc1WWgtBXFZvnkpspNjsYXDZ
HpKvRoVzdBi10itD803tYTDN7E4y8ZuoaXzVLgF4/6zmsbow6uCdibQoo+C3
41v3JRIr+Ur03ICCoN2X7I4+w4gaifSrilwIj8S2x6J7MJrEJhWur61BWylG
sl6MZumClywq4UASQyNtIH7X5PPL1O7ZIPOkQ7z7SP8J3z0d4rKhVyU5Bf0Y
ZUlcKp22TYfCV7UKDXHMROzDsLkmEMeXKsWvMLJiZmc5jhkCS+H/gD+A0Y7i
bJOoTR/o1tauF+nE1Ysdl4cZj9Pp7NBx7iBGdb053M28UXr3uoHp54jTyzLd
/vQcpsXxUZ/OHMLoaEtfxrEFL+nJ8ndOicR+Tzazu/s7ae37AyumDGM0dKX9
/fMLzXSSq4HsEDE7Sh/U0VJBy/ae3DVGfHrQ9MTluvP0mezAuXNf//8P/wHN
YmRm
          "]], 
         LineBox[CompressedData["
1:eJxF1HlQ00cUB3CQgSByVI4QkCMhggIG8guHFMlzS0NlCoJSWw/kELQgh4ig
Ayp4EAUiUSJrUUZTpeBBoxI8goBcHkkRFOVSubwoXgOURLQg2O1MZ7ozOzuf
mf3nvffdZcWkhG2apaWlFUb2v2d7gKbZm4aR1n8rZEh0M5i4gjNzbOanSr4k
DJ+oJ24wttlzzecJn8E5t7JUH6PVG/2KdbvG+I4vWps2G2D0lyBMoFLOgvjQ
7lO9xCOtRVKvMF2Q1Q1mLp+DEbUlrobWTQNe8ThFGWKU2z7npvquIaBgRukn
I4xMRm3a7tuYgfAGKzvBGKOx4OzuVL45KJ1c1/URry0dvftstQWEaINpowlG
r645Mi9nWIJky7IR6iuM5Jzdb1dlM6Czd0XLb8QKS72oH3ZbQfj12P25czE6
UdczezhqHkjZyZF/E8dT8jPNAht4UbjDN9EUox1Hn5/NYdpCfGL+eIgZRm25
CXX+tXYge3z0fiPx7d5VbrmZ9jAacLKCZ44RUq1/LaUzYQfzcgzdAqOtbQZe
yhtMqBFXQx5xtWyXb6kBC6Ynm6wnifUkrQV9cSxA8fcmEukYGWVt/V3RzgJh
V+ejfuLHkVVRGwUOoPQfuBRqiZE7q3+bWbMDGFQOi5qI1fIllz4EskEimvQv
Z2B0Rt3QTE+ZD50fdewtrTDSz9rlpjB0BMYmo6k84p78X4aXVzqCdCnzSpI1
RnOf0uNYegtApglge9pgZBG87dfrXc4wtiH0SznxkQfhO6MKXMDjwZpeS1uM
0nw/vxf6u0LNhcSiKeLwveJ6/YpFME3fnpJshxH2MK9UreUAEmYHDRKvycmK
VOm6gTJSonPLHqM9F9mW34e6g0FryaAnk9QTPXGF884dQr4uqz1LbFeVaGWA
uCA5e7GYwcJo4mGeW/FBLnSaKdJExDV6n7K6VVxg7GsM/Uwco4xMitajIHzk
D9ctDhgF5sdEtgEF0vAO2jPi1Fvnq6+lUvBC1fdyJZvk9333oFxKQXpFbkQb
cdq+7gMrVBToFfB6AueT++U6FpNvKDie3L/iNrGhjjTBRYcHzqF5LUsdMTom
GIqNMONBDddDUEtcZW41YGzNg2DTgZveThjV22Zer6HzYECdt7iKeLZBQEuf
Pg+2dnnIOQswmsypmxgbpWCWYsDlAvGEl71V2j0K8PH8svkLMdrcIjMeLKHA
aaen3Wni6ndlVysjKFCEDxbPcybzFix7HWtGQSBfNLeY2Hxvx8H0Wi48tfM6
ZOqC0YX094/WrOfCzHNR9mxXkk+m+hDtO3covOX1SUj89HQRvaXQDRzKn6Vq
LcIoTHs6R97PgYB4700fiaP4kXvddi+CgpHnQUNuGGkO3Ak91eAMdu0Fd6Ld
MRJqLL/51sQZKuWLl/YRJ2tKaOKIhdCRLuZ1cDHy3P+zOEjjBNZTPlZNPIwe
3Mhu5c6wQdb38qifB0YZ0kaF3JsNUH/YsJo46U5Jwo8JDrBh36svlzxJ/68G
nRY0MWE85kimixdGFx9mNEQp7UEo8FWXE2cmjTdMztjCeVrhnye9MTqutvCZ
9rcG3ze+0YzFGG2sVi8sW86A1pahJ0XE52Mfig8vo8OoeEmbyAcjG7amXKZr
Ct7mw1cyfMn7N1q3wchRG1QfJBwNMX/tnnza1Ef+uh6/cylLSF5TTeLUJ97y
XY2Nt2v7/f8f/gOw8zsQ
          "]], 
         LineBox[CompressedData["
1:eJxF1Xs0FFgYAPAJlUJ5DElN5DGDnmpaZXc+F2MGK06FJg0y0bYl8qpYMhGS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          "]], 
         LineBox[CompressedData["
1:eJxF030s1HEcB/CLkTzUeSZCs1ZjibJO7D591102TwvDrylxDz+PeejIblG6
yqIW4kulVrdGHtKRdSd0kzy3pCcqseLq8hB5LJdF37a2Ptt7773+f38285OD
aS0Gg7GL5G+n7i0KMRzBiPHv4sVdQVzi1xWTSjfKAjKfnZlwHsXIrcMryXGR
DdnpnxS3iJ1YVqI66/2Q5wBnTVUY9V+fefpl1hekaRqbZeLsx7hIow6GKjtq
LOkzRtKM0z6/Y0OhvvvBg1Fi2v2VormLgmaRiSTsC0bsygo50g6HdtuUgKfE
MmzncNXmMPR29lqDGiOdhpAXvcwjMJDirL5P3PgsRjo1GgkfN+bWb/mKUWmP
p3xNTxSMtatPXSMeVwWcM8rnwWwS189oDCMts0wnKYcPv6xuW0qISz3e4BY1
H7TbVlULxDxXuu6YWACGiRF1seMYmQyy4x8tCcDcsjlziDjcLLG2PEYIdq1W
PoETGE0r1yTu6hDC1oR083biHLl+QYIxDa7mb0ZYkxgNvi/RCfGnYU+Lm+wu
cfE6edPccRr2xeWfsP+GUapj2o2APBr8TKe8i4gddFVX4otpCFH6mq6dwuhQ
AbP0wEUaImIqP54g7pUaFGil0BBtrFszTbzTQhWdy6EhuVkg5k9j5NlXbjCh
Q4OYbuUOEN+s5ic4NQhBssHe2Pc7Rszz21IDKSFcaMwcVhJzObpMvloARYLB
KrcZjCaV+jtooQBuGHmklxO39HOVkS/5UN5QvM96FqNjcW0V1HY+yHjz6y8R
P6SKPwSLeaAwCPrAmMPIUNKzn6qPgha5rCKNWCQZvtOviAT3yu8uamLsXb1S
MBMBlaWuCmoeo4GF5Lfj9oehMKu+3XMBo6HatpWwkoOgK5r3qyFmgkLjMxAG
GUL315sWMdJn2VJlZqEg9FGMMH5g5HzUoND/VBC88/oZKyKWceZYc9wDEODi
MaMifh7n/QQn+sFu06aVzp8YWU5PTLpyOFCts5ztsYSRKkuvu6+NDfZLXkbV
xCd5gXqdOe6gN6y0uaQh+763wmQxh9ir2q1llzX//+MP27yHbA==
          "]], 
         LineBox[CompressedData["
1:eJxF13k01WsXB3BKpWS65qgkc4aM5Qzbg86hMjvnl3JFyBgJUW4hpTJUyFOk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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQXdnCp8x/cKoDAxQI9T58NwHI1xYqerOS7aftpc5P
c3gOTXV4fVkjZV0/p92kNmbvDiB/2SIOq7jVwnaCDarL6w9PdSi5uWWRp6Oi
nc/6XXKfgXyt0xdPRH9RsWu75z8t7chUB5aT5/N3ntGw+2VT1ep7dKrDd87U
x/ylBnYmOfx/DwD5ml9/xhybZmSXN3tJicmxqQ6nPuvcajtpYrfilOWb5UD+
kxU+huas5naPfp5Llj4+1UGu6FFwj4SlnYxmyu0+ID9Jyv+MwW8ru7CIn0FM
J4D6181pnLDWxm5Ce9+pUiC/2OZqlLiBnd3pbcpOL4F8nctM9obN9nZsz3bs
jDk51cFp33SupcEOdg6ifoYXgPyrC40epZ1zsKtyebzC+dRUByuZ65IiRo52
W4orFLYD+b+MuZY+qnO0e7eId4bWaWB4vA8o59jqaKdxaRH/PCD/ZKhBy+4r
jnZJjBbtgmemOrzN0d1veM/Rbq7B2X8tQH6e9VnphRcd7W7EJ5X9APJXHp/S
a7/e0U6o//vb7LNTHQ5KcHI4lzva+ezrSb0P5PObrq97qOlo1/ZW8W7QuakO
sso8TwOOO9gdkNkecgzIr365RO+4v4PdL2+fM5bnpzokyv6d+6XN3s6k+qHz
WiB/npFNsYOrnV3+qrLdChemOuTLCB65e8vGbtVNbuMpQH7/q9ZyCw9ruycc
C1exX5zqILFuScmeXku7iPTTM98B+TftOV68X2RqN2lagmDSpakOLhqJOuXF
xnZnjn7tuArka5r3hF2XNbRzVFGo2HN5qsOSt4wfFzNr2NUEb32vf2Wqg1vT
3pqOCiW7bU1e6YuB/ICNtyX+eEjaaT0sCeu6OtXhxq72f9trN9muKgy63nMV
kR4B0/w5Rw==
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQHflP8lMg5zQHBig4zZb6VoJrmsMRYdcf1nyBdgc+
1e2dDOTv99X661YcY7fl3oxePu5pDs/7FLvmmabYzdl2RpeFZ5pDwr2yryIt
BXYTFj37WwfkHzPf4P3qXbFdSx/DuZ9Afk7myr1TasvtctNM8t7zTnNY4MXn
08xab5cU5GeXxTfNYc4OTi+t+ka7MLsMvqdAvqBn1C+O3mY7L62me/H80xxM
V+1w3t7VamcnNmfdLSBf8uKn85Mi2u2MmLbVhQpMc2gMdFE69q3DTu3deb8L
QL7p/hd7q1O77KRuvZTzFpzm8HOttNq9Jd12/MeY3x8F8qdtlrgnvrXHjmWT
7H4HoWkOHInSmcHTeu1+zDXv3w3kX/SI99rt0Wf3pjMw3kx4msMuBgXWqjN9
dg9Ks/U3AvndMjNldin2211JbP2vLTLNgc2ATWSZR7/dCd/555cB+R/PLcrL
cOy322O5c76i6DQH/t5V67V5+u02ql7OnwPkq/2NiJJa2We3TPCtvbjYNAe7
zS8/xkn02c36yyYwCci/4jLjp3JUr13fS4UHPOLTHLa4LPgyOa/Hrumq1YZ2
IH+2m23azdBuu7KDIQ1MEtMcQu6tuign0GWXtTYvoBbIXzhfZVff3A67uJkd
Cj+AfHe5Z4uC/7XZBbUu+lAkOc2B650W/wyjVju3wj0H3gL56xbpNbVZNdtZ
xV6bkCE1zeHXeZ16T7FGO2VTLsM46WkORXt4Pd5NrrCbFLzi1AUgvytGqZB/
UbEdQ5FbirPMNIew9xP2XTiRY3d3XdN0DdlpDjWsCvOMvnjYXatfm5Mli0hf
ALLCCmI=
          "]], 
         LineBox[CompressedData["
1:eJxF0nlIE3AUB/DN0qG0LMWmTldqWYqphaLzePzUnKymOR2bbktj5kWH4gFl
SWothRIKf5kahopKRuJBHnPeulw2A1HBxSjziFoWWjSzjdkvCHrw+PL568GX
5ybLSUi3oFAo3mT/ZmJnsdVsL0aUf5M2NaIzEXfzDX7Lgl3wHWrfX+3DKDIL
t22FeYCtL28ttx+jVCua95w7G560HPm0Tlzt61KeNoDAx3VHn6XAKJZdPk6j
RsPpPd0b5wcwqqzqH3Nd5cHirbs/dMTtJfclwtB4yDReMCQpMeIyWJJfq3ww
5MH2PHGjywvV1pVEuK1nmOIHMdpoKC0VaQVgL9s0a4iXB3sKnA8LoUk7TeUO
YSQpuSmPOisCf37zbhVxpIletyBOghF1MS1iGCNdzP2aOU4yxCGRzRCxKj8w
E9mLQdfnT2ePkHsPfNZZo2K46Gezr4f4eF8zPS9WAr9bV+xOjGI0+1PTFaaU
QAVryKGdWJ86P1xqLQVGdbWj1xhGCmu986lgKbTSc5ktxCmW4c/vxEghQM5l
uY1jZJthSuIFSWHC5O5WT5wNIloNTQoJBSYPpwmMMhtv1F/ql8DSlwXPh8Tr
TY+pM1wJ5KR1eO2fxMhTsOI0qBSD+W2FTyXxpLpME7ZXDPcSZH7WKowKHdp2
+BHJwJwOPSknXuTKa82CJHgW4RBIfYlRRhGnJJorArbiW1AxsVnBrPNiCUHt
rw7ZJq5lBsy0zwlA+LQxvHAKI7+e4Z357ERYO3gdbRK/qdIzmpb4UPBIEHVZ
TfqZ+WhkBMeDha0v5zOx48akR/4SDw6Zl858eIXRu95j2gOW0dBROBB3bhqj
riK+sUyBAL5W8bXEZbKVdGVKMEh0HNHsa4w4qoqGTqMdhBiuHbXW/P/HPz8J
Now=
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQLbm6NPbVk6kODFCQ8krs1eqnUx0Uj+/Nn2GpbMeV
1C8j+2yqg9DhkF7bcH27DTfZ/fuAfLU7rKGnmM3s/pz4sbng+VQHNy829epj
jnaLHAqfPQTyK+4cvqwb52rnseOlRPCLqQ4zgiXff5TwtJu8/Fat6cupDpzP
dTdwVgfYWcgHb1gG5Asm3Zh2sTvI7t6004/EX011KDtutiZkbYidVtse919A
/szy/uM2/JF2F/6aVGW/nuqwarpQVw9ntF1Z6do1d4D872uKZ806HWMn81b1
vu+bqQ6bm3i6dobG2R1KmSe4H8jneGL2ynpFvF3GHTEXg7dTHUT91NR2JSbY
8YX0ly0E8lV3X15w63KC3ZbT7CuF3k11ODPvwtoVWol2kc4Nt5uBfOt7J6f6
piXa/dv1g/crkP8uPmfhp7ZEuyVGhQ5p76c6ZHKmSh7sSbTzWvWy6DqQf2t/
gtuj8kS7D4pJSz0+APkZPIX1Hol202beur4TyGd7JfLo4L8EOxvBYC7tj1Md
PmuoP7o0K8HuUcdpmzlAviX3h523ZRLsOhhc8nk/TXV4+MYihZsr3k6vYs/C
OiA/c8EmtS/LYu2uvDe58h7IN/mzzOeIQIxdVfpatsTPUx1KT+enn3OPspO/
r2p5CcgXupfGkeoTYXckbF6285epDlm/nx64JRdml3VObN4WIF/spZtS0/5g
u2172Zmnf53q0PlAyyvhpo9djGmDKce3qQ4hDrmXtn92s2Na+yO9EsjfutjR
nH2tg53fnJdnor9PddhSWsYt+FPcLrBlw7LO74j0BAAMjCOr
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQLfPDa6WG9TQHBih45+rIymIzzeGKU+vsdYsc7aaY
XP/UDOQ/fhnc/+68l52lcu4DZttpDtMEjz+KnB9od0+Q+VwzkH9/qvXR32Wh
di0MM3cz201zCJfVnBr5LsJO673eymYg/5nJxh/vWWLszt89Mo3ZfppDdc7X
qda74uykdn8oZHaY5rD3m7/B1/+JdgdWtsU3A/kxKc7aLxOT7VJnyPgyO05z
OGB43kvycIodV/smq2Yg/33S3dwlUml2G0o9NJidpjks/B1evDI+3S405Z5o
M5D//buGlXtnht2voBJmZudpDteirRbO6cu0W+DI9bEJyOfWKms/kZZl52qw
4B6TyzSH5IRjp19yZNu9kjM70wTkszCJ+srnZNtN4D2zk8l1moOKgM+r9vZs
O9M/icubgPzO7tAmp6Bsu1uvvk9hcpvm8KdU+kvu4Sy7hpu9TU1Afvm5djnN
S5l2qieUC5jcpzl8m9nyYFJpht2pbTtjm4B8jxu/JU4tSbMrWOrvzeQxzaGn
9fqyt2EpdmJTnlo0AflMyxgzZZoT7XY3VasxeU5z0Gw5UfPKIcYuoVBQpAnI
v7n6EreeT4gdW8JyRiavaQ5Hkl9XNum42a32s33fCOQvT186f+9WJrvvAjmC
nV6I+AUAGI/UkA==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$65789#1"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1066., 0}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, {{0., 
          FormBox["0", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.2, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.4, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.6, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.8, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.05, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.1, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.15, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.25, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.3, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.35, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.45, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.5, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.55, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.65, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.7, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.75, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {156, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {208, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {260, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {312, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {364, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {416, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {468, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {520, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {572, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {624, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {676, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {728, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {780, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {832, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {884, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {936, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {988, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1040, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1092, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1144, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1196, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1248, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1300, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1352, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1404, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1456, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1508, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1560, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1156, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{None, None}, {None, None}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1066., 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 1000 people\"", TraditionalForm], 
        FormBox["\"%Positive \[Times] %ILI\"", TraditionalForm]}, {
        FormBox["\"Year\"", TraditionalForm], 
        FormBox[
         TagBox["t", HoldForm], TraditionalForm]}}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, All}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1156, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 475, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{1066., 1430.}, {0, 0.8}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{None, None}, {None, None}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"OC43\"", "\"HKU1\"", "\"SARS-CoV-2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.79096634556618*^9, {3.790966425237339*^9, 3.790966454603299*^9}, {
   3.790966491150526*^9, 3.790966509642466*^9}, {3.790966583577635*^9, 
   3.790966594007172*^9}, 3.790966659549314*^9, 3.790966703393758*^9, {
   3.7909667383899107`*^9, 3.790966757715486*^9}, 3.790967166819141*^9, {
   3.790967206499619*^9, 3.79096727099717*^9}, {3.790967305889214*^9, 
   3.7909673423461*^9}, {3.790967440118722*^9, 3.7909674858629427`*^9}, 
   3.790967633111467*^9, {3.790967671807901*^9, 3.790967812899515*^9}, 
   3.790986120764835*^9, 3.790986154907075*^9, 3.790986213066638*^9, 
   3.7909862490280943`*^9, {3.790986298382011*^9, 3.7909863272991123`*^9}, {
   3.790986432124242*^9, 3.790986453558629*^9}, {3.790986576906382*^9, 
   3.7909866345433292`*^9}, 3.791024598576089*^9, 3.79102466009927*^9, 
   3.791024900351776*^9, 3.791024955991094*^9, {3.7910280013731213`*^9, 
   3.791028043311933*^9}, 3.7912389828509083`*^9, 3.7912391270712137`*^9, {
   3.7912391651118507`*^9, 3.791239191604376*^9}, {3.79131107712294*^9, 
   3.791311087967208*^9}, 3.791312914271863*^9, 3.791464935057178*^9, 
   3.7939113636204643`*^9, 3.7946551110191727`*^9, 3.794655375980809*^9, 
   3.794668107946237*^9, 3.794668507325815*^9},
 CellLabel->
  "Out[1758]=",ExpressionUUID->"26eb3f8f-b08b-48ce-aa39-3d86f9692348"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3C.pdf\>\"", ",", "figinvasion"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3C.png\>\"", ",", "figinvasion"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668463523735*^9, 3.794668464522566*^9}},
 CellLabel->
  "In[1759]:=",ExpressionUUID->"5a5bd183-29eb-4791-9690-6c29a02d70e0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["30/0 | 40 | w12:", "Subsection",
 CellChangeTimes->{{3.791024299513517*^9, 3.791024333549387*^9}, 
   3.791024387646628*^9, {3.791027963156403*^9, 3.791027968136772*^9}, {
   3.79102802686504*^9, 3.791028026929071*^9}, {3.791028175206419*^9, 
   3.791028181254373*^9}},ExpressionUUID->"51a78905-2a31-4f38-b551-\
2a7d344cd3cf"],

Cell[CellGroupData[{

Cell["Define parameter values:", "Subsubsection",
 CellChangeTimes->{{3.791024353689595*^9, 
  3.7910243639133368`*^9}},ExpressionUUID->"0d8963c9-9028-4435-9d07-\
25448f133c77"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi31val", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi32val", " ", "=", " ", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi13val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi23val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma3val", " ", "=", " ", 
   RowBox[{"1", "/", "40"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"importtime3", " ", "=", " ", 
   RowBox[{
    RowBox[{"52", "*", "22"}], " ", "+", " ", "12"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.791024391785356*^9, 3.7910244703065147`*^9}, {
  3.791024832104692*^9, 3.791024893824339*^9}, {3.791027983305586*^9, 
  3.791028012584515*^9}, {3.791028185343968*^9, 3.791028188782642*^9}},
 CellLabel->
  "In[1761]:=",ExpressionUUID->"053c03c5-464e-4617-90c2-ef43d6c54fc8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the model: ", "Subsubsection",
 CellChangeTimes->{{3.791024365809227*^9, 
  3.791024367637371*^9}},ExpressionUUID->"cd46fbb5-29e5-424f-90cc-\
2d9b213eb78e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"runmodel3strain", "[", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[1767]:=",ExpressionUUID->"a0a92c39-3ef8-42fd-845c-c657e5b63e77"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot output: ", "Subsubsection",
 CellChangeTimes->{{3.79102437504543*^9, 3.7910243813336277`*^9}, {
  3.7910245019903917`*^9, 
  3.791024504277298*^9}},ExpressionUUID->"80b761df-a1a1-4d2c-a0e7-\
814ade46f995"],

Cell[BoxData[
 RowBox[{
  RowBox[{"figinvasion", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}]}], "}"}]}], "}"}], "/.",
         "sol"}], "]"}], "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "plotrangemax"}], "}"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "yearbarchar"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "0", ",", " ", "tmax", ",", " ", "52"}], 
             "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"importtime3", ",", "importbarchar"}], "}"}], "}"}]}], 
         "]"}], ",", "None"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicks", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ncovticks", ",", " ", "All"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"\"\<'\>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{
                 RowBox[{"i", "/", "52"}], "-", "2"}], "]"}]}]}], "}"}], ",", 
            " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "tmax", ",", "52"}], "}"}]}], "]"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Year\>\"", ",", "\"\<Prevalence per 1000 people\>\"", ",", " ", 
        "Automatic", ",", " ", "\"\<%Positive \[Times] %ILI\>\""}], "}"}]}], 
     ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "imsz"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<OC43\>\"", ",", "\"\<HKU1\>\"", ",", "\"\<SARS-CoV-2\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"oc43char", ",", " ", "hku1char", ",", "ncovchar"}], "}"}]}]}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7893824421170883`*^9, 3.7893826157339983`*^9}, {
   3.7893826664946747`*^9, 3.78938266695546*^9}, {3.789382731126128*^9, 
   3.789382731675748*^9}, {3.7893827767664127`*^9, 3.789382777444231*^9}, {
   3.789386619546466*^9, 3.789386631208551*^9}, {3.789387810394597*^9, 
   3.789388029020711*^9}, {3.789838710858089*^9, 3.789838717718485*^9}, {
   3.789842556270996*^9, 3.789842651382614*^9}, {3.7898426863790817`*^9, 
   3.7898427300803967`*^9}, {3.789842819806529*^9, 3.789842948950203*^9}, {
   3.7898429865388527`*^9, 3.789843021987234*^9}, {3.789843093799283*^9, 
   3.789843184820764*^9}, {3.78984336766575*^9, 3.7898436006321487`*^9}, {
   3.7898436712471724`*^9, 3.78984370597163*^9}, {3.789845657271617*^9, 
   3.78984565935472*^9}, {3.789845785029049*^9, 3.789845795524316*^9}, {
   3.7898458658704863`*^9, 3.789846118358913*^9}, {3.789846154006332*^9, 
   3.7898463664972258`*^9}, {3.789846403235764*^9, 3.789846484288625*^9}, {
   3.789846522317915*^9, 3.7898466387710238`*^9}, {3.789911908017222*^9, 
   3.789911994611348*^9}, {3.789987417920609*^9, 3.789987519668146*^9}, 
   3.78998766533955*^9, {3.7900151606852503`*^9, 3.790015162261084*^9}, {
   3.790017373012323*^9, 3.790017443684984*^9}, {3.7900174921119833`*^9, 
   3.7900178416947412`*^9}, {3.7900178781015577`*^9, 3.790018049008872*^9}, {
   3.790018143265133*^9, 3.7900182454606028`*^9}, {3.790080424619478*^9, 
   3.79008045222733*^9}, 3.790937591828598*^9, 3.790937628558119*^9, 
   3.790937755476927*^9, 3.790938168272998*^9, {3.790939252734089*^9, 
   3.790939274532484*^9}, {3.79093932502175*^9, 3.7909394034475937`*^9}, {
   3.790939491200864*^9, 3.790939533093276*^9}, {3.7909396652500963`*^9, 
   3.7909396778141613`*^9}, {3.7909397335725937`*^9, 3.790939735050262*^9}, 
   3.7909399443534927`*^9, {3.790940134103973*^9, 3.79094021526552*^9}, {
   3.790940254309019*^9, 3.790940255328331*^9}, {3.7909403051360607`*^9, 
   3.79094031494598*^9}, {3.7909404920878763`*^9, 3.7909404977980022`*^9}, {
   3.7909406269986343`*^9, 3.7909406299951353`*^9}, {3.790940726648095*^9, 
   3.790940771458849*^9}, {3.79094080944941*^9, 3.790940811632804*^9}, 
   3.7909409745994387`*^9, {3.7909413836357393`*^9, 3.790941469640398*^9}, {
   3.7909419009848537`*^9, 3.7909419011777773`*^9}, 3.790941934145125*^9, {
   3.7909429495176973`*^9, 3.790942950149515*^9}, 3.790943062385366*^9, {
   3.7909524619930143`*^9, 3.790952484646926*^9}, {3.790966313488199*^9, 
   3.7909663273901997`*^9}, 3.790966398007543*^9, {3.790986123275064*^9, 
   3.7909861516486263`*^9}, {3.7909862083701267`*^9, 3.790986209160791*^9}, {
   3.790986242927669*^9, 3.790986244031867*^9}, {3.790986294640409*^9, 
   3.7909863255150146`*^9}, {3.791024642180931*^9, 3.7910246434516687`*^9}, {
   3.7910247121220627`*^9, 3.791024713209406*^9}, {3.7910247441953907`*^9, 
   3.7910247453652563`*^9}, {3.7910247761867857`*^9, 3.791024874373518*^9}, 
   3.791024910533731*^9, {3.7910249449382544`*^9, 3.791024947047079*^9}, {
   3.7912390857336597`*^9, 3.791239089355637*^9}, 3.794655078550572*^9},
 CellLabel->
  "In[1768]:=",ExpressionUUID->"7e2965c3-403b-484f-86fb-03e0a10478a5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save output:", "Subsubsection",
 CellChangeTimes->{{3.791024505581291*^9, 
  3.7910245071250677`*^9}},ExpressionUUID->"2202baba-50c5-4b4f-9b22-\
372bd322c038"],

Cell[CellGroupData[{

Cell[BoxData["figinvasion"], "Input",
 CellChangeTimes->{{3.790966344065854*^9, 3.79096634514146*^9}, {
  3.791024648443697*^9, 3.7910246488615093`*^9}},
 CellLabel->
  "In[1769]:=",ExpressionUUID->"4224cc08-ce97-4a37-b24b-9011202cb9a4"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c8ll8bAHAyQqnMJGRVklRK2ddBCalkryTZm6xQtqz0PPdjk73JziZb
ZhlFCJVKpORXKsR73r/6fD+P7vvc51znGgLmzlqWO6ioqGx3UlH9/98PoavU
VAUk9MV0/9Z9sjPEDx7RdsM2Uf3+m+BzBlUO45x5bP4vT1PZy5ygNKdDpbeQ
hCy2XHYwTzqC2dffCbJFJHRDJpThhrsjsJ0V+/IEm/yKbX2QxRG8O2KjiGIS
OlV5YnhI1wGO7+qdpi0hIcWn/i/kNu1hRuvfCS9s28dvFh/k2oPye8uXxk+w
PRiOulPZwx7q8xyHy/D71AnlY69toU3V3ioBu/3qwoevZFtwJ6XXMpaT0LGP
z3cd0rSFN4cYjL5h+2jfuZcxagPR1nLFZhUkRCN70Xk60QYUylw2R7CfMmXp
3TCzgRyFN2m1lSR0iSvVhn7NGvTDmFeOVZFQo0REJ3enNTANKSqmYudx/o3V
iLUG5xtFHwKqSejQhsO1rzLWIJg7c/Y/7C+VVSMaLNYw9pU1zPIpCW2zMSmU
fbECGT9fEfUaEqqBDSnTDCtY7ii724R9qz1jK/W+FWTsmu8TryWhkxOcuztM
rUBLm4snE7v8Sv6nAWQFdCkajmx1JJQr0RtUI2wFde8DWkKxVThtBnyZrMBO
9OneP9g1D5zLuFYtgdfti5ldPQn5cvTvj5iyhJf1vJXT2G1XrX4877aEIGot
mmsNJFRLmrs0VmUJkmphOm3YJWQV58IsS1ggNeSeaSSheS0RnUsUS0ie+LaW
i13iE5xYEmoJV/iFVLmaSOi/Ut2Z8buWQGWjnxSJTR+f2tPjbAmVZVGLm9iC
r3XXfKwtwfL3M1nnZhLS4vDfvWJmCVzwM/oddsDnxagjJpbQFyYyo91CQnVT
Dbr8hpZwb8jkZDe2G48D76y+JZziJAdIPSMhAdZGwsLAEt7f6Bouwj522MKy
0sgS4nL/CvK2ktBGs9DFPlNLUF0+4f4Ie/NCzbsnFpawfta8i7qNhAIFJxZN
HSzhiV88pzs217OL+2Y9LMGss8/6E/bGZ1bdU4GWwLp7u86gnYTkW+bPGMZY
Qpf2GaZ+7GLVaxM3H1uCd4q1sXwHCR3WNyxSK7UE0Q8pJWXYHvWMrDxtlvBW
9OU/gU4SWgJrr+lXlkByo70Wi63f4K1E+moJZPFJ+X1dJES9p8HEeqcVEItl
YtHYJzWa8uLx+VLyQg8ydOP92cHDcviCFcSaGzOFYAfuYKs4ZGUFcXyn/25j
u87++i8u0griJ+kXfHtIaCE3fCS2wgqStCq77jwnIRnBoYtmO60heU949Xfs
lRWGAZVz1pDadyPbvpeEdkzTDH+xtoY0JcbA2334vrYZTieNWkP61ozzLDbX
I2+lfmYbyGioNjXuJyHdmScHqS/bQJaEmZz2AAlJxfD4Dw3ZQPY3yeMvsOkl
z0mSOGwhp2gX9+VBEnr95UhN0U1byBOs/a00RELdjFddFLZsIX8m+lMLthsL
s/y8lh0UJJu/knlBQswbsW2Xiu2giHVPlcRLEtL85V7QbW0PxUMfMkuxmfJm
xPkH7KEksp4kOkxCZ6VzQ6rPOkDpDksnwRESeu/WvG8XmyNUrTYeYx0jIV5/
9W9vGJyhupTMFYPNIPOM7gzFGWrsrHcyvSIhuRWp9lAWF3yfWD9SvyahZNe3
nzcKXaA+bWH0HnZ4sF9S67oLNBi1tP/FPpbaU1B11RWaRmwzfoyT0PlzmftT
qdygOQYeOU7geLv1gnXQ1A1a1Dnuf8EO+mE9lt3qBq3trcbv3uD4bhfunXp0
Bzor9+8fnsL7d7xiZNzMA7qclumuTOPvzfjx4uGcB3SLdvx8jn3yIFe9tKUn
PM9yGml9i/PlTR0zxfte0Gt6oU1uhoR+dDMcpWXzhj5u7vI67C/rlfpRT7xh
kOh6WD5LQmb2tYZzP+/C0NUUP7E5EloM7eQ7k+UDL5lc7QuwO3bOeV7V84WR
IB61jHckdOb4uzcLo37w2u0OLekDCbHeZLqYxBkAWrcGm2jmSejAw+BOckgA
DF476uGFXaaqG0pZC4BOsamPph9J6GPnpxrDz4EAByXTRrDzSWrrnlZB0MD4
SE/lEwk1eFW5Xl4MgopPSj0nPpPQ/fwF5X6qEBB7leqfic3lYD04SgmBgo61
8xwLJESn9uqfjlgopGUUFWxi81U4Z6Y5hUG0EWtk/yIJCefHWz1UiAAGNQcl
WMLfs8z6upQmEoLPd69XYudu8JdKvIwEH3Yf++Sv+Hme5k+8AqLh144xoT3L
eH8sHpqMWTwElx8npgOxGR1T6jqux4D10DsN22/4PKO6j18TIsH7Jlm6t9jb
co8PJeaTwLQ4rlnzOwnpfT1b+uoUGXTC1cSlVnC+0ymP/aZFgJJSxd6dqyRU
r7hTYXMyFlpO7Xrug53CfcfOJDoOpA9ZBnzDNj3qtXz9Qjyc2uT68eo/EhIy
nVD/8DwBihfdCtV+klBwocDZf3GJcOTNwK1mbCed/7Kz7ZKAtyZgJOcX/v53
K5WJx1MgMWcykmuNhFw85v1tuVKBnXJWORpb/0jxgRHmx8DkslB15zcJjVr9
6H7Ilg5/jmnGKf0lIXHLMxTt3ky4w1V0pQbb+vmLWT6rLPhGT0svuo7Pb2vH
WTOGbPj4odaTZYOEMtf3Sb+7kQNmIywnQ7HtX+pYu7DkwnSr/ec/2F65SVss
/bkw8viQwdwmCU0WuoUIX8+Hq9F39+n8I6F+B6rHH3gLoNdn9HkPdpdzu8PV
HwXQqv9AumyLhBy+KLlXlhTBE5bv3PepyEj5gQ61891SiFUVi/mO7R21S4/G
pwx8/W2pb1GT0S/z4fXfqBzUlj98Vt5BRoeuMYuy6VTAx+cT1Yy0ZNTQt749
mF8FA9scIr7YRhkp9FdVqqHqnHbKV2yLHU4vMxaqITBnMPAFHRmtWuaul0nV
AG9A+9W4nWRECrnPqUFXD7S12230DGT0X3FQr2FbPSwty0l6Y0/Jcmz1BzRA
vXHtQWNGMjLtvrdwi7EJdM+XLPDvIqOQfCGWS/LP4OG3uKCSPWS0syB2Dwt1
B7gfHv3Fu5eMlvWmsoSdO8DYZJ/tI+yi+NgWtrcdcKwv8prbPjLqFrP1G6jt
hK5cfx4pVjKKu31GXu52N5RMNz0qxP4Urxw11tcNFLb1HQfZyCj0ex931ake
uBXo/uUf9od9usW2az3wz8S2poODjA5LMXP13u6FeUreMUlO/Lzywqd5tb3Q
3/chNQ87bb5RlZ+hDyqpBfZx7SejM75f9tHq9kGSlGlwBDYtr9YDobQ+CHBO
WVvHPvklXErrQx9Y503YOnCRER3HHh0L4X6QZNfWvHaAjJjunLmQmNQPPJdJ
Ha3YDIaSl10H+4EmaPCcBDcZRXH0/Uvf7IfFOqaibGyxU/x7GI4OwPD3S7wc
B8noT/rc9CONAag7EkoKwxa1O3Fc2HEA0m+00/zBnqAYPaoMH4Cw2G1PWx78
/7MYZE6kD4Bjv9ziJHbxraY/UeUDkOV5cEOXl4zcyH8+U5oHYEJgfdcw9n5V
Zf2YzgFgHpzg0eAjIz7B43X3uwZAybv2RA/2e7KYkH3rAHgLxSsoHSKj5sSL
Q+ZPB+DJkPu1ZmzlIUtLz5wBeH9X20yKn4y+W+svNj0cAK7DEq5V2Iyd4x1a
rgNw9eW+IHEBMnr+uI1K79oABPt+Jwqxywf9D349+v/vG8oWFiSjB2+E6eQ2
+uHbcEl1OvZ/88V9Lr39IHQvqotbCD//iMhIPdEPBiJ2r+Owpb1NtS7p90PH
/aN/ooTJaFQu/zjtaB++3/SMOw/jv1cRMsiM7APxV/MHgrAfG97ruKnQB4nH
s2S9j+B4GbTnFUvpBacJHn8LETI6kfj6dvqp55ATvPFoFjtf9dbIqxc98EZ8
MsPoGBk53tBaZ3bsgQuhCe2aomQUFCRz1iGrGw5IsNLLi5HRK4sSYnmrE66+
XeGsww5u8ktXie2EkPAXR8+cICP2a7+fqR/rhG8z0WrHxMloQF4sk1a7Azqj
dj7kOEVGcyvLlKzCNlg/9+kxCXtg2KSxHbXByfedpbtOk9GMGMtQ3UQrJEsF
vaSWwM+P5WAk72oF54+bbN/OkFHNPqm5la0myCFNCduexfEp3yBUBk0wKdsg
OY/NcI6BxSK4ES4QXvqTkmT09Y7FoT3sDcANq8nd53G8EWezbExqQXPxZbGi
FBnJ3xhNWaypgdC4sqYm7KYjGeOT7DWwsuQwUylNRkmXEqrZpqqhK/GzQLos
zie1Qkc/kirB3VN9k0WOjAROD7Vt760EYZ0nr0OwbUsm5ZiICgjZeyfKTp6M
Xg4EebxKKwelsK2fkkBGu2/p7uiofgKrt2+9KMB2ZdLzujBXAlmKnYUHERnF
qzzVPchSAtT/IkypFbHJRb9cg4qg9Q7H8wElMnJg3nJRzcwHl+veWaBMRtwp
ivb/fubBoZNTfpXYzC2d/lev5MH9xYzTiRfwfWnwpLfalQvyt8RSbquQkRL7
VaXWhiz4qvDI4zX2tQt/r1SdyoJUntVrapfw9zVE2QQVZcLmeC3tSVUyetTu
s1+/MAMario7rauRUZ7DEYeqrMdgJ5an6qiO84eQjrFeTyocYGIUmsNuEX8D
l1dTwLtraLzrMhlpzny4EmiUDCLZpyulNMjoBZR8dk5IgomA2Ohi7Os5UabM
k4lwXs5IkXwF77cPl2iDcwJ8OtB8kPYqjtc3v1/6tsdD/O9Da57YjT4rR3S5
42Gt8mORyTW8/6s0Lu0TsVB9zJVd5DoZVbF7pXZFE2Cxc+xbMvZW7SnXB7QE
sH8818ushfd7VPGoQQAZ7mRs3vsPm0xa2F0VTALB+zcNrLTJqISvPoNmFwlG
jNsl3mCPtvLde3f8EUjsD//cokNG0/wHbd0cHsL7n4ttp3XJSMWQX6s9PhrI
I1dSc7CvkUi//HqiYOUh2/VIPTIaezth4iUbCWW06Q26BmRERYzvT7N5AKV6
2RIj2Fm/q18/rAqDkoL8oquGZKRaue+8PW0YFGiUJ18ywvEt+MrzRG0I5KVV
s3ZiG8zStlZwhUDOSl0kMsb5LF+5yMo/GDJi23ykTXC+OfD1YrNxEKR96lp9
il2xs9dl93AgpEr12UncwPntnbnpZ/VASJweMTpuSkZ+7b09xZcDgCQ8L8Nr
RkYZkuwXT2/4QYznQmUSNr16ANF3xA+in38V5bxFRntTlimmhr4Q7vCLe685
Ga2Xys+Fj9yFsJa/RBT24uKcSDHXXQjZt8XEcBt/r1mO1ycLbwiopt+gsiCj
zJ/mfnN7vOA+/a4797CLKL0msg6e4Gewd+kvdvi+WzkLQx7gvbl/atUSx6O0
gv6jbHdwuXCscd4ax/+9GWf/UDdwij9x5pYNGa19l7/5nsENHBZOF7/FTlB0
BiOSK9hEy6S8tsXx4PHm9maRC1jNKLBp2+H4q1Y2+iDvAhanlKNeYIvdybGs
LXAGs7HLvs/t8ftMVAc49juB6RHN/y44kNFRvYS3zAaOYOKtY9+GLWlavAOl
O4ABzw3jBkccX1p7r5LAHjQtnGRLnMnIkIrvO6XdBq7WuFWJuJDRty0zZd5T
NqDB4HU8F5v1RX6EW5Y1qJb4H0xzxf0FjZXB+1grUNkKpnC7kZH9n+/xT9it
4IJm+K4E7LBaGYnCREtAP0kbj+7g+1KbRlVTYgEKKnF3druT0Q//th9hchYg
l5i0FI79qWXMjPHlbZCSy5oK9MDrvadamkN9G06HVDXe8SIjngXrMc3oW5DM
l/Jt+f8O0bU4KnULaOuDBGy8cX/gp9H07JMZTCxff2ByF7/f9Y7e4mUzUAqX
bniNnZ3brKK7wwyKBQWWNX1wffCheWnjeRPu669oXfTF/RHrVScaG1NY+DEe
+gz718Y7hsefb4BW9LM6aT8yCqBySIizvwGH22L4xO+RkVOeZe7hABMYED2x
yOmPvV/DyXvCCM51sfOSsY123erq9zKC9Jub13YFkNFrRXifwW0EbrH9T7ex
N4+gC052hjAtXrVwN5CM/FvnaiX3G4JKb/LBn9hPM+qnhXsM4MCWbeBCEO63
3nCEnztlAEGJ16vNg3E97njEefaLPnyVkP48jb0WN+fDkqsPrdYMV4ZDyIjC
9XNM4LA+iO5Y8b8civsLY75LZ77oASV1vLILO5y0/ORzmR5YDedxNYSRkecK
HQ/dRT14aR9z+ewD3M9wKb3QZtMDGXrP+6XYtQ/jVvfN6wKz7MX5rHAyyl14
E5QVrQuer8T280aQEcxupVhY6MKcM7t6AvbVMTsDJwVdqM75UBYVic83uH/t
3F8d4IP+93RR+H4JJa/Nv9GBB28qOQKwIfL2q7omHVi5k6y6jp1bzC5YlKkD
RnuCfN2jyUhic6WgKlwHOgtsS79hvwtbkRx11QFx5evvbB7ieiljHUV7QwcS
30qxf8B+ym9nr6yuA9Te/JduxOD8jvYkRknrgB0rg884tkK2zeiEqA6MlXwv
uf6IjO5pxswe4dMBhUvjs/3YrxznL7qx6UDBuxZWFRK+/4rijE1MOsDql3ex
FZs+r1mQllYHfDljvGXIZGS8rS2hvq0N8+UexdXYMxWV4w83teHq5Rsz4gQZ
vRVIqRza0Ia6jxdYCrGrqobMd//TBsEAsQtClP/ni+eECpUORHOzez3G7h7e
Mg2g04Ff1RuF+2PJaKhrMKdltw6YXvswTcY+/1FBmY5TB55/6du7O46MereN
DxgI6IBESKVSGLbAR3H6RnEdSOVL9qCKx/fZom3htIIOBCzRublhz8z1FAVe
1QGLOleneeypt0L9eWY6oBr61k4vAf9uLe6U464DYlpq1s+xw5sOaflH6sC+
Q09vyySS0dLl/r3KWTrwc4nfrAT7aIxW4+9GHWgK/WNASiIjH+mzndd/6UCG
loXujmQyqiss5aDn0IWQQy+vu2PzTF2Q7z2nCxr1+eoGKWT05BHt76QAXTgV
xnapD3v7wNV7NQW6wK7tryyXivMBH+kT9aguTH3Vk+N/jPtV0boeO3E9aKlv
lyKwEwKJouybepAVJi5Jm4bXm9uar0LRAzt+evEF7CNcD4ypdujD1WVXUaN0
XH969XpOy+uDRMPbIwPYFru+1O7w1Yd17aeHyjPIiGbsj0jjlj7M8AvwCGaS
0b9M8vTABQNoX47misUOO5JK0//QACIfWLB4Z5FRG9Ws2KyIIXA3stGgHDIK
NGR0Kgk1gq0H/tsV2DuFD027fzSC9zpLG0K5ZHRLuPHLvKoxFH1r/7kzj4zu
hA0lnTpoAjGN4j/uYnOq2iWoRJqAW3jy8hK2w/bYovc/E5ARdPv0Ip+MqOMi
lSpWbgDf97fvFQvICO0ZEqFzNYUdTWqzVdjcaE88w5op9OkKTCQU4vqbSAbT
nWZgGPGy92Yx/n08pDUHboGcnlz3MHZqEKlvNPYW8AsVtCuX4PlH0H1z7/It
WGjybzz6hIyqT+S+58o3h4GIpdokbF8my0BuxttQrqdfvasU5/MQzfBEp9vg
vSL+5Dv2cza3UeKCBZg0JxfeKsP1mjpEUvupBaBI+rxR7KSk+/e5RC2BQXgm
rbYc36/g6SF5fitI1H9I8q/E/TCvnnCksg30JSaLbmAH6ud+yftoA5tv8js9
q8hIdkYrkDnGFm6ZtP9xrCajiJJA5+FVO4h9/IL4gl1awlvdVGYP3TPTYpZP
8bybOt+5290BRG/9NjOpwfXqsfSzf2xOYJJFuzGOLXhS/ZHKihM8+sASp11L
RnJ7B9zkXznDT0uxXvU6MrrN/inu2lsXaLa7dVq6gYw+8zotzm65wUqxU381
dk63c/3uuDsguOxreaqRjLy+7dsvftodwpzjk442kVFsWbnsNT8PqCvPPpON
XREouzJ+3BOWfpQP8jWTkb5EtPut956g6d5PzdlCRjbNAioUS28IejqRQsbe
y/UkfFLiLlSvfZRkfobztTnXogGDDxy4S2VH24rrM9tA/8VBX3h/T3JktY2M
Bl9WeFL3+gP7MyUHp3Yy2vOL7cp/LgFwiUqTfhHbKJ51i5omEEqC7GTedZAR
6dhNxUmpIJjp8Boz6SSjFLVGrv1vg2AfXajTBLYulXjZmwfB4PEgPetFF65X
zX2yGz9CoOB5idzlbjK6wHmxcq4iFCYZG153Y5847C1scDcMFKLHmFp6yKhB
y7iHlz8cGMiMd0p68TzTuVHr/CoKZEY4mUX6yGiHecr26clocGATzs/GPnrp
6dmNhYcwHKcwldyP4492THODlQS045c9OAfIaCFV4q5jEQnOcRnuJbA/Pd7w
plwiQ3LyHeWIQTLqC61iKaUQMDAV8JZ2COePk/efbStRYJsnxisA+zD9Ym/z
HwpYpBcUe73A33t49bWkdxycyHnLZjWM46H2gJjwQCJM7nf2eoN9tEbmy/mc
JAiLoprSGMHn1zpFOhicDHNuQllnRnG+lnP6PKGbCoSi7SnqV2QkbuzVIXMs
AxSerlPcseMeXS0Xr8yAJZHo35+xPymZrP5RyIQL+8pahl7j/lw/rPi0RRas
zfzUSJ3A89Npm581b3MgSyusfO8bvF9fJr5/Dc2Fa9372YOxrTiund0lkQcF
T2SmbCdxv+784PtkXD4Y+wXYnp/G9YBzgl41Es9fB3aHjczi9ZE9FWselIPD
w8dfLs7hee5F4eDUr3I4QH3ySj32uzN+ib8sKsBt4Tp7xjscXyMHhEIvVsLh
2oQsxw/4/NXkc8/troYR0WP077BlSiT+O3a/Gu6nNdjqzJORuhmn8afv1TAR
+vaU7Ec8f5yU89058hQidYSeMXzG++FYfX0yqhbOPa8W9MPOODOcuOt3LXyQ
VQn7jq26xLzy0KwO5IRsr7xeIKNWS9Gx9hP1sBC/Xq72BefrfhEbDnI9xDFF
szdjhz190fTnRz18+1E6lb2I//5vblx9cQMkWyLYv0RG/B7JKfK0jXDpzXBW
JHZD+SWUYdgIGa0/bV2/4vrmfOLazfVGuHI2bHAe+01MWITzxSZYz99/2mAZ
z5vXWkS6o5tA+5HMH4VvOB+dUovu2tsMDpfLOMuxxVzM5djUmyFkp7CkwHfc
v9jxSd8IaIbUjkRtAvtX7PGVmMpmqPZndqNZISNF1WW/2LlmGJANIrlj8537
99yUqQXmf6+VfsTef4LLau5kC2xW2Q/q/cDx+3aqjPl6C7C7zC31YLulfJmd
dWwBMTFdJulVfN/fzs1qhrXAhYVekSJspr+s4zeSW8AkR+HSwf/w71VC1TuL
WsDDrMoyGttXfXvy2tMWiOERCfmH/cTFn0quqQXyJlKznH7i/Cgvv2OspQVa
YlnaZrET9WJ7+Ztb4LVm2KzmLxx/NVnkk7Ut8G33xr827Lu7n9jvedIC9L3O
PGfW8Hx69+u9wbQW4Audl8nBXvTa4AyIboHzioaGHL/JaFI955O0Zwto/hv0
CsOmo17VYjFpAZt6pfjf2Ez5jq58Ci0Q4FFbbfMH579XL5bu8rRA4mmx0TfY
J88Qywq/m6F8OeOH+l88DxLD8hFDzfC8kGNfE/YlE+c8j6xm+CuwrZG2juPj
E4NtKWoG1pk79ns3cPwxHmeU3tUMoskLEQHYy5zjee9HmsCIdaTbfJOMaNvm
6ziMmsBtSOXjKLZVkFjCuwNNEBnZSHPxHxmt1J/6pzneCI07ctHRLTyvntaQ
y7jcCDz/eTUsbeP6zhNTmM3bADOjvKXuNARKfBgYuye4FszjbOPCmAgkz8Ws
n81cCc+7/K9T7yJQQtO/1d8VFXByLY7ZD/vnR9ET3PoVsKnXHuq6m0BDdm/W
trLLIYHroKfJHgItPqw7wE0phS3V0xLj2P7FDs4yS0/A4u6lb9f3Eohq3G9P
2sUnIDF5x+rSPgJ9eH807xZ1CQykDOhJsBIo8uWhkKC4QpAYeM/6BFuFL6eM
oCqEpM0/Q0fZCNRC+SN2wKkArG4cvsTLTqCQ7h2X0zTzgfrQ/fMMnATimXjR
0nomF85lneSaOUCg07GWxb9cMiF15OKYATeBzlkHK7rRZAINjQlpFNug+Nhr
5cQMeHk7nKH3IP6+tw/LY8npYH/43Z8qXgIZ3eb7KhKRCiO6v6vF+Qgks/+0
3evhFJAKY3YtxH7enapaxZcC9J+lv6QdItCdLJ+A2s4kyCgg3kQIEGh3Slrg
TpQA9G8K4mgFCcTwX0TQtYJ4cGR8dt0f2z212UqOPR5k7JZ63YUI5LB3/uKz
tVh4dfxCw83DBHpsrjAdOE+AnImR5yR21HLQCpMNAVnRLhK6RwgUxNipW/aN
DC7LqUXqR/F+Vnj9pacjA1PZr2TJYwR6nV72TbcgBpZYSPwF2D4Wy60/Fh/C
gLtoHrcogSqc9Se4JB5CjMzNim3sgXolm7zBKGDpft7TK0ag9uTKoaPnI2BV
5PYVuRMEKm73KghMCYeRqH8jpdjcTvyuJTThEHtdYoYiTqDrPYfVeGfDgOtt
ys8bpwjUHPBm9mhrCPyFcz4vsZmumj9tRiEwmfVyW+k0geJ2qKoHdgZDqg3d
LhEJAv2QKHFWeRUEh346CayeIZA3N0fs2IFAoNJnzLc4S6B5GdF9sxUBMFef
LTaOvXpG51SURgBk+U+cb5IkEHuy/cd9bP5wZJfS1bDzBCKmPL1nkB/sdJoe
/YPtucv/W3WCLyy89DS0l8L78ZHp7rtVHyiKL7bQlMamv+4//PQunBDk8OWW
JdCteX/Fi/ZesCe0jOohtm+qP/r3zhO+fVYL28Y24jtrccHEE8qf3CfPyxGI
47ziryPGHnBWeiG/VIFA2v7S35b87wBHatAJAcD/fzj6efe+O7C2xVNFwT4Q
LakTleMGdZ3XW7wRgaxDDfsfjLmCnGbjmJISgUL3F86b67gAb5Wu0VPsi0pU
mVK/nGGLY2X2qDKBbISYTjmqOEPrlPDS7gsEeqLQdjtrzRGUrWOoxy8S6Gx5
lTdblD24KfQJa6vg/fB/fNPxmx1kcdCrvsD2dTnAoa1nB1Sd92J6LuH3NZtm
XThjC6dS6iuUVQnkqqnsz1ZgAzfdfo09wz4ynVj4H78NtPA7HqxTI5B6+Qk3
bz5rWP5doHBWnUCDly3WP2ZZAc+L+Vvl2Mkjanq/Ra3A955JQcFlAgmqRz3P
vGgJUpOXJZOuEEjX7/Mzt6zbYF3xwIDjKoFMY2cKTRRvQ3x4hy8Ze7Zbx//0
B3P4dU62PeIagf6mippfPmkOwnu8PtJpEujSm9D9tm9ugc7HSoYgbK7SEm7h
sFtQSRG95nOdQPQmfz8e+2wG7+ys3Naw7c0stq+nmME+paw4Ny38/scnfEau
m4HzyoFpO20CLds4kKSiboLYFUZbY10C9Z2zV7d6eAOMhS9Gj2OTJHt/f99/
AyI3Asq09fB+HAyqvpBnAl8K//y6rE+gE00HbZcGjYEr8OyB59hfmmKo91ob
g6qBi9wFAwKhnFW2dBpjyKNfCJIzJJB+Ot3iExUjePVWKK8O+8wtVlnaZUOg
fXqz96wRgRZqSNbu8YZw+/b43hPG+L6dfPJdf9UA+Fu7U3lvEGitYk5RZUAf
riXsaE3CFp5lkwqM0If7TgofOEwJ1BRPzGmq6cNbnppje24SSCGNNs77pR7s
/vlDIxK7lHn9YE2CHsj1n3ChN8Pr3yW/oX1LD5Lv5tZsYR/7aFgYvKELvZrv
3vjcwvfvgNvO7X5d+HOU998adsfeg1mlabqg/zpW+bs5geRyrviFqutC2JOX
Vva38X7b6agnC+lCTcjuyM/Y351u0Dzb0gH2MyEvZy0IZJsxGMWN5/EyrexS
Q0sCKY6nPBxK1QF1t/boUWzLSk/32wE68JH8zu6KFT7f44svRy11IKCCSq0H
W6zq6A3uKzpwcPjQUUVrvN82JqOnz+lAzYoCXSM2qegjL4eADmjuM/1w1gbv
p2mjTCuzDiydvNdWiv37EN29k5vaEHYtNV3EFuffe0Lnb37VBn7nxntZ2IVa
D15cntGGxphJYx47Ao0XxCauDmuDXulf6XhsoUQxp+s92vBjkItrnz2+n8FI
zKpFG6KXz69FYNN5tVaL12rDUWb9MRoHArEwtWUWVmhDu5hn5T3smadsGq+f
aMMNjTjSb2xKzS3W6mJt+GNf7eTqiPdf+I+2EjYlalRjCVtVx+x7QIk2iBev
ilo6Ecgk3KXCpUwbevtYGGex/eLnfFmrtcFi8dRnA2cC1evYnLJu0IZtRs2u
EeyCB8vrzu3akHzMOVvDhUCPWrLZTg5og6RaTGA3Nt+3y5/yxrXhpc2Tm8iV
QJ3PgmfezGuDffiAfAN2wlRlWN9/2kBfsHTwrBteb2LQHT9aHcjsYVp/gn3t
ukjrf5w6IPf52MTROzjf7+gKP3tcB1yP2MQedMf1MFzQWshQB3arPHCLw+Za
Pf1iyk0H8izzNPd6EMhM8qqAW4wOKIZ2iUdgD/TsvPG1WAemc+Z303hip0mH
aPbrgFcnzZIf9kK8qkXuVx1gnRfsXcM2HP75d3WvLqgK3Qpd9CLQjQVRv0QT
XfigFHDbwhvny4qDsVRhunDfPF1xBjuoi28lqEIXqjPf/hu+i++LfVLR9h49
uNa2OXXZB9//n1kFexT1YHHuYEMX9j9Ks8ktDz3g5zfyrPfF/UKN33Gaj3rQ
CHd1zvgRSGMzZdGeXx/0biZKPMHea9S1oW6qD9Fpr79l3MP5l3+nQfY7fTja
8muA+z6up/diQ2WPGkD7W/biWOwd3Tmzoc4G8JtH2zrcn0Cc6x+uuTAYAiHn
dnFHAIGypR3CzxgagpgJWcgPu3uGifp7iSGYp7yYdQ7E79dL+S/lhhEMHdAw
0A/G8ePm4bzjkzF8sP++/Rx7d9v93R5qJvCnmciXCcH7JUDLx1ZuAkLmb9Z4
Qwk0dVVCgP/BDZCq9kt7hO1X8cyw/vcNuErPr0IdhvNFloDMmL0peBdZxc1j
X7ope2DF9CY83GSU13uA68fFm8UCMzch6+qT+R5sr7X99CmnzGBg9b8zxeEE
kqzJvF9bbwYCsoEjrpEEEm+38Cz7eAvOPRT2+YBt2tH0/NY5c9CY7RHQjSLQ
bZEvO3wjzMEzeI+rVDSBahIP+Yqevw19/Sl7tx8SqIzbivCrtIBZXqh1iSFQ
dWLsTUsuS/jp/N70PXbRx0o7jUBLOMR+rLTrEc5PbF5ZjiZW4G5SoxFNJpDU
TlF3OxkbiCg1/PkP+3n8yUsNDTaQRvUvxZnA8WN0RapLwRZ6c5SXtCi4PkiU
ZHtp2QHf8suIA3F4PW42dSrFDnAG3E9HYUc2s5i5aTiCKnn/m03sXXMjIYqr
juAmaSoyF0+gC55V+zQ0nKHn3lJ3XiLOXxPrTG/4XGH6RYwTVxLer9E9r0aC
XWFVQIIzElvu6/nq4iVX4On2tnRMxudVnKih2ukGLnvoac+mEmg6eeCCcYo7
hJoVFudiC9oZrQQe8IDkSg3t/Y8JdLxpmHQqxQO69ChZ69h21A5rAYWewJ3O
r9iWTqCxY1yf/X96w31LyzC5DHx/rzCU/U67C++OF/XXYu/q0PMMvOoDBXVn
9EozCdTL+yhfs9kXzo2o2KdkEyh3quhY0dv7kJwYVc6ZQ6C3/k7KAdX+8M/0
5S8y9iZdzpsO1QDoXDIMCM/F8cF49N+Nk4GgTecY55GPvy86iEx1OBhq+ism
V7BfBVANXy4OBm5i7ZBDAYFoJRxtNCRD4D1fQJF5IYHufe6UqtcJBRcpyrNr
xTi/h3S9Du94AGNb47T92GSuA0SlbTic7+JRVykh0IuhqV+n2CNg63remNwT
Ak1I3Pbz9YyEaPv6L8fKCORhPJJv5/YQVk5viediX396WkFfPga0/yi585cT
6O6fpOsnmB8Bd+jAFmcFgQ6ZqjxZvkGCgrRZNtoqAu2cI121PU7AbkthQ39s
mwRwN8olwPm4bdo69sVpL/a/AhQ4V7cq8qOaQLFlGopXhGKha5hOYaaGQFkP
PxbVqcSDSKJ6sGEtgUaO1664v46HaNNHz8ewzSvevf6BH6qzxKXdX4fPT8yw
83h8IrynFbOpayAQtU+W1m2WFNg6r0UQLXi+mZa6GqWUAdOnDmbSPSPQx6GW
fwxJGdBwbL7MG/t8zEZrwEoGeBz0HDRtJdDN1YY0+axM+LqVxHC8Hdc79RJd
mn3ZMNX17n5HF4GMhQWNA3flQV1L0cNz3Tj/nlMaXHfIg/jaO6mF2DbKLxTq
hvJAq5Cu4VEPrmeDeYZdRD70RR/7ZdyL++P6sGaVg4VQp+1q/3MAf79mgqww
XwnEa8j4WA/ieanUl6PWtwTcL9JETGI3Xh8YtJkogVPn4/Jah/A8MEuKfRPz
BPK5699Fv8T5on/DoG65FELYgla2sTVGd6vtVSoD892Xt92GCfQt9fTGfGwZ
8G1N8xiO4PoWHDEyw10O8e+oDA6PEWjShy+BsaIc3Cd7rRKx95MvHz8yVg5a
o4THrlcEkhX8Iyy1Vg7MXcKUH9gbPuU8vOcrYLF5OdPiNY5X16TlOd0KeF5T
Uz6OLdTeFux7pwJCClSHmsdxv7kYzspVXAHmmSxvT03gv/9FPcLcVQEoeXIp
G5t7k/pF69sK4KNkr3O+wf2HzVvZ47/wPB3lwBiJzTn99tKlXZUwGSLJ9Q87
4BDTlX38lVB3b+uIyyTOH3zN5KAzlRDv2SP5AbtoqsU0+WIl3HEmXdCbwvFt
NL6prVcJGdPrKyPYtDH3qj5YVcKAmuXja9M4H2gLOb/0qIQ/NS/UBrB9dqNr
XMGVICwss6b6FufnUEbv+phK0CTnZHVhGx0L3VmZWAl+W3uuKc3g/28QsLmd
UQkF9nc3WrBDPFIys/MrYWziQ77sLJ5feOj/Pi6pBCqVqzp12K8+f6ddKasE
sao6Ksk5PO/QGaQnV1SCAb/QkwrsiIuzQunYoQ8fGoq/w/XJ9tV+6vJKqFz/
TVeM3ShifLITP2/G2rzy6Htcn+XJfF/x+5heDZjmYEfvNNPxy6yEc0rndwl8
wPeh6HD+3aRKMC/LrH2MHVJKc3bxUSXE8Oy24J7H9a2G98BYSCU0RHjuS8A+
+2nARt67Ej6vzTWxfcTzttGhXWJ2lcBucdmWhG0Vk1Kab1QJaPgpB/MnXP9o
e93q1CohsTjSif4zgWh0ecrqhSqhk+sXdzC2W+zAtYY9lbASerNnG3tz879J
1z8VoGZ2lv/vAu53u4LoxJ5XgOdg2oDHFwLVGZzPUCytgCwZxrur2B4iE41n
KRWwzj4zvLSI929c2OytYQUcCVK9b7NEIJ08ibf5shWg9b1S9CP2bpG0ubs8
FVDc+yB45iuB0jnP0ZpNlYPJ/dOSw98IZPH7bJHVtXJo+RySWLOK42Phxdyz
M6UQ2HD8ZuA6zges3O/+2ywALpe73RvYm3P0OqHFBVB+uOeE5waeDwNZhL2M
CmCOZL5pt4nrjcLFM/n1+YCsk5J0tgh0tccp4Mr9PNhi2zl2dAcFBWffDWQQ
yYH4Xh3ZLGyJ3OA7g3PZIO6flcVDQ0ERmw/znZKzwXRR3pWFloKc9mzJ6uB8
09zqvmeDjoKkKjwq9u7MAj/H96pDjBSUEEGlbiiYAexCp8pVmSiI1vaAvOZY
OpRM3NvfgR20R1b8k2U6TCsf+FS7i4J2swY7/olJA1luzeBMZgpyO7Cgm/En
FUZePF48uIeCtAqC/n5OSAW70KXr8diS15iqeKVTIXkljD9qLwV9sn82pB6Y
Auvdzc3uLBS0NyEuy1gkGQi/XYe/Y/daWI0/f50EohKG0baseL2tY5m7HySB
0eOfRqZsFKSpbPx153Ii1N85/ucSBwX9qai8azmUAJrH7t5sx37faWBwMCoB
Fma6u+U4KYhxx1xKuFoCcKmbx53eT0GNF5Je3e2PB2/+JImDByjIdEit/cKH
OIhksL/9EPt0x7k3E+VxkLoiF7uNrfyMR+Klfxy0ts79+sBNQd7drOenBOJg
pKDyiN5BCjrDyru28DMW5kkh+s+xc/XWeq/0xgLjLZH6Eh4KMqITdWPxjAUe
tfUvfLwU9KqETsfuaiyInx7gJmOvFRyb3yMSC1rULn4efBT0U0bB8/QsBZIz
a0GBn4KO+adEJZpQoCQiwqUce2JmjHk3UKDF1ThTUICCXj+SUK8XpMB7xe0d
OwUpKJBmb239MgE/jw2fuYvN2MWszPiKAHrWbIsl7EeMSYeimgk4/l6l+4UQ
BeVTXM4LEAQo9HH9VhTG52sr7HLmPgGalYtHq7G7tn533rEnwDy5yeDIYQqK
4Uk/+86QAPegmIhEbGY5thofNQLC7MwamI5QUM9KpwLIEJCoJbHkh10kZEES
FyOgSIaW5zu2+DoDoXqIgCbB1xq3jlJQf1K/6EM2AoaYCu6NYm8d7VTcZCBg
bvVu6UURCoI+ppa4bTKsTl6ercWmPC8NNPxNBtoO3n2ixygo/evTjEsrZOAs
/o5SsXe75n43WySDCKXNdY8oBV25TjHO+0gGGV9KVgD26/C4Ya73ZLhy23J0
FXs/W7tC/SwZzC6fp7U8TkGRS+Kk8BkyuJ1hlBzHDvzTXfMAO+TglKWaGAW9
Wdg6XIf/Pp7mSXwjNoue4PeD+HkFS/d7TpygoMzLL8Se4vc1jGr+ScemfZX9
NxSvZ6BR8BirOAVV/pN3IeH1zmT/NAzBPjwsW/waf89KVHfkGnYHx/pLIyoC
drgnNtqcpKDw1++6DjERwG5i93US+8fhMzuOcRBw5IIc75VTFHRVz4faR4AA
KbE9V59hf69XBs6TBKizz90/fZqChLMPnqdWwP3SfPAchwTOF6RYo+GbBAQN
6LKEY6vkKxe3uBEQW31UaR3bumrEcdcDAvJS/7o5nKGgfWMsdU2pBNSF9GfP
YMeJDKePVxHQ5/B4TPMsBam/nJO5NUDAtI4zXQf2/cV96aafCKA6zGadL0lB
qxmHu/v4KGAWGCYpdA7fv8z9nIs4ftve/qVJx/7QGn/wrTkFguLnMuLPU/Bw
79VwqxTH86q2M6sUBcXf72GmG6eA8rUe+RjsMIfG2xnUsUDLUDoZKo3znTz/
sWWTWLCwECiklqGgPA+NyacPcf/XGut1D5udJ3UppzUWwu76snvI4vwAOWvC
J+KAYUn1qoU8BSl+6h4XE4wHm0tNPHPYXT22J1Mt46E3++SSsQJ+fnLHeGZx
PESacIZrA96f3tdEFSTAYl2E3gtsd5XRhvmHCXCZ45/wZURBSQJlsj9nEmD3
0Ic2JUUKopJrbv4TkQgOovqkFux0IFmwzSfCYFifqYwSBaWavbQ0UkyCGKjY
OK2M98ckv/s5XTLsq7gvKXARr2dGqz+/LgVcmFdpHmPzOfF9KhZPhWFbyxEu
FQq6ELNt87ggFQhBDed9l/B+lh46W1PwGFbvP5OPxhZXXVZiP5kG2lMSuxlU
KUhJ+VH6YH0asMceKNzGlmIZURucTgf3lWgvXzWcn7956xbKZMArDSqV39gs
ZRKyBhEZEE/3+f03dQriOblZIS2eCVxe1TwzGjieqnmCFxKywHv06JLhFQqy
vPzj7s2/WfDmZEr9K2z60z8O9N/IhuSFQL3BqxS0LXeApv9kDvAYXSM1aVKQ
xf4lA5f1XPCraTeVuo7v90dvFcIjD96ynjtRjT2kpdAk9zMP0vp5+oq1KCjt
iOyA62Y+CMgv0qToUNBoab6LhkwRbPa/S9mjS0GxLl5913qL4LXRmzNB2Gm2
hy68NS6GaO/nt231KIjrWphyW1QJ/KnK6zhvQEF9mS79z/eXwahSmnExdt4u
W1uJzjIoHY77j8+Qgu4xJ584J1MOt7+HCNEb4XrTVEUjvlIOQ6K3g8eMKWj6
5hSz4J1KKKw3Oqhqguvf6aW5rIlKCFHVqmrErlHmt6ZDVSBtpfgh6waOv+Lo
cH32asjJPKTsepOC/v16bGky8hR8uKZ37LlNQTMpvuOeifWgmz+aHIhtrvFe
opGzAU6d65f4hZ0hY1M/H9cAH7UbzKctKMiERfKvU3wjaD5KbC+yoqASagvz
ktRmOM5HMuKzpqDNgWMzbnwtQP/kwSoZW+Y4l/Vmegs09nkK3rWhIP6jXxMK
M5/BEXrdoEt2FJTNIszEO9gK1HEa3I3Ywd3iU/eY2mBa6EKluD3OL+YRTv9U
2oCseOY9hwO+30x0zV+b2sDhpahPBLZX9nbhkbU2ULkpyPoPez+L1wCreDts
+rEozTtSkNWdyz9ik9phfBfjpL4TPi8Njm8/B9qhMpnKrR9b7LT55+StdrCp
+55Z6Yzrr/hI/nWTDlC+9Fn6iAuOlxAqiZPhHcD3emY4CbvZfHpquaIDRv8b
pA50pSDWwotBFVsdwN1foLOKPRCXYvCOvxPMsoLzb7vhenLg6HoV6oS8u6br
Y9gyZXzDnKad8FVT+orKHVzfTlHF/fXuBAkR9oxa7Jcjzx5eIXfC3e1vqyLu
FDS5ZMlDm98Jra97LyZjy6PY5X0NnUBfmpO4ywOvJ9Hlt21fJ2iE+i/5Yecp
tenRTXQCxcRI4Rv2RDCTxtT7Tpg8I0m+6Yn3+3eP06fFTuDftW/+JTbBemhE
YKUTrN4vnlPywvf78DmLqNVOeFLfFVGFvXOl64gg9k9SxrSwN86/jErkT986
QcbG92Q8No26UN/UQicEgF7Qzrv4fc4b1nRzndDDefqVN/YFwpuwHeuEPd92
iSxiN3Rf/7i3uxN0uj75GPtQUOJw1Weqp52QnNo2OIAteONp56XMTpi7k8qv
4EtB3fMdPCuRnXDkstedMmzvL7MOO906wVFQq5vfD58vdUh7ql4nVP8VO0Bg
9/H2ZDyT6oT1lzsdaO5R0I1Ny8xArk4I829m+YTtEMJ5V2y4Awb0Ei3071OQ
3HLUnFxRB7CJ36l9jl1mzdApE9iB5y2RG8X++PlF+9f1jnXApyqacp4A3M8w
+N/MWm+HE1EzO2Kwmdx0iyT72qFBOrbAJZCCWvTF4giLdhiL3/5PMhjnL9Nz
/3rC22Dn9deRrWG4/zgTNzR+6Rk4dQXXvXpIQePK/sJJtrVAw0JVqBlDQcP8
bkEMn2sg0cQvqR+bSJtOm7Ksgbb/3H3aHuH4jFk7uGH9FNgFreSekCnoPzpN
ya/+VVDo+F5MhKCgKM4/vppMVaBQb8qbjT0W6eESHV8JNpr6W4kUXC8nD38t
qq6AxvuqrSFx+D7Yd+3fz1AOmn2d5dvYClpl3FXKZTDPoZjpE09BhcN1cMy3
FPY8kQ5ySaCgS0VaKgu/SsB8SvSCSRIFhXadULvCXQS/j+SfHcdudPw7wuhY
CNFuQoe1kimoWm3/GqmjAJ4y8tCrpuD6evjduwnffGCQYn5+5jFef9YNVw6u
XHgcHFFXiu3w6pfy2oMckHhBV3gsDecXMfFk5Y1sMLbaijiUjvutpgX3r0tZ
UBr7/fKuTNwvyP43++G/DFCes5cLw/78uuBE0r0MmDi+IEadRUGe7MXrKkwZ
sKNjjvk3NjOvY3q6QRro/hh+8T6HgvS8kc43wRRYlLvaeiOXgmrvja6lmSfD
/fC+8gnsvxKRBjr5SVBwqIM8lIfX99TwsTEkwuaVau2GAnz+X05PvMiLA3LS
qQuShRT0a7v7QdKuODjyseRsOTZx4Q/XQ/dYuOaXy5FXhOvVrPN2lBYFsori
x8kluP/MS2OVkSNDhUgCmfYJzp8OFqnjPSRozUu47IVtUp112FmPBDNZic9M
SnE8d/eci/wTA9wpyflHyylonU7ynvFwFBw7kHIrGfv2OIfjHfYokEpIOchc
geuFmFLiHZNI0KOkPlrFFnNo4qxaDwdKVJpXcxUF2dzqfEvjGAZZjOmnT1Xj
70ns5RIbC4XKB+lLWdha/conjSAUXgZn3Ax/SkF1W3lqZgIhsNsv65J2LT6/
f/QCnixBcHA9i7ob+7ezhMCh+EAQ9c5ulKrD68lW/W8fXyCouuec5KvH+XRP
IMX3fACEOOTt/9JAQcZa7G43ee4BZTFv2LgRf/96MsOgrh9k2eRHDWFTpkcS
iVhfaLUo2K5qwut52s8RL+AD/0yKPt9voaBvy1PlXzy8YPdUUeYPbLa90rK2
rz2Bx7DY2OIZBe2ZpJ2Xl/UEGd2SF2qteL3VmqseLB7geaW0lr2dglqp0t9w
LbtBaH+p6wPszSt1TMjRDWLVyo6vYxuLaeUurLhC5cXy9NkOChIwMHhjssMV
vslXPijqwr/PPfs1GO8E/xorFXm7cf/v8thPvs8RdstUbTzC/njj3ystGkcQ
PVft7NFDQb7yNvGTofZgLV6jj3rxeb7QC9J/bgOd/AZlTdiL9I0Uv/02IMi2
Ti/dh/O98u3wNXtrmP4tX3O6H+cnzljyRWErkFmcZS7FVk+81zb4wBISpgMt
RQdwv34ws4RlxQK02rrYhQYp6NrCh2YYug3lVdYO6dg72YpsPijfBuY8xs6D
Qzh+/OSsapvN4XnklTvsL3B+nepK8W6+BQo6r4bphino/PWaCKmxm5Cq4nUs
CPsTXeXWrk1T+Ct1IHALW9e/v9db1BSqeW+c+j2C65ftSJd2sgmw7tt+cGcU
x8vIp1WTKWNw3pE5+x377OfmNhlBYxD9PB+zMIb7HdKMb1+rIYS/Cftk8YqC
VAcDdx7lMoSP/SIK77DPtrX3PHE3gIxyh+U3r/Hv5XT7EuT0gdPn5+X+CdyP
3d/V95FGF9wd4rMvvcHzfVJPrneADgybSm10YFe6DKVxUutAtLJfUdMk7s+n
5WI3mLVhUZJvh/QUnodlhvXpk7Xgkkir4VPsVsfRl9nHtGAHMy1j6TTubxMk
3oloXwez7Vwz0bcUdIoroWXmqyY0/7hUl4fNkiNp1RqhCd6vo6zTZ3C+VO0j
XUq6BsvpbN2kOZz/dsSRqhc0QJ14ysv8joLo+LMMO9Q0oCBE3yMCu+XQrdbe
sstgbpsiHPSegnRsP1XzRKpDq7G83xb25AbjF74tNeC9Ojvq8wHnFw3ZxQee
ajAhIRR8Z56C5jpq85ndVeHc4a7J79heUhvMi38uAWW/tYTDRwpaYpCPKwm8
BFc3i95ZfMLz18i7nzZpKtDZJYH0FnB+yQp/tk59ER5S1Wm9xD71LmNHV84F
0JOVt1T/gudDHr1rD9QvwEL5pUiFRQo6M+uhl5emDBVLA6l12I4lmsYzGsrg
c0SrTGKJgm7en5xs/6cEzKkmY0e+UtAOK7fai9ZK8Pr1u08Z2PZKl6+0HFKC
DBbrv9zL+D4VDFQnTyqCxANXvr3fKIhTe0jpkr4i6LmF2fz+TkEMbtZPRu0Q
HHqyy9d1Be+3kn7oxFkEC59JD5ewS5by/EapEPjcSKmc/YH7w/LzZttyAMqJ
/F2GqxRkOpraIjmnALtHc8dHsUmBpiJUDxQgTbV8s+c/ClKrF1v8MyMP1sGS
e5V+4nqhHj268UgeTrU0CDRh9/nUMatckIf2M10q5b8oqMD9LsvdGjmIclI3
FF2joEOKYQ1K7nKgU/jCPgdb5rtu835JOfjMN0lK/E1Bbb9OPMp9Jgvlhjez
Wf/gefZ6qTxEyIJP7PzTaOz/ipuVC3VlQfmF7XP6vxT0uDDy25ywLOxm+j4Z
gG0aOKD0dk0GXl1wX17HpvnGXhDbLwNp/n+33ddx/ij6FfovSwZO/aI5bLtB
QXb/utWaDWXg78mI8x+wmxmntqikZaDdbo/6jU28/32iAy+4ZSAql2Iyji1T
l1V9ZFsadOa4nK//w/l00HGW7pM08B5MC+zHfnDogpXtC2n4pCsUe3EL58fW
t+ZXGqWhjFSQ9wxbrXv125NCafDuP1EvvY2frywr/CBZGhTpq/qrsA00nHle
PZQGJkWpmRNUsYjpl8oPSrA0jPo2r+RjG56UMW71lYbUGiUaQepYVN5rb2fq
KQ2WP3o4UrFBRvG7yx1pEBe7IsK5IxbN0f+v4vqOp/L7AwAuIyOEhCTJKJFE
IorPkT2zk1FCdrlGsrIJZT/PFSEK4YvsjMyyRyqphLIKiaZI6Xd+f75f93nu
veeczzoVfuveirDm9FwpGTu0tixh3VcR2vPOGLDQEehTv3S7d4AixI+Pn4/C
3jYsmeMUhtfHa++9iT2ilV45GofXZ/Ixyp+eQL/rnWOfkHh9Nz3Sv2H/uqfI
JJeP19f9tdiDgUDamj3Z0rV4fbRXH33AZtl4XdvSg9en/GfIbiuB3m27Fjo/
idfnHz41hm3f0Xmw5pciGM7FN+szEsiPMylEiVMJUkyIjBbsVm0LcV4pJRhp
zb5yhIlA/EecNk7rKQGf1H3ju9h+ScwDi+5KYJ1ZIcXNTCCVfivvL4n4vBkb
mWOw7xb2v/esUQKx6YF2VxYCBc7TPGJmPAEup0ez32J/rex6rCR3AkofvQsw
2Eagmch/y1yOJ0A2/ZuMDCuBRhkG5+b6T4Af/R+2e9i7+R30f9GdhAYvhkVu
NgLdk9lyaVLlJCB9vrtr2MlyG+rhzSchqmFfiBs7gazkXpD2W5She7+k1Tj2
tEM+vbO2MhhuUeFq206g4gXnAeH3ypByWWtZhoNAj5ivfN48ogIjb4367mGL
r1Q80opWAes6h4jrnASiq2js9z0OkCNy6dw6dkzLnDmRDjCd7KfkzoX3x4I5
JP43gIt73DfDHQR6Uz3CdswJgZ/QA3uenTh+eA9ZhRurQmNCvUosdl/WWvJq
iir8/d3O/xv735BP1ciIKkS9HHk+wUOg1+fvKAjYn4LuU5Plp3kJtPlm+3hZ
6SlgqfgY346tHPtxaW39FKTE/z5VwEegzhppbtZsNRj5RbeXdxeBLnEXXaD9
rgZ8F9k2YrEZVTmHOPTVIQeEqj348e/nJOjOMWpA6Q8NETkBArmbmfgEFGvC
lwun/xVgfzn7QUdntxYcfWr5lncPgSSTHZ+IpWhBY7F72ga284et45lx2vCX
54rnJUEC8T3IIUJYdQBFhei9w2b9yyjOQOhA97kUusd78efq7ffTK3WBZSDz
nZwQ3n/CmJdBWw8MFfObCrEN5e97PJ3Rg5EdD33i9xFIN53lgeYhA5juGZ8x
FiGQpcZxI1k6I/AtuW47iC16u4HZxNMItt6UfaUtSqDwLcyGJe+M4ODp2D4Q
I9CTCp1DFYPG0HjkqHoTNsdh2F+rZwL6XJPN8vtxvkpe/Fk8ZAKUl0crpQ4Q
KDWBN1tl1hRoH05KFGM3TtTx6V81A+JWXL6oOIF4DDkmRTnM4aH1u/TdBwlk
PL1nVs7MAjan4kOYJfH+fvirZSd1FpIfH1uLwo4496tHdvUsCBe896I5RKDb
zfuCubutQMNF/uIv7DVL0aILETYwqjM16S1FoIeuYtZBl2zBRfKm5TL2A94O
cxb7c3BzeUpv7jCBtDb8FXLk7EBw+GannTSBZGbU6G1b7KCiUgHGsY/lNryo
MLgAL3wTZF8cIdB9n+3HtoTYA//G8V3tsgTijJAeLzx0EUrHZ1JPHiVQBue5
LfsXL4JKSyJrPbZC/vNqhwdOcCF89l+5HD5/vYN9l0xc4Jt9UoDEMQLZCb6p
mjniClHqSt8LsAtGn1Z68LlBEWPyhyx5/Py1oTwteg9QWlCy41MgUO9C9Zor
8yUY6Jt7k4ZtUXw6VGnXZVhJODEYf5xATi+uFWpKUUCe+2O1vxKBdPrbeXLq
vaHnZ4rUD2xvFldnIw8fsHp18r7nCQJt7+oY1jzgC9cyUzOdThJofF/AFama
K8AerMw9jV1+4UZhTYwf5NrOJ9gqE6ioMPBR2YWreF5VCTdTIZDG3rLKY7IB
YEG78PsptuDbD9wU8UCYn0nz1QMC+XbVeXmIB8G2+wvOpxCupyEmZ7ZpXQMT
KdLwyCmcX6Fbwm7Rh8M51Scp97BfdKRVh+SGg5v59xEeNXx+e3WsVlQjIOKa
sfVf7OST81o7qZGQmBKWQ1HH+bwq2bFXJwoyCx5MzWCf+3qZz5YW318G2Vz6
NPD+r/eN7Y6NgZapk/8paxIoDEbffje7Dn0/3ZcrsHv4fqwVi8fC9J4+33Qt
nN/zehes5+KA63JMuKMOgXKy4gVt6hNAMKL2yStsxnCQrWhLBAnqLKOeLoGe
7W8FkWdJcKrlVKKMHq6/4ollAQwp4M3+L3NTn0B3jLOUOr3TIET48KSXAYF+
uNx/ILCLgHh5231z2KviazpfHhNw91zT/X5DAs0eCvspeoAKz8uv1twyItCh
nTqr20QzYLKj8Nc2Y7zf8Qs/UpczYHH0pVIots/Mnr6U5kyg/Xe0/aIJro8H
JZraXbJA9vSXQVkzXM8mpbPHv96B1BWXjwNncP1Qoztz/809yKG7JYEscfzu
MPdUtsmHEt7uS9XYWQX3FGff5UMHiP3IOEsgZPOn8+1CAXxLmqJxtsb5czyd
05y+CEyPWPFvOU8gTS82SfHDpdB304PPG3szv97KoLQUTi2E8Mxgb5E4Ivpe
vAxk797j6rQjkJf6rbVbAuXAwf2ZJc4e18eIY6dCFh5ALOUf02/s1xxR9fyS
FUAzyMno7kCgltNFdjR2FbASLU9n4Ij7u/XxboHOCnCa1t7Sgh3OcUZD+mcF
TKpY/zt8kUALT9mnI0QqYehX6AaHE+6P3vk15YGVoGmWuh6OLdUjl+R6rxKa
K/J/fcNuCchUluyrBDm2hz8dnAn03+vsiI/LlVDq2vt9BBuND1WncVaBaNfb
rxouOL9EVOPFZKsgS3h5pQ57kmU2kTCqAu5QmuUDrgRaptu2+dqjCm685Vq6
hc0pdur4UkwV0B4XW2R2I9CumF/7e3Oq8PynMB+IvV332H73mir49kXnwyfs
B/WylKfdVeBmYDNr404gRZbrz76/roLp4svTg9gOO/rPvvpYBWe3hr9X8cDm
FHEK/FEFw/Zpkw+w/9358HJiswq0WwvGhS4R6AMKVqJnrIa23fVjKdhH7qyl
fmGtBgX/vte0l7GX2QTvc1RD+cj4qA+24NZBLimuatgvszIyi/2ELVI2lrMa
chK2vDD3JNBbrraMVvZq4Fnc8awLu8ZRtXaMuRoSNfc/VaAQqPBgAMs0bTUw
3Ds+WIQtf9OsZXK9CoL/6fbv8sL5b6wYMrZcBT+sbXvjsZmSGj6+m6oCj3rP
7g1s+z0lz9efV8Esd0Snhzd+/7+Iz0c7qsDGi3g8gU11OKyc+aAKXgwWthv6
EKjdsEVB8XYVdMT0Nx/xxfthftbC/FIVKM1MNOVhGyp9MfpsWgVV8KWB6wqB
/N3Ds74fr4K8Ne66H9iV2dp9kZuVwGd+oOaiH66n2zmdJN5VQnKlYtUoNu9k
WYd/SyWEuZ0rr7+K6+/OJ2ZaAZWw1kUpPeiP6+G54R+zZpXgKRJZkon9dO7h
rovSlXBu/H5hcADOt14tD62pClA2/JqDggiU+9/+2+JKFUC/t0CpCfsiXcB6
GUsF9K1Yjh4LJtBen4YTL2segEVKG5vkNQJNTL54mrlSDpdHkoJ3hhLowPVG
dzrLMsixOmy1GEGg790iSYLsJeAoOf3TMRLPjyfoRs/nF4PEHzLlHbYUj6jF
M6ViqMv+2zMSRaAVqoUp4VIEQ+8HFFpjCPTH5XZibm8hbDq57yTiCVTCb9u2
58E9eKKwt5L9Bp6/FLlebzO6B/FML/TjsPeL+tps+3YXeEqUokJuEqjp/UcH
a8W7cPgz83eXRBw/6TOBKy9z4Udzc+IMNkNKJid/WC40JnpJnEsikFLrx+lw
yVzQPPLmgmky7tfimYWSrHfgvE/RsHIqgfJ7dZjYyCzYr27jUY99aWX4U+Xf
27DEzcF0NI1AL6WPPF90uQ3+dVdBnMDzdM/6151amZC8rlnORcXzq+FtMWHh
W9AWOnfjYwaBorai/d9OE0ATuefr2UwCtQlnP5v7mAYoxtxiADvjLJX9fXga
tN/sFKq8TSBu8UTfZ02p0JFRUBuYjecVddEsWq0UoM2e4P+MneW1ejl6ORnU
cneGnc8hkFrTT7vJ9GR4Uhitq34H9++02vnld0nQWX3xHVseno+FthrsckuA
rQ+z1cOw77woM2V+eRM0G18Wf8OOaTrCpKR2E7raNHxf3cX/30/QWvzgDegZ
FGPOy8f7K1LX0bQrDpie2V7eUUAgdtawbYrZsaA9Qr6Ixtb8Xph7QyQWescY
ctwKCZRp010VfBz3t49zsnJF+L4ig8TFI6KB5dOeW4XYEbcKpOf5o0F32fwv
XzGuX+mejnx1UdD/o7P7L/ap3DjpjO+RMLCl0Kb7PzyPJjSmDMRFACvDZLti
Kb5/aDKe6JCLAAMmngOl2Nedd6T3T4XDEHvM1+QyAnWzIqEl1XB4utspxuoB
gfqZ75pr7woDjr05nwawLSfdfrvcDwUj4VEjqMDnT5XsfrI3FIbFNXeLVuJ6
XZPC3cIfAs+P7a/4XIX739TjB00KwcCleG6nXTXuf/IUm/quIDA5SQ18jv1g
KfZHqWUQvDi1VeNhDYFc1Q5sU44OhJHTH96E1eHnrU1lDP/5g0N36/gf7JOn
yn1Hsvzhm0rGO/+HeP7QWr2hq+wP2w/rz1HqcXx+Mu18EnMVcgrE5pewow4l
sJVIX4VDe/4tujQQaOm/UgX01g90Wau+2DUSKNJn2FNVyQ9eR974Po7Npm8z
lvj5CjhvOK5aNuH7jtvCSdN7VyBqkfeP0SM8z/z5R2XjuQKtPdcYVVvwfXer
PMdHHl8wRGdYmrGFrf2Nk8Z9YPzhETbFVgJdHeXbapTvA78LZ7hk2vA8Y3pg
/ouiD8QKNu8sw24z9LdpZvQBXiqV72A73r83KU1Br7xBLlpHcF8HgeqdEHtZ
sDc8/iO8LxtbwuCD+3YTbzDx/SOy6zGBpkRyb5066A2eDg8Ocj7B8zTBMPpv
3As2x2IPJWBfWX0WdK3BC26a2Eszd+LzbDioUJXuBSWqO49t6cLxp3VUUvys
Fyg2LCtcw6Z+ZBE8d9ILeo70KK1ju+b9d+3YPi+wKMpTvtJNoObDfbtLGL1g
bm8Q+or9TXt338MVCvimm6ld6sH9oMTUyuoNBWi3H9ZcwLbcLM9NeEKBlBhG
nYu9BDK5dkXRsJICQpvv9aawFz/t2Jp5hwIPrjQa2vbhehb8hc4ziQIqn9OM
32A7OHgd6Q+jwIDjJTPzfnzfeP4nttSHAtbjmmeeYTdurLFwulBg0VTIymCA
QHo7BqpXbSng379u04vNZCEtYWNOAUa1F+c1BnE+fraeVzWkALWx1L4dm0+J
ybRImwJisjEXlYdwvw4IHEhSp0BN8XmXBuxjC2t1a6oUOLVP0f3YU1w/e3p9
ZxAFnt3iulyJLWJ21MUIf27HsUSRGsbnN1wsjdQosHy906cYW/m8a0GtJgWu
/cvxE3uG51fnui/VehRgveofkId90XGaU8WEApnLxsF7nuN565kK8xkrChx0
kgzNwM4R3/NqiyMF6ifoI3a+IJD5h6EgVU8KaJpPRqVgJ6yW/eYLpsDLgYfX
2UYIdGJU+lhCPAUc1VPi47DrC4sK8jMp8K3JLYHhJZ6v1++YXSylQPhR9eRw
7J/ns3VftlIgfiLP5if2riRl95gXFEi9/k/cdRT3V42Cxw3zFLgtY/tzHFtj
6zll338UyH/b2G70Cq9vaoyjidcLyqL5Ep9gH1XjEKPKeEGdtJ/V8dcEajia
nchmgOMpUub73jcEslHev/Il1gueSSW1pmEvEKOlHsVeMPZq6QbjGI6HX5oG
+f1esCRZJLqC/X1vorXzTm/4+ZLhq/1bvH4pOgVGZW/YDHVoHsUuuBjFfsPJ
GzhGBC1axvH8HDK/71KrN+wKCRaWncD9+vsCOb3sDcLiY8sF2IJNcn5uQj4g
F0xeT5gkUHTE0sz7OB9Q3v/ddMs7HF/Ol7qW2n1Ac9hI6Aq259ZDkep/fMBS
lLXB5j2ON4NV5l3+vnBhyDV6GPvplF5aXYMvuPl3G6tP4fsDk8+Vqb++EDwQ
sSg5jfPNw7hKOPEK5Pqu796YwfHWyURfPuwHxYJn5i/PEmgo1idqQfwqVPXU
1ExjXzrlt886Ct/PBCgGfXN4Pk49Maiv4Q+DXYO7VD4QKC/j2UHG//xhlCL5
oRI7+ovLPlfuAJh/8iEk4yOBqlqOF6R/C4Cvl9X12Obx/S/72L8c50D4zXeX
NxxboOVFSe/7QGC9ZFvhsoD3Z0BhRPB9EBzZOTKl8IlAw1OTtjM8IaDYKlP+
HzbaOXBUujIETrkmBe5dwvnQsXBm2igUzJp1dzB+JtAvFrfFHKMwsHUueheI
Xdh+ZkG4OAycOLeWLmOPCLDlNeL7of/FdvXRZRz/alczMzvDIXz7Xk7dFQKl
Kles75WMgPiG4Ilm7BFXRlKGiIAstuN+BV8I9Hufg6ePVyS01pbf9/2G5122
WhcZm2iQK1o5/AH7ubymotC7aCjKPFJ35ju+n6kcLYlzioHU0KonSj8IxCz5
0swr8jps9f6uV4o9z2R4RGtXLAQ5yr3Y85NA+8KlotVqYsFRp26KZhXf58PP
89r9joPXJ365eGP/sCgTeV8QDwaHj3+ZwaZnbdmtdeYGyO9o3Oz6RSDSMe9v
1sBNYJpo3p2wjuNXTYeopUuG4KebdzexYy4I0ezyTYav7SBB+U0gWy6Oesv5
ZBgrbD9uuoHnpSGvvJXxFDidQdv2BHvlpMq2JNtUeHJDTUv+D54X0zuepU+n
Qhml03zXXwLFeordC/idBsIOWyfisb2fHp/MTiCAaq7l+Ae7lfiz3ilGQphS
r/e7TTzf+H1EQxepYEI/mFRAQ6LWSOWg0IMZ0LXKxsu7hUSe+xXskhYy4MSC
YU4s9ojniuT2ikwQHRoudacl0cU2TaV9xlmQ0cYpN4HtIfAhnOdQNrBXmzQZ
0pFoMDjlmwZ7DvxKH+mVoScR5fvEhuTCHfCI32l8Dzv9WZv0Aa9ceB9s8Zqb
gURZP+7ZtH3Nhb4Lrz/8wnb5I7Y16F8eZEmO07Uwkmh2fshIyCgfOAT33JBm
ItFEqroPzZd8iOY4x5WHHXIi6EMXUQCXf74TimIm0fjVQgbK50JQbZ1R1t1G
opvnS2XYJvG8XCna2YTduwzDX+6XgET+RX0pVhKRLzNUQq/+B9xxH6042Ej0
rT/ccv5AGXww+XR1lB1/vq9j+1vnCihuGMwy3k4i0dwxI9aVCvAQqmgfwL55
ynxqGN8fvn323faYg0R/Bh1z+TOrYDN2M+cBF4keng2KBIZa4Gnl7IrlIVEP
m6UsV0AjvBH7sUjHS6Jl4L8Eck2QdXN0eyj2g7NFH2u/NoGw1e2zV/hIxBXB
u73cuxkO/xT9fIEfvx9HI7VFrQ00JY9znxAkkbhiee6uM4+BOZVfsQ77wCOX
vCN1j2Fg7Y+tzF4Smbozsb7d8QRMutrvHxAi0Ritahtn3xPYKZU/cBf74UuX
HBnhTnidFvN1zz4SNb3lr9vm3wnnLuid4BYm0XszvyUegS7Y1yNll4Rdw1Ob
MOHaBbOHOaJZREgkN61+I76mC+6T34qjsU32Or78tNEFbn9GhmhESXTPoUt9
GLpByuHh9yDs+DD1Yyxh3fClN4PvF7YtF9O0x6Nu8Es/Z/9ZjEQWggoGTAd7
QHETXXfZTyIjojTzp2UP/HEUKZ3BPnaNVdovqgda+xmenTtAou2/Pjh7/NcD
EbLzP99ghxk/s2se7AGNjD5+c3Ecv1pqomafeoCJpgzPpCSyjut/JUDfC/1O
SY56B0kkZB2VyszXC4mDXnFd2BkvI/k5DvSCsZxZuaoEiS6Yu14Sl+kF7tvy
Lx5hC3BcyzeW74VXW3atKUiSyKfzHM9N7EyXDYFqbJZLKtoT+HnbpxOqhw+R
SHdSzPe0eC8Iybc5FWMvHdojt7yrF6az7t4QlSKRQbJBd//WXiigi664g03a
XV7YWO7Bn3/K4TqMzzM4bCNnpAe/b5IQjS0ln6FmVdeDv78+aA37lmnYpDrR
g39/r5u7NIk0Xq41BVzugddbYiwnsatmXUN3avTAzttLmsZHSBRteSbuGF8P
JA82iCjIkEjwoEdQdE03DDoJcZVgT/IXbaxd6wYWmus0e2RJtH+lQC9AvRui
Zc0maI+SiCnBsfhobxcEpi9Th+RIlPOFTry9thMeHjGPVj1Goje7mBI73Dvh
R2+TTw321QfTIfRCneD5J9YoUx7nR3r97rnIJ+B4QYTF6TiOtzdVTPLKj8FQ
0vLa3xM436MSek8TbXDjSYs75SSOD6+lg99V2qDHVsxqBrvynXJy24tWUEv+
Jt+rjPe3DjnOhbfA8Z83vxBAornGoznmS01wJfH7JCMi0dt2X5Uq3SaoOmA1
GIi9IebY3F/SCFJWB0rsVEnU9fReXxalAYRb2x0OqZHoxrezNVw7H8J5S3GT
O9jjzdyVHZF1kPU1EXGpk8hXJPBJz49a4BW12bOGvVmy141msgZY41ZHH2vi
+jTIn7Y4WAU6wrad8lq4nv678knEqApimh5XF2M/6ttYfj9SCVuWk5OTtEk0
qtOQPTtXAasmkrrWuiSillolN+iVQ4Td0dFX2EWNdMExTmXAdvmEvZkeiU56
WHfTXi8F0Ti9QAN9Em1tnpXvfV0Cpq3uJWCI62ksz1Bk832YHPCRf4R9Pf6q
8BDdfXAbC+o4fppEp44mvzx4uhAift4YkzEi0ba5Ftv6H/lQIVnKImpCIp2w
bPnr/nfhpGINNRcbHBgONM7mQbfmI+E9piTa3XbHS8k8DyYvDCjxmJGIeNPk
3noqF9w8R7pSsWPDFsZEQu/AavC4yXZzfN6EkGlWWA6w3VpyY7Ig0aKY5Fb1
zCy4VfBjNQo7z60rg7PqNohW/4nYcoZEJWUW574OZ8LJIdbbv7Eb+DZFJUQy
wI1eqn/pLIm8Qj2lYrmpsMp57IyrFYkkrtxImjtPQvhe5Zk5bN5fv7pXKgi4
pWSwMWlNonCCh9/VIQ1Etc2vW9uQqF6nVDH2SSpUmNvueI2tNjegWSuRCt2U
S5LPbEmUyP5KLJ8hBUxCrjw0OIfz9S2dkkBgMkzeuKbWh4222azt+5AEq4UJ
1o/Pk0jfSq3j6UwCiE6U3ai9QKLj61/f+UE8VCzW8srak8g4jXWCyTUOTq41
3yvHtqWdsMvOiAXTHUNN9x1I5MeYVbDCfh0mhUa1RB1JZKm0KadqGgNuhydf
5GJzZtn5tWZHQ4TO8qeMizi+9rg6BapHAfuZ1as8Trgf3DzQZZEbCRmOm3Rp
2BruQq9yt0RCRSi7wE1nEp3uvVLV/yIc3tUe1g9xxfXl7+mxKYdQGN3Gn7aG
LS2m79VyKQSGLjCMebvh87p3ork49Bo8Yht3dnbH8V6XZ1bUGAQ1Dt3lU9h7
L7iSijOB8F9D1U9rDxJJivUnvOYKhMyLcZFGl3C8xyqm28f4Q0qTb18f9jGG
bWfe916FWE47To3LuF9petkm77gKV5vl7yh6kuh7Jg9Xdf0VMNs52yjshecJ
VRXhKXUf0HN/uiUbO3YkMjC7xhtOtTdq83qTiFXtjt0ufL+VuZQyus2HRANT
/2Zr93qB+OPgPTHYWgGGsXF5+D65y8WRxpdEzK7+4xEHKMDeqfLtB/YY2WD/
KOQyMOyWUPS8gv9vNyTR3L0Efyg7wxawuygBQfEDHvBJYIlt0g//X456LYq8
O/T4Zhzs9ifR3e9p6MwZF2jti6KoBuB8ZUhmci93hjohysMmbFOxFcS0zRkK
BjQ1KgJJtFbsMi89chGyhGVvSgSRiF1YzN4eXQTCf8+LfGw1pYaCy5WOECH6
wy4jGOdr5MxhtzwHCAh8d3/HNRLdv1p+j13IASjDfcsJ2Gfeoamvd+3hfHBe
cEQIiQpkWE/M1FyAkyOGt9zDSERzs5KjjcEOjkoovZvD/rs3baeuxnmQCBPb
bxeO67mD3vWE6HOw69CfarMIEoXmcp0q4bMFjoiPv4ewU68/MhF2twGm189V
dSJJVP705gudx9awGln8VDkK539Wn9l0pBUsvyF46rFTuic//Pp0Fuakw2xl
o3E+x5llMp09CyNvLT7tjyHRu4zkpQBVS6g8Ss/IEYvrT4TPpzNaFiD8yIc3
ApuTDF9vGTMHQn3mwA/skknW/0K9zMHfvEP7dRzOv5dGXPlFZrA4IXNWNx7X
W7NA+TfaZmDtlOf6CJvSJreXeckUVK6Gxefe+H9/yPpCe8IUKv6tZHLdxPV1
1K0q74MJ7Is9/18U9lPE8mmWMAH6DJUBlwQSnbexF2FdN4a+xj9sMkl4/83/
jm2fNIKTah6C97CNnV+qz2cZQVn/28M7k/H+8T/vfWtrBMnjjafXsQWUvnr1
9Z8G2osSdu4pOH8nhA50nD0NPp8zKBPYNKGnbsR/MgSLTf+U9lQ8H1H2Tgnz
G0JPzHze0TTcnzsOS7TUGYDidsuqAmzDTbH2HgsDEBBSeBFHkGhf2RPpd7n6
MKP6k9uESiK34WuFb630wKzPUewJdonzrHk/hx50mYwck0/H/Xy+z5naqwsl
DtUW/LdINPVzsDdCTRcEloSdb2I/LdEQi6HXhQTf1Kub2I4Z39fFe3SAEu11
azoD908x+ifcZ3Rgmm2qyCwTn49xy6S2sA6YUo0aurDl9jhMf17RBvn70mMl
t/H8VPcu73yqNhRJ31kUyML1lctrnMdZG3bVs28kYndI2/3doaINf3o+7/bJ
xv065f3rjm9acNnY9tAcdnCsdKnLsBa8ezNw8kwOiZopb/IUK7TAyP6kQS92
Nmvu+8OpWtCx+J/tiTt4XhDUSFL10wI5n92Xy7BPusWPuNloQcFGfMjeXBId
rpJ5dU9dC3iifiemYMs1/GmeO6wFsaxud+jycLxv+K9K7daC38SbB1ewxUVj
T19j1gL3PTptH7FVAuKfDa9rwnhB/fDZu7j+KYhHiC1pguFh8al+7KTbzM7+
7zWhrS79q/I9PP9Pj0Z3jWqCLDDSVmBr6RyfZX2qCfndflzC+Xg+Yh29rt2r
CTuNPggT2F6uln5+nZowov9reHsBidSVjr6PeawJhA5T6A1sT7veHQvYZpq7
pBgL8XxOGxuW06UJ3GoSbyOwX8ZdTynqx+/DibhN7NBz7yuZXuD3T+orBN4n
kftCiX7bOH5f0XbuJ7ZR2r+B4Xn8vvzlNK8iHA9PVrNP/MLvy4aqfsbmyWtT
oWfSAkI6ecWlmESdB68YyOP9MTuUlz2LHcKtk/LmiBZwH6zSsyvB81TpVpWf
2lowIvZ4/S22p4r/9WQH/L7wyP0z/5HoGbdLXlUYfl5gle50KZ7nWz7tLOrA
z/MxVvVhh2/uV4//iJ/fyWenWUYiBjpbQ77t2mDGdZC9A/vb20DXC4rawL1d
6ZFyOYkyM+JcfJy0YWSbnlsDtr5+qqANVRsIJhu+Yw9IdJY+59zBXvw8bYjv
oQpcvzune4oUdGBkM1G4CFtTQTvDz0cHiI07wyKVJOrbTHpwsUoHuH+2H9pd
heu5fsvEViVdGPn6fIyKHc78rGA2QheI5ZlYrmpcH9aLypWf6sKOeYY55hp8
v5ikman31oPnszxp0dgnWcpatvbpQerUAdUttTi+W5hjJcT0geutTvYa9qYj
r1fYR314/spKz7cO53txg/E3QwNIHXFfX8HmlucsbW40AK6hBPOPD/F8wd9r
/+6OITzvy6FzqCfREdcXmgG7TkNq94PKSWw2uYmKP+mngav9GdtoA4m6g0+r
K5gYAVfNzq4nTSQKUg/mnws1hucV+33RI3xfMGe92fvcGFLLFIQfYb/m65ua
ETcBrvtnQ6qb8fk/E1o4/M4Ent9zOyTdQqLcZ/bfMsAUUnODxkqw1c8dHH9w
zxS4MrPl77bi+jaAR72rZvCcWj67p41E3gm8v50+mkFqWmtqBjaRvPo3z9oc
uBKmlpPbSTTPrnXomrEFcIaJ3Q99TKLGdiWIvWoJ+g8aBb9j3+yPTRahPwsx
k6epTk9I9PPnNuZa8iz8PhkYbdCJz/8Zv4p3jxXIeWz/24bN2/NLjcHNGi7f
zveV68L9NCbRy5zTBqbXhxx2d+P7nffohw0vWxA46Pg2EZtelcOvWfIcWFiu
m9D24PpK4zbCv3QO+utETi1gn+TeuPMS2UGNj7/Qwz7cv26vq5fS2cPyXbZb
Ev14/VFN6oUh9iD+/O72HOxp7fsC2zbtIfvI4GbUAJ737m6n1rI4wuvz9n5r
2Lf+Grcb33IErqRfn90H8e87zq8ySV6EmM/7JkyG8O/FFLcn2jlBm8BDsy5s
Gyuhq210zvBbT39A8Snut7Rp2iOlzuBZ4tckNEyiL3z81AROV7B07s9Yfobj
K7kt7K+kB6RS7Tjtn5MoPahP9BP9JRjo/Bn7EvtUbuBA09wlUBUV8n/0Atdn
+6UO2TZPCDatXZEewffNqskHCrYUqIvQdb6H7RAu+n1ykgISU74W8S/xvJIo
thbwxQscOViG/mJLcjs97Qnzhhy4o+E1iuuJU8cpcx4f4MrplbN8hetdSejk
pLEvbFgJ7tj/Bu+XrWOYI8dVkI+vjs/Azn8dtiE2fBUoDdq0bGMkijOd6+2j
+sMsr8/X79hJIk9LGxQDQVCLydX5LZ5HG2+JRPAEgaVf9vsx7OsvVMQlNoJg
YKT7afs4vo+9eTcqNnENttLbah2bwPHrUUXD+DYE0NFvLUXYoSnhipNToVCb
IlCeNInn7RO1+d0M4ZBj6HXT9j3uL6+q0ircI0G9a6FlCDv4+FKk5vYoWFS2
/wpT+HyTnOjN66NAXsrUQnga56Ph6airu2NgPL8/Ng17y3li6O3LGIgQUG+i
nyGR/IR1yRnqdRjcdkzoI/ZG8+G98hJx4B1ZZmI5S6JhSefFxb9xwLchFt2L
bTMounj2dTw4LvIs/jdHItG1HR8Z7t7E/XGtmvIR/367D02gZjLcRV4fprCt
4zkZXQaTQbt+gc90nkR18uz7DC1TIO3+2LVjCyTiV1tX0wlMBYmYR1q/F3E+
lbvteYhvwsN/5QLdP5HoziueveIZJPhdKSsdx579+YOFUZMKHY45nK1LJDJb
UxaXKUuHs2phbyOXSVSdmuz/sTITNhvX2H5iJ2h6ywaE3IZ8WS/ktII9zzBO
ns6CL/vsC7S//L+/HfG3+ZcNsTTqnmzfcL26oGG71psLdc2MdOk/cTx+FjN0
bs0Hm2Nhx5hW8fNS/W2fNQqAtmzNOQC702qVcXGwAAyzFgasf+H85mimfTNV
CHOB/VShdZzfDdlu+jzFwH08SaLkD+7vFks7UlLLgEm0+LfoX/x/phQPLBwq
hz/bH/fdwX5Jae5U6SqHuY+rbuQm3l+q9NLajwdQl37uvzAaKgpvHd8tIFgJ
JZH+QRvYpH/UYSbHSsjxTNXz20JFEul8/bFFlXBdq+uTOy0VidLkRI0eqgLL
X1KHztBTUa6PgGP13mrQn9H68wy742Lz3dNnqgE9vTCgz0BF0vSfzlXdrIaD
90mPU1upaLjb8cbVL9UgmPbgZDO2yOOHM1WCNcAV2st6nJGKsqV2Wzjr1sBv
i7+lUkxUxDygNbmRUQPLp3ivFWGzf5D1amuugenDMgYizFQ088U/sGuyBkb5
9fbkYM8esDxK/7cG+rde/MzHQkWsYs7/Ufhqoe1bSHMa9olrLZcZZGqhZvJW
Avs2KrrXOFPzSLMWivqqbOOwWYZKllLP1kJW3YAUPSsVcfYI9Ee71kLy3Q9/
Q7A3SlQvEH61EJVIM7SO/SeeYbg1rBb8A/lzfNmoKP5e8gxzbC1ccpK7vIJ9
K/58nd/NWrA3MVRxY6eipHujPNsSa8FCxYV9Dlu30oQYxJ/rSkRMnt9ORftU
F2i78PsqPFnlY9gVztx7/4bXgixtXYg5BxURJYvp1/xrYf/yU8Nh7PKKpssm
HrXAP7YgqMdJRa4fdsrE2tbC9i66lU5sOOSZcUi/Fuir9rQiLrz+HJEGg+O1
sJatkNSE7Tc8r7CxrxaW4ozPy++gorv/wmU0mGvh/RV36Urs36eoHieXa2Dk
QvQ/SW4q4mJaffxtuAZ6DO48LcR+t+eFWmBlDVSKvfDM2klFUhOUDm2PGijk
/Ay8PFTUtIOptE6zBjL/buVIxe5VzWxX21sDES+VKq7z4vg5SK6y9leDX7tZ
GC0fFb0afBzqnVMNbmWXja5hKzxi6NWhVINJ9N0v3ruoqPbctaC87dUgcoxF
5txuKhJsuF+rDFWQalrUN4xdtEOaXYK1Cmi8NR3VBKjIZzTKUPd1JUyUR6SL
76EiOY1ES6fLlZAuvvH3myAVtdCwU5rTKmCbwFLfdWEqMuGyZm3KKYNApXjH
39gq6eERXYfKYN5SfNNDhIoGu5XElxtLoZN0lDERpaJr6eJV06/+g9DtE+kC
+6lod5jrNT+eEvhOO+RYeRDvb4xEuEZNIdjv89gUkaAiuiCZ3+z6hTAMLLeo
2KWjFcbTswVQFqzZHySJ86vgwPW+XQXgvNoioylFRQLqdb7uKfdglNu2vx6b
8t/sWUvZe6B+dMNR8jCOxxaNfVEjd2EfReEWhzQVGY6r3SsWuAtvFx5sjh2h
Ig+WoaDQR7mgy2R4y0CGinqMOO+0OOdC/f4lmTZsHt9bDMbcuUA6iF8skMX5
32j3fW46B05P5PZ7ylFRwJ2TWaevZsHj4ZRb9MepyCrd7OSjPbfApfVATBT2
uUtDz4yS0oG9vNmHXhE7bv7SBl06WN5YMKRXoiJr3ld5lFUSljVUGehP4vg3
rPQb3EwDQu7Vt0js1YyL6qyxaaAocuk9nTIVmbKHX+fiToMomowmOhUq+mH7
W1FXLhX4m7540SEq2l+8wXKQSIa24pjzkdg/715qd5NNhou3BAzoVKnopHX2
qmxhElRc0RanO0VFUYcvICGFRNA4kjtJq05FHAkMkSeTbsCioPxABLan+tek
bV/iIZltoIFWg4rW6W5X/jWLh7HFXwStJhUlv+HZ9gP3L0rBaT1abSoKrlkQ
bqe/DjzE3PEI7CA/Wz3tqBhoigjaT6tDxfeTp1u1GWNgq939LbS6VPTykbuR
DW803Ob/93CLPhUFdqmlPraNBMRMFoRjc+yXU/mwGgEffkmkbTGgohuMnz3n
UyPgyEuLy1sMcbyO1rpovgiHrqRy0S1GVLQ3reZbvE8YeISoc4Vjx2f33Rne
Fwacl8b+0RhTkcaZlcXZ/FCw0d36lsYEn/eMnbzglRCgVczqCcOOP3/q8vjM
Nbh/QLaOxpSKlE84RE9ZXINv9OdSaMyoaEoyX8RYJxhuff8eEoadZvfL6XpP
EChPx3nQmFMRjZVXQZZeEMS21mrRWFDR/Ze81fS2gSBVrncsDPvOBbLjwKcA
eJ41JUxzhorq0zyE+oIDwP/GVY4w7KP+FYujnAGwJ5Bt8x92hb4Kr1KJP/wP
3GQV2g==
          "]]}, Annotation[#, "Charting`Private`Tag$66988#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c8ll8bAHBFGkqKSkY/0ZCQnSTXMSp777333nuFrPQMJJtkrxCSJFuk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          "]]}, 
        Annotation[#, "Charting`Private`Tag$66988#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJxM13c41f//OH6jNBWSZJSQVZSRFe6PFMrKykzKDiE7K1tGxhmykr2yjj0z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          "]]}, 
        Annotation[#, "Charting`Private`Tag$66988#1"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1066., 0}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, {{0., 
          FormBox["0", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.2, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.4, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.6, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.8, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.05, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.1, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.15, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.25, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.3, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.35, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.45, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.5, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.55, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.65, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.7, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.75, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {156, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {208, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {260, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {312, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {364, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {416, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {468, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {520, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {572, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {624, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {676, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {728, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {780, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {832, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {884, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {936, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {988, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1040, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1092, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1144, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1196, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1248, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1300, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1352, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1404, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1456, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1508, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1560, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1156, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{None, None}, {None, None}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1066., 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 1000 people\"", TraditionalForm], 
        FormBox["\"%Positive \[Times] %ILI\"", TraditionalForm]}, {
        FormBox["\"Year\"", TraditionalForm], 
        FormBox[
         TagBox["t", HoldForm], TraditionalForm]}}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, All}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1156, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 475, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{1066., 1430.}, {0, 0.8}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{None, None}, {None, None}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"OC43\"", "\"HKU1\"", "\"SARS-CoV-2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.79096634556618*^9, {3.790966425237339*^9, 3.790966454603299*^9}, {
   3.790966491150526*^9, 3.790966509642466*^9}, {3.790966583577635*^9, 
   3.790966594007172*^9}, 3.790966659549314*^9, 3.790966703393758*^9, {
   3.7909667383899107`*^9, 3.790966757715486*^9}, 3.790967166819141*^9, {
   3.790967206499619*^9, 3.79096727099717*^9}, {3.790967305889214*^9, 
   3.7909673423461*^9}, {3.790967440118722*^9, 3.7909674858629427`*^9}, 
   3.790967633111467*^9, {3.790967671807901*^9, 3.790967812899515*^9}, 
   3.790986120764835*^9, 3.790986154907075*^9, 3.790986213066638*^9, 
   3.7909862490280943`*^9, {3.790986298382011*^9, 3.7909863272991123`*^9}, {
   3.790986432124242*^9, 3.790986453558629*^9}, {3.790986576906382*^9, 
   3.7909866345433292`*^9}, 3.791024598576089*^9, 3.79102466009927*^9, 
   3.791024900351776*^9, 3.791024955991094*^9, {3.7910280013731213`*^9, 
   3.791028043311933*^9}, 3.791028197016271*^9, 3.791238991044907*^9, 
   3.7912391281833563`*^9, {3.7912391662624893`*^9, 3.7912391929904222`*^9}, 
   3.7913111123306513`*^9, 3.791312915358374*^9, 3.7914649466155167`*^9, 
   3.7939113646492987`*^9, 3.794655111881997*^9, 3.794655376904603*^9, 
   3.7946681085317287`*^9, 3.794668509272519*^9},
 CellLabel->
  "Out[1769]=",ExpressionUUID->"98405843-3da6-4fdb-848d-373ee6fd862c"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3A.pdf\>\"", ",", "figinvasion"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3A.png\>\"", ",", "figinvasion"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668472835826*^9, 3.794668473632133*^9}},
 CellLabel->
  "In[1770]:=",ExpressionUUID->"9743288f-4533-404f-8882-d360a203f6d7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["30/0 | 40 | w36:", "Subsection",
 CellChangeTimes->{{3.791024299513517*^9, 3.791024333549387*^9}, 
   3.791024387646628*^9, {3.791027963156403*^9, 3.791027968136772*^9}, {
   3.79102802686504*^9, 3.791028026929071*^9}, {3.791028175206419*^9, 
   3.791028181254373*^9}, {3.791028790183381*^9, 3.791028846375497*^9}, {
   3.791028883603808*^9, 
   3.7910288836591063`*^9}},ExpressionUUID->"4a29be5f-0ba2-4b94-a4ca-\
99fc0a53a19c"],

Cell[CellGroupData[{

Cell["Define parameter values:", "Subsubsection",
 CellChangeTimes->{{3.791024353689595*^9, 
  3.7910243639133368`*^9}},ExpressionUUID->"0bd78647-b111-4aeb-8a6e-\
b778ef126e9a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi31val", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi32val", " ", "=", " ", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi13val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi23val", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma3val", " ", "=", " ", 
   RowBox[{"1", "/", "40"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"importtime3", " ", "=", " ", 
   RowBox[{
    RowBox[{"52", "*", "22"}], " ", "+", " ", "36"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.791024391785356*^9, 3.7910244703065147`*^9}, {
  3.791024832104692*^9, 3.791024893824339*^9}, {3.791027983305586*^9, 
  3.791028012584515*^9}, {3.791028185343968*^9, 3.791028188782642*^9}, {
  3.791028796016445*^9, 3.791028870301771*^9}},
 CellLabel->
  "In[1772]:=",ExpressionUUID->"f2c27d3d-0649-4c00-b9d4-651a789fc131"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the model: ", "Subsubsection",
 CellChangeTimes->{{3.791024365809227*^9, 
  3.791024367637371*^9}},ExpressionUUID->"fb07e9bb-10be-41b0-ab98-\
fc28d0e1e034"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"runmodel3strain", "[", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[1778]:=",ExpressionUUID->"435ec262-e662-4883-abc1-b2f23931c62b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot output: ", "Subsubsection",
 CellChangeTimes->{{3.79102437504543*^9, 3.7910243813336277`*^9}, {
  3.7910245019903917`*^9, 
  3.791024504277298*^9}},ExpressionUUID->"888ded4c-697d-4575-a43b-\
b097d6639de4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"figinvasion", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}]}], "}"}]}], "}"}], "/.",
         "sol"}], "]"}], "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "plotrangemax"}], "}"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "yearbarchar"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "0", ",", " ", "tmax", ",", " ", "52"}], 
             "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"importtime3", ",", "importbarchar"}], "}"}], "}"}]}], 
         "]"}], ",", "None"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicks", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ncovticks", ",", " ", "All"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"\"\<'\>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{
                 RowBox[{"i", "/", "52"}], "-", "2"}], "]"}]}]}], "}"}], ",", 
            " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "tmax", ",", "52"}], "}"}]}], "]"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Year\>\"", ",", "\"\<Prevalence per 1000 people\>\"", ",", " ", 
        "Automatic", ",", " ", "\"\<%Positive \[Times] %ILI\>\""}], "}"}]}], 
     ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "imsz"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<OC43\>\"", ",", "\"\<HKU1\>\"", ",", "\"\<SARS-CoV-2\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"oc43char", ",", " ", "hku1char", ",", "ncovchar"}], "}"}]}]}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7893824421170883`*^9, 3.7893826157339983`*^9}, {
   3.7893826664946747`*^9, 3.78938266695546*^9}, {3.789382731126128*^9, 
   3.789382731675748*^9}, {3.7893827767664127`*^9, 3.789382777444231*^9}, {
   3.789386619546466*^9, 3.789386631208551*^9}, {3.789387810394597*^9, 
   3.789388029020711*^9}, {3.789838710858089*^9, 3.789838717718485*^9}, {
   3.789842556270996*^9, 3.789842651382614*^9}, {3.7898426863790817`*^9, 
   3.7898427300803967`*^9}, {3.789842819806529*^9, 3.789842948950203*^9}, {
   3.7898429865388527`*^9, 3.789843021987234*^9}, {3.789843093799283*^9, 
   3.789843184820764*^9}, {3.78984336766575*^9, 3.7898436006321487`*^9}, {
   3.7898436712471724`*^9, 3.78984370597163*^9}, {3.789845657271617*^9, 
   3.78984565935472*^9}, {3.789845785029049*^9, 3.789845795524316*^9}, {
   3.7898458658704863`*^9, 3.789846118358913*^9}, {3.789846154006332*^9, 
   3.7898463664972258`*^9}, {3.789846403235764*^9, 3.789846484288625*^9}, {
   3.789846522317915*^9, 3.7898466387710238`*^9}, {3.789911908017222*^9, 
   3.789911994611348*^9}, {3.789987417920609*^9, 3.789987519668146*^9}, 
   3.78998766533955*^9, {3.7900151606852503`*^9, 3.790015162261084*^9}, {
   3.790017373012323*^9, 3.790017443684984*^9}, {3.7900174921119833`*^9, 
   3.7900178416947412`*^9}, {3.7900178781015577`*^9, 3.790018049008872*^9}, {
   3.790018143265133*^9, 3.7900182454606028`*^9}, {3.790080424619478*^9, 
   3.79008045222733*^9}, 3.790937591828598*^9, 3.790937628558119*^9, 
   3.790937755476927*^9, 3.790938168272998*^9, {3.790939252734089*^9, 
   3.790939274532484*^9}, {3.79093932502175*^9, 3.7909394034475937`*^9}, {
   3.790939491200864*^9, 3.790939533093276*^9}, {3.7909396652500963`*^9, 
   3.7909396778141613`*^9}, {3.7909397335725937`*^9, 3.790939735050262*^9}, 
   3.7909399443534927`*^9, {3.790940134103973*^9, 3.79094021526552*^9}, {
   3.790940254309019*^9, 3.790940255328331*^9}, {3.7909403051360607`*^9, 
   3.79094031494598*^9}, {3.7909404920878763`*^9, 3.7909404977980022`*^9}, {
   3.7909406269986343`*^9, 3.7909406299951353`*^9}, {3.790940726648095*^9, 
   3.790940771458849*^9}, {3.79094080944941*^9, 3.790940811632804*^9}, 
   3.7909409745994387`*^9, {3.7909413836357393`*^9, 3.790941469640398*^9}, {
   3.7909419009848537`*^9, 3.7909419011777773`*^9}, 3.790941934145125*^9, {
   3.7909429495176973`*^9, 3.790942950149515*^9}, 3.790943062385366*^9, {
   3.7909524619930143`*^9, 3.790952484646926*^9}, {3.790966313488199*^9, 
   3.7909663273901997`*^9}, 3.790966398007543*^9, {3.790986123275064*^9, 
   3.7909861516486263`*^9}, {3.7909862083701267`*^9, 3.790986209160791*^9}, {
   3.790986242927669*^9, 3.790986244031867*^9}, {3.790986294640409*^9, 
   3.7909863255150146`*^9}, {3.791024642180931*^9, 3.7910246434516687`*^9}, {
   3.7910247121220627`*^9, 3.791024713209406*^9}, {3.7910247441953907`*^9, 
   3.7910247453652563`*^9}, {3.7910247761867857`*^9, 3.791024874373518*^9}, 
   3.791024910533731*^9, {3.7910249449382544`*^9, 3.791024947047079*^9}, {
   3.7912390975006742`*^9, 3.791239100746409*^9}, 3.794655074950905*^9},
 CellLabel->
  "In[1779]:=",ExpressionUUID->"1527a34c-be74-46dc-b1b2-2dfc84aa9837"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save output:", "Subsubsection",
 CellChangeTimes->{{3.791024505581291*^9, 
  3.7910245071250677`*^9}},ExpressionUUID->"d2c7f15a-651e-49ad-a675-\
ad0e70cc940e"],

Cell[CellGroupData[{

Cell[BoxData["figinvasion"], "Input",
 CellChangeTimes->{{3.790966344065854*^9, 3.79096634514146*^9}, {
  3.791024648443697*^9, 3.7910246488615093`*^9}},
 CellLabel->
  "In[1780]:=",ExpressionUUID->"3368ac59-2d8a-455e-9acf-3c4d7c4c787c"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c81V8fAHAiRamskiirlJBIIfkcK5SQvRJy7b1JNhXSHchKRvbeW/bO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          "]]}, Annotation[#, "Charting`Private`Tag$68188#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU2nc01t8fAHAhtKRtJaUhIQkheV977733lr03WVk9A9kyslcRMsqmSKIk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          "]]}, Annotation[#, "Charting`Private`Tag$68188#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJxM13c01u//OHCV0kBWiIaVQsmMJM9LIcooO3vvrKyE7D3vgSRlZiUrm8he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          "]]}, 
        Annotation[#, "Charting`Private`Tag$68188#1"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1066., 0}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, {{0., 
          FormBox["0", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.2, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.4, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.6, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.8, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.05, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.1, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.15, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.25, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.3, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.35, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.45, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.5, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.55, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.65, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.7, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.75, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {156, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {208, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {260, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {312, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {364, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {416, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {468, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {520, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {572, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {624, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {676, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {728, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {780, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {832, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {884, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {936, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {988, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1040, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1092, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1144, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1196, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1248, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1300, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1352, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1404, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1456, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1508, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1560, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1180, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{None, None}, {None, None}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1066., 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 1000 people\"", TraditionalForm], 
        FormBox["\"%Positive \[Times] %ILI\"", TraditionalForm]}, {
        FormBox["\"Year\"", TraditionalForm], 
        FormBox[
         TagBox["t", HoldForm], TraditionalForm]}}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, All}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1180, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 475, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{1066., 1430.}, {0, 0.8}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{None, None}, {None, None}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"OC43\"", "\"HKU1\"", "\"SARS-CoV-2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.79096634556618*^9, {3.790966425237339*^9, 3.790966454603299*^9}, {
   3.790966491150526*^9, 3.790966509642466*^9}, {3.790966583577635*^9, 
   3.790966594007172*^9}, 3.790966659549314*^9, 3.790966703393758*^9, {
   3.7909667383899107`*^9, 3.790966757715486*^9}, 3.790967166819141*^9, {
   3.790967206499619*^9, 3.79096727099717*^9}, {3.790967305889214*^9, 
   3.7909673423461*^9}, {3.790967440118722*^9, 3.7909674858629427`*^9}, 
   3.790967633111467*^9, {3.790967671807901*^9, 3.790967812899515*^9}, 
   3.790986120764835*^9, 3.790986154907075*^9, 3.790986213066638*^9, 
   3.7909862490280943`*^9, {3.790986298382011*^9, 3.7909863272991123`*^9}, {
   3.790986432124242*^9, 3.790986453558629*^9}, {3.790986576906382*^9, 
   3.7909866345433292`*^9}, 3.791024598576089*^9, 3.79102466009927*^9, 
   3.791024900351776*^9, 3.791024955991094*^9, {3.7910280013731213`*^9, 
   3.791028043311933*^9}, 3.791028197016271*^9, {3.791028800675058*^9, 
   3.791028903057754*^9}, 3.7912390019922*^9, 3.791239129268549*^9, {
   3.7912391673599243`*^9, 3.791239194182262*^9}, 3.79131112468777*^9, 
   3.791312916464918*^9, 3.7914649553429003`*^9, 3.793911365784424*^9, 
   3.794655112830102*^9, 3.794655377596319*^9, 3.794668109288743*^9, 
   3.794668511376586*^9},
 CellLabel->
  "Out[1780]=",ExpressionUUID->"0ab41845-67cd-476d-abcd-7b473cd421b1"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3B.pdf\>\"", ",", "figinvasion"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3B.png\>\"", ",", "figinvasion"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668482491755*^9, 3.7946684830969667`*^9}},
 CellLabel->
  "In[1781]:=",ExpressionUUID->"1f2374d6-b7e6-4fb9-876e-15950adede43"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["30/30 | 104 | w32:", "Subsection",
 CellChangeTimes->{{3.791024299513517*^9, 3.791024333549387*^9}, 
   3.791024387646628*^9, {3.791027963156403*^9, 3.791027968136772*^9}, {
   3.79102802686504*^9, 3.791028026929071*^9}, {3.791028175206419*^9, 
   3.791028181254373*^9}, {3.791028549256338*^9, 3.791028557369301*^9}, {
   3.791035318670187*^9, 
   3.791035318969039*^9}},ExpressionUUID->"d379f03b-7da0-495a-b753-\
526f123bcfbb"],

Cell[CellGroupData[{

Cell["Define parameter values:", "Subsubsection",
 CellChangeTimes->{{3.791024353689595*^9, 
  3.7910243639133368`*^9}},ExpressionUUID->"27b9806e-9784-4adf-9a12-\
39cbf74da847"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi31val", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi32val", " ", "=", " ", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi13val", " ", "=", " ", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi23val", " ", "=", " ", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma3val", " ", "=", " ", 
   RowBox[{"1", "/", "104"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"importtime3", " ", "=", " ", 
   RowBox[{
    RowBox[{"52", "*", "22"}], " ", "+", " ", "32"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.791024391785356*^9, 3.7910244703065147`*^9}, {
  3.791024832104692*^9, 3.791024893824339*^9}, {3.791027983305586*^9, 
  3.791028012584515*^9}, {3.791028185343968*^9, 3.791028188782642*^9}, {
  3.79102856406721*^9, 3.791028628976904*^9}},
 CellLabel->
  "In[1783]:=",ExpressionUUID->"a5da8fb9-8fbe-4693-a044-ac2998c166a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the model: ", "Subsubsection",
 CellChangeTimes->{{3.791024365809227*^9, 
  3.791024367637371*^9}},ExpressionUUID->"64e557ef-7bd5-48f9-9bc4-\
dc7ae47498a8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"runmodel3strain", "[", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[1789]:=",ExpressionUUID->"f3d22003-55e6-45c1-91c6-aed9119f97e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot output: ", "Subsubsection",
 CellChangeTimes->{{3.79102437504543*^9, 3.7910243813336277`*^9}, {
  3.7910245019903917`*^9, 
  3.791024504277298*^9}},ExpressionUUID->"51a9455f-92da-44be-bf44-\
a8b55e176b98"],

Cell[BoxData[
 RowBox[{
  RowBox[{"figinvasion", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"I1S2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2R3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2S3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2E3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2R3", "[", "t", "]"}]}], ")"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"100", "*", "scalingfactor", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"S1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"S1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"E1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"I1R2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1S2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1E2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1I2I3", "[", "t", "]"}], "+", 
              RowBox[{"R1R2I3", "[", "t", "]"}]}], ")"}]}], "}"}]}], "}"}], "/.",
         "sol"}], "]"}], "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "plotrangemax"}], "}"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "yearbarchar"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "0", ",", " ", "tmax", ",", " ", "52"}], 
             "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"importtime3", ",", "importbarchar"}], "}"}], "}"}]}], 
         "]"}], ",", "None"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicks", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ncovticks", ",", " ", "All"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"\"\<'\>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{
                 RowBox[{"i", "/", "52"}], "-", "2"}], "]"}]}]}], "}"}], ",", 
            " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "tmax", ",", "52"}], "}"}]}], "]"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Year\>\"", ",", "\"\<Prevalence per 1000 people\>\"", ",", " ", 
        "Automatic", ",", " ", "\"\<%Positive \[Times] %ILI\>\""}], "}"}]}], 
     ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "imsz"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<OC43\>\"", ",", "\"\<HKU1\>\"", ",", "\"\<SARS-CoV-2\>\""}], 
       "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"oc43char", ",", " ", "hku1char", ",", "ncovchar"}], "}"}]}]}],
     "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[1790]:=",ExpressionUUID->"6174542c-aa72-44c5-bb6f-802892929ca3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save output:", "Subsubsection",
 CellChangeTimes->{{3.791024505581291*^9, 
  3.7910245071250677`*^9}},ExpressionUUID->"48b03727-9a33-447a-b146-\
91d904faaecc"],

Cell[CellGroupData[{

Cell[BoxData["figinvasion"], "Input",
 CellChangeTimes->{{3.7946550400637712`*^9, 3.794655040768918*^9}},
 CellLabel->
  "In[1791]:=",ExpressionUUID->"70a1a684-bc5a-4b1a-8ab0-92eb28340453"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU13c8Ve8fAHBFVqVEJSGlIdHXSEX4PCGUQmZGolx77yR7FNK991ghe++9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          "]]}, 
        Annotation[#, "Charting`Private`Tag$69388#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJwU2nc81t8XAHAJaShJJStRkhBaUpxrZct47L1X9t6bjPQMZMvIKiMSIiOz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          "]]}, 
        Annotation[#, "Charting`Private`Tag$69388#1"]& ], 
       TagBox[{
         Directive[
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.008], 
          Opacity[0.5]], 
         LineBox[CompressedData["
1:eJxM2Hc81t//OH6FlNKQbJGMimSUSpxzEJklMynJFtlKJXtv15C998oosvdW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          "]]}, 
        Annotation[#, "Charting`Private`Tag$69388#1"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1066., 0}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, {{0., 
          FormBox["0", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.2, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.4, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.6, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.8, 
          FormBox[
           TagBox[
            InterpretationBox[
            "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0.05, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.1, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.15, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.25, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.3, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.35, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.45, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.5, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.55, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.65, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.7, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0.75, 
          FormBox[
           TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {156, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {208, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {260, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {312, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {364, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {416, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {468, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {520, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {572, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {624, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {676, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {728, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {780, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {832, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {884, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {936, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {988, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1040, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1092, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1144, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1196, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1248, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1300, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1352, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1404, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1456, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1508, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {1560, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1176, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{None, None}, {None, None}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1066., 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 1000 people\"", TraditionalForm], 
        FormBox["\"%Positive \[Times] %ILI\"", TraditionalForm]}, {
        FormBox["\"Year\"", TraditionalForm], 
        FormBox[
         TagBox["t", HoldForm], TraditionalForm]}}, FrameTicks -> {{{{0., 
          FormBox["\"0.\"", TraditionalForm]}, {0.1875, 
          FormBox["\"25.\"", TraditionalForm]}, {0.375, 
          FormBox["\"50.\"", TraditionalForm]}, {0.5625, 
          FormBox["\"75.\"", TraditionalForm]}, {0.75, 
          FormBox["\"100.\"", TraditionalForm]}, {0.9375, 
          FormBox["\"125.\"", TraditionalForm]}}, All}, {{{0, 
          FormBox["\"'-2\"", TraditionalForm]}, {52, 
          FormBox["\"'-1\"", TraditionalForm]}, {104, 
          FormBox["\"'0\"", TraditionalForm]}, {156, 
          FormBox["\"'1\"", TraditionalForm]}, {208, 
          FormBox["\"'2\"", TraditionalForm]}, {260, 
          FormBox["\"'3\"", TraditionalForm]}, {312, 
          FormBox["\"'4\"", TraditionalForm]}, {364, 
          FormBox["\"'5\"", TraditionalForm]}, {416, 
          FormBox["\"'6\"", TraditionalForm]}, {468, 
          FormBox["\"'7\"", TraditionalForm]}, {520, 
          FormBox["\"'8\"", TraditionalForm]}, {572, 
          FormBox["\"'9\"", TraditionalForm]}, {624, 
          FormBox["\"'10\"", TraditionalForm]}, {676, 
          FormBox["\"'11\"", TraditionalForm]}, {728, 
          FormBox["\"'12\"", TraditionalForm]}, {780, 
          FormBox["\"'13\"", TraditionalForm]}, {832, 
          FormBox["\"'14\"", TraditionalForm]}, {884, 
          FormBox["\"'15\"", TraditionalForm]}, {936, 
          FormBox["\"'16\"", TraditionalForm]}, {988, 
          FormBox["\"'17\"", TraditionalForm]}, {1040, 
          FormBox["\"'18\"", TraditionalForm]}, {1092, 
          FormBox["\"'19\"", TraditionalForm]}, {1144, 
          FormBox["\"'20\"", TraditionalForm]}, {1196, 
          FormBox["\"'21\"", TraditionalForm]}, {1248, 
          FormBox["\"'22\"", TraditionalForm]}, {1300, 
          FormBox["\"'23\"", TraditionalForm]}, {1352, 
          FormBox["\"'24\"", TraditionalForm]}, {1404, 
          FormBox["\"'25\"", TraditionalForm]}, {1456, 
          FormBox["\"'26\"", TraditionalForm]}, {1508, 
          FormBox["\"'27\"", TraditionalForm]}, {1560, 
          FormBox["\"'28\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{{0, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {52, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {104, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {156, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {208, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {260, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {312, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {364, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {416, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {468, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {520, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {572, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {624, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {676, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {728, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {780, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {832, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {884, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {936, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {988, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1040, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1092, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1144, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1196, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1248, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1300, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1352, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1404, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1456, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1508, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1560, {
          GrayLevel[0.5], 
          Thickness[Tiny]}}, {1176, {
          GrayLevel[0], 
          Thickness[Large]}}}, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 475, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{1066., 1430.}, {0, 0.8}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{None, None}, {None, None}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"OC43\"", "\"HKU1\"", "\"SARS-CoV-2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.14400000000000002`], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Thickness", "[", "0.008`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.794655041081243*^9, 3.794655113828259*^9, 
  3.7946553784764957`*^9, 3.794668109975444*^9, 3.794668513631555*^9},
 CellLabel->
  "Out[1791]=",ExpressionUUID->"5129e16c-55c7-4510-b85f-ef0ceb993aba"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3D.pdf\>\"", ",", "figinvasion"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig3D.png\>\"", ",", "figinvasion"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7946684965938396`*^9, 3.794668497196781*^9}},
 CellLabel->
  "In[1792]:=",ExpressionUUID->"4d7cff73-b1ce-4e11-a987-fdec47aa3c16"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Single-strain model with interventions", "Title",
 CellChangeTimes->{{3.794656062586166*^9, 
  3.7946560669412603`*^9}},ExpressionUUID->"c59c641f-2437-49ec-8027-\
880b99f4a54e"],

Cell["Set parameter values and define functions: ", "Subtitle",
 CellChangeTimes->{{3.7933924736210012`*^9, 
  3.793392483595557*^9}},ExpressionUUID->"4b1cccbc-24f4-48ad-a586-\
578804dfe71d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Seasonal", " ", "forcing"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"beta", "[", 
     RowBox[{
     "t_", ",", "amplitude_", ",", "baseline_", ",", "phival_", ",", 
      "gammaval_"}], "]"}], ":=", 
    RowBox[{"gammaval", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"amplitude", "/", "2"}], "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t", "-", "phival"}], ")"}], "/", "52"}]}], "]"}]}], "+", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{"amplitude", "/", "2"}], "+", "baseline"}], ")"}]}], 
      ")"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", "0.3", ")"}], "*", 
      RowBox[{"(", "0.044", ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Probability", " ", "of", " ", "needing", " ", "critical", " ", "care"}],
      "*)"}], "\[IndentingNewLine]", 
    RowBox[{"pH", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", "0.7", ")"}], "*", 
      RowBox[{"(", "0.044", ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Probability", " ", "of", " ", "hospitalization", " ", "but", " ", "not",
       " ", "critical", " ", "care"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"pS", " ", "=", " ", 
     RowBox[{"1", "-", 
      RowBox[{"(", 
       RowBox[{"pC", " ", "+", " ", "pH"}], ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Probability", " ", "of", " ", "not", " ", "needing", " ", "care"}], 
     "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"nuval", " ", "=", " ", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4.9", "/", "7"}], ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Rate", " ", "of", " ", "progressing", " ", "to", " ", 
      "infectiousness"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"gammaval", " ", "=", " ", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4.8", "/", "7"}], ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Rate", " ", "of", " ", "losing", " ", "infectiousness", " ", "or", " ", 
      "going", " ", "to", " ", "the", " ", "hospital"}], "*)"}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"deltaHval", " ", "=", " ", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"8", "/", "7"}], ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Rate", " ", "of", " ", "leaving", " ", "hospital", " ", "for", " ", 
      "those", " ", "not", " ", "going", " ", "to", " ", "critical", " ", 
      "care"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"deltaCval", " ", "=", " ", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"6", "/", "7"}], ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Rate", " ", "of", " ", "leaving", " ", "hospital", " ", "and", " ", 
      "going", " ", "to", " ", "critical", " ", "care"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"xiCval", " ", "=", " ", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"10", "/", "7"}], ")"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "Rate", " ", "of", " ", "leaving", " ", "critical", " ", "care"}], 
     "*)"}], "\[IndentingNewLine]", " ", "\[IndentingNewLine]", 
    RowBox[{"amplitude", " ", "=", " ", "0.6"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"baseline", " ", "=", " ", "1.4"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"phival", "=", " ", 
     RowBox[{"-", "3.8"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kappaval", " ", "=", " ", "0.01"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"importtime", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"31", "+", "29", "+", "11"}], ")"}], "/", "7"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"importlength", " ", "=", " ", "0.5"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ptest", " ", "=", " ", "0.05"}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"probability", " ", "that", " ", "a", " ", "non"}], "-", 
      RowBox[{"hospitalized", " ", "case", " ", "gets", " ", "tested"}]}], 
     "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"tmax", " ", "=", " ", 
     RowBox[{"5", "*", "52"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotwindow", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "64"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotwindowlong", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"52", "*", "2.5"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fs", " ", "=", " ", "18"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imsz", "=", "400"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"seasonality", " ", "=", " ", "1"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"thresholdprevon", " ", "=", " ", "0.0035"}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{"0.00375", ";"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"thresholdprevoff", " ", "=", " ", "0.001"}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{"0.001", ";"}], "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"thresholdprevonmoreICU", " ", "=", " ", "0.007"}], ";", " ", 
    RowBox[{"(*", "0.0075", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"thresholdprevoffmoreICU", " ", "=", " ", "0.002"}], ";", " ", 
    RowBox[{"(*", "0.00025", "*)"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7933824016469603`*^9, 3.793382433659927*^9}, {
   3.793392485521379*^9, 3.793392487521698*^9}, {3.79339263520496*^9, 
   3.793392714713307*^9}, {3.793393907287566*^9, 3.793394084370824*^9}, {
   3.793394124891756*^9, 3.793394206023793*^9}, {3.793394441118215*^9, 
   3.793394499802842*^9}, {3.793395056647203*^9, 3.793395072470455*^9}, {
   3.793395198721662*^9, 3.793395223075577*^9}, {3.793395308028611*^9, 
   3.793395309601819*^9}, {3.793395347946869*^9, 3.7933953670198517`*^9}, {
   3.7933954298851843`*^9, 3.7933954353875437`*^9}, 3.793395884942059*^9, {
   3.793396053807115*^9, 3.7933960594453506`*^9}, 3.793396128405074*^9, {
   3.793396161221387*^9, 3.7933961906697693`*^9}, 3.793396465160309*^9, {
   3.793396504452037*^9, 3.793396508265297*^9}, {3.793397487135983*^9, 
   3.793397487468416*^9}, {3.793397550483906*^9, 3.793397645934012*^9}, {
   3.793397959099144*^9, 3.793397965523966*^9}, {3.793398010877906*^9, 
   3.793398011155649*^9}, {3.7933981065674*^9, 3.793398113113698*^9}, {
   3.793398152790327*^9, 3.793398153271265*^9}, {3.793400392723693*^9, 
   3.793400405980054*^9}, {3.793435391281775*^9, 3.793435402007841*^9}, 
   3.793435658448827*^9, 3.793442193613069*^9, {3.793529326303412*^9, 
   3.793529336159178*^9}, {3.793529752701681*^9, 3.793529753185114*^9}, {
   3.793529799203206*^9, 3.7935299163981953`*^9}, {3.793530266700755*^9, 
   3.793530280587278*^9}, {3.793530881386142*^9, 3.793530927344369*^9}, {
   3.793538235163342*^9, 3.793538260139104*^9}, {3.793628653007725*^9, 
   3.7936286716887293`*^9}, {3.793631355447322*^9, 3.79363135877636*^9}, {
   3.79363511837593*^9, 3.793635121678879*^9}, {3.793640210320211*^9, 
   3.793640212976606*^9}, {3.793717624257094*^9, 3.7937176364463377`*^9}, {
   3.7937181586830263`*^9, 3.7937181600631847`*^9}, {3.79371824819411*^9, 
   3.7937182498865433`*^9}, {3.793719529331539*^9, 3.793719531371969*^9}, {
   3.793801368888749*^9, 3.79380137088395*^9}, {3.7945068973633747`*^9, 
   3.794506899289358*^9}, {3.7945069689090548`*^9, 3.794506975979354*^9}, {
   3.794515007202763*^9, 3.79451503752429*^9}, {3.794515303183168*^9, 
   3.794515304564411*^9}, {3.794568621072503*^9, 3.794568624309305*^9}, {
   3.794568986678349*^9, 3.794568987896283*^9}, {3.794575949964862*^9, 
   3.7945759530774317`*^9}, {3.794578117606739*^9, 3.794578119556025*^9}, 
   3.79457841354583*^9, {3.794579345472109*^9, 3.7945793477511873`*^9}, {
   3.794579472478606*^9, 3.7945794748459587`*^9}, {3.7946560803732767`*^9, 
   3.794656083835322*^9}, {3.794656812871163*^9, 3.7946568159399433`*^9}},
 CellLabel->
  "In[1220]:=",ExpressionUUID->"c499504f-1ceb-4881-b311-7e11e2002f34"],

Cell[CellGroupData[{

Cell["One-time intervention model", "Subtitle",
 CellChangeTimes->{{3.794656141961429*^9, 
  3.794656151572268*^9}},ExpressionUUID->"fa81f003-75c5-4ae2-b047-\
62716c9d6491"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"runmodeloneshot", "[", "]"}], " ", ":=", " ", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"npi", "[", "t", "]"}]}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Eq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pS", " ", "+", " ", "pH", " ", "+", " ", "pC"}], ")"}], 
          "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ISq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pS", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ISq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RSq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"gammaval", "*", 
         RowBox[{"ISq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"IHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pH", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HHq", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaHval", "*", 
          RowBox[{"HHq", "[", "t", "]"}]}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"deltaHval", "*", 
         RowBox[{"HHq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ICq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pC", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"CCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", 
        RowBox[{
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"xiCval", "*", 
          RowBox[{"CCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"xiCval", "*", 
         RowBox[{"CCq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"est", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", "0"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"npi", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", "\[GreaterEqual]", "importtime"}], " ", ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "kappaval"}]}], "]"}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", " ", ">", 
          RowBox[{"importtime", "+", "importlength"}]}], ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "0"}]}], " ", "]"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", ">", "npistart"}], ",", " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "-", "npifactor"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", ">", "npiend"}], ",", " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", "1"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sq", "[", "0", "]"}], " ", "\[Equal]", "1"}], ",", " ", 
       RowBox[{
        RowBox[{"Eq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ISq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RSq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"IHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ICq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"CCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"est", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
       RowBox[{
        RowBox[{"npi", "[", "0", "]"}], "\[Equal]", "1"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "Sq", ",", " ", "Eq", ",", " ", "ISq", ",", " ", "RSq", ",", " ", "IHq",
        ",", " ", "HHq", ",", " ", "RHq", ",", " ", "ICq", ",", " ", "HCq", 
       ",", " ", "CCq", ",", " ", "RCq", ",", " ", "est", ",", " ", "npi"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "tmax"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.794656143809965*^9, 3.7946561707148943`*^9}},
 CellLabel->
  "In[1234]:=",ExpressionUUID->"a5a54cc0-489a-4805-a9b5-2689653bac7b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Scenarios without seasonality:", "Subtitle",
 CellChangeTimes->{{3.793399465012445*^9, 3.793399466532864*^9}, {
  3.793399751722608*^9, 
  3.793399754956258*^9}},ExpressionUUID->"a2881e2e-df61-49d0-8b5f-\
f54342137197"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["No reduction in transmission:", "Subsection"]], \
"Subsection",
 CellChangeTimes->{
  3.793399477540875*^9, {3.793399521439707*^9, 3.793399522112132*^9}, {
   3.794656593032816*^9, 
   3.794656595489422*^9}},ExpressionUUID->"40b28e49-d460-48ec-8746-\
eb8c66c42df7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", "Infinity"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", "Infinity"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399492532537*^9, 3.793399494161208*^9}, 
   3.793531410142632*^9, 3.794656294693379*^9, {3.7946565971782837`*^9, 
   3.794656608029134*^9}},
 CellLabel->
  "In[1235]:=",ExpressionUUID->"fdf2592f-4492-4541-85ca-cc9f9a0363f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 4 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{
  3.793399477540875*^9, {3.793399521439707*^9, 
   3.793399522112132*^9}},ExpressionUUID->"8c249c33-6546-4d9f-b35e-\
8d9e3556249c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x4ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399492532537*^9, 3.793399494161208*^9}, 
   3.793531410142632*^9, 3.794656294693379*^9},
 CellLabel->
  "In[1240]:=",ExpressionUUID->"7594814e-de43-4145-9be5-dcdbb9670a35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 4 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{{3.7933992329693327`*^9, 3.7933992555778427`*^9}, {
  3.793399525594367*^9, 
  3.793399525741004*^9}},ExpressionUUID->"f79e9a77-8013-456c-a541-\
f5c51663e4de"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x4ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399315213257*^9, 3.7933993165674553`*^9}, {
   3.793399545518386*^9, 3.7933995487281237`*^9}, 3.793531416107319*^9, 
   3.794656298669973*^9},
 CellLabel->
  "In[1245]:=",ExpressionUUID->"d1cf0c26-6111-466f-92e3-1dd17ff28f6f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 4 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{{3.7933992329693327`*^9, 3.79339925716903*^9}, {
  3.793399528205628*^9, 
  3.7933995283740892`*^9}},ExpressionUUID->"bce3105c-9f99-43b7-89ed-\
fcc834a9d51e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x4ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993218469267`*^9, 3.793399323343088*^9}, {
   3.7933995573415527`*^9, 3.7933995591570053`*^9}, 3.79339968634774*^9, 
   3.793531421678059*^9, 3.79465630227176*^9},
 CellLabel->
  "In[1250]:=",ExpressionUUID->"59dd2c9d-bfb9-4313-8c9d-8e893c97f274"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 8 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{3.7933992329693327`*^9, 3.7933992683652267`*^9, 
  3.793399530922187*^9},ExpressionUUID->"dfd6c851-51e1-4bd8-bfad-\
38e2aeefaf00"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x8ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399333176015*^9, 3.7933993347797613`*^9}, {
   3.793399564060018*^9, 3.793399565800709*^9}, 3.793531427272615*^9, 
   3.794656306455594*^9},
 CellLabel->
  "In[1255]:=",ExpressionUUID->"7d2d8250-b4bf-490c-8fcb-47ca837c8e2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 8 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{{3.7933992329693327`*^9, 3.7933992697381487`*^9}, 
   3.7933995318393707`*^9},ExpressionUUID->"89ad829b-a6d8-4adc-ae1b-\
ea1537596cdf"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x8ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79339933971128*^9, 3.7933993447259073`*^9}, {
   3.7933995699621553`*^9, 3.7933995714070253`*^9}, 3.793531433299389*^9, 
   3.794656310797707*^9},
 CellLabel->
  "In[1260]:=",ExpressionUUID->"c808532e-47dd-4960-952e-3d49f7293db0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 8 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{{3.7933992329693327`*^9, 3.793399271142034*^9}, 
   3.793399533265662*^9},ExpressionUUID->"8a3ce68b-7f6a-479f-89c8-\
3ecc566c14f5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x8ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993510017*^9, 3.793399355489079*^9}, {
   3.7933995766752453`*^9, 3.79339957785371*^9}, 3.793531439081506*^9, 
   3.794656314857704*^9},
 CellLabel->
  "In[1265]:=",ExpressionUUID->"4e06ffa5-7827-4111-904d-e96d2d6a9f19"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 12 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399272105081*^9, 3.7933992721489077`*^9}, 
   3.793399534075979*^9},ExpressionUUID->"26a39f6f-6bbe-4b59-aeb3-\
0a8ed357c3ae"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "12"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x12ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399361183338*^9, 3.793399362533517*^9}, {
   3.793399581956794*^9, 3.793399583491564*^9}, 3.7935314447933826`*^9, 
   3.7946563203031273`*^9},
 CellLabel->
  "In[1270]:=",ExpressionUUID->"68aad3ef-63e5-4be4-b1fb-aa842406a107"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 12 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{{3.7933992329693327`*^9, 3.7933992730731287`*^9}, 
   3.793399535141101*^9},ExpressionUUID->"1d4b5775-4bf8-48fe-acfb-\
74e41fbc3e20"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "12"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x12ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993681391363`*^9, 3.79339937205424*^9}, {
   3.793399587617723*^9, 3.793399588967922*^9}, 3.793531450505888*^9, 
   3.79465632495481*^9},
 CellLabel->
  "In[1275]:=",ExpressionUUID->"8f2adf23-2df5-435d-821c-20dcbd4b086d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 12 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{
  3.7933992329693327`*^9, {3.7933992647742147`*^9, 3.79339927434074*^9}, 
   3.7933995359780407`*^9},ExpressionUUID->"dec29f79-d42e-4073-a216-\
a1b76c51ccc5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "12"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x12ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79339937659689*^9, 3.7933993810271587`*^9}, {
   3.793399594422448*^9, 3.793399595895485*^9}, 3.793531456575253*^9, 
   3.794656329314076*^9},
 CellLabel->
  "In[1280]:=",ExpressionUUID->"017aa20e-7c73-4eae-90f7-991f1a8cdbca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 20 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{
  3.7933992329693327`*^9, {3.7933992814335947`*^9, 3.793399281502411*^9}, 
   3.793399537074873*^9},ExpressionUUID->"597c11eb-87e2-44d0-8b3d-\
0d85cf07af50"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x20ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993880864887`*^9, 3.7933993917177887`*^9}, {
   3.793399600368608*^9, 3.793399601802167*^9}, 3.793531461585596*^9, 
   3.794656333618998*^9},
 CellLabel->
  "In[1285]:=",ExpressionUUID->"3809af86-6ad0-4974-8778-46741ef171de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 20 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399277678028*^9, 3.793399283469496*^9}, 
   3.793399537955764*^9},ExpressionUUID->"77a445f3-7b22-4e2a-b665-\
6e75a26d1c2d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x20ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993962656393`*^9, 3.793399401506068*^9}, {
   3.793399606332426*^9, 3.793399607735317*^9}, 3.793531466994946*^9, 
   3.7946563380000896`*^9},
 CellLabel->
  "In[1290]:=",ExpressionUUID->"51f9ac7b-a648-4c3c-8f37-ed97aee0a083"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 20 weeks, w/out seasonality:", "Subsection"]], "Subsection",\

 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399279561842*^9, 3.793399284879805*^9}, 
   3.793399538717667*^9},ExpressionUUID->"3eb22a45-bba7-4b35-a6b7-\
bcc9fcbeacac"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x20ns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933994062015963`*^9, 3.79339941354417*^9}, {
   3.7933996119376993`*^9, 3.79339961337514*^9}, 3.793531472126583*^9, 
   3.794656342805777*^9},
 CellLabel->
  "In[1295]:=",ExpressionUUID->"1a62a7db-c2db-4fd9-8774-cf80bc6e3b38"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, always on, w/out seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.7933992814335947`*^9, 3.793399281502411*^9}, 
   3.793399537074873*^9, {3.794563629289771*^9, 
   3.79456362993823*^9}},ExpressionUUID->"c5f228d2-6a26-4bcb-bd82-\
f27460b3e6c0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "Infinity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2xinfns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993880864887`*^9, 3.7933993917177887`*^9}, {
   3.793399600368608*^9, 3.793399601802167*^9}, 3.793531461585596*^9, {
   3.79456364061405*^9, 3.7945636457286043`*^9}, 3.794656346338563*^9},
 CellLabel->
  "In[1300]:=",ExpressionUUID->"5e265148-91c8-456f-8c50-6e7e72330ce1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, always on, w/out seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399277678028*^9, 3.793399283469496*^9}, 
   3.793399537955764*^9, 
   3.79456363371795*^9},ExpressionUUID->"000f1f57-ca75-4f46-b8c5-\
515d278a685a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "Infinity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2xinfns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993962656393`*^9, 3.793399401506068*^9}, {
   3.793399606332426*^9, 3.793399607735317*^9}, 3.793531466994946*^9, {
   3.794563650832695*^9, 3.794563654216235*^9}, 3.794656351030836*^9},
 CellLabel->
  "In[1305]:=",ExpressionUUID->"9c18eeb2-280b-42ad-8d92-fa297a4593de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, always on, w/out seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399279561842*^9, 3.793399284879805*^9}, 
   3.793399538717667*^9, 
   3.794563636152788*^9},ExpressionUUID->"0f2490b0-44ba-4793-94b3-\
c573d2b4724e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "Infinity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2xinfns", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933994062015963`*^9, 3.79339941354417*^9}, {
   3.7933996119376993`*^9, 3.79339961337514*^9}, 3.793531472126583*^9, {
   3.794563659188136*^9, 3.79456366464567*^9}, 3.794656355404402*^9},
 CellLabel->
  "In[1310]:=",ExpressionUUID->"0f07bd29-f918-4643-8ded-d7a2dbd71b31"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Scenarios with seasonality: ", "Subtitle",
 CellChangeTimes->{{3.793399223691386*^9, 3.79339922746588*^9}, {
  3.793399745478477*^9, 
  3.7933997476104813`*^9}},ExpressionUUID->"a9ef91f3-6f4e-4c97-9ae2-\
440a2a7904dd"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["No reduction in transmission:", "Subsection"]], \
"Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.794656523198559*^9, 
   3.7946565268718853`*^9}},ExpressionUUID->"7a1a0bb4-fbbb-44e8-b70a-\
ee160d597d4a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", "Infinity"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", "Infinity"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sols", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793531070703244*^9, 3.7935311206105127`*^9}, {
  3.7946561812706957`*^9, 3.794656207812388*^9}, {3.794656533012623*^9, 
  3.7946565491447763`*^9}},
 CellLabel->
  "In[1315]:=",ExpressionUUID->"f8b026c0-50cd-4a3d-887b-4bf492116aa5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 4 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9},ExpressionUUID->"0c3c0d85-a444-4ab8-b0c0-\
a9370c7322ec"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x4s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793531070703244*^9, 3.7935311206105127`*^9}, {
  3.7946561812706957`*^9, 3.794656207812388*^9}},
 CellLabel->
  "In[1320]:=",ExpressionUUID->"9a697622-55af-4e43-b433-45cd2fd2487b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 4 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{{3.7933992329693327`*^9, 
  3.7933992555778427`*^9}},ExpressionUUID->"5a962afd-9818-4ec8-9542-\
cb32541ee009"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x4s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399315213257*^9, 3.7933993165674553`*^9}, 
   3.7935312655774603`*^9, 3.794656221205476*^9},
 CellLabel->
  "In[1325]:=",ExpressionUUID->"5cf35696-07fd-446f-babc-9ba2cce9aa4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 4 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{{3.7933992329693327`*^9, 
  3.79339925716903*^9}},ExpressionUUID->"f5f3155e-1f2a-4e8a-9b75-\
955c997d75cc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x4s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993218469267`*^9, 3.793399323343088*^9}, 
   3.793531275552277*^9, 3.794656226330966*^9},
 CellLabel->
  "In[1330]:=",ExpressionUUID->"d14a76b9-4d81-469a-9395-5d97063af91d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 8 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{3.7933992329693327`*^9, 
  3.7933992683652267`*^9},ExpressionUUID->"6f3ba592-7fe4-471a-abf5-\
52d43c18ceaf"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x8s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399333176015*^9, 3.7933993347797613`*^9}, 
   3.793531280544818*^9, 3.794656230855027*^9},
 CellLabel->
  "In[1335]:=",ExpressionUUID->"5d96bee7-826b-4630-9fcd-07fc5fe63c44"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 8 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{{3.7933992329693327`*^9, 
  3.7933992697381487`*^9}},ExpressionUUID->"0544be84-3918-496b-9cc8-\
346494d60794"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x8s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79339933971128*^9, 3.7933993447259073`*^9}, 
   3.7935312868547993`*^9, 3.794656235734951*^9},
 CellLabel->
  "In[1340]:=",ExpressionUUID->"e24fbf00-200a-4870-b18d-b0cd30bf3b57"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 8 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{{3.7933992329693327`*^9, 
  3.793399271142034*^9}},ExpressionUUID->"d0f8c2d5-2e2b-4fa9-a962-\
f128d78e765e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x8s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993510017*^9, 3.793399355489079*^9}, 
   3.793531293238635*^9, 3.794656240543942*^9},
 CellLabel->
  "In[1345]:=",ExpressionUUID->"f91ebda5-8516-4c68-bf92-c257477f8caf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 12 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399272105081*^9, 
   3.7933992721489077`*^9}},ExpressionUUID->"6093d10e-d633-416a-ba8e-\
597483920057"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "12"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x12s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.793399361183338*^9, 3.793399362533517*^9}, 
   3.793531299687305*^9, 3.794656245397924*^9},
 CellLabel->
  "In[1350]:=",ExpressionUUID->"9687dde1-520f-48d4-b3a5-b4b1afcda18b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 12 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{{3.7933992329693327`*^9, 
  3.7933992730731287`*^9}},ExpressionUUID->"f99b2e33-3ed0-4e46-ba04-\
edee1d98b485"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "12"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x12s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993681391363`*^9, 3.79339937205424*^9}, 
   3.793531305640201*^9, 3.794656249506648*^9},
 CellLabel->
  "In[1355]:=",ExpressionUUID->"b102d5e3-4a83-46ad-9fdd-836089dcb77b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 12 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.7933992647742147`*^9, 
   3.79339927434074*^9}},ExpressionUUID->"ff1df3b7-b09a-4d74-b412-\
ddf6f9c77646"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "12"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x12s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79339937659689*^9, 3.7933993810271587`*^9}, 
   3.793531312020275*^9, 3.794656254195436*^9},
 CellLabel->
  "In[1360]:=",ExpressionUUID->"0dcda806-b4fb-42df-ba8f-55d0ae78c6e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, for 20 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.7933992814335947`*^9, 
   3.793399281502411*^9}},ExpressionUUID->"fc4e06dc-c073-430a-9baf-\
611f6205a34d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2x20s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993880864887`*^9, 3.7933993917177887`*^9}, {
   3.793401945007869*^9, 3.793401947831801*^9}, 3.7935313198762913`*^9, 
   3.7946562586254377`*^9},
 CellLabel->
  "In[1365]:=",ExpressionUUID->"24d6ba3e-1cc1-4206-8e6e-7afd169629ed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, for 20 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399277678028*^9, 
   3.793399283469496*^9}},ExpressionUUID->"703b0ba1-ec34-4b4f-9ce7-\
37d8f1a3db7d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2x20s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993962656393`*^9, 3.793399401506068*^9}, {
   3.793401953401556*^9, 3.793401955734735*^9}, 3.793531326118956*^9, 
   3.794656263455139*^9},
 CellLabel->
  "In[1370]:=",ExpressionUUID->"dce6e139-4bf1-48fc-8109-ad3e92fa98f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, for 20 weeks, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399279561842*^9, 
   3.793399284879805*^9}},ExpressionUUID->"1f90269f-2a19-4711-a94e-\
80cd1431c32f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2x20s", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933994062015963`*^9, 3.79339941354417*^9}, {
   3.793401961576688*^9, 3.7934019640987597`*^9}, 3.793531331811985*^9, 
   3.794656267733266*^9},
 CellLabel->
  "In[1375]:=",ExpressionUUID->"97940b84-69df-44fb-91da-d861770a1899"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["20% reduction in transmission, 2 weeks after \
establishment, always on, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.7933992814335947`*^9, 3.793399281502411*^9}, {
   3.794563540767796*^9, 
   3.7945635477547703`*^9}},ExpressionUUID->"998ca9e1-1f15-4b11-a933-\
a0af0a9f3ba0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "Infinity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol20x2xinfs", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993880864887`*^9, 3.7933993917177887`*^9}, {
   3.793401945007869*^9, 3.793401947831801*^9}, 3.7935313198762913`*^9, {
   3.794563565654498*^9, 3.7945635736030283`*^9}, {3.794563604364476*^9, 
   3.794563604751375*^9}, 3.794656272370204*^9},
 CellLabel->
  "In[1380]:=",ExpressionUUID->"092742d7-fd6f-401f-a3c2-7824fe1083ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["40% reduction in transmission, 2 weeks after \
establishment, always on, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399277678028*^9, 3.793399283469496*^9}, 
   3.794563552857114*^9},ExpressionUUID->"6d43e062-6a0e-4f09-82a6-\
f263d0871ade"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "Infinity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol40x2xinfs", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933993962656393`*^9, 3.793399401506068*^9}, {
   3.793401953401556*^9, 3.793401955734735*^9}, 3.793531326118956*^9, {
   3.794563583248794*^9, 3.794563600605731*^9}, 3.794656276787828*^9},
 CellLabel->
  "In[1385]:=",ExpressionUUID->"2ab26060-be7d-4e65-8a57-ece189ab671e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission, 2 weeks after \
establishment, always on, w/seasonality:", "Subsection"]], "Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793399279561842*^9, 3.793399284879805*^9}, 
   3.7945635553668737`*^9},ExpressionUUID->"ca09e891-9ec4-4b1a-8b94-\
e34aad01dd79"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npistart", " ", "=", " ", 
   RowBox[{"importtime", " ", "+", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npiend", " ", "=", " ", 
   RowBox[{"npistart", " ", "+", " ", "Infinity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60x2xinfs", "=", 
   RowBox[{"runmodeloneshot", "[", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7933994062015963`*^9, 3.79339941354417*^9}, {
   3.793401961576688*^9, 3.7934019640987597`*^9}, 3.793531331811985*^9, {
   3.79456358910157*^9, 3.794563595418207*^9}, 3.794656281767881*^9},
 CellLabel->
  "In[1390]:=",ExpressionUUID->"56c2f6fc-fbc8-4b7d-b5e3-05c5336fba65"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Scenarios without seasonality, with brake-pumping, prevalence-based threshold\
\
\>", "Subtitle",
 CellChangeTimes->{{3.793441379782955*^9, 3.7934413874126987`*^9}, {
  3.793462250233782*^9, 
  3.793462253686784*^9}},ExpressionUUID->"0e4fa598-d9a7-48da-9f7a-\
7754df60b798"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission:", "Subsection"]], \
"Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793437443696271*^9, 3.793437444289612*^9}, 
   3.793441042673633*^9, 
   3.7934413670396147`*^9},ExpressionUUID->"c3e4d880-40dc-4cf9-9a9e-\
b6e0452a3b15"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60bpnsprev", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"npi", "[", "t", "]"}]}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Eq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pS", " ", "+", " ", "pH", " ", "+", " ", "pC"}], ")"}], 
          "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ISq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pS", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ISq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RSq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"gammaval", "*", 
         RowBox[{"ISq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"IHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pH", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HHq", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaHval", "*", 
          RowBox[{"HHq", "[", "t", "]"}]}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"deltaHval", "*", 
         RowBox[{"HHq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ICq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pC", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"CCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", 
        RowBox[{
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"xiCval", "*", 
          RowBox[{"CCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"xiCval", "*", 
         RowBox[{"CCq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"est", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"npi", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", "\[GreaterEqual]", "importtime"}], " ", ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "kappaval"}]}], "]"}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", " ", ">", 
          RowBox[{"importtime", "+", "importlength"}]}], ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "0"}]}], " ", "]"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], ">", "thresholdprevon"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "-", "npifactor"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "<", "thresholdprevoff"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", "1"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sq", "[", "0", "]"}], " ", "\[Equal]", "1"}], ",", " ", 
       RowBox[{
        RowBox[{"Eq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ISq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RSq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"IHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ICq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"CCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"est", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
       RowBox[{
        RowBox[{"npi", "[", "0", "]"}], "\[Equal]", "1"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "Sq", ",", " ", "Eq", ",", " ", "ISq", ",", " ", "RSq", ",", " ", "IHq",
        ",", " ", "HHq", ",", " ", "RHq", ",", " ", "ICq", ",", " ", "HCq", 
       ",", " ", "CCq", ",", " ", "RCq", ",", " ", "est", ",", " ", "npi"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "tmax"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79343745681075*^9, 3.79343749950867*^9}, {
   3.7934398988085203`*^9, 3.793439978221882*^9}, {3.793440080079546*^9, 
   3.79344008237633*^9}, {3.793440128860087*^9, 3.793440129365903*^9}, 
   3.7934403352992573`*^9, {3.793440999081519*^9, 3.7934410007737494`*^9}, {
   3.7934410441673737`*^9, 3.793441046502714*^9}, {3.793441121159895*^9, 
   3.793441121403966*^9}, {3.793441183647852*^9, 3.793441183999271*^9}, {
   3.793441370675906*^9, 3.793441373807287*^9}, {3.793441418586039*^9, 
   3.793441420853744*^9}, {3.793462310972574*^9, 3.793462330950387*^9}, {
   3.7934623894739523`*^9, 3.7934623972261343`*^9}, 3.793531856263274*^9},
 CellLabel->
  "In[1395]:=",ExpressionUUID->"dc7d79e7-d1ba-4403-af03-71eef77810ac"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Scenarios with seasonality, with brake-pumping, prevalence-based threshold\
\>", "Subtitle",
 CellChangeTimes->{{3.793441379782955*^9, 3.7934413874126987`*^9}, {
  3.793462250233782*^9, 3.793462253686784*^9}, {3.7934629832457542`*^9, 
  3.793462983480081*^9}},ExpressionUUID->"5130feeb-a0d8-4a29-ad06-\
2d43f388a1a0"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission:", "Subsection"]], \
"Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793437443696271*^9, 3.793437444289612*^9}, 
   3.793441042673633*^9, 
   3.7934413670396147`*^9},ExpressionUUID->"a6b60215-b711-4640-be1a-\
c042919c64b6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60bpsprev", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"npi", "[", "t", "]"}]}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Eq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pS", " ", "+", " ", "pH", " ", "+", " ", "pC"}], ")"}], 
          "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ISq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pS", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ISq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RSq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"gammaval", "*", 
         RowBox[{"ISq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"IHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pH", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HHq", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaHval", "*", 
          RowBox[{"HHq", "[", "t", "]"}]}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"deltaHval", "*", 
         RowBox[{"HHq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ICq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pC", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"CCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", 
        RowBox[{
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"xiCval", "*", 
          RowBox[{"CCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"xiCval", "*", 
         RowBox[{"CCq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"est", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"npi", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", "\[GreaterEqual]", "importtime"}], " ", ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "kappaval"}]}], "]"}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", " ", ">", 
          RowBox[{"importtime", "+", "importlength"}]}], ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "0"}]}], " ", "]"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], ">", "thresholdprevon"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "-", "npifactor"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "<", "thresholdprevoff"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", "1"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sq", "[", "0", "]"}], " ", "\[Equal]", "1"}], ",", " ", 
       RowBox[{
        RowBox[{"Eq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ISq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RSq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"IHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ICq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"CCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"est", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
       RowBox[{
        RowBox[{"npi", "[", "0", "]"}], "\[Equal]", "1"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "Sq", ",", " ", "Eq", ",", " ", "ISq", ",", " ", "RSq", ",", " ", "IHq",
        ",", " ", "HHq", ",", " ", "RHq", ",", " ", "ICq", ",", " ", "HCq", 
       ",", " ", "CCq", ",", " ", "RCq", ",", " ", "est", ",", " ", "npi"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "tmax"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79343745681075*^9, 3.79343749950867*^9}, {
   3.7934398988085203`*^9, 3.793439978221882*^9}, {3.793440080079546*^9, 
   3.79344008237633*^9}, {3.793440128860087*^9, 3.793440129365903*^9}, 
   3.7934403352992573`*^9, {3.793440999081519*^9, 3.7934410007737494`*^9}, {
   3.7934410441673737`*^9, 3.793441046502714*^9}, {3.793441121159895*^9, 
   3.793441121403966*^9}, {3.793441183647852*^9, 3.793441183999271*^9}, {
   3.793441370675906*^9, 3.793441373807287*^9}, {3.793441418586039*^9, 
   3.793441420853744*^9}, {3.793462310972574*^9, 3.793462330950387*^9}, {
   3.7934623894739523`*^9, 3.7934623972261343`*^9}, {3.79346300484235*^9, 
   3.793463007973894*^9}, 3.793531912445612*^9},
 CellLabel->
  "In[1398]:=",ExpressionUUID->"4155d2c0-dcdf-4104-b009-14333fb31f08"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Scenarios without seasonality, with brake-pumping, prevalence-based \
threshold, and a higher threshold assuming more ICU beds:\
\>", "Subtitle",
 CellChangeTimes->{{3.793441379782955*^9, 3.7934413874126987`*^9}, {
  3.793462250233782*^9, 3.793462253686784*^9}, {3.7934629832457542`*^9, 
  3.793462983480081*^9}, {3.793463526719618*^9, 3.793463531203787*^9}, {
  3.793468450891225*^9, 3.793468451026733*^9}, {3.794657004981165*^9, 
  3.7946570062627172`*^9}},ExpressionUUID->"08aa2ad6-736e-40e1-a40f-\
75c55daeba1f"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission:", "Subsection"]], \
"Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793437443696271*^9, 3.793437444289612*^9}, 
   3.793441042673633*^9, 
   3.7934413670396147`*^9},ExpressionUUID->"17788797-649d-430f-a733-\
10ee5d3775e2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60bpnsprevmoreICU", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"npi", "[", "t", "]"}]}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Eq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pS", " ", "+", " ", "pH", " ", "+", " ", "pC"}], ")"}], 
          "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ISq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pS", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ISq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RSq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"gammaval", "*", 
         RowBox[{"ISq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"IHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pH", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HHq", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaHval", "*", 
          RowBox[{"HHq", "[", "t", "]"}]}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"deltaHval", "*", 
         RowBox[{"HHq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ICq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pC", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"CCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", 
        RowBox[{
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"xiCval", "*", 
          RowBox[{"CCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"xiCval", "*", 
         RowBox[{"CCq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"est", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"npi", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", "\[GreaterEqual]", "importtime"}], " ", ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "kappaval"}]}], "]"}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", " ", ">", 
          RowBox[{"importtime", "+", "importlength"}]}], ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "0"}]}], " ", "]"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], ">", "thresholdprevonmoreICU"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "-", "npifactor"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "<", "thresholdprevoffmoreICU"}],
          ",", " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", "1"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sq", "[", "0", "]"}], " ", "\[Equal]", "1"}], ",", " ", 
       RowBox[{
        RowBox[{"Eq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ISq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RSq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"IHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ICq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"CCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"est", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
       RowBox[{
        RowBox[{"npi", "[", "0", "]"}], "\[Equal]", "1"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "Sq", ",", " ", "Eq", ",", " ", "ISq", ",", " ", "RSq", ",", " ", "IHq",
        ",", " ", "HHq", ",", " ", "RHq", ",", " ", "ICq", ",", " ", "HCq", 
       ",", " ", "CCq", ",", " ", "RCq", ",", " ", "est", ",", "npi"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "tmax"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79343745681075*^9, 3.79343749950867*^9}, {
   3.7934398988085203`*^9, 3.793439978221882*^9}, {3.793440080079546*^9, 
   3.79344008237633*^9}, {3.793440128860087*^9, 3.793440129365903*^9}, 
   3.7934403352992573`*^9, {3.793440999081519*^9, 3.7934410007737494`*^9}, {
   3.7934410441673737`*^9, 3.793441046502714*^9}, {3.793441121159895*^9, 
   3.793441121403966*^9}, {3.793441183647852*^9, 3.793441183999271*^9}, {
   3.793441370675906*^9, 3.793441373807287*^9}, {3.793441418586039*^9, 
   3.793441420853744*^9}, {3.793462310972574*^9, 3.793462330950387*^9}, {
   3.7934623894739523`*^9, 3.7934623972261343`*^9}, {3.79346300484235*^9, 
   3.793463007973894*^9}, 3.7934635609625072`*^9, {3.7934684759877863`*^9, 
   3.7934684776885977`*^9}, {3.793469024656068*^9, 3.793469025339758*^9}, 
   3.793532081207529*^9},
 CellLabel->
  "In[1401]:=",ExpressionUUID->"e69c1d47-b091-454c-bc08-a90db52932b5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Scenarios without seasonality, with brake-pumping, prevalence-based \
threshold, and a higher threshold assuming more ICU beds:\
\>", "Subtitle",
 CellChangeTimes->{{3.793441379782955*^9, 3.7934413874126987`*^9}, {
  3.793462250233782*^9, 3.793462253686784*^9}, {3.7934629832457542`*^9, 
  3.793462983480081*^9}, {3.793463526719618*^9, 3.793463531203787*^9}, {
  3.794657007470752*^9, 
  3.7946570076151533`*^9}},ExpressionUUID->"5c1298b0-c1b1-47e6-9ad8-\
be0f63d2231a"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["60% reduction in transmission:", "Subsection"]], \
"Subsection",
 CellChangeTimes->{
  3.7933992329693327`*^9, {3.793437443696271*^9, 3.793437444289612*^9}, 
   3.793441042673633*^9, 
   3.7934413670396147`*^9},ExpressionUUID->"023af686-0753-48c0-afb7-\
efa5d8abe745"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"npifactor", " ", "=", " ", "0.6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seasonality", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol60bpsprevmoreICU", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"npi", "[", "t", "]"}]}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Eq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "*", 
          RowBox[{"beta", "[", 
           RowBox[{"t", ",", " ", 
            RowBox[{"seasonality", "*", "amplitude"}], ",", " ", 
            RowBox[{"baseline", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "seasonality"}], ")"}], "*", "amplitude"}]}],
             ",", " ", "phival", ",", " ", "gammaval"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
            RowBox[{"ICq", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "*", 
          RowBox[{"Sq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pS", " ", "+", " ", "pH", " ", "+", " ", "pC"}], ")"}], 
          "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ISq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pS", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ISq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RSq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"gammaval", "*", 
         RowBox[{"ISq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"IHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pH", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HHq", "'"}], "[", "t", "]"}], "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"IHq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaHval", "*", 
          RowBox[{"HHq", "[", "t", "]"}]}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RHq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"deltaHval", "*", 
         RowBox[{"HHq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ICq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"pC", "*", "nuval", "*", 
          RowBox[{"Eq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"HCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"gammaval", "*", 
          RowBox[{"ICq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"CCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", 
        RowBox[{
         RowBox[{"deltaCval", "*", 
          RowBox[{"HCq", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"xiCval", "*", 
          RowBox[{"CCq", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"RCq", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
        RowBox[{"xiCval", "*", 
         RowBox[{"CCq", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"est", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"npi", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", "\[GreaterEqual]", "importtime"}], " ", ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "kappaval"}]}], "]"}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{"t", " ", ">", 
          RowBox[{"importtime", "+", "importlength"}]}], ",", " ", 
         RowBox[{
          RowBox[{"est", "[", "t", "]"}], "\[Rule]", "0"}]}], " ", "]"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], ">", "thresholdprevonmoreICU"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "-", "npifactor"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"WhenEvent", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "<", "thresholdprevoffmoreICU"}],
          ",", " ", 
         RowBox[{
          RowBox[{"npi", "[", "t", "]"}], "\[Rule]", "1"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sq", "[", "0", "]"}], " ", "\[Equal]", "1"}], ",", " ", 
       RowBox[{
        RowBox[{"Eq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ISq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RSq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"IHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RHq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"ICq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"HCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"CCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"RCq", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"est", "[", "0", "]"}], "\[Equal]", "0"}], ",", " ", 
       RowBox[{
        RowBox[{"npi", "[", "0", "]"}], "\[Equal]", "1"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "Sq", ",", " ", "Eq", ",", " ", "ISq", ",", " ", "RSq", ",", " ", "IHq",
        ",", " ", "HHq", ",", " ", "RHq", ",", " ", "ICq", ",", " ", "HCq", 
       ",", " ", "CCq", ",", " ", "RCq", ",", " ", "est", ",", "npi"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "tmax"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.79343745681075*^9, 3.79343749950867*^9}, {
   3.7934398988085203`*^9, 3.793439978221882*^9}, {3.793440080079546*^9, 
   3.79344008237633*^9}, {3.793440128860087*^9, 3.793440129365903*^9}, 
   3.7934403352992573`*^9, {3.793440999081519*^9, 3.7934410007737494`*^9}, {
   3.7934410441673737`*^9, 3.793441046502714*^9}, {3.793441121159895*^9, 
   3.793441121403966*^9}, {3.793441183647852*^9, 3.793441183999271*^9}, {
   3.793441370675906*^9, 3.793441373807287*^9}, {3.793441418586039*^9, 
   3.793441420853744*^9}, {3.793462310972574*^9, 3.793462330950387*^9}, {
   3.7934623894739523`*^9, 3.7934623972261343`*^9}, {3.79346300484235*^9, 
   3.793463007973894*^9}, 3.7934635609625072`*^9, {3.793469009403984*^9, 
   3.7934690100300627`*^9}, 3.793532054139822*^9},
 CellLabel->
  "In[1404]:=",ExpressionUUID->"e9dc0a1c-52b1-4510-8018-8899b77c1414"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot incidence without seasonality for one-time interventions (Figure 4):\
\>", "Subtitle",
 CellChangeTimes->{{3.793442141741558*^9, 3.793442155627501*^9}, {
  3.793640279194034*^9, 3.793640281743907*^9}, {3.793642464810849*^9, 
  3.793642465266344*^9}, {3.7946566264424133`*^9, 
  3.7946566299709663`*^9}},ExpressionUUID->"160c2d5f-faaf-47bd-a49b-\
70c0233dfd59"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"line1char", " ", "=", " ", 
   RowBox[{"{", "Black", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line2char", " ", "=", " ", 
   RowBox[{"{", "Red", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line3char", " ", "=", " ", 
   RowBox[{"{", "Blue", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"line4char", " ", "=", " ", 
    RowBox[{"{", "Green", "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line5char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Black", ",", " ", "Dashed"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line6char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Red", ",", " ", "Dashed"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line7char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Blue", ",", " ", "Dashed"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"line8char", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"Green", ",", " ", "Dashed"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prmax", " ", "=", " ", "850"}], ";"}]}], "Input",
 CellChangeTimes->{{3.79339982821106*^9, 3.79339986270236*^9}, {
  3.7933999978938227`*^9, 3.793400003045478*^9}, {3.7934849909146833`*^9, 
  3.7934849978857813`*^9}, {3.79348503674374*^9, 3.793485052714149*^9}, {
  3.7934855796938047`*^9, 3.793485580159594*^9}, {3.7936402999196587`*^9, 
  3.7936403176036463`*^9}, {3.793718714083852*^9, 3.793718741365986*^9}, {
  3.7945076539946623`*^9, 3.7945076542109547`*^9}, {3.794575999550634*^9, 
  3.7945760001252604`*^9}, {3.794576670674024*^9, 3.7945766708056517`*^9}},
 CellLabel->
  "In[1477]:=",ExpressionUUID->"35976152-c853-43c9-af7b-d6fbec4053c3"],

Cell[CellGroupData[{

Cell["Four weeks:", "Subsection",
 CellChangeTimes->{{3.793442276145667*^9, 
  3.793442278863884*^9}},ExpressionUUID->"4aa234e1-ee7a-4d63-a6db-\
41cae3a750e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sf", " ", "=", " ", "40"}], ";"}]], "Input",
 CellChangeTimes->{{3.7936403438253593`*^9, 3.7936403471896343`*^9}, {
  3.793640381348299*^9, 3.7936403977456293`*^9}},
 CellLabel->
  "In[1486]:=",ExpressionUUID->"fcc0e3aa-4e5f-49f7-b1e6-87a602c15158"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot4nscrit", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x4ns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x4ns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x4ns"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x4ns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x4ns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x4ns"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", 
               RowBox[{
                RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "4"}], ",", "2000"}], "}"}]}],
         "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7936404543772306`*^9, 3.793640470827922*^9}, {
   3.793640511433079*^9, 3.7936405164159317`*^9}, {3.7936405863378353`*^9, 
   3.793640588977378*^9}, {3.793640901850996*^9, 3.7936409110413313`*^9}, 
   3.793641022966834*^9, {3.793641344008607*^9, 3.7936413515934067`*^9}, {
   3.793642469646597*^9, 3.793642490096284*^9}, {3.793707616488316*^9, 
   3.793707617304297*^9}, {3.793718726457984*^9, 3.793718726948018*^9}, 
   3.7937188032738047`*^9, {3.7937188403160963`*^9, 3.793718857504669*^9}, {
   3.793718889953663*^9, 3.793718900240761*^9}, {3.794507384296419*^9, 
   3.794507388282158*^9}},
 CellLabel->
  "In[1487]:=",ExpressionUUID->"9d8a20ba-d60c-4912-9a5b-6a9d62e5c7f2"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF2nk01G/UAHDrLyFbyFbJviVm7Ms81xhjZhBCJFu2SrZQFCLbVNZsIWtK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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59685#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF2nk0VV+8AHBTESJDylCZZxLXrLu/XMOdhIwJISGZQ8o8XCUkhRAZI0NI
plSmTMkcomgwkxIhU/W8td77df+4d33WPmd/v3uffc/57rWOgL3H6Qs0VFRU
k7tf//tLvDDX3zhfhaX6vw8djsfzE3ci+n8rZKakP+XO+8+k7ncVGdyV/9nc
4dfLO9wt/3n8+HVcHPfgf846aBB1k3vqP4cxPBWL5l79zxZnsst+LNPB/5vp
b5iV3lHW/yxi9H3uVQznf77So4pSVrn/86FKto/U1Mf+s1XstskU1z/nOEy/
aZP+Z+mDz57FWPyzlp9t0sHyf1ZKN89PPM7/n+1s8q0fffznSCJvaur8P+cr
3R68ufrPiyzXSG6MAv/Zr0FfVV7pn2P51zhfxP1z9QSuq1dD8D8P48OW4/T+
eb20not8+p+VA1TtOpz+uZbj+HrjnX9+ps3DXzH3z++LzHU8f/7z1oEkF9k/
/6w2zlpVxCH0n+t89xBzsf/8Iv/H5cTEfx5jlk09nfnPO96X6g8U/fNJNMMQ
1/DP9e8+ZFAW/vnjSe5XuLV//pNrNkdNJfyfsZ798sEH/9lmmMVCg/+fgzXI
QVuS/9zA0N7uB//82Z3uG4YkDGJhdnxGS6cR1ZAm+09TYUDDbZWilvmIXz1E
+YmtMEw9Ej2qdL0ZQfYLK49LwvCgSaaoDPcW2dJvhcn4CUP93xysCfkzCnVT
LvgaKgy5ah1SbdFzKOutT1dhjDBkGYTo8Asuo0bVimWnZGFY8HWXjHq6jj5n
LnGJZgvD3bau2HdLO4hqr4zGVLEwRKwqdOBmqYHf1cUup1oYaKp5tR7m7gHN
gYIo2yZhKLTUng0t3Af2KtPFR7uEwXBO7Z7V2n4IfyDYPzYsDM2/FLT2aLFB
s0sG75lFYfCo9rskepwLns5fumSzvjt+ufOjB/MOQ56z2vPzVCJwIhX3Je0E
L1Ac31m6c4qAGge1+A0CP+Dt2dIiNETgyuYcPkdGFFS/fJq/oSsCggpe8ryN
YiBpW6p6y1AEivh+BL8wkQBmG9JoioMIYJ/01BzWl4beM5TDpbEikIlfFat5
LQeNI8bOT5NFoMrhzvKT8yeg3FywtjZLBM4Nzn/K2TgBd0wbzF9VikB5qxnX
LKcCmBltJo+M7cY/aEi5zK8Ien3tM+MzIkCXaWtffl8RVAySlSZ/iIDo/WYV
B04l4NZXGP5GJwomJVe+c/5VgjG820Ha3byZCF5NJxtUoLtd/QKDsiiQn6m0
f5FShXpdxqr9mqLQVifm6XdPFTK1C0wOm4rCF3LlEq2rGtjDl7syQaJwe4ON
hpFFA+aUTdktunf76533eENCsCZ6kvWxmxi4HimY+HYAB9gJrfab/mLAzczo
KG6Ig6gMfIhzhBi86rYbpbqNAy5OkyWhVDFgo1kIyGDTBiXqS71pLWIwc8yr
aZtPB/w/pMTf4BWHG2EO0gXmerATv8rq8FocAo4ll9oskkCbtNWuOSgO6z1T
Xm5yZIjdSxV67JM41P4KaBLxIcORIKYf71fFof95E0P7FhmwLoJ9RvwScNjR
MWzf3lMQom14G12RgOSOxRYiiyHQbBYf4BWRBNLTD5rnVU8Db7fWT3RcEvyF
99LynT0NmOzRIQdVSbg7s5eBOug0XCDQ3y/Vl4Q4jpGTxk2noSPVXkTLTxKK
cuoqpcnGEK/GrXaxXRIk9Aj0WpdMgC8w6nzNRSng3TKJIw2YgaLhEd2xy1Kg
/3v0WP6WGZwSrhSnDpaCfbHmihpC5hDS9eUb8Y4URKXrsvL5msME30n/j3VS
IKFQSl3BawGFL3/G7mGWhr1Hj0i7+ZwBpb+21cal0hAxvDKYbGoFZP3GcJ1a
acA96Fb+FGkF5+8fM1Bulgba/It8TpVWcFv54yzPsDTQKKcMKHJaw7zHWe6J
37vrNOVLbP+wNaR/Ng301JcBTv5kJ17nc0DdTNSKW5QBvz1rn+ut7eDwgSKW
kHUZMJsJY/S8ageyNvs+eFLJgkfO9V+aSXZgudV+2YRTFuI0DzPhu+2gUl7n
Ia+GLKjIMeSMYe3BMRcxFMXIQqmikYKQ+HnoisT0tEkeByI5nHqY/QKosb6h
SVA8DhVfOl5pKl6AR6l2ymfhOJjhbkoMmF+AiNJbWUumx4ETXTOyzdg9fmTO
+3DYcTD56xEqI+kIj6QyDrm8Ow4n7zO4OxKdgKtagYyZOA4flydHGDycIBI6
Q/8sHoe80Fb67rtOUF607UOgloOCKyKNz8adIKZB/OM4lxw0CfJTH73sDM10
PhtafHLQkbC63J7iDBuEBvZHAnLwJ23yVUK9MzgOmup5S8vBKxuZmiLmi6A1
H16+V0sOHl045zjdcBGuyvZ0XtKTg7azbg7syxeh/DL3dB9ZDlIL9u0dFHKB
o3/KuO+by4Hyd/cX3XEusMk+Hn7cTQ5k2yNpP3pdgnINZVOLFDnQFpB0K/Fw
g9mwcI+XGXLAWzzcWfXUDY62d0cL5srBNjB/u7/hBrFGDvWLj+XAp9vBZjrS
HZwdE8TCXslBv+6AyGi+Bxy7/XWz8LscRF8kOmH3ekG9XUhhxU85mLErrjsn
5QU2Chxnnm/IQbyVcmuLoRekD6vVdtGcAN4DdNWm6V5w+MhNvyWuE5Ca+Wvp
ipI3sBeJ/8SgEyAwV5696XsZ9rRcWGyIPwFmHte2Tfj84OuvTx+H5ORBiqcl
hWk4AKqd4puJSvLAM8bru39fIIS+w+Y3qMsD0/m49IMagcBVk+FWqCsPJIal
xhM5gaDld3Yn0Eoerub5Rjq5B0Ha6jC38A15EEx4jRPeEwL45W4T70/ywK4Y
832GJQw47IJUZqfkwVvUROKraBh87JPms1qQB+4SNt4BbBj4lMdM6qzJQ+Wz
imycexhkehC8uZkUYK0YKpLehMH6t5b4RiUF2FPuemorOByarH0uK2oowGub
XprcxHCI7RYyL9JUgGzltEC+onAQfBx+NJGsALnVtGZBg+Gg7wqPnex3+8sI
q30nGgF5C887WW4pwL0hOdW/jRHgfs9AyOWuAgyuii6ND0SAsvZkQGuKAijX
pw4HT0VAZwajTGCuAoArLpmWPhKWDc/Ez9cqQIKqxrm/+Eio+704q12vAJHr
WsrDFpEQWRQKWa8UYFI+VdjZORIO0z1aNutRgNYBLqa6qEjA1qwbt0wqANv+
gLS/DZHA4HCz5Ni8AmDPZNSkdEfCwIGjewK+K8Ah/7GCmfeRcMFFp/rEpgJ4
pIuaP1iNhNgjiYczWTAQH8Wv5yJMAbNOMa8tDgxYcewzvXecAseuPH9tyo0B
dN1++7IaBSr6Jq4xC2Mg9oQFg5oBBUYjToxfVcXAvsSZuQUfCuTItSoOYTFA
9lwLigqigOu4xS05bQzo6CpndVMoQKUcimZPYcBRu0nCOokCnZMcKVomGLhs
vj6fl06Bu7cLfmScwUDTxYsTybkUEF3oyTZxwMCy3aSMfzkFfiTbb5VdxMBz
+XejjtUUqMOtn2bywEDSyITHn+cUiPwRXezos5uvEV0WtokC+hlH6JqvYqBh
yERNrI0CXMQnVkdCMOD7JfBobScFPq9rV/lHYiD0J0Z6uYcCRbkj+wejMbB1
UxE3MEABH0NXx+PxGKARU8adHaYA9vff+puJGKjSXWGKHaUAfdHdQzOpGJC+
eCzIYYwCfWZinpqZGLix/4rf1EcKpNE+70jPw4CuNHaE6QsFHMpPCWwUYkCU
aynl/QQFZK0nrhqXYYCTvqPTcIoCG/v8BkorMUBvVh7mPk2Bpup9Uox1u/mc
ie9XmKHAzfMZERcaMDBzkdyTtWuTAyfGGlsw0DLWE1O166MvWzB8nRiI2/fn
iPeu5y5axF3pxYCqXlPK8G5/FVyL0wODGOgK+806uRsv4FUIVvY9BtKxU1n3
Jimg7clxL/oTBuSXt6JXd/NlOVKwNDWFgTs+Wwe2PlEAzCLGJ+cxEOCfovx2
nALe8efeTHzfvV7TAwO2HyiQ16H+7MtPDDi8VObNHaHAMPXhgs8bGLCnMiWk
DVGAQX018dNvDDSW1Sbp7s6vmk9f+EcaRQjo+qHyaHf+H8zcsBljVgRP/IpX
7O716jt2gfyBTRE+BC3nszZTgOaMptp7LkVoHDB3JrykgOObzYMju3XT3m1E
P1FBgRS6Ydp3Iorg9hGTpfl4d32drFgeklSEM9RXNM4U7M53uUv3W4wivBF5
vfYkjQK287rPB1QVIUbRqufnXQrcERQq7McqgrnUAamlWAqsJ36I7MUrwoKD
2HnOYArUXyVrvLFShOoY/VxR6931WCEu2WmnCBkYV1stEwoILtIdfu2oCAfu
f73DS6JAlM3Ln22eivDENe8Mg8ruesTJFjdHKsJTy7OhH1goEBzImNoUrQjS
lx29VmgpUF41E9V4SxG27jl6vdmIBE7xTPv6FEUoyj5M2/YlEsaYD/DUlSjC
5X0zWd/LI8F1ePnGk0FFEJzeCMvVjoQHrD1+5aOKINPw4ZW4UiT04Yscyj4q
wt1lbNM1sUjAPLeHx3OKEK4ePnZ9XyTsZL799WhHEZycP3GdfRMBsRerHLOE
leB9tGFujG4ELMDjG0ySSnD8LzffC4UI0Dv8sMjvuBJ44Y651vNHAE174ney
mhJIjYz7aGyFw1VhH79NAyUgLrLkqhaHg+Mn+ajTAUrAEybLwrE3HDRNyx/S
DSjB+r3K6K2HobAOxVPOIcrAmmWksxISAC/yvt6/EqkM2mtneopMAiCcQdo4
KloZbDXV8j0lAoClr6Qp964y/NQUnBF7ew1Ez5U++FigDNkx+82txa6BWdAT
C5M+ZdCyj7qf/9Yfqp7VdCEBFbCVxPJugh9cO7IRcUpUBXr9kl/MHvYDCFNR
t5ZSgTJMybutH77QhX9WeE1RBVw6hc/dzvaFqXd1UVUEFfjQ8mGJQucLnOsv
QcpbBS6fj5/d6b8MPvItlVyvVEAkoOLolTgvcMTwZyV0qEDt1s0LXU5eYKEU
GMPcsxuvae2GhZYXqKth7GlGVSCPaVaKa8MTaLTyWL9/VwFfUhy/tKMnxBtF
urTyqEKM8wBXXao7FHlq8/t4q4KudVMoMdoF0r2zmJauqELJPu4KarILxPns
rF8MUoWXE2tvxVldwNO/svvcDVVwP+m81Zp8EZRDhQNID1QhFVtkgyl2hpZ4
umHBTlW48tnEOHfOET6VtsT0C6gBFeitEJ6eh75vdIvyYmpQ/dzj3snI89Ao
rUNOlFYDzWXm9gTT85BV1MpsrqwG7C+aJ85s2oN9flvcGFkNhuTm3p3VsYeZ
jI742Stq0HWdlef5d1sYHmP4gQ9Sg5kh9ndBrbbQzkswLApXA8x+Hf3UdNvd
+u/1Abc4NfAZoLMdIdmCS1JnwkqOGuCjRbD9VufgW2zX3d/davCBXB5du9ca
Pr5hXrV5qwYUkYHbI/VW0MOob9I4ogZJL2YNU69YQemNbs6ISTW4VsnZvLFw
Fjwje5IYNtVAvSLiLduoJawG9N3jEFaHBNNoq4Z+C9h2GbwvcU0dYn33M9bJ
mIKJknWCbIg68OvtZIZtm0AJ9UyUQqQ61B+NI9S+NgGblF9eJ2+pQ6P5zVQP
JxNoauXBG+Wog4BK4bWlAmO4zm+36t+pDkEVhUlhGqfh89f5+aBedagppM1+
f+A0qNR4fwofVAen73mqydNGsKAf2Rn7UR1+Pktnlb9tBPoBBVlZK+ow3xuo
MjtvCBzD38gdPBrwEY02gLUBuGb7aXUf0wAZ0Rs/EtgMoMX1r/KAsAaIV5mt
3247BX60bEJjshpgfd2U9q78KRiVw2wuaWnAONe38lB2fciMufbw0CUNSJ7e
x933gwhSmvR/HJ9rwLHrv0zJR/V26+VisZFGDSggBmMPfNEFDKehEaFNAxIu
FRd75umCxmxKnlS/Bix8s7pGLaMLp+IkST9mNEDkwPsqdR0d8B7VT7nKfhJo
/cBtdHc/uK610rRw6CTkCvSb1lvhIKAk+evZIyfB+Gf8dwkJHESGfMJixU/C
OKZP6/YrLUgW8ZqmwZ4EifNTa35/NOGZV6J87MXd9q+DrKkxANgPKla/3U9C
MP/Gsuk5gGbtcYq7z0k4w29jGbVbVnUeEh01DDkJJ9bSqq/VIRh7WRNyMOkk
7O1zHe68hAUqxg9dDxpPApPK6dIz6+qglyPg9OQQFjrxlekmGcqASWERbePD
gmj93MCcnTLw39qeei+ABaHzDV9YxZRh6+qQPZ00FtLdyFsHnirBY6NoG3PA
QoDq3jd1/YrAQb1s+tsZC66dynqx4hig+jXOye6OheuOGoZP1hRgcbHzrehl
LJTnPKkx2a3r2kbyjAyDsJBrAAzstgpwtdxCPzcBCwzdsoG6mfLw6VyjNqEO
CxF3MZnJCiegy/QxrU0DFi7/6Fk9zHACaklpzd4tWHCOe/eVflwO7ij7QHoP
FirPJBeI3ZADHVZxjaUJLOhub7vnth2H4vp4hSQmBMHTxcemLWTgypFzgl+s
EPRqCbQw0UuAvaGc2Zgdgs8kztzODnE4FUF9850jAk6bDmqhGHEQnc9d7vZE
YLl01jWNTRwGK+ca6yIRJIyGOwSIiIEc2ftcYgkCtoJ9JW+dRIAvBHc3/gkC
4RtvRsLlRYC+grP9ZjWCqAcizVW/heHjoRrZsEYE2YM8i9lJwhA7uf3bbRAB
iWBy3euNEMxdo6Tr7SCwMJAcn9IXhAUzKedsKoBkod9zwC8Itj84aI7RAjQc
EPy5/6cAkISmFXkYANz7Jd3XUwVAMPp6xgF2gMN72wOnF/mhz6TL9bcIwNlg
I5ly8jGQXjRleqcPMLmzk1/bxAO1JuSGm4YAA0SPPegqD+Beal3GGgNsuvCW
3TjBA5a3jn94aAHw84qZgHUeN0TL7Sv2OQ+wv29FoO/OYZjxeUFkvwpg6K2h
rZfABd7jFX9aAwAYDZZouE244LdOYcXVYAAb0uiR24e4gPNQMs+XCACDm056
TlkHAffMY6HsFsBEWsW+qGeckPVb8KZ+HsCpB1siRxk4QNqRG0tdAKCivl0e
OMgONT2sK5WFAMySQxxO2ezQk7lzhq8MIJRD5vKoBjv81hyW+PoMQI3daXnf
NTawjIp+faMXQGZzUvE88wHgYP3B0LIF0Psl/LvUASYYeHnzOuE3QH+py5uE
N4xwx1Vkb+9fgCLRH6YPrzMCe6cl7Xs6TZg8ZOjZQ71rSuvvJRZNML34+sqv
3wxwYDtthVdIE/p4ayhqnPTQV6jolS2iCbR1m9aVo3vhtkXfkqi4JmRRzwQ0
Z+4F1uo9307IaILPbHJaksxeYPHynNVT1oTwH6+GvhnsAeZZnbHLJE3wj6Qe
5Sqlha6kz5ab+powyFg3JBpIC7HaAaPBhpqg6EJjXUWkBaac8uFoU00Qyam5
QJinAUZr3v7Mc5rQ5D8zIi1NAwxvf7S+uawJ0oPzrOPtVEDXcL9MKF0T4uE9
a1/GDnqvoY3/9EATPogz/uY32EFldYuf07I1gXKjuIdIvYMsq0+ysxdoQst+
FX5+52305PEnH6oKTTg2IBNxB20hm3QhtfF2TQg1Ug1+wLGBMDxdAymdmtCx
ptnr0f8L7UvxuWTSrQl+dxIY1uN/ocq7relvBjRhgXMbc5j1F2KKcfr7bFwT
Mh853PE9uI5qrxa3JP/UhC/EK4Mamqvo1i9j69Pru/M7Tt0Ytm8VnffdWdu/
qQmzN3H3bAd+IhYvfTHK7n2TNepO9/SFn+iC81L05X1aYKf99dnE3RXEbq5g
YHhMCxypFpIIjMvoEub56D6SFhDE5O8UlSyixr6hklp9Laj1yf1peG4RHXT7
EeJkqAXXv8f7v2ZfRA0PRURbTbWgjEZzQizwK+I4dNs71FYLBhb7FywtFtDz
TQemX75acLCNPyQTM4cOJId8fOivBcqspPcWP2fRBfm0JyYBWoBfuSnbWDGL
WC/1mleEasHnpdNj8Qqz6PyYap5bjBYwCKm17D85g5gaWE5OZWnBjGXhNyX3
KWR7VuLA3VwtsDfdEmFXnkJVv3CTmvlaIPDws3c41RQ6J3c1OrNYCx63N3Hz
JU2ip9mTQ5bVWlBVJqLH0DqBzkbWuve/0YKHTT+uXcR+QcUE+6z6dS2gxp84
t8gzjjDSAli0uZsvh2F5Wv8Yqmf5/KFhWws4CheTaaPHUN9b60NNVDjQ+z2L
/mx+QKvWZ269YsTBrfqpBsep9wjrbRjYcRQHFucnPMJHR1C7CSsPQQAHPMQL
JKb7I8hQuafmtRAOonmjJRSsR5D9DulnpzgOjFLvpxlPvkPXo/RcuuVx4Koe
5uK2Poz60rAWA7o4EHNp7L+gOITOBP1eO03AgayWK9z5O4gmzr24+5aEg3cn
Faj1OgfRqrBa76AhDgoGXMdO2Q0i7jJF3XeWODDsij22mPQW2b+Sxoy540Ax
S/4I5dAAWvvKc2AmGQfNUQsq8597UGLGbHt6Kg7kzWLaDGN7kIJBZYhxOg5K
IHglR6UHeVXoLzVm40DlkWM9TWI3+uYf2nO/BAdPbQIqDEy70PSemVijZhy0
v2DJP0rViSJrKrQZWnEgdWnCnu3ZayR0MWSnvh0HHFUP97V7v0Z2XYddpbtx
wOQ6Nu8514HG75BI9CM4qExTaL8y1o6Gjj3Z9/IbDs5+ShLKmW5FPv1BTZd/
4EDz+eyTxsJWxBFBvCr5EwdYqSj6cPdWZDQzOXdvAwe/5lZWZzZbUHcJV4c3
rTasOv+Q5jrcglpVA6PEubVhwHC/dYhnM6oy1qNN1NaGs1evkDH7G9ANUi2F
T08bwip96D69rEdWOAmGhwRt0I0t/WztUY9oFJj2V5/Shtrqfo3ywZfoFHsv
14iFNvSXx/VhHr1Ac31mknxu2sCqm/zysXcdet7RXpLnoQ0qvWcocLwO3WpU
OS7jrQ3v681JUYvPEKacB4O9og36Ow/YBS8+Q2HxH0/ahmlDHG/WaWuXWsRz
ytEoL0kblvHJdRu7D85vOu/eSqdoQ/lJ/Y1Ko2rUeBJvVpWmDUe0y5SouauR
o4zk2bbM3fGVH1iHwir0lPm7w1yhNpxQvIXj76tE5De+/tL12oCVP21JpfQU
heApmZUz2hDi/VyUaFOOBmycreTmtSHhc+RlW8VyJOxL4i75uns+Y23mB+Zy
1JnNdjf3x67j/3L8ulqGOLczou5saYP1lHBmIK4UPXpc7ebJogMrvkrFVpvF
aOtVquTiAR3QosMHGj4tRvrvA2edOHTgcUjY6zW3YrSyF2d37rAO5F+1va8/
XYQ0bHtNTgnqwAPuQK+/HwpRH/ucurSSDtxnuBc7PFuABCXebBSo6MBt27YN
hpIC5ItKq4TUdUDv7vfFXs8CxOPqc5wXdKC15Ygc504+cmilEmIk6oDvrzw/
HHc+2rjCzThnrQO0j2SnQ9zykMA4cSSXogPidYT3F32z0c1m9TLTGzoQPvjI
cL9uNlopkI6ij9GBAYmIP7KHslGzNwvm0m0deCuzPTldl4UcGAbi5e/rgMdK
xPct+iz0SOGMXlO5DuBEn1VRvDLQAW7i0ctPdWDa/LV/p0AGuvpHbU24WgfE
muS+fhtIR8TXfLk3nutAUmkObZtyOvpq8/mPQZsO9ByxY/Rguo9kbzpVf/yg
A7lJzwq1R1JQsodF3O2POhDaU94pm5SC/poQHLS+6IDxft8TXadTUN8xKfb8
GR0YPECzfrDvHvKq+u7mtqwD9BaB9qkDyajys6/Izl5dOHn8PC3VWiJSU45M
5JbXBVKJ74MnBQlo2J5bKQOjCxu5fIpd1xLQ5Vul7/iVdWHv/u0XlqcSUMn0
CI+4hi48OMB3oWf9NjqaKJOtpLvbPn/M/yv5NqJZHn5sbKkLSn7uF8q4b6EH
fK4G76x04aaD5LB4dxxSx1MvW57TBe2j2ga2YXHIJ1MKY++gC7dLmaf+fI1F
M/qhdZ7uunDwjInlk9cx6E2RRHtcuC7MTZwYyM+LRs7D9c5sFF0I+kx7Y8I+
GtHRmDAmXd/dh9gHbnYKRCPsmWD99FhdMJl+EX0/+wYqp3/7tihZFxhu/63Z
X3gdJToEfm4v0gWBR49YXw9RkNXR3k3qt7rg63K568T9cMTC7V31fEgXOPaQ
ZGedwlETx0Ev3xFdiBte4JBUDEei+87OzY3rQiWdD69hfxha+jkz3DunCx2j
WisTrGEo/PWfpxl/dOFNrzEeTwhBmJZsD3NqPSBna3+aWwlGs/XaUmx0enD8
O0aakhGMyJU3cyL36YF+eGbzw7UgdDCTK+ESpx7cI7h9UHkSiB75yLqrSuqB
PZ1XjJLxNWTp0S/xU1oPknyfHtVmuob2u/hMlxzXA84woQH+lqvI+1ydFb+i
HnAsHfLRULmK1Im6JHrQg49jgg9KJfxRzzEb8SFTPagp0z3DctwPhfJQT92y
0IOV0hcxDSu+SOFgXib+7G48p1t4jhpflMK4wPXCdrc9pk/9nqYvsl/z3ZN7
afd8gZqXLdY+aK0zbsIzTA825FWNGCq90RjTkPNOhB748WXEfo30Rs1kvqXd
ZxoMYP2bjc280e2eou0HMXrA1fHa6PGWF5IcaOfsTtKDOyJGrlYEL2QzSq0n
UaQHV1JMN99seSBtHkJ3ZYke1Jcmbg8VeyCps7eNoUwPRhk8Ep9be6CNsaO2
5pV6kPrSdmV/izu681n9KqVeDxZSRNWC09xQ26xv8ZcBPci5V9ZH63oJlYi/
POE2pAf5XApXL0lcQncv0tVuvNOD98V/zoTOuiDbr3daWMf1YFh/VDr/ggva
+l42fnJWD15/urly++JFdHx9njVtWw+Ees0Phd9yQlzKJ5JF/ujB/NbIncNm
Tmjnij/fEyo8eDuqJVoddUKdm3slOvbg4WWNVeRsuSNy+C2ktc6Kh2fnzdK/
jF9AKXQ2PqeF8VAyPvxC0swB/Tl/SLFfFA/pb2Y/Dos7IIdXfWsGEniw5DnP
z7lzHsmF467oy+LhpmFmuUbeedTxV/waXgUPqWfP9vJv26NfWz9DsGQ8bLwh
GTA12yEry8fw8hQejuS2LEhk2KHmZ47UGkZ44K1ssmvxt0O3/EfDVc3wwLV1
KsHphB0SXa+nYGzxsG402aD5yBaZLUfHSPrgIVqgDq9sdg69MMSRC/3wAK3V
a+U855Bg+Q6z+FU8bN1a6v/1yQZ9d/e4JRKMB1lSvlPBRRtk0iNukBeKh4Qx
CHkmbYPqZCZYhSLw0Hz7XDThuzWiLJok8N/Aw57Qu4/nL1mjBRLL6cybeMB1
jk8Gilkjw+J29qNxeIgz5dJJ/GyF+FzUEnnv4OG7/otGU6IVqpw9do8rHQ9Y
5cdmMWuWiEdv1DzpAR7e1NcGJ6ZaotD8O4c5s/Fww4VeCXfSEpEv7Eljy8dD
Vlq8W0rkGTQ1sZDOXI6Hi0aK9cY8FoiolWcdU4GHJ99xR583m6PybOujjFV4
UL4xght2NUeBtn2Z9HV4oOer2pJtN0McH6tyaFrwwJh8ve9Isim6xRwUVNOG
ByrZI7wEvCliVNe2cH2Nh7yqGpacHRNEkzKwf7gHD+LDyjngaoKC21Lnbvbj
YTv+OU+tmAnaWrV9hQbxcC0g9FvjtDFaMVryLxzFg60Eo/HCRWPkHlptbDOG
hzpmt3oNOWO0UBoky/EJD2r5K03hm6fRFybmqcApPOyMvLNJTDiN+lrFDQyX
8BBArXw6o8cIkVeXJPas4MG5xMzqcaYR6hCsoatbxUOGUHKGuJcRagjRqRPa
wgNN8+PmVk4jVKpqL/KLjgCmDWlEOGuIYh/f387gIYDADMM5jc/6iGHMfvj0
EQJ0q/WcCbqujyIZJZ/Q8xNguzBP99RxfRTgVOvoJUKA+HyyqFM4GbkIDPVr
yxEAHuVPciuTED6J5dFXHQK8W91pEx3Fo5ZXQ+FZeAKUX2oi8t/BI1hJtzYl
EYApSEeQi4xHygZSHA2GBHD2iO1ab9bbvR/jg++cJcDRiDZG/xe6aE9QmImq
FwE4u2dTWlu0UeXy4mbDZQLgi9nG1GO0kYOjRaauHwEWJ1psfhtpoxaD4wvG
Abv5dUtJu33GoUjB8RB3CgEC7tWJ61PjEF2HSnFuKgH2qwxW+5tqokqNPEPJ
dAKoF1owfxfQRA5PWNfLHxBgTXaj7f13QC1pM1CfS4COmUUfkZuAItwSh0ce
E+D60ZGF1DiEaDh+ULM0E6B0y1smo0oDVVw/W5DYQoDg885ljLYau/uBNjJv
OwGcLtXoNjBpoObpjHviXQRgVJLq4HBSR+G1JBncMAHYWmdT6WTVkLxMzcDr
EQKoKooTdSZV0US2oL/hBwIE/jVW3ExVRVoxm83WnwnwPkSpt49JFVHbFFj4
L+yOF/swcZRaBZUPsP/5s0gAtVv1madeKSNbveBcyhIB5ldMmM5HKaNGOdPv
d1YJIDbaxBXKpoxCaWkjH/8hADd1URyXohKiKrQpm2Anwp/z51lkfDCobfGd
e+ZBIqS8MukvU8KgWDkjWavDRMgq6w0W2lRAh2pxj4eOEOEXA9Hvb5ACkm0X
L+4QJ8LzVwVf/G7II6vplfxSLBFMfRt23hTI7dZ7ro6XNImgbudLMnWTQ3Ou
0yLi2rsmmGyYKcihy6vv8rIJRNgZmL/TGXYc3aR9mZNoQgTNMbkCxTYZ9Ezg
+oNrLkTo0tWszE2WRMEXqGyU3YhQJi08/kRFEmkXXj2y6kGEtfl7hQ1jEqhP
zjXdzZcIUznUs0ekJFCyz/RZSX8i+F/7hLk9JI6sam14Z68RwenLkc864eJo
Dhml2YYSQexgLEPDhBgqjeg8cySCCJMvc+3zksWQTzuO+z2FCH2Pv749oC+G
/p5SSjGO2T2ed6yquUkUcdnwJusmE+Fd66fLZl0iaCw70ZQ2lQhBlrjwobsi
KGd6/8HG+0TQHh7+/cRSBMm4USWqZhNBznD3HzojjLQDpxOkS4hgOZsu/H5D
CHmnlcWxNxOBx9ct0phVENXspF1vbiHCF+KXNy0DAmjHJirMu50I51Q4BU4m
C6DrQta+A11EENjbcuLSEQGUXsJofecdETiP5d0bluFHrfUXpNm/EcG42DzL
o4EPMQoYiTYvEeFHDI9SjiEfMozQ4PdeIYLHZmOv8CQveq/HwTnwiwj4t/03
XJh50fe+xu0EGhJ8nap0lvLmRgoKJWuae0jwJEHHh+0AN/JPure0TE8Co2uL
V+bKDiNaS/dJo/0ksDFL/vJs7RA6PMn7hu0wCTAPmJKOpHMhax361iYeEtyJ
+1tTT+JCOQUr9V5HSJDopNG+/PsgknZ9XdEvSII1+SJhG5eDyKunsiRMhAR7
+mbLGoQPomq5rPwT4iQQKrueTTvBiTTX/NISZEgwdJNePuICJ4oyt0/UlNuN
p7C6f1aKE3U907+1LL/bn49VZ9AaBzILFg43UiGBwP3aq6yxHMiFfuAiG44E
rHMhtJPl7Oil1A0GNncSGMiMr3dN7kdKg4e673iSgCW0eKvVfT8qDyxI4LxM
gjCJfHfvTWaU093Gc9ifBJXrwo/ZWJjRDY89MsfCSSDx2Kk0Q5ERnX4abiST
TAJz+W32uOt70Zuz7FxlKST4Us7ZM82+F2nT5byXu0+C02dd2XIe7EHKpk3n
MVm7+T56r+RVQ4f4fv31VS/atdWA6IMlGjSrFpRGqCeBSprBSAH9X6ztJPO5
N40kEI03buBV/IN9H5MupP+KBPGUXzPVDr+xXWPPSww7SPDbXpzueec2tiJ4
q958gASRuq6d9pUbWCmxmxGjgyTwf1rKeHXtFzavlxt/9h0JsL9ych1Vf2Hv
8av224yR4Nq3wq/HOtewgc1XJi/MkCDrr4f4Zbaf2DUX+kezcyQoiQ0JL7m0
gnXnuOd68SsJYlpP67u9XsbaOVSvuf4gAYOIvuZ4/A/se2bduu8rJCCFL3/2
XF7CmlQNBXuukeD5zBeVmc7vWN29a/Q+WyS4zpT17WXSIraxNLJrbWd3vqv8
zPyvf8WqmnMmXPlLgnt2G33ZYQtY6UcKPAF0ZHC4y8KxEj+HfWj46uPOXjJQ
0ZXMeObNYo9uns4N3kcGMmnvFEvzDJaN6C0dzkKGNHlaHwvuaWxWEyuTGhsZ
hF8fCziCm8LKqT6eX+bYdY2snYf/JLahnNhRyEWGzt++OlHPJrCnxOfy7bjJ
4Jihrpe2dwI7nkmhcPORITm5lTJ57gvW9ZCQQ/9RMqzOn+FPa/2M3b7VqBUt
QAaBFKzSuvJn7M29NgKawmS4iLvcfc79E5Y7ePvvhigZHrAI5vyJ+oh9tJby
sVyCDAfvHpRQrRvHqrgpvXSWJkN3/2hWCMM4tn3q7X3+42SI6NrS0/Iew5pZ
eV0bOUEG8Ug66+VfH7Azb1nO3MaQQXTafKU79QPWl1SijFcmQ5LKwYgd+ICl
e0XgolIjA99zglP6+HvsXbXZ1RoNMuDnTW//9HiPFayIfOuByJCD0pb0Nkax
TyQEK8S0yPBM7YrfJ79RLGQ33P6kvZufuT4X1eIItvewtcc9PTJosgU1LpmP
YG1ub+kbEMnQO+3ouFr3DhsUosjUYECG4d4FFxOnYSzzr4F5v9NkKPuoU6L+
ZAib7u7ZIWtKhvbNsVKDn4PYOutiygNLMmjhNV8etHuLXVcXoAq+QIZXbZ86
Q4d6sZSn9R8Vncmg9tVL1nm7G8spZfXymwsZ3JcjJBm4urAKPPeuWXuSITtK
6kq2VAfWc4N5TSOADAbS+HPMvQ1YOYHUPyW3yP+9X/s/dMQNRQ==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$59685#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13k0VV/YB3CkSKVCMhXJPI/XfPZjdt3JTJnHBiSzyswVpVAqyiylkLlE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          "]]}, Annotation[#, "Charting`Private`Tag$59685#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxFl3c81V/8x81kZ48o2WST7XPeXPve6xIim+yRWUnZrlBGSGSFdip7NCRZ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59685#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFmnk0lV/Ux5FKUUnKFJlDZveaOV9c8xAZEpIkocwaJCHcSqKkkgjNQiGh
FJIimWUqcyGlhGhA3vuu9b797h/3rs96zj177+/5PufZZ61HxN1/214WJiam
o4yv//012/uppXLskS7T/31YDfgD+vmSyf+zSkZK2kO+m//YvKGzMJ2v6B9v
9/j5LImv+h/3Kpw0OMv39h9nrt9Kj+P7+I+j2B5uPs334x877sh68H2SFf/P
7ItRLsZCa/6xhM23Ty/OcP/jw40aJOUH3z/mKVrbx8y86R8XDxnUN2mL/uMO
k6jJs8b/8ez98g0W2/5jtTCN3bX7/uPSdQqzlUn/8WMav3Dhp//46e3vwcnJ
Yv+4h0P+yraM/3g+aH85573/WIeMsJ2t+I/LO9+nx37+jyvYamoOQfwfD/ix
fqWYi2PJwMX2KRkBXaZ2Pa5pe3HEEwHn8pwaXWGtCLUCN3GYtexO1p76o4us
py7++8VxVszDrfK1AHFb/idK7pA4yr1lM8Tuq5BIX7U7XyLFIePcHaIYaUQy
20Lqs8+II6w0LXdO24FUahRO7rskDrqmhNtY7R4ykDGxQTJLHNMTwekJWwMI
0zI57Y854nD+lP55/85QInzAZ/f1YnFYDp3YFdR4gui13qG7PRcHm82E6Mmu
OOKuPpwjVC+OdKV74/cSk8iJa6ItPR3iOPCNjIvMp5DrrG6zqYPiMOyIi5L2
zyRVPukCO8bFEWIVqfdL6RZ5OLZ/v+usOHzW/C74EHKP3PTSLNvDJAG5xqkR
WfN8kjzKxu69UgKd0ylsAu0PSaxnp5MftwRsXzeVGw+VkEPDt+4FC0nAPCSu
6eGxp8TTI+TPESkJ/BRdjLfprCTbP+ibHVeWwJMVGmbKz18QE/e1qdHaEqA5
XkoVY64hGoP9Y6eMJMDOd8rLLq2OyLjd10iwlsCX+Sv1CZcbiUD/sdMXnCSQ
X+ydx3ashXC4mneneEggaaPhM6nBNrLQwyd9zU8C+9bs2rUqvIN8c/505MYR
CRjVvn8XbNNNmnbE8t6Pl4C27sh6y+x+Utll6/XwEmM+l369xMuDJH+7aGlp
pgQ+Oi5xXBf6gSTZV2x/USQBlVc6o4pXRkn027N3assl8FydXr+9a4yE2Lr8
bKiVgEekFAuP2jhxsPl9qatHAs2slwW+ZH8nxs01I70jEhAV/+A/wzZF1Lde
Uv3wXQJ/m1MOjByeJnyWKh1fWSVh07tycFvsLOkx8V2/RE4St/Zf7E1xWSAN
NVp72dQkEf1mh4q0xiIpN1r5aJWeJC7U1+yMTGJCBu2OHa+9JNZs0ypddpEF
7hi8IBcuiTpFesqS6WWwrXjwQfmkJOq1rcdzN7KBpntcRf28JFw5bngctFwB
CW2BNv1bkrifJbJJsJodn9TsuRwbJNG1xEbhWxQnuovF3Hd2SoJJVqDRVHkt
6qhTBe6DkrgmM9Q5MbwWOSqJNr4zkvikZKrxx2Ed/BRenzshuBkpcW4PNXdt
wIykzpo8381w+XM49hqLIHSH9GvijmxGePdMY8JPQdDTTSK8ojfjz3IxyU8T
QtjAbTchdmUzgsMPTrgdFIYq8/6m1OrNKGWyf7YtRhRH3qcknhKQAtMbywG/
SUlUXrpm7CkphUERxZAQ+mawbbu5aKAkBZmxff2CglK4UvvAf9FICi8UvAN3
bZXGk0evth4KksKux7kmZTVbMJ/4Y43Hayls5nl6MzVGETTzPzV6b6VQHP+Z
+XyPIuKXMUVu6peC0ot3sl5UJQiGs39/90MKWntefigfU4Kuj2izjbA01HWU
nMhOFUTQrM+Rw9LY2mh/wTxQFSy/czgFJGQw8qJGbMBVBwIN+tNEQQaNhTWP
tJp0QMnqbvfQkMFFJsEr16GLvabLr963lMEkFzfnNUmC2ivuEvqHZJC39Nrm
pgggUZNP07tGBl25T+c0QvRxd3X+xoQWGdjrZ9w/8kgflUNGi4XvZdAhcUfG
4ac+puJCqucnZKBUU27/45gBHN43WZ3j3YLa5yza3xJp2HiMvqfEewvWla44
FdBhBKq1oFFP8BZ4prm0Bokaw0q8SIr5+Ba4rLhmqeRvjIj6wa9mSVug/vhl
9eeVJhjaqHOk78kW/Iw6d/iUuSmyn03HL+WQRUOOwAbtaXOoLroV296XRVdk
oPC7GWtYWFaeMCyVxQq3Vam3pGyw5+qmrWpVsgiv3ij21dkG59T6Rvk7ZHHB
a+/XHy9sMObvzDe0IIu/cqabl6duQ9qA/bEASzk07OC4Sd1lh0L5Rybu2+WQ
wxTPbJ5qh9pj3OvtdsvhSkVL57d2O8zwtuWpHZRD9f2wayNW9rCyse7/myYH
Ya79fiXGDmCuMtM/Oy4H61UJQqP2juDlvLc6YlYOcl8XYwJTHSHvuuJ9AJM8
+AfXWqX3O8LpT02wHbc8Cq1PVvTu34EiZcNbAtry0HT7+k003gmeNwjbvTPy
8FhHv1M97oL6GErjKxkFvG/NvbhFYDc017xhOU9VQPucn0isxW7cvbJbzRkK
eCVfULTt+G5E30/InLBXgJLeBWeLD4zxXZ+CeKMUsPi3J7Gu0B13t6Tz+HQq
wHaWzTzYywMbilUsKEMKcOPvKtuW5YEY1EX+HVfA9QqbVQ/eeSD/3lyIKbMi
etyrlgxY7cWZCqm+3g2K+PHReJW8jif0x07kL9NXRAZ9tuaNkhdC5Rvr9hsr
4hkv5G4FeSE/mG+42UIR1w4tS2cq8oLQ3wd8V7crwuHj2+O66t74zdV7QsFX
EXyjBRNdRj7I11azd0xRxLu2uPLEYwew6dyX39nfFOHBHsQTdjMA5bsjsgun
FeGVntVL6gLgqrJuR9kvRTSdPimn+T0AaR2apfUsStDyJrRG7UDwCsYdmtjA
uM/KXske6AoE1z2paQpRQqOf7IAsXzCWVu8dr0hUglI9Z3L4s4P48rO/r11R
Gf4vm25v3B+G4n2JVWaqylj3R9OiID0MkZ26tyu0lJEywm1t1RyGDSXpvtlG
yiD9AXevUo9B/5Dz/DEXZfjue6juyBSO1B8dfOKnlNGnYkd+JR+HyWSDXVC/
MiK2XknN6IzEut3h6qMflaHcYio6MBGJvmbZjS6flXH2IFV/JVsUQvLPfDCc
UYY79f5zHvUoZPibBvGxq2D5NYuFv5eiMPu1OrFSVQWcgh/a1LeewM3PZXWr
E1Sgzrvqj9WNaPhd3irmc0EFkhfiX5cUR0ON9iHsZYoKllgmDX5/HY269JVy
x26oYMdF/3UtE9GYtN6ROFaqgs+3m3KpGjF4sjA+SitXQcOx3StWmccg5l4k
Ml+oYDQ+WOaBSwx4We9OOjQy4h8SE7CJiIFuyaxt9QcVzG537fr9PAZsHnG5
m8ZUcI51w8n1rTFo5RRaGvZNBX8Wriz7ORiDvT6GxUq/VVAeXyW4gjkW8YLJ
vBmrKfjev/2Mk3YsuqOVekM1KJhkcpXXuxOL64ovqe26FIhY9AeFPYzFgV7H
BEUaBXcfLX8UXBELJrVIMmpFQUzkloy0jlhIfm7MsvOgYAevdPcrZjq+X3L/
88CbgkXuIYNRdjqeGMxuY/enYFve0T9V6+mwTBdkrQqloLr58docKTpCrA94
KiRSMM7cG69mTofuwmJ5XDIFPYIidlts6Vh+7wLPyBVGvNCWM11OdKQuKatN
u0nB/TTPUFdvOjzyrUR+ZVMwG7xkSDWADvmdQ6G2Dyhgd+UWqj1Ex/PiFVtW
PmHUOzd7jzuajrg96dF7KyjY/+tPbdMpOuw4lXoqqylYcaXTziCBDqFn1ZSN
dRQIs0hS/S/Q8cnb8ezhJgr2BsfZ2KbQUbhhfLj1LQW3ZzizJtLoCHsRoSv/
joLWqwckaVl0rBa8M/HxIwVP3c71rc+mAw7RvR/GKGj+dURyRy4dQYm73gx9
o2CjHDOb6wM6btZqPR6cpmCfQHKseCEdHcy8dwZ+UXBkMC0rt4gONq0fyf0L
FMRurnWbLaZDM6T5RB8LFVOLLB3Mj+k4kJcb0LuciriPVXxNT+i4NnLKtYeD
inirSJrrUzqaN+21eL+WCvWSh34PntHBskNP890GKpout+dXldNBSRKU6hag
ItHbVSylgg7PN7/XdwlTUXrrVZ9CJR0prB1LOiWoOPOSPneawXU6hZPtMlQs
XWxNus3g+UMJ/W8VqJB0Xngdy2D5fJ+GNgoVBfNdjZsZ7DZmVNaqQUWlqlNT
PGP+JFGx7BZdKgJdDv4uYsSvdl681GxARX+lUFgmI7/Z5PcxTSZUSJSYndjK
yF+qsSSo0ZIKt6Sv2lWM+pyWJ7s1bKPi3q25rl+ldMQjwKp+OxUiNO+YaYY+
5aEW2m9cqEi/E+VfyNDve6GUTN1uKijVpZ1Uhr6i46y8rz2pEHLjWwxn6G8n
Mbi0dj8VnXsfbD7DWB+667PpVwFU9FbQL+xkrF/p5SuDLw9Scd8xJ2bmFh2f
mw82VR+l4jW/tI7tdYafDeRzqmKoaKnexbE7lY7jx1ZeeX6aiidRinfWXqIj
/9EIvTKBMV/dY+7T5+nglspwL09h6K9heb/hJB1Gu8Osn6VTodgZEHX1BB1H
UrfrPr1ORZvDYJBSOB09HJz8T3Kp6Ol8/7c4kOEvo/HljwuoqDCKwJ39DH9F
1M6UFDP0C7r+zW0vw0+TkS2PKhl+eBU7pOTI8EfH5KmCtwy9wvJO2Gkx/LGm
8VB+NxU32EbVUlUY/jC55/Ggj1FfgYN17haGH8rckfeJCpneGBU1Acb6ZrT9
vDtPxQYuj5qpn4z9w/uRZ6a4KqwHXDe63Y3FZ+SdYpdRhb1Qi0RhWiyMeW/d
O6SgimdFF8ObzsWCpSb5m4WmKgLei4T4HYlFqHjIod9bVcETkspsZRgLz35l
+rYwVVQkaJ/g74hBdbHM3WeRqlgza+7qXRMD0QTROim6KmSml+NsaQx6tblW
L55TxbmNE+cdUmNglzp5Mee2KpqYzmkwM/ZLPfv8W6ytqjDssi6hdUXjmuzd
Gv9OVVwZE+pXqInG/JLMsXc9qjgenaP451E0SgsT5QpGVfGcztshfyEa8pz+
j3YuqMLM4EuDtEU0Nr6Re1kspYYNBXOLU6UnMIucj14RahiaUt/McyIKT29+
uXo4Ro3Rx/FG+PlH4QSbrC39tBo61pxheeIShdXNuc9vXFDDcNSomYJaFCR3
3b/Wd0cN2cFFvBlfIuEQXuBo16yGutNxYz+2ReLR45J6IqKO86tKZq5rH0eI
cnXRhhfqiFVM4+M/HApPinDm+Vp17BXSP/nEKhSOqsfOcDSqY3vQW/sgyVBo
aVLcWbrVwbfnd7BMxxGw6N9c8+2bOri7ine8UT2CRJsYn5f8Gtg5tyKULBzC
vQCacEiQBnb7Uy3nskKQFpTJPnFYA0nv/a39w0NwNmR+1jtcAwun7RaX7whB
wJGihl2nNPAnwS3oLmcI1CLFw8yvaaDMw1UuLyoY1YmsHaJ1Gjh+YZws+ASh
/371mRYRTQR8zZ8edw5A81fWceXNmui2LfGY0A5ApayhRbKsJojjO1t+oQBk
3nvJsV1NExfTWCbanvvD/farsz0Wmjjoy5n6sdkPI+m1iaOHNaHgk8Tu9PcA
vsbXX1ho0ASvWN/s2Uve6HvD8cO1TRMenOUZL9y90bjS0q6ySxOCV75+NVXw
xv1TDdzRHzTx0cGay+S1FwJiGi+y/daEpb7X0mXMXvgR1nx5nbgW0lz2SbpF
eGLO5+1V6aNaqJPtei1RvAd2qjvPy0do4bTp7OKHhD3IZR6hq8RoQfqa5vmh
fXvgmvIzUCdBC03hku8y+Pfg+Ut+E5vrWrBeFErhjnbHSeHdP47UaWHs6zLK
w127sa7jq0UtvzZ+tmVSN8a74kDWIf2GTdrgvV4kXGXhiuoDi2qt4tp4MdQ1
07XKFYeWrBXrkdeG/6YWne3nd6JbkfJ7Ql8bg3ozbifTXZBx5ugtnv3aGF3V
o6Bb54Qtesv/epZp48tJDifNwO2MfjNnc1elNtTnWXjLNLeDwm1tY/pKGwUe
35RzWbdDezTl5pYWbXQqq5f3XHGA1VkZ8+8j2uDpHhzY89oeQd2WKaFcOvjs
mRITqG2HWf2p5595dDDc1Dp9i8MOYbmXvjgL6iC5preL9NoiJqJfV1dKB6Fa
o1ZZEba4JBE4zKKrg4So9RJsr7fhcWCycry3Dnaa/s1q87WB7nt1lwU/HZif
EZbjpNmgitYb6xeig0dMex7c4bdBHY9kt3WEDrpUnzEN11qj51lJxPqLOsi3
4vc7KW0NppXv669V6uBo5hLfqhlLGF8X2VfAowvupDo9x4emoKSslny1URcH
+Fd+cTliCuGEuY/vRHTRu795rE/HFH9C291ZZXXxY1fx3u11JsizOe26nXHu
UzQxq2EeM8Y65kn7BS9dsBhfLz+sbQSmn73cXH66WBpcff0TmxHGx+vaJIN1
0ecYxPy63RCvum7aWIfr4kG048zbAEOE5jta3jivi+bCzM1Lcmno31VJM32i
i9CGciNWVQPU2+ctca1gXGfjtuJYYYBS89SqoGpd8MwNCRzu0UeSGuMebdTF
n4/y/EEx+jBcI6U9MaQLzWkax1iXHnLKE1UushN4P0xQVL0AHBbcJTroQjAk
/b689Zw23K0VHXp2E8zcv2O22UobVtHMcZ2eBHpFml5rOLQhOXZjsiGA4N7t
Va0XT2vhbdGnyicxBKVzXQXOZzShaBG0KzmX4IB+7VjDXXVsjDC4kFhAkHDk
bm2bnzqWF3LXxBUzxssu8XCmqqOPp0Q+qpLgs5NUz5cXaoj/MLfg+5YgdUhF
cnZEFZ+OxqYZzxOEars9b2X0AZ8dtnhlMQGT6pNN4Yy+xe37OpZNSwCVDwt1
qf0UmIsNU/nZAJGzcUmS4RSInj6ZzskFLJHINPR5poJmu/oDCxLAzafTEwM2
ypAdt2fvtARWzX3h9TytgFI7i4o4a4BTL9fnoJoCDJ7pB+vaAvNUvxybEXk4
JSi8v+UIsFzsbvM2ksdpxRU5IXuA2mURj0bWyGEk5KkZVyjQfP/M3hOvZBDU
W/j3ZRjQIDehEBcpgwXD7MLQ4wzdF3ut9bVkwM1ziX8wGlgdlh3ztFAaBo/9
Pz9IAHifbtXNy5ZC5oJonOVNwLp3TaZKsSRkPfl0me8w4vVaz9KPSqKkcc1U
UTbQdZd/ZxCRRGPG/I6ND4Cno0G+7G8ksKDXIf3lMcCz0nWt4Jg4nOinX59q
Av4If6yKJmJYt+Y7W/UfgLZIUy2wEEbrs7iTpgsMPbcsc94mLoykAxLLmhYZ
+rj99sj+tQlcdU5L3rHq4Y17xt5pJwbHvlyYWK0HXv5v61ykhMA5lzolIKYH
1+9yKmuHBdCcTQ3MktCD0udy8ihDAOccmyckpfTQOD8WxuwsgDXFS78qyemB
YpQ6c6aNH6sDA0aN1fSwr9aSql3PB45Rw55gcz3cpeffbn3Hg/qLA06/LfVQ
wTrQaJzBg3haWPdxaz3IXVyja+XBA/br+R2n7fWQfmM4aMX3DVi5U6AlY5ce
HPQfdXGt3gC2tu8v3wTr4fLCdRHHPdxgrbj6QCxNDyNi9LOBPmvxTptm0n9N
D9KfYrmWa63FgyfjA6lZerjyKgQCHGvhVKzDxXVHDz1CHm5PHnCiIK8/hKlQ
Dwu/FO1df6+Ba5qYZm+NHgpuPL71ynEVKPz1rSl1evCyNtmWzrYKK1JC9ts1
6KH0rg6H+WMOFF14mfamVQ+3T8tdExXkAPuZfYuPe/VgVN/tEP1tJUpDc6ov
Tevhr9iv9bRiNiT8tN25bZbBd6bUEoLYsOfg/Myq33qIUJCuTVBgY+hnuTn2
rx4uWaUH5OQsx16vidPBK/SRd2/pGuHcZeDarrLVepM+njlcPeBfz4r9lLLu
Feb6sKXrDUhEMKOyuT231FIffd+O2rRuZcZ63+8R+6z1MZF2+968MDMqbklI
vrTXx3tv4dqX1UxYx3MuKNJNHy2HVc6xczGh7LcH+8+D+li1QiohK2aBcF6K
6Lt1RB9uhYFLUykLZK9yaoFdmD60TYpjvYfnyZr9TdsLI/WBDRmBMabzZE+P
xk3fM/rYR/uZ7S0wR9grVut8zNTHa6M/HFMffhE3Z2nOCzf04eO17qNl5i/y
6KfBB73b+qBs9VnvtvMX2aUYejojRx8Bm2+2ZXT/JA+zPrQ7FeujXZi9y+Hd
LHGOKfVreaOPEywqTdN/fpAcU/fM8ll9yBi27UnNmyQUWRFd8lsf3z+4VF6O
nCTlqwfeV8zpw0DoQ/pSu0nS3LaT5zmTAS6zSEQpz38nP3buSHix0gCiImmd
hTbfiW6Q9bFaIQMcUtuoeV/4G6mxW8NvKmIAhyHXZe/bvhJrtcaS12IGePyC
5UDtya/Efd58uk7KAN2jiso9k+PkJN3Yp0HZAL2L2o/yGr+Q5lRdx1YjAwTm
cRanZ4+RHeELM9tMDdCn7zOysG+MDO16eqHN3AC/rbOMWTePkR/imk1vrQ1w
O8D87sLtT4TvAdWo08kAVRNslND7o8T9hSylx88Ae8OnmIzeDZOZL/ycI5cM
8Euztf1i6hBJTh+tSbtigM2PZO+2eA4Rla1FEbZpBlDuF1G9qjJEAgstJyqz
DGBx+cfF1sZB8vVIZOPVXANcGRnuecA+SIaXjsTbVBng6nRynLB2P4kpKaSx
vTTAsTzbm5uH+4iYd8R8eY0BzvqsLBdN7CO763kPyDYYgOfyuXVfhntJb5K5
+fIuA3zcbqcaca2HtG8qWPHsqwHyKpwOM2u8IyEt4c+Dvxtg5YWqmLmJbrIu
2ixUZpqRnxTNvuJON7EZ+fDp8i8DOO056ZnG100acjfUBi2h4XhegdPBZV3k
pcYxuhQfDdnchau/sHSQR7bGS5JpNJTaNuZLhLaSU+alsRuNadi/sZLjt0kr
cTGQZrtlSoNr0IieCV8rYVFhX1VsRYN9dOFn+7IWYsXVtKHLkYa7e0L4OZe2
kE/NDjIbfWmYGGGSEnJpImW1Nbk3/WkQPeA6rbOyiSRUqivIBdFwe1qZTeVx
I6Hk81N0D9NwOpo1JJmvkUQl9um4RdHAMZ+18deHesJv5Wlz8yINRbfVw2zT
68hXw8422RQaThwdnirfXkcqdUwcHqXSsPVAoWIvVx3xlJNxfpVBA//zFi7Z
M6/JQ45vHp+yaehtkf47Fl1LLN4cPCJbTkPWTZfu1ORXJMIkNqNohAbf2cSB
YKkXpNXVy0VxjAbnALF5u59VRPygOV/uFxq0nwqqFL2qInVZay/c+E7D37OT
L0Y9qwj3XDo96Q8N3aHPJRZzn5O7ecW+AasNscV/Z2K9VSX58+KKzDinIe6s
3t0+LV5JLN8dG923zhC/mWKXrfhZQaaWGezexWsIyuWXwtW2FUTbrcnOStQQ
78t4H3/eUE6auT5pyaoa4rnp4GeBqjIiKv3m1x11Q/xIju9rOFpGDpL7j8S0
DDH3ZEqDQikj/AdCFARgiJXRq3LWZz8hHi+ZxFaaGULU7A0719XH5NdhvpWf
dhqiIkdl4OK1EiLSa9Z1I9YQp5h3nTLhLSJxVVoP7E8ZwjP8/DuVgYdk6o4s
ffkZQ3TN5Gwvu/uQVAWtpuw/Zwgu3kD3y1oPiQdba6LyVUOU3CHPLL0KyV2V
HcbP8w2h9ExFJ+99PuHkMxMKfmiID6v4FcJz80noX80Z8WJDyL88INIenk/M
Xm+8carMEC37ti8XFM0nX1wH/m59ZYigfeu5KIP3iXzcvuK+94Z46M8vam2c
Sy75O54918f4/yuOe6q/csiinamH/qAhljA7qCy7l0OaN23huj1iiMs7nCa4
OXNI4KNvvr6ThoznuUL68+FsUjRwUGJ+mRFs+gxP/2/SmmoxyXzKRgi6y/42
d/AG6XDnU02nGIFQPSKe5d0gwQn3O4XVjCBRbf7D7OgNkjvcxS/F6Gsvx/cM
vOe+QYSS5bJUjYzwrIb1ZfvW64RlsiPP1skIa0f9H0v3ZpJrGw9s7XQxQm/d
Ju2lBZlEy4R50mmXETYm7fXZGZtJQjK2UNw9jDC96/COAIVMMmIZ+STAzwg+
Nit/f+LMIG/uSdecPWGE9Xq6bZlX04hXR7nX2lgjKAe9Db9snUZYWexWXjxp
hMLRXVtdlqUR3R3HLdPijWCQ4bDPOuQqyV/e1nbvkhFOXCiT59iRSpI9jg3U
3DPCjvgxrfUkhSieW3vCPM8IngvO2sf+XiYNZbfFmh4Y4a8L70Bo+WWybF2L
Z0eREVQ/+a3VwGVy5LnE14/lRnCVvyBQY3aJuAg1/WZuM8KF0NIGkWPJZDVf
0KOydiMUKJX6OCCZPF+3PvBglxHjhBCzWntpMpFc4fzpUy/jXLA7yof//AUy
MT3S0fTJCO/y14SIFSSRE6//Pkz/a4Tw08caPLnOE0p1lv92ZmNMZut15gye
I6PltC1rWY3RJdw2mlVwjlgUxV2PWWEMUy5nwSzbc2R9xobz+7mNMbfs78NO
kkjuhsj7acgYo0/P9vrZW/HEyb9FelrWGDtjdeYe28eTVT4hw7kKxpBamBq6
vSyeBO164iJMNYZIXIVrlc8ZomVmZL4cxlDk61/OpB1HGje5SrXbGwPs6sKX
WE6RSH7mjwmOxvC92L73TflJorL+ZoaJszG+2upqPg87SVJWft7w1M0YNL/A
xG8/6cR95uDSG/uN8ZvH9cvW37Fkpu7sUECUMU4RG2854RjSw97uNR9tjLVa
LjMbxqNJlcXGCcYzEatbN++7WxpNzjXem7t2xhjMrUzzVbbRRKa1hrvhojGS
+Z987jh/grh2MxtL3zNGzibNjxZbogiN37ShKJdRT4lMljtTFNnifM4WD4zR
Ysfm09weSX71CLltLzKG2I24TUVRkSRpQCs0ttwY5zdsV1EviyCvRg/mDLYy
8l/3LLnHPJzkSj1T8m03Rjw7iV/BHE4ueLOW/uo0hjnn1asjxceI25ek6jW9
jPhkkLlA/Bj58+1Br86oMfyot8fpbGFEYXZsTeqcMWaPcWmpTR4hKayuIdvE
TRB3LKQs2+gg+buHh9oiaQJwfWQd5DpIPF40z2yVNkFjWt3e5/0hRPGEwWFL
ecZ4Pi2vkaMhpHZR6qiJugnOqxVcrnsUTH7+mY7QtTDBr6VTmXM6QcTFKQ/P
rBjjV3EllXEGkarHnszaNibwlfMu6P0QSBKOdJ/QcDCBffHToyZnAonkbHks
xc0EJeO/1Er7AojD5OkzMiEmiOw885hJ0Z88tTawyD5kggdT991fDfoR0fx5
DqlQE2TpMlrcZD/yzc8/QeK4CRq88k4VzPmS2HG788KnTOC5rFDobtsBUjS6
6fKGNBMs7vXI8LzrQ9b1PbrOUm2CvqmSac96T5LAER5e8soEe+f0PsYmeJKV
WjTHA69NQFmeFmxm40lYUlpXdTSaYFiq0q+6ay+Zspk4kt1tgtvJtR1hEx6k
+aXUVusJRv6r3vn+0tpDLH5MSC+dMsGMuYd5INseUitawvrkhwmSzpbXJLa7
k4oIwydif0wwxf8h7VmgO7mv4S7xk5Vxzt85XtpTsJvE512dS+c3BUrioges
3Ahbj3vHNkFT0LyWLdwQcyMxK2UKlgubItGiXrfp+y4Stq/UM1DCFD/053LG
DXYRH5H2FpqiKfb9OX6l+vNOYnJx9d0vhqYwE7P4+EPHmSwNj7LTCDSFxNvA
baVcDqRocvx3RbApfpVY/7WvtSceno4ZRodMEdif12J33J5Ub1X4bBtmirVC
qvpRX+xIjGhvhF+sKdodq89/rLMlrLXqOTeumGLmyXKJrZk2pEj7prVMmine
C53msN1pQzwK1szmXzOFiGO71zC/DalOHUH5DVNI+4u0VV62JtG+yR1deabQ
c0nbb6C0lbCs+868uopR7xvb9+zB5qTwpPOd5GpTdL2Se3Oa2ZzRv76yEKgx
xe5zqiTivBmpGk6/LFVvCs6Oo06jj0zJiVJzOYMOU1yWdho3W2tClOVKWl93
mcIxSTVeLNeYDGWJHrF+b4qbTgkLmSbGRP/M76qdA6Yo2OYwl0k3IsyudxyP
fDaFa1/bpC2PIclv5fr7d5yRjx5P7mQFjbgZH78RO2EKxYuisbt9aKRS0f5b
0g9TWOxQ02ysNiCRS5bE5P01hZr1sO7Rc/pE8YifNIXZDN0aP8KNTfTJwHh3
45MlZtC5zSPNzaJP0JHPV8tmBkFrfZ+qMD3ClO36YIjLDF3DhZJrT4G8Gu/0
y1hvBhl2/oefzUHiFW3kXXjNsD6D7+I2LhCeUoO8dkEz8CvQnN5aEiJfI5VT
K2WG0A++LUYFOsRleOr2fV0z2B1bMyNupEkei5y8dtTHDPEuhuGNC8rk+F4m
VzVfM5hxnn5bcFKZ0LJDBX/4m+HNSK5h/lpl0qx4IM33oBnkefoPK0oqkU/E
JtUt0gzhEZ+2q9+SJxtcBS4ZXTLDGKvCbdFTm0lPVrL9kitmkFvGx780R5Jc
H161vvKqGbaIcr/Na5Igcr5MyRpZZnjb3yJULCROaMeGz8vmmqHn4xEF1w5h
EpT64CxXlRlsDz0Pexe9npTMp56sqjbD47dGInuEucm8Kz0qqIZRT+em/h0v
uMhJsZ0HW+vN8OxXwYSVICdJy125M6nTDEqL1Ak2y2VkcPWsg/47M1zOXDJi
/3MJkQwctJ7qMUO12SqdkAJmkk8tpW0bMsNuFV1jkvdH92X5Xlmur2Y4tWL9
sNzTYd2VIjaSVRNmOOvc92J8ba+udbS2cNCUGcqalY54RDfqOidmiWfMmP17
H+x/ABaVeBU=
          "]]}, Annotation[#, "Charting`Private`Tag$59685#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFmnk0Vd8b/82EKGNImTPP7jXv53IN914yj8lMkSFTaDBeUoQkiRCVMoYk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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59685#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3c81t8b/62iEoVkRlb2Hrd1nwu3dQ97ZoaQhIxKNjeViIQkmQ3JykqZ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59685#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFt3dczf///99CKg2FllHae49TzuPWOKd5zilJpJKk0tA0QloHEQqVSkXZ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59685#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0.\"", TraditionalForm]}, {200, 
          FormBox["\"5.\"", TraditionalForm]}, {400, 
          FormBox["\"10.\"", TraditionalForm]}, {600, 
          FormBox["\"15.\"", TraditionalForm]}, {800, 
          FormBox["\"20.\"", TraditionalForm]}, {1000, 
          FormBox["\"25.\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[113, 7], 2000}, {16.142857142857142`, 2000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0.\"", TraditionalForm]}, {200, 
          FormBox["\"5.\"", TraditionalForm]}, {400, 
          FormBox["\"10.\"", TraditionalForm]}, {600, 
          FormBox["\"15.\"", TraditionalForm]}, {800, 
          FormBox["\"20.\"", TraditionalForm]}, {1000, 
          FormBox["\"25.\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 850}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793640458833197*^9, 3.793640471714593*^9}, {
   3.7936405058523483`*^9, 3.793640516880765*^9}, 3.793640597711855*^9, 
   3.7936407366379633`*^9, 3.793640911618548*^9, {3.7936410235115643`*^9, 
   3.793641027674835*^9}, {3.793641347904949*^9, 3.793641351939537*^9}, 
   3.793641391018841*^9, {3.793642479752921*^9, 3.793642490567113*^9}, 
   3.79364641731458*^9, 3.793707618021345*^9, 3.793707662572912*^9, 
   3.793717672640687*^9, 3.793718175266699*^9, 3.7937182685384502`*^9, {
   3.793718723978971*^9, 3.7937187436549387`*^9}, {3.793718806973386*^9, 
   3.793718901003211*^9}, 3.793718959807323*^9, 3.793719541017272*^9, 
   3.7938013943488493`*^9, 3.7938014748299513`*^9, 3.7938015707028637`*^9, 
   3.793801638272567*^9, 3.793801741889409*^9, 3.794507025467761*^9, {
   3.7945073848860617`*^9, 3.79450738876585*^9}, 3.794507496338254*^9, 
   3.794507541365992*^9, 3.794507663329699*^9, 3.794513110556073*^9, 
   3.794513179331951*^9, 3.79451503272505*^9, 3.7945153168070593`*^9, 
   3.794568643074168*^9, 3.794569005824923*^9, 3.794576050772787*^9, 
   3.79457668662955*^9, 3.794578139879937*^9, 3.794578429562291*^9, 
   3.794579361990045*^9, 3.794579491064411*^9, 3.794656648767623*^9, 
   3.794668111095714*^9, 3.79466833651616*^9},
 CellLabel->
  "Out[1487]=",ExpressionUUID->"89020fb7-2b6a-494c-87c3-053f93033af5"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4A.pdf\>\"", ",", "figoneshot4nscrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4A.png\>\"", ",", "figoneshot4nscrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668170187586*^9, 3.794668175834317*^9}},
 CellLabel->
  "In[1488]:=",ExpressionUUID->"47efdc16-3059-4e27-9e9c-86695073e7ca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot4nscritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "solns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x4ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x4ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x4ns"}], "]"}], ","}],
      "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.793646421184304*^9, 3.793646429323791*^9}, 
   3.7937076227765007`*^9},
 CellLabel->
  "In[1490]:=",ExpressionUUID->"a3b37dd1-1f56-4eb6-aa47-fdfd1dc4a04d"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1nc8le//B3BKpUh2VpFkZWXPc73PcOxVyCYZlaiQUcqWTUsiGUmFJCEt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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60002#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13c8lW/cB3CrErKSkMpeWdnzXN8znGMWhUqSJCmRUGnIlkqIkqxoWNlZ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60002#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13k8VN/7AHBrqWSPSEWUJfu+n4eZMTN2RakkJC0iW6FkJy22SLKEtMra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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60002#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF1nk4lO33AHAUCSGkSNmX7PvOfZgZZsZekkqSpEVKKFT2SCqEZEnWUpIt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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60002#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.793646429849951*^9, 
   3.793707624477703*^9, 3.793707663340981*^9, 3.793717672987616*^9, 
   3.793718175621484*^9, 3.793718268907634*^9, 3.79371896038622*^9, 
   3.7937195413954887`*^9, 3.7938013946540413`*^9, 3.7938014751061068`*^9, 
   3.793801571011133*^9, 3.7938016385604877`*^9, 3.793801742304904*^9, 
   3.79450702595752*^9, 3.794507496709774*^9, 3.794507541710725*^9, 
   3.794507663668606*^9, 3.7945131108491*^9, 3.7945131796383123`*^9, 
   3.794515033068891*^9, 3.79451531713087*^9, 3.794568643407506*^9, 
   3.794569006486268*^9, 3.794576051238998*^9, 3.79457668699123*^9, 
   3.794578140424238*^9, 3.794578429922683*^9, 3.794579362290388*^9, 
   3.7945794913846407`*^9, 3.794656653771756*^9, 3.794668111239688*^9, 
   3.794668337389928*^9},
 CellLabel->
  "Out[1490]=",ExpressionUUID->"d0f106eb-0f39-4f12-a9bb-eead8a651454"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4F.pdf\>\"", ",", "figoneshot4nscritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4F.png\>\"", ",", "figoneshot4nscritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668188049608*^9, 3.794668194014349*^9}},
 CellLabel->
  "In[1491]:=",ExpressionUUID->"f5576089-d139-4463-9350-8b56db5109cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"figoneshot8nscrit", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "solns"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x8ns"}], "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x8ns"}], "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x8ns"}], "]"}]}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "solns"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x8ns"}], "]"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x8ns"}], "]"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x8ns"}], "]"}]}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#", ",", " ", 
              RowBox[{"ToString", "[", 
               RowBox[{
                RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
           RowBox[{"FindDivisions", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
              " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}],
                 ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", 
            " ", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                 "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
              " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
        "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
        "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
        "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<No intervention\>\"", ",", " ", 
        "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
        "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
        " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
       "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Opacity", "[", ".5", "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"importtime", "+", "2", "+", "8"}], ",", "2000"}], 
           "}"}]}], "]"}]}], "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.793640548791997*^9, 3.793640579046043*^9}, 
   3.793640618867655*^9, {3.793640919037943*^9, 3.7936409215073757`*^9}, 
   3.793641019556532*^9, {3.793641363983626*^9, 3.793641366798842*^9}, {
   3.7936464423732843`*^9, 3.793646463204339*^9}, {3.793707627583127*^9, 
   3.793707628443535*^9}, {3.793718905610779*^9, 3.793718911467928*^9}, {
   3.794507401742484*^9, 3.79450740592568*^9}},
 CellLabel->
  "In[1493]:=",ExpressionUUID->"801aded2-b276-409f-be4c-4eb3df0d3198"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF2nk01G/UAHDrLyFbyFbJviVm7Ms81xhjZhBCJFu2SrZQFCLbVNZsIWtK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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60276#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxFl3c4lm/Yx62QsvfK3mQ/tuu01zMQUWSFyshWyqpQRqQkSbbMZEaSkCIr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          "]]}, Annotation[#, "Charting`Private`Tag$60276#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13c8le//OHCrCNmVvQnZe18vzjGO4zg22URklD0yTyGSERIiI6WkSFYq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          "]]}, Annotation[#, "Charting`Private`Tag$60276#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13k0lV+4B3CkiBJRUYlkJuMxD/vLOTiD45AxJGNKMoXmzJIUSSUNhCSp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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60276#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFmnk0lV/Ux5FKUUnKFJlDZveaOV9c8xAZEpIkocwaJCHcSqKkkgjNQiGh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          "]]}, Annotation[#, "Charting`Private`Tag$60276#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3c81u8X/4UiGYWys2XTbd23dR173cOMJIQk2aMo404oUgkh2YnsPVJm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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60276#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3k8Vd8X902VKArJWOZZZAyXvbgX9+K6piLzTDJlCpF7TSFTSCiiNBAR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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60276#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3k41O8X921FKqIiUiSErDHGfr8xM/YtCi22JCVLlqKUZVAqFCVkadNi
CVG0IdlStuyFiiyVsrRQoWee63qe72/+met1zcz7nPOec5/7fDa4+23dy8HG
xqbHycb2f9/N9o61VX26r8/2/15cRqL+70QukP/PatmpGSUiN/5j86bue5ki
pf+xg8fM0ySRmv+4X/mkUbxIx398ZbV17GmRj/9xJE/JpjiRH/+xo9PVwskp
Lvx/Xvovcpfxev7/WNr229jzM6v+4yPNWiT1h8h/LFwqMMDOLv4fPxg0etWi
K/kfd5lETsUb/49/3a0Qstj6P6Ye03Jr2Pc/Ll+p/Ksq6X/8kCYqcW/sf/zk
5mTghQsb/+O+ZUppW7P/x3MB3hUrcv/HemSEJ77yf1zR/TYz5vP/uJKnvv4w
pP7j975cX9XNpcD5/mLntPxafbZOA8Hv26RwlqzdWZFXry+hE04tdpWCWZvb
Bd3pP/q4+mSXn7cU4jd6uFa9WEtcuf9EKh6WQsV+heyNd9VIhA/11pcIKcjv
7A1SiWCQK+1Br+6ckcKx8oz8v7rbSZXWval9KVKI1ZZ2/dSwh7zPnhCSuSqF
7xOBmQnW/oRtsaLuxzwp7BzL/Oy9O5RIHDzgdu2BFCwHo1wCmqOIwetbsa7P
pMBjOyF5suc0cdcczlv/SgqZqrnjuYlJJCpLsq2vSwoHv5HxDXOp5BqX66/0
D1Kgd52OlPO7QqoPZK51GpdCkFWEwaxqDin55O3t/EsKB/h/Fw8F5ZIbXtqP
97BJQ7F5ekTBvIhcGOVZup9XGt3fU3nWdpaQGM/uHb6rpGH3oqXCeLCMHB7O
yQ1cLw3zoNMtJWFPiKdH0J8QWWnMSP47a9tdRRyGDM1ObJHGoyVaZluePScm
7gLpTF1p0BxT0jey1xOtD+8+nWJIY6nIKS/7jEYi73pXK8FGGl/m0l4lXGom
a9+FxSXvkEbRg/0FPGFtZJmzeW+qhzSSxOhPZT+0k/k+EbksX2ns43dxWX68
i3zbORZyPUQajIa3bwJte0mLU8yau2eloas/stryzjtS1WPnVZLC0tv1ziDx
0gdS5CBZXn5FGh8dOR1Xhg6RpG2VDs9LpaFWpzeqkjZKmB3xtxoqpPFMM/aV
Q88nEmS3a6apQRoeEbIcwtRxst32d0pPnzRauS6t/XJnkhi31o/0j0hDUmrI
7yfPNNG0TtEYmpTGQmvqwZEj34mIpVrXVy4Z2Pbzftga84v0mfis5lSUQY73
xf7UXfOkqV5nLw9VBsyXTmpyWv9IBYP3/nIDGSS/qt8dkcSGbNot+zXbZMC/
Vad88UUOuONDsuJxGTSqxKZyfl8Mu8rCoS0nZfBK12Y8X4wHNP0TaprnZeC8
7LpHsOUSSOuubTfMkcHdqxvE19UsxRh1m6Bjkwx6OG2Vv0WuQO+Dje67u2XA
prC22XSLABop08XuH2SQJT/YPTEsgDy1RFufnzIYUzXV+rN9JXyVX5yLWrcJ
qaddS7RdhPBTRo+/wGcTdv05EpPFsQ76g4b1p0M24Xjvz+aEmXWIzTQJ92Ju
wh/ujTJjE+shtMp+YmPaJgQeD55wDZaABrt3S3rNJpSzbXu6NVoSIW9TE0+t
lQXbS8v3vlMyqErJMvaUkcWHDSpBQbGbwLP1xj8jVVk8C/3xZt06WaQ1FPr9
Y8iiq9ThoIu1HB7dr7M+HCALxs2/xVfrN2Mu8Qe/xwtZzCrak+EIFdDM/9Qb
dMjC2Gd3fHS3Cs4uZosQfyeLmNDjzHtKqlh3fOnkmx+yiC3vdkkZUIX+AclW
Wwk5VO677xFkpIZwms05ckQOy9IWPn5aowGO33kr1krLIyXJ32GmSAdrmwy/
E2V5PH9/gi2TXRfqV3s7PbTksWW/YMFLW13sNeW+fNdSHjudEg8WT+qiIc1d
2vCwPFTkz2SJy+ojUVtEe3+9PBiyqtEcesBtviKxhDZ5yLkZfrnuClQNMv7d
eysP929xTV+YwPTpoJq5CXk8pBw1PfAC2P62xercms2wW3ThE7uNAcTCYveU
7d+MAaMr7h1mhqDYrGP0BW6G5tmoB15ehrCSKpVlP7EZZziPHU6JMUT4qw9f
zZI2Y+EdW/yTCkMMiumFDDzajD/BAv0KCkb4O9m+g7N2M8b1DuRGM4ywqvaA
nmzLZkQPzi4LcjUCwyeVI2BoMzYk+j0QSTbCnaffzy5apoDbOreHI78bofr8
aT95IQUUU0seXuKl4c3eDVutJRQwVF7SQ99AwzI+a+E0dQWoindMeFvS4O+c
e1VhtwL4VTSvjFyhIW6LQbTtPgW8bhrQqCul4driHs/DhxTwjGkbjwYa2u8u
UqiKUcCG9VoruL/RoPHP9YHdXQVMy+9KGlWnw8KyKopergAru/yf2+h07Lks
bk2tVsDux6TIcxsd56gDo6JdClivc0v5UBAdn/x2igzOK6A5uO2r5l062Coe
DbdzK6JTYHFXw2M6hJaJ3qsVUATvDc9z/xroMLzdY3ZHWhHie8593zNIR8b7
bWH+lopI2cJ/TUSAgXtK903cHRTx/ndjwNRaBhrCVq22d1OETdh6hWAZBn6u
aS+gBisiaDhqBVObgWX7thyVC1fE+eGES3w0BiTvn2esjVOEQENNhYklA1a2
Nu8WMhSxoMV/9qUzAx7ZhXmTNxWR84MnbfU+Bo595QsZLFLENysaj4AfA7fj
mlbU1Sji59PLo+tPMFDRrdBf1qyII1W1NVtiGOiQPnvnTo8iNulbDvw5wwB7
tZlh/LgihOfDE3JTGVizIpcv/Jci3vZ8PJOcxYCS85K3/mxKuHLlc6raDQZ2
/KkPtF+lBMuBjrrLdxnwN9kExnolGJlSd+wtYeBkSuwyTVklOJzWGBwrY6B0
Cz1nra4SrLZp3JGoYqAx4sah5QwlPPjRadL1nIH3zZz6/6yVQH0zcteknoFf
Ynt4p5yU4K6TmRzSyMBy7+quwT1KeGGpWOjZxIDUww3XO3yU8Ifx8uHKVga0
uSP96o4o4eSuPO+I1wzYbHuvUx6pBLYa9uMFHQx4Xic8uWeU8PMex83LXQyE
TWV1XL6ohFnnwSzzHgaSycKV+GwlROyUX1PRy0Bu/G6f8DtK+ECVKf3+hoGq
t0+0DpWw6r26VPrrWwa65MQW73mqBJFTU+vy+hgYP3LstX29Ei72fbNV6meA
o+5NFqNNCSsTRYOOsFhklba35lslfEw8Qz3JYhX3NKr8sBKcWhytnVnMKJrl
FJtQQq1emu88S2/XgkPr8t9KCHm5x2QviwMsyjL+cShjldFkfAor/ql0of1T
y5QR/+JXx3lWftljwZQhIWXo6n6rcmDl/0Cjk71TQhmU7ZXzY90MvIpWb66T
V8bp11upDFb92vwvOc5TlNF8PrGRzvLndpobdSeU8epmYsMSln9CUrPe0ubK
iG0ZXZbcwgDzbsKViW3KYGtUCBx8xcCkpnTnQ1dlEPvvXbMvGHB+/nhJtLcy
yrb78HfXsfR7xgLWRCpDzNPt/tdKlr57+K3BM8qYYXtyb9MTlv7X1X35KcpY
mfoxTqGcgSl2I7pBvjJOxJkspBWy9M72hi4tUwaXeQ+VK4+Vv5D/3c5nytDq
HmDq3mTpbc4UPtCtjKCcuCDRDJbeAzUL9UFleB+q2f0shYFoVoctjCtDO5ZH
Tus8A0W5f4NM2VVgVuDunsXq/zOVsgP9Qip4Muxkan+QgWquoFlDMRVMjPdu
vrSXgVnTSsHbG1Tg56M1WsQ6b54d24wDFFRQrX9m8oANA4afoooWG6pgWrMt
dukWBkKVmhu9jVVAzRvWE5JnxQsUGW61UMGldtrU3AYG1i8Uilx2UMH6jUZc
bqz58FuwP0rZRwVVM+8ak7/RUaRL3eaYqoI4zsNSMtfpGI2M8nuaqYIXPodH
qWl0rK9vipO8rgKxtKEXSol0nLX1qBgvUMHxbYKizUfp8PI8vynyuQoSt0tt
HLShQ/zcl993vqkgW3BRbscsDRVu4XfufVeBR8uYgDZrXjqrrXR6PKsCvViT
5oQhGjK6tMtfcaji5U3Vy9zNNKxZd/rwhJAqvFZe/0iu0SCYK/tdnagi6nKt
opAJDYtq9o5XJqoiK8qOmXrGCF9m3g10qmxBT8t7+Sv/DHDj8+NGvgQ1WIVk
9q200oPvJeuNB5LVMJnX2fxJXQ9U2tCx2lQ1vDXmm3q5Vg+NmbyKYdfV8Ftz
u+79T7qYsnFK/FSuhiamsJJ4rC70y37Z1QypwbttQNvrmQ56mar9oVrqGH9m
lb3HUBvXVGopnfrquKb2YfN3eW0c7HdMUKGp49OerdkXV2qDjRpBRq3UEdYd
1S06rAWZz81X7T3UQZnzU94Tp4Ugm4OeyonqeLM06hh6NaE//6/i9AV1rFgu
FCxVownu3GThkTR18D/h0GYUaiKd83FDxg11/PXSDbCO1cSzB0s28z5Sx5wE
434TVROn92Qy91aq40LTrU0/pTRhv0K1r6pGHcVyYvsDBDUxtt8x/kiLOpqH
UrmOfqOCb92tiY8f1RFn95DCm0dlXfDM/qFP6sjx5XbRzaAiINHl5eA3dfiw
bxl7GU9FF/uaW+9n1fEjpkJvaQAVPDo/LrybV4eA4SfRSg8qtINaowY4KDhS
ku/W40BF1sgp575lFMyYPE0yJFS0iu+1eCtAwetjDOVLalRwOBlovxGi4PJ1
o3RHWSo8X/5e3SNBgXffXKfsSipSubo4u6UpsFz+elZ7CRWNevemOuUpsG66
e6fqnwaUig40tatToNpVb6n4TQOunxiPX2tRoLLHzkt4RANJkhvvtOlTcGDR
9j3HBjRQs/NfSqsRBS2/ep/t6NbArwtvo1tMKOhb+nlxWasGZJvLApotKRgr
SSk636iBHdwXXJu2UjCcvFtivEYDZ+Fv9cqBAkWjnrv1lRqoCLXQfbmLAnGn
K6XSjzUweU9WvtGNAhEf69PcZRqQHOda88KTgmCh8FO+JRqwl/6wqMGbgo4t
Ndy7ijQQ6/z0e50/BdsKD9m3FWig/FLah9pgCjqzjl5pydPA59bglpqjFLwq
SBd1zNWAGO/Wp8/DKSg9FT/lfUcDlkZKedXRFCzq47NfxuITYbxpz+IooNq/
8ddmcdH9kdiqBAoeOzmGzLB48Ft1UGUy6/t3fiXTWPqrZLPdK1Ip0Dp0v0uS
FZ/hdszmaSYFGldmbZMLNRCS7qD/5BoFAxulhC/d00Buu5rC41sU8H2+TFV+
oIG+ZStEH+VTcOv985pdjzTAxxjnflhMwZspw3YJlj8Ib/hZ9oCCsh/xPmEs
/wLKbww9eEyBmpHtOX+WvzemItruV1FY99YazQWW/13yuytLayno2uvvJtOj
AR4PrYKSRgrcln7k+fxOAwe7pk4Vd1Bw2EOy0XhKA1n8zYeLeim4/bHk7dAf
DbSa5HoUDlDgFxZiLb6ICvXH7igYowCpK8RC1rL664e+Uv5XCngn1ttf2sTq
L8W1YnnTFCRnfS5wUqdiLrt95vYcq/+a11x8aU2FUm/h8C12DdAq/syEOVPh
Kni2/eZiDSzdNana6UNFTTSt8MYK1v/693Hb8QQqzu6/73lFSgOjEgYZL7qp
+IyCU0vlNSD0qa42+isVxmtycg8ra2DLOo2JZVya4Ki/8M1CWwP5mRM/T6lp
IlQq6PBvaw10M/V9bTM00fXXO9VjmwaOt3z8drFcE+rtex617NCAaAyFo7hT
E5ORdgs5ezVQ79sy7CeoBc93W2K3HtPAFfesSLUULdQ8kL/9NEIDQ8uDLlo/
1IJkgmSjbKwGpJZ+2W7Rr4V+XUG+f+c0oPXDRfPrJm3Yp09dzLupAc8Ir1dT
9dq4d+hTmVC+Bk4fbnqmOa0NftMPvZHFLPYsNPZep4PGmdZ1jk80cNeX40Xq
YR0YbCvK4XqtgbQs3TX66rrIUrhd78c6Z3PD+fq8nrqY47zy6U2fBh60Hulq
StVF+b1ExeJRDbQ1+1wxYNeD0gq/+7vnWf79dfrAPaCHs6Oe3Q0cVLSXiK5/
IqyPzxXOv9V4qAgbudsVtFUfOT5WerysOaH+5HLyn0Z9iL1UrH3AmiPGVW0J
JxsIjl6THt2gREUtZ4W2ySKgO3TdknjW3KlTipfokgGSZJdb7tGnYvnej6JJ
3sCS2PEOfnsqVHojC3L+Ar+Q99ErnIpIziN1IlRDPLnx5fKRaCqi9rZt3OFs
iCgeBbvYOCr6OC+lSMQagq81/9n1ZCo0ejt3GnUbQsblbtbALSpGRJRe/g43
wvbjxY72rVQUNRWuXzxOg9iHKf49nVQkOHRWiIrRMUjbUn/oDRXO+q5mtRZ0
+C4roSR+ZMUb9DR9X0hH7OVSwcZZKgTu8beYH2fg/sOyV2SDJo47r6r/SzHB
0XWzTCsZTcwPNQ//8DMBIjV1dm/WRN3bYrmUXBO8Mnl45yhFExpdCUOdG0zx
sftR7H1TTbxIMPvls8YMq349xeYATRxMWD8muckCQVtqSoWeayLD/PyKf/tt
4KkuceV8gyba/HKjVFNs4KgRdmZZsyb+XjGxfF9tAx1tdXcO1j0mJxlT9GCd
LTgMb/B/+6aJqt3jAm69tki0jT5QK6qFyisji2L22yHC7v02SGjh7BsL3slM
OwRs0zV4LK2FFUNrh0Ze22G70w/hYhUtNB7jEw7Tt4eYm0dtBkML8fFzea5i
25DrT5MICtBCg7ni5PT37cgIuLJ04ogWeLPl0pNVHRAfNPdr/3Et9KbGbWr1
c4B/SGmTyyktcA8q/JT45gBqhNQx8ywtBDx+z6037YiaRK4uyUYthLzvHtQW
2Yl3d2vOtG3QhuzH3VZTYy5o/co1voV1TgaFYyTU1rmiSoFucUFBG4HCJ/8w
GK64klu7zIGqjUbVtTZhaa5wv1kX32ehjW2PZwY20dwwktmQOHpEG58viex4
leuOr2dfJc83aeOG9z+JLZV7MfBy2Q/ndm3of+lKy/++F828lvZVPdpwzGm2
PCXribunmlYxh7RBT01o3pPsCf/o5os8v7WR6jPLWeCzDz+OtV5aKaWDTs19
jRHq+/H3QMdluaM62JG7/4MRrw/sNXafVwrXgf6p37JeDB/ks4/EqkXrYMO4
6Oa+KB84p84c0ktgnWtV7p/Fcz54VitqYntNBwM7V08v+eGLkxJuP0IadUCj
63mGhfhjZddXiwZRXRz64/LreWIANhtwL3g+1oWuWFXiC74jrP03b1NPlS72
HbEVZqcegfoqG1vTOl10ob3ZyOUIdEdTb2xu00X7kciekcIjsIqXN58c0cUl
EYdrJ21DENBrmRoqqIc1P+uplhdD8fDQhS1n9+thUaXkuIJwGPTfau6a99WD
63JKVrl+GKpp/TG+QXqotfg1utkzDI3CMr024XroHLy1r6Y0DH1Py8JXX9RD
YO7URLrNcbDxvn2VVaWHa22eh19EnoDxtQ37illzJj3p3rVa1wiop/LJ1Inp
4zVF/HmJfwQkEv5+fLNBH8ZOP41jIyLwJ7TTnUtBH6PHedK6siNQYBvn7AB9
BLTkyAn3R2Al+9S2eS99WLskMe/ZRoJtpn+VoK8+ThgPNxS6RGJ8vLFdJlAf
+m+KGKd9IlHXc8PW5rg+HC526HeeikRokaPl9fP6EFWuzCp7Gol3LlU000f6
WOG1g99RIgqvthVwOlfq4xXvqvjfm6NQbp5eHVDDincnkBpAjUISNQgZzfq4
McYsH7WMAp1fVndiUB9Tf9q3vgmJwpZFq/9yjumDrv5IRoEZhfV/2R+t+cri
F1fztsZHYXbkLdVwRh9feXqzxa5GIa8iUe3iUoJ/661iMuqikFoaNn1nBYHr
hdPaZ1uiEJ27v7hiNcHtGN4Eq54oOKcYKY+JE0xzh4qZfYqCgO+MvI46gXBE
R4HQEiYW9nz8ZK1F4CBmoHJxBROfndpue+gTaNan3f0ozEQNPU8mwYSgWU1v
+Kc0E0fWuUh+2EXAc2/3xT7ChLuNyvY+NwKilHatis6EFZP9dLcngRzX/t2H
zZmQ+XR9qsmfgPH2497t25kQFAuWfhFMoOBzLSRiJxPzVgynmqMEk9+b6o65
MtFROlb1KJogQFqtc3g/E1WjD3/cjyOwuxB4xN6XiTzRM7LFCQTOlc+ELwQw
ERWheO5WKoHu6wtCsUeZ8C1ZeH4tk2DLCQkHzRNMOI20zGReY8Wjp+14HMmE
ikWAy4V8Vj1C/qlqp5gQCzdKTiwmUH62q032DBPc91bVn35AcPK4c+23eCam
Pw7/iXlMEBdSExhzjokB4TKlyCqCTwP9b8eTmGg0O+UeVkvg1P97TuoiE/eP
O6UcaSTIavDvUrzExJUi+caAFoJs9t/e3GlMnB36O+/Twcp/0/MXxelMhAg1
qe7vJcg9OzunkMHEHtOsvR4DBNbR1YKhmSw/w/zSXIYIRNzM1qRkMaFdiKYd
YwS9wQ9Fo7NZ/g4KsG//yoq/WmuT0RUmBFYPqdtOE+xPmjZrZ/GccamXxQyB
RLPSBfWrTIwdjckwniP4KnNSZB+LP2/f7HWVDTimb/PzAItdJ1dyiHMCjfpD
BmBxV9zc5QzWvd1nmyYyytIz3zhMEeUB7l59meLC4qonTS2XeAEDx/b2O6x8
NLY/2L96OXAxe8mXWla++RNZnMn8gH5fza8SVj2ScSczVwgC1k7LVwex6k2V
9KcmrAKeSYgcXHyZCb4njm1LhQHJctGN3iy/orcZeMeJAP9u0Nyusfz8/U1u
EbcY8PHgC8t8lt++pwSzo9cDrhff8sclM/Fxw19Njg3AwvWCZs3zTLTavzo4
Lw1cG9z5TuAsE4xvpYuPyQIOBxGlE8fEk5OZV2blgWLbqZeasUzceuTb8V0Z
uGw0J1EYzuoPewffQ1sA8x2zSbJhTCR9JTwT6sDge67QwyFMnJAQ0P2sBSzf
mux7zp+JHw9/d+7TZdXDKPu46yATB+wG/Yb1gapmRubCPia2xZZcf28EBApm
1FY7M6Ewvm1ptyWQw332kb0ZE+X2FpWnbYCUh8fdHWlMGD01DNS3AzQT+7kV
9JnYkaD8NscRKN+SlERTZSJOZUle0B7APfJlCG01E6vS/jmzrilQP5xNa1vO
6j/2X4J9Xiz/LZzDVRez9F8PHjXyBZQlDHm8f0VhJOiJmWAoKx+lnJctHVEI
6L+3UHsMePcnN2v+ZRTm6XfuhZ4A5hYuG7M/j8Iq4RTRD0zWXtZtln+mKApG
D/0+FyYA9QO8GuVxUbgyL3na8gbQs7DmULN6FBQ8RfTZbwETSxjWZ+SiUNbM
P116B6jGjzqp9VFozp5zEitk9dt9R5OJxax4Bl1yXx4CPjs//P7WFYkdsXEv
TrUAnAGPO+f9I7GSf5Kn5g9g1Xuu4fS5CLx+evqk6TxQURPSVB4VgaSD0otb
/gHR3MmXO4IiINi4g/MNlwHu7wvn7HZkcUzt/ASfAYzyrfkFJCKw4m/69NqN
Bkj6pPrT3iEcy0bpfYHmBvgY0cuoCzwOrsrLhRszDGCXPi1deSoUb3RpJu+y
DLBuUKctzTMUhY/G36dfNYCvk394CC0UOx7oCQreMsAk308jGlsoigveBbHd
M8APiWEemZAQOGds1O6vN4C4iPTr8/uPoDw0ryblO0sv/7tK6vZgJMzY7d76
ywBrVTgi5ijB2BM893P5bwOYFP+5HbQ6GHyHLDfFLBhgR2gE77WOIOz1mogL
XGKIH57I+GsXBEEHNWsbcUPY9jS8n9keCG/1x71LzA2x8vBtnvX+h1DV2plf
bmmIx13F6tJ2h7DaZzJ8n40hvgj91TfROITKHGmZ2m2G+HyVWTI4x9ovhM8F
RLgaYmRK6pDvGX88/u2xdCaYpUf7Nc+xyw9LK/n0Pl4xhOV2+cRnKw/Cdafc
iuTrhmgu1s6w+OCN+zNGQwY3DTHqu8JNqNAbLiqhcdl5hlBeEI/2NPdGydWh
zh0PDBG+mnPNXOwB7Iwu9217aYjbdK9hTt79yDN1v1LxyxC5r25Rookn1BU2
6JPfhshWXWzSLOyJCr73byv/GsJaR+aR1eRetLbvFn7GZoSIhxPh01f34sdu
p4TnvEZInt9b8Zx7L/QDbMIa1rM+X9EWcbh/D1rT9R1fM4xw3S2gwKbIDU7H
539uNTXCW9FdeuqJbhh0eZLcbm6ER409/ma+bvghpd3SYWOEwThjeT5FN4gU
UhjdO4xgF1L/5Fs+a998rqDe52uEr+czPr7zdsHPL6IrRlKMYCF7TiSweycu
ZI7WZ6QZQbpZdbAgYyfUrEvD7TKM0NoyeGer+04cumc5UXXVCO3Pl5n3fNuB
ryERzZfzjVDwSW6+dtkODC8aOWtbbYQ/4tU2j3c6IrrsHo2n1giuFYO5OzY5
YuP+8LmKeiOobOvl3fXdAW6v1hxUaDLCcfuu9qizDuhPMjfn7jEC3ddt+9bn
29EpXrzk6VcjyDn0nThpuA1BbcefBU6y8rmqzOBdtQ0rmWah8t+NYJDpMT0y
bA/bkaGxS7NGCBFumcg7bY+mfKGGAE4aJpRldLb32KFWKyxWVoQGb2H+tEfM
rbhvZ8x5gcbi94+sDYRtcMq8PEbMmAYdkZCAt5+tsctIjifHlIap+Mta929Z
g0Nt6fIHVjTU7OCJH5O0hpVgi1CPIw1f3F/maIpbYax1u7yYDw1dEoOir5Us
8LihPv+GHw2bTv0e7p82R0KVprJiAA0PCq4GO5eZQ71IVF3/CA156dqfHxmY
IzJxQM81koaB4fndr3aaQdTK0/bGRRqos/Odd2+Y4Cu9u10hlYZr+t36hazn
tyo9k+3302m4oVQ+sEbHBJ6K8jvrsmmYUeAfl2o3Rsmybx5jd2hIWmPivozH
GBYvg0MUKmisgT+2OzqajnCTmOzSERouRmv0RDw3xGtnr10qn1i/Xytdt/my
IaSCzUXyv9CwxH750KZAQzReFUi+PknDsYqzwQJShlj1NzM26Q8NHnIpielx
Brhd8MDHn4+Ov5EM+SWsuf/neZr8+Ao6hOIeDLPWJli+CRvdt5KOzxs7uExZ
9+T0YiM3lzV0LHr4esqmgLUnubbYW0nSoZixn8cnUx+tgmM6Chp0XCpR4jW6
pAtJuZeztzTpaPnXFN7mqItgcvf+Rh06Rgq3rvzAes4QPRikvBZ0aL28eyf8
ig48atk28prRsUT2jHZ2sTZmj4jwju2mo2R1w/HMz5rY0G/Wcz2GDrbsWzkp
xRScrtYp3HaKjtl5u9xjxymYvqUQy32GDnrVEakeUwqqA/jUvc/RoX7Kvfj7
kDo8eF4nbrlMB1ePf1n6OnXcVnMyflZEB42v+VlHzhasEDFbH1hCx4NskfuV
IVsQuqD9U+oBHU8ZnQuCFltg9kLs+qnHdMQ/5l808V0VX5zfL1jX0ZGpdGN2
r4kqlE7vezDwlo5hMqCXxqmCFD/H+HMDdBh1tiRbPFTGP3tTD8MPdIQZqwmt
O6iMVvHNgjdH6OiuLux+066EQ/e/+fhM0bEYBzZl5Cmi9H2w9NxiBsqn00S+
Hd0MbWr0BZEtDOzi/jg7m7AJXe4iGpnqDIjlWLz77LgJgQl3uyWoDMhoG3+2
37gJ+cM9orK6DIwX8ETFP5TB+guKVzUYDKQFOdGDv0iDY6qrwG4HA7V8MVtN
PaSQJXbQunsXAwe4TY6aUaSgY8I+tcOFgefkd23pYikEZW9Wd/dgIHjUVelZ
7kaMWEY88vdloKW/lPPqjCRe5srVx0cxIHVrXUzN9Q3w6qrwEohh4MFhhyPT
RzeAi8Oe9+JJBpKmKveEbd0AfacTlhlnGXji8XvlVdaiVcTd3p6bwsCtG6tV
1uyTwAWPsPf1uQx4fVkprhCxHrvWt/xmb2dAP79VaWSHKPhEAu4/7mSg0Puk
39Y1oni2cvWh4B4Gtl7oUt/TJQKZJTvHxvpZfhVeFD9oL4KJ7yNdLWMMJHKr
Kkw6rEHUi4WSzAUGcmsDuw8fE4J6zVU/B3ZjzGR+fBFiKITRCtpmAS5jhBtf
E+ThFYJF6elr0UuMsUly51xD+mqszhY6773KGLvuFP4url6F20FKvlryxlje
4b2Ud/NK7PBrk/uuYIzCiJO3Tf8IYvmBoOF8ZWN8X6a4wNEoiACXR7skKMaY
XR8iMnBAEDpmDHNuGIPnasXcqnsCaBZ3lu3cZgz9mBDjpG0r8LMxftA/0hin
MwuyNduXom9pp9cc0xhPL8XUPzy3FNUWYhMnY42R29dyrttqKc415/7NOmMM
eZqN+9ArXsi/rl/VdNEYgWErj61qXQLnXnZjuVxjBFiQvKwpbtBETZtK842h
UzE5Ssq5sXnnOTsUGuNQ2OeH+8K5Mdu33tWh1Bgqtx68YfBzI+m9TmhMhTHc
thRpS1MWo240OO/Da2OMLhJ7FZjKhXzZp6o+nSz9GnPmgicXkvdzlc92s/KZ
rn6+QOGC65ekGv5+Y6z3OJm5s5MTf74V9uuNGuP8+n3vvEQ4ofzrE3/6X2Pc
EHOR6b7PjlQu56CtUiagP1lbKhC4QBb2CFPaZEzwbnvtxNrNC8TjeetPazkT
cO0+ItE8NE9UooyOWCqZoDwxtmejwzxp+Cd71ETTBKWLf/vvpc+RmT/fw/Ut
TKA2J94lSP6QXTsK8NTKBGuMzXO+sP0h1Q892XVtTTBvzK6//flvkhDSG6W1
3QQv5O6VvjX9TWR+VcSou5pAL/P2yujds2T7VNwZ+SATWFRPHVPM+kWe2BhZ
3DlsgtaG07/ivH4RyaK5ZbKhJnD57sbco/aLfPP1S5A+YYLr7COdcY0/Scy4
/XmJUyYoU32RcHLhBykdFb8klGGCru3rOrzCvpOVA/evcdSYoGi7jmldwyRJ
WHb8eFmdCUaarM8dzpwkvDo0x4MvTOAbYeR5IWCScKS+Xt7VbIJHb5dJrF4/
SaZtJ0Lu9JogO5F3TPLHN9JaK2ttM2GC76UzDdtOjxOLHxNyi6ZNYMPF8y8B
46RBsozr0Q8TrPoyuyt25gupDKc/2viH5Q/3Irvb+76Qu1ru0jNcpshUjQqN
tflMzhZc/pspaop/It/0hIzGCE+fe9fWdabI6OCucOQaI9G88sXcEqase5ye
q1M3So7tK/c8JG0K9x57927zUXJgQ2cbTcUUD/maOAydR4jJRb7bX+im4N0v
8KQu6yNZdDzSXuuQKQKz9tRfj/lASqfGf1cGmkK8K2mj3s4PxMPTMZtx2BSe
bI4TuqofSI218me7Y6Yw4fYs9h54T6Il+8N9Y1jxeZYY7dN7T7gaNPOup5nC
ylXCuFJkgJTq3rCRzzDFMj6bwPrWfuJRzP+rKMsUKbxKb0+c6ic16SOouG6K
ywNaV37+7iNMnwtdPQWmSAsJbHnz8S3hWDnJzldtCtqNKAPD3l5y7+TOWxdq
TMGpnjd+Pr2XuM/VWaytN0X/q4t9obt6SfVw5iXZV6YI5vn1atlgD4kqN1c0
6jIFQ7G2UuhHN2F3vuUY8tkUvVm3TIO3dBG2O86Fg4JmmJm6J17K107qxrt9
s1ebgQt/KfF9r8lZFVulXWvMcJXd6ejn3NdEuNyooHOdGSKP9sQpmL4mSvWy
eQ2yZrhyIiIv70wb2TU8ffOuvhneFOtrHN/USiTlDnp6G5gho+LC6UV/WsjY
wWFpWZoZCrq/j03mtJDAH903rpqa4d+1MH1nthZymvPptQv2ZmiLE3ZUqWwi
DzeczDp6gBW/OvnAJ/eX5MReNmeqjxl4+mbbWkRfEtqd0HU//MxgSdlQFNje
SFpVDmb4BJshtkmrZJzRSMaIbbprhBkkMucXBWi8IELOa1MYKWZImNu3X0ej
ngSkF8YLVpux9oqsHqf856RsLv1kdY0Z1stW2vuHPidzzrGRAfVmYDhRj3Eb
PycnN+4Ofv3KDIe5ppnFQ9UkI593d1K3GYpdpgoaJKtJbcVeBcGvZggtr20U
LqsivBtsZaonzPCDwWl250wVsWHqSgRMm8Eket98rmsVeWO8ctXrGTNETTIH
/iytIt9aq/6e5zCHR7aDhktLBVkztPalwBpzhCoGSorvfUJ207lrn4maoyr9
tNXOtU/ItVvTFYfWmeNhTn6I0+vHROHgi3ttkua4RH+jf8HwMTH4eTj9vKI5
zkS59DZvfkQOcL/eL2Bkjo6DpUeKxcvJ082neAR8zeF32bCjIryUaHQINyX5
myOk5MqKVValpCjs1vlVgeY4EMZR9laslFxrqhNdE2IO/w1tBtWPS8gpv0WK
4lHm0C5Ltx5fuEe2lkTZKqaYg/NH9VGB9GLycqegUGGqOfYevkqs/YoJjeva
G5XL5ti80ungT1oxoW57tkf9ijlaL9vNH50qImIz/4J1cln1TM6K2FkXkVHt
4+mmFeZQqVrNFq51l7gOLXN5WWWOOsdxd5nJAvLmTMZGy+fmELqr6ht7q4C8
6nucb9PAqt/fyMRgTQG5d+JPhcNr1p7d6613nj2fhFUfGdo7wtqzl8gO2X2/
QwTMAhSi+CzQNUNtPGR8k1x5xr9UW8ACJ7qaGquX3SQqWgWfplZaADqLtItf
5xAr2bGbbiKszy85eni65pDTi503GEhZIM0n7JB/1A3C9dxUiE3bAhfavc8/
GbhGkrVHf5TpWoAtw1j4TP41Inkvut2PWMBx17+Hb45eI7haee4dzQLNNRzb
59dcI8fDKUsrrS3wRN1pzHrnVfJLZwPbib0WmNkQN24/mU1iSioGKF4W2FlU
mbw6I5us2rzr6dcDFrikdDeoxySbqIleOrrb3wLSVekRhjlZxH922U/dYxZY
/n6qecO+TPKpdPbT33MWqKbNOXxcfpn0Kba2hz6xgOrVyLWhoykk+4vAcc5K
C+zQfOJEClOI+x07mfhnFiiUo4zdOpJCPkl1h1yps0BMW8ngnyUp5NfagXX1
rRbQ5ZEU2qh+kQjwju9bNWwBb4Hqw2FZyaSjXlEga9QClP042uOTTFJj/B5t
+myBzR3THLl6yWQ9+/dlOhMW+D30/XrBQBJRmP1d7PbbAvs+e0pRZZIIY4R7
7u5yS+glrxC3e3mOLLlhmqO5wpK137QGc187R165nbGqFrTE9NPntqqh54hd
P9/VTmFLFJ66r/hC9hxx7VjNmNtgCZu3d9TyhRPJseqN50w1LFGSoSEmUX2W
FGURqY/OlljcdbaJ59wp8v3od243N0uEXzuzPMTuFNFwuPWlf48lLjsL7ooS
PkUe8/OXdHtZoj2nTMrr6klSFzFg8DLAEq1+bh4hT2LJW/fjLvdiLXFwWjUz
jz+GrCeqRspxllj9sLD2ZV80cV07LJN/xhLBfvfnYnOjyUi7xbecc5b4leuY
0mwcTSZpYsfT0i3xfPfCkWtxTLJ40+P0iLuW2JtoWJskE0VMOf1OzBdZgm64
WPT130hy9p2k+9ESS6QJcAvsa4skAqmn5YLKLZGzqGr4/PFIIrZkR/m+aktw
G/HLf+mNIFu+zHZadVnCRYah60gPJ7sLNQTWLVhCXxBeLWNHyYMds3ytbFbg
+pSaY3H9KOFb/GgZk9MKfJdLw5Kdj5KqXXo8n3isEHxOffZ4dyiR5KX9K11p
Beaz7VJ1r0PIiIftVws5K3TrSNlunDhM9Fes/PJvsxUO1ebKaz84TC497hi7
p2SFXu6zL4VPHCYmgo4f16hbIdm4RcWR/zDJrXR++1HfCuo8aXRZajDxFT34
IszeCjIJWqmLMgJJXa1ivbKDFXZ3ey5kHQgk4ocmagadrDC1tyb3jlYgaa0P
qDJxYeVnt6JLsDeAbAkOLVt1wAq5fl8Oq68LIDMtsTn54VYoyb/7ofSRP4mI
uRrZl2uFzYGvH9hfPEiWH+E2cyuwQpnLjqxTdgdJupeP4EihFSQOvmuIFDxI
Ssy1rk+UWiH14/uR50neZESgrYaj0gqXNe9/m7l8gJhnsfHItVthE/uhYInn
XqQn0bO1oNMKQWW6sg1xXsQj8lXqlh4rvGxd9K/dxouc8EiV0+1n1adwbs2a
9/tIkbyKufWoFbxjY/7acu4jQmUuCcF/rbC9YTri7K695Prt2u1/5q3QXnAh
8LDcXqKSvlk8nM0atF9qp2t+eRDT4zOFpxZZQ7DowMb4JA8SZpTYdpnfGk6r
14akNe8hgy0Vq6o3WuOBWqhFs4M7KRhbd5nPwhrP9zYu6O92IacyY1wHrKzx
d3dnGdsiF+Kx9av0XVtrTG6qqcwpcCZiT54UWTpY40jY8PU/bM7kdOLOurPu
1lifM+S4LX8X8dJIm+INtYabBjP5hNAOQvvCVvbmmDVsONKXFNY6EfErXmG5
J6wxK53y1ibYiXQt0eQ2i7aGeq3Spa+djoTe3yUWl2iN35cDT93NcCCS0atM
uG9ao9anX3mfwTayoBm2vPu2NSSpgW+MZu1J79eh1zfzrPEro3Ayp9CenHMo
2c0otkZDwjKPf+L25J/81sCYJ9Z4avQpUp7bjvS1JWZxtlvj7f3Kw0cnbUh5
7Mye9k5r3GgYs6UV2ZALOi5y13uscfJJ6O1b/jbEPEep1HDAGj2qJy+Fj1iT
RyFNLyI/WYOnXHD5vX+WJEWRkmg7bg0OV+7ijXGW5NBghv2GCWuI8Mfv7Ftp
SWQtDr6r+mENfymFVwqKFoSLvePGuRlrvHlLSXnx2Jy8v69zwPWPNbJ0i33L
zM3JkwPXlVXmrWHvl9I922dGLokv/fnvnzUeZvRvPednRv4PD/fjBA==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$60276#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[141, 7], 2000}, {20.142857142857142`, 2000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 850}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.793640561309989*^9, {3.7936406007279778`*^9, 3.793640619274135*^9}, 
   3.7936407371030693`*^9, 3.793640921932763*^9, {3.793641020095443*^9, 
   3.793641028238113*^9}, {3.793641367539876*^9, 3.793641391818853*^9}, {
   3.793646454393449*^9, 3.793646463714933*^9}, 3.7937076289031763`*^9, 
   3.7937076646762943`*^9, 3.793717673438632*^9, 3.793718176099379*^9, 
   3.793718269333499*^9, 3.7937189119617367`*^9, 3.793718961026936*^9, 
   3.793719541834216*^9, 3.79380139505795*^9, 3.7938014755108356`*^9, 
   3.793801571395419*^9, 3.7938016389442*^9, 3.793801742820375*^9, 
   3.79450702641641*^9, {3.794507402360146*^9, 3.794507406367613*^9}, 
   3.7945074971288643`*^9, 3.794507542134782*^9, 3.794507664085531*^9, 
   3.794513111295895*^9, 3.794513180075007*^9, 3.794515033502537*^9, 
   3.79451531756131*^9, 3.794568644037795*^9, 3.794569006953068*^9, 
   3.794576051761636*^9, 3.7945766874504833`*^9, 3.794578141163995*^9, 
   3.794578430368981*^9, 3.794579362920628*^9, 3.7945794918723288`*^9, 
   3.7946566577488413`*^9, 3.7946681114805193`*^9, 3.794668338499515*^9},
 CellLabel->
  "Out[1493]=",ExpressionUUID->"42d6fc4a-91d1-4521-a386-5a938589b1bf"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4B.pdf\>\"", ",", "figoneshot8nscrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4B.png\>\"", ",", "figoneshot8nscrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7946682018446074`*^9, 3.794668208148054*^9}},
 CellLabel->
  "In[1494]:=",ExpressionUUID->"c2596c68-80ea-4180-a39f-29573db1482e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot8nscritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "solns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x8ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x8ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x8ns"}], "]"}], ","}],
      "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.79364160744447*^9, 3.793641612397052*^9}, {
   3.793646477609962*^9, 3.793646482835202*^9}, 3.793707632403079*^9},
 CellLabel->
  "In[1496]:=",ExpressionUUID->"a740ee4c-0017-4501-811f-2f21ce8f1e27"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1nc8le//B3BKpUh2VpFkZWXPc73PcOxVyCYZlaiQUcqWTUsiGUmFJCEt
UVZ2SMNI5jmiVNKu33X3+H37nD/OeTwfr/d1va/7Oo/rvu9Nnge2ey9jYWHR
wl/Er6k342kDs4bE8v8fNqrIwdfCZ9D/rJaffeGWcPE/m3U9r8oTrv7nnV5f
HpwSbvrnEeUT1DThgX8uELBKSBae/Odo9lsyScKL/+zgWHhj4QMb/M8cf6Jd
jDau++ctNu8Yj1P4/zm0WwdlLwr/8/pqnlFWVvF/rh2ndvboS/7zoHH0hzSj
/7xUUS9ovv0/ax3V2dXm+5/r+JSXGk795zs0EYkqxn++X7IQdObM5n8e5lQ6
vz3/P/8M9KvnLv3PBmiaPe3hf65/PpQXP/ufH7K3toaA1D+PBbDNq5thw9x1
S8kViOUZmfeTHbbH5js13ipIQi9S66YHNjeLxl1FEoLC+y4H/Ih6H6oUKx15
rPoerRiC7eJP91s0R1H+WlfeRmFLfb5Y9M0GNehUffDNwlYtplVyOaKx/PeC
0oXYp1a0nixxQSwrFfUny7AXt9i7SXkgct+VBI9G7GP2b+ee70aP9uWJOs5h
Zz6Tep7ph24x/fzclrAfBwmWHvBHxXt07+1m2QIsYcKxL+0OoHif504B/Fsg
6lvhws0Lh1DI1OXSoI3Yqn6nL+UGIh+v4O9hsrg+pnzZk4tBaOcExfS4Kvbs
NhKUBCNjT56cWH1cv6/VUKbqMNJ585qZSMe5Ye+H3EchSN6jQifdGue6YbyP
IBSJvo5IOu2Ec7mOTfvSQxGnm9nLbC8ib+M5OhaKfg0Ly10MwH59V79VMwy9
c2aEXQrDvl6gsflkGOpxjBeqSMXjo6nrD9qEo4YXO/bcysK2p+4Vvh2OKndK
1tUV4Pr4sQ9UiSPolN3DnY+rsZ0yu67/PILsbb5lvRjG9Tozl2WHIpBRb+v0
yDTO3TSaZZyOIW2rLM2JBWxfAdUvQ8eQsIXa4DybNEQFKyj3zBxHw8b+AssV
pQE+ttomZ0ShrlY9b3YtaWgwPedX+DIK1dPX1KwlSwPLkpvgF6lolE+7Yitk
h8cbkvltHkYjT3hzWvEYHu/WCbHLYhFDy47XoQvnAjF6jMZ49LJ2s6frc5yf
yNymIJ6A2jU+3vR8g+e7q2NTdCwBlall2Ph/xuaU2iRHOoEClJ9kxmyQgSie
vtCOrkT0Wdpg3XV/GQDR5wvccqmINE5pTQ6TgYa5MYPJS6koIc84ck+sDLCw
9Z+hS6QhQX7b95vP43rbXdTWDelIk9WvJ6dJBgoOf63nE8xEYUPZGYmisjDm
b76C2+IUasi6aOQjLQvgvbA4e+4UYt9e/Ie6TRY8Mh/4V06cQufbbhz4Q5eF
Ah550orjp9HdmharkEBc3zhcLl5/Bv3MWFzn9QTPp9fNERZwDtHMvreSB2RB
4tDJQYMn51DqSpYo8dc452hLENmSjTYc41h4tYhzFH5SaiwbkfZJ9tpIyEHD
F7ngvt05KJJmnYlC5YBlXmdud3EeavtjZ7whRg485I+38/FeRNz3nFl+pOJc
QekMV/RFVLDN92BtkRyA4Pj8R8981LDxuLVitxwUtHAx9+cWoGXfyrhFt8hD
rwJYbj1ZhES7KJ+Qsjx4fE1vbu8uQuqFL5956ciDREb0Jv61l5C3yarcCgt5
fF6N2MpSLqG2855bKCHyULBs5IvgyWKUoSusu7dVHhr2bOp3qi9BV7kqxdKf
ysPCtqlQt1VXUMM4/U/VkDyM7aB1S9tcQR+Tg5t+vsfzvT6YyjlzBdkP9Vhm
Cm2FStq3865i15BYRMLu23u3grWV1+LVijKkYb2BPhy0FTLfBHV1sZUjS6lq
WdbjW0GFA3QGnMtRZOebedNTW0Hi0VPtNM7raFzMIGz0Ls4HdOInwyrQtQef
UldwKkDi5Z5E34eVSPOPR+2OCgW4ut2aFi5djcwtGmIM6xSAPV/yjLVHNdqd
K26l9QjXf1wTcTOnGmVqjc6IDOKcefQsH08NYh5wFh7/pQCVZYFhh9hq0YUx
u4iDFoqQmLJYbb+yDlUp1Rh77lSEhaiqMmWTOtQWwS9gu0sRrBU3TOan1qHP
Qv3XtQ4rwteiqt0mAneQpY31698XFEE7QO7Ic8W7iPWRKSVtThEkknL5kyLu
IyHuUq7IJeygwGS1J/eRktvqoYMsShB2RsAjWvABcvreGmTLrwRC0XK3Vt96
gKpVDS+L6itBJr/BjZFP9cjnEmIvTVGCyUc7GlLaG1BnnHp3i7wyxLlcyj1Z
/hjprutYdlJDGRTqJEY73jxGV8/v0nIGZfjJFmMZsL4JxVakF7y3UwbG7Oen
b2ObkO4LRqBQtDKMaTzhbd/VjK5uzVu/77kypJYrmXNta0UUZkzlSooK2LoJ
/AkX60DhSt3tfkYqEOG4iRTt1oEqg4Snes1VgHN94ylmQQfa+PuGcO5OFVjo
ogYPSXeib7wjMcr+KhA2LSSgqtWFKvW17ByyVcDcd0Uy594eJJ759tu1dyog
0RB5pWJFH6rfFXmt6pMKDPAlzPvL9SE3NT7He19VQFZg/I6pRR+6MKhb17ls
G9Csz/c5ne1DQhuSQ94LboOmY6KBLdL9iLdU9pM62gZ9GXnXLCwH0Iom77mH
GdugUubT9FDZIHr75fXoMxVVKHb7anzg6BCq9c14ZKqpCgv86r8GiodQ1HNS
yUM9VfBKecup0D2EBG/n+V+jq0Lpzd6WUolhRAlx/hnhogpfjfL9+puGUc7i
oLBUoipU/BI9Irp6FBl/6LINfK0KH9exDIuTxhDfrmPaM5OqEHCk20zGZgyN
9iqIucyqQl/o3QeiXmMouDJlwvCzKrjHp6W2J42h/AMmgcIcavCKvkxWe2AM
Lc03ZTRoqsHB0vIfot5vUPHsvXaudDV46fdwfe7hcRRwzmrzvtNq8MK7WCYx
fhxp0SaONmerQaKNEbvr2XHUnrdGMeKSGixdDpl+UD2OPlg7ZjDr1KDAeW2P
48dxRLq9tKNpQg1cOuWk5/dMIHav5HJxphrMXpp1tAqdQH3cG1ccfacG99d+
TMyOn0De+wxrt31Tg5t+rM2vCydQ6oYzQvlc6hBn9qKS/HICvYzdNhKuow5z
Wfcm7aiTqEilWeMZSR0Ovg0Jk7WeRPtHHNJVaOpw6lWV8bgLfo/TikIzlurw
O3hNN0fIJJKe7S609VIHzywPce0rkyjYer+PcoY68InvsGBbMYW4Nlx5Pzmp
DtKT6xZZbkwhsI8dmWCqQ0gXyynNuikUmOHeMf5OHaq3PFnr2DiFBlmFrox9
VYfOe9W/vPqn0MXpRLdhTg3Yli0dkLs0hZQq93X1q2vAdZ6kr9k608iDSb/X
p6MBatb56lfJ0+iU5OZrT0kaENKRwLhsMo2WzgzF9RhrAGXQYrO/4zSqDzfX
73DRgACjW88Uw6aRBVWp7FGcBnRuOiuQWTWNjkesOd+YpAGrGo4kn74zjSpr
phMa0jWA3TpI4UTDNOKXzfesz9YAKaMHPqh7Gg1zcovcLdeAioHp20uMabR/
8EPizQEN8Lw0MZEtOoNS99b4FEhpgrX504y9ITNoFq4ncshrQqJ5xHGhiBlk
JHS5NERZE1y8XNvqomfQstYz78x1NcE0Y/n7rtQZFC4VHPLNShPsq8u5LYtm
kM9r1YTtRzVhmuPH4cb2GdRUK3/1QRSuN7u28mzPDJJMl2yXTdCEs2zNDOeB
GTSiz8v1J1MTBO3DRJtGZpBtzoezZSWaECDIepB1YQaR7Sovs/VpQui0UJMx
LwNdVLjaeuC5Jihq261wF2Sgn8sLmK+GNeH2sza3fSIMVFeVoXhzRhMcpg4/
9pBkICXuAzWuvzSB/q5FrWcbA4l1KDbXymrB5d+y5k8sGWgJyib3RGrBmRKx
llfRDHS/+G1uaJwWBIzcrjkVx0Ax7Ao7EpK0IPNbxF3qCQbi6i1vvHRaC8wK
VGgnUxlI2r3i4ugVLZAefS82nMVA9sduOtj2akFRkvMnUinu9+bDut3PtIAr
SuV2RjkDjdNUWw+9wvmDouRXFQwUwHlLI2NSCxqHfuW43WKghNxq3vavWmB/
NfjHpvsMVHPndifapA1KA3ojhZ0MdGTD11hLaW0IlDqnndPNQBCtree6VRss
TLmi0noZqNP4zrUjGtqwNYW80nuAgSaf302oMdGGhugd5JdDDMS/9AC2BmpD
6O43H8aYDBSs2lQt+Fgb0hssxu8tYyIfdYmCk23a8FxwZh+djYkcNCNSOLu1
oXmt7oXOFUykp6vuueylNrzYHijfyc5EyyjF69690wZxiSjN81xMlGETt69Z
RAdi9O6+DBZmoqgdY3YgoQPTw3XGD0WYKNBOn3xviw6ExNrzrBRjInvHxfU3
VXSAXDk1mLiRicR2eTVfoOtAic5pI6/NTFR6kCYRHKgDjXfO0Y8qMNGFwAKO
96E64LLx8FCGIhOlBf9c2ntMB+oCK9wLlZjoYFh1l3uiDqhYSjncU2EirSip
o2YXdeB04tWlDnUmaspgG5Rs1wHmsw4xX30mqj3p0ZjXowNXdvPGWhow0dXT
98uFnumAmr3FTjUSE6WcC47lGtMBltYGn8+IibbnT6p8/6wDd/sj552pTPS6
oinl6SZduPqWerbOhIl659nmVGV0wb5yIifElIkaFAzNzyjowplTa9JUzZio
oLSZc6eWLsRHpFkWmzORZ0lL2rC5LtBcm2YPWDHRdF5bxkyoLmgafFYqt2Wi
wWH2BeNjupArsP+0mR0TtYqaWJfG6ML+cxd1mNhXzz/h9k/TBU+VQ+7iO5lo
39n2kx+LdEHlXOH5UEcmmk/tPP2rSxcUdxwpHHJlotEOzkW3fl1I8S003+XG
RN1rLGwbXuiC0nXH6CnsisQu/tgJXVglfCeb6Y73M677LPs3XeD6aDU3touJ
Fo/2nuOT0oOf2SK+Gd5MNHmX+2uwnB5EhNw68gf72Tdrh0ElPbhk4Gkb4IP3
N/Sp0HkdPbB68d7H2JeJwoL6zm+00oMdDkc83+1hoh/7BnLljujB4PcTUWz7
mchW0/WkUqQeJDQuKbtgl7NOJ6jF6cFY2q1vVdhu2V8OGaTrQawz15SrPxM1
NosY2xTpgUTLGqdrAUx0QmLXYli7HuQFvrgpdIiJxt4ymcd69OB7jgHPbmzt
24GvYwb0YOrdyevl2LMWce2po3owU9VYbBDIRBZHrxQUfNQD8qj1Y/sgJuIb
nDdvE9EHjnLlAN/DTLS/MITSJa4PpTSZ6BLspv1/tPqk9IFqcOLdJHbIcp7N
w0r6UNgn89o9hIleqqh/e0/Rh7dbo+iWoUyUn3Lk8no/faDvlMrlCmeireRV
v33u6UPDw+MXZSKYqLK0TOZFgz50Cbg2O2Cr81vbmLToQ8AyLY8kbP2Z7OKt
T/Vh64pNXxnYlmnyZgvT+sDbeXm48Bg+Xy8tssN5DYBN9Enjj+NMtET52Di7
3gD2CgcNSUUy0dHyrLfOGwzg6ynWKAvsuMjXJJKsAZjNSRzIw87acmhqGckA
LCNPrdGOYqI7h86opu41AJHlLyiO0UxEGtJ2+RVgAGEHLAuOYj+ijcQHBBvA
NsnJ3Dzs9vXSL60jDeDgE9bAMezhB7cjBc4agMtVvbpdMUzEsmao82KDASRE
fkrcEYv7B0UurWsxANLvaNpB7NUjmyWiOwwgldeuIhWbt3J/0O5BAxiQO5TZ
hC1l/1tYds4Aar7/uKwSx0RGRZt8b64nwUdZvr7v2OrZXNItYiTg+aRM4Yln
Ion0H5OvNuH8RWmIDPb38GeebAokOPNkrfIO7Os2SW47gQTR3zrmr2DzsX6w
+7WHBJGTFluMEvB6v4zw8waQQGrtDwkn7Lm59n7pIBJYRCvP7sdueVFsY32M
BJyFMjMnscMrHSwunSRBBrf0+ZfYr90baCZ3SVDb9NbM4wQTddpdX+72kAS9
SdrOB7HrzHIeBTaRIMWrG0Vhn9IKhgvdJKAlxiTnYxuuk9V/P06C9Ja2bcPY
ZfUZamc5EFRHV22xTGSi0A3ukm9cEFwt7HJZn4TvJ9Yq9sO7EGTZlhdKYlvG
siY/90HQdnnzE0VsaealD10HEWSX/WmgYg9UMxruxuHXHlYflwBsFfNA9zPl
CBotBqLrscUiqaczbiJYsz2Qtw17VRV/a3It7icnmfwUe3T9baXoBgRimSXK
k9ipEz9++Q8g8J7udGRPZiLGkfgLRj8RlIhNuZljz9pv3VPIAtAUcy3CFttj
gW+Z+HKA9Tf1412wzTZPaYiwA6Rdqt+5H1sy6UQeNy/AKPce9hTsXtvO/b+2
AAzIzjxqwlaYs+N4bgFwYm5+Xj4F76et+cNka4CkQG3DbdjUB5Qg0g4AHumT
yVrYTunKQ5cdAK4x5ceo2Ekqq8uCdwPUVKjcd8aeDr5vyhsOIJbOsSsRO3Ck
6nfzUQCHx6E30rB/GV6rCj8OsHiY+e4UNv/6LJE3sQAuelnkPKLfnQOzN9IB
Mn10dW9iF/ySTLYoxus7J3N+EFvBR5jEegVgVlxyzRD27e51H6uv4fmKYgJe
Y3fn/3QUuwFg5buGl0H0Iw/Kvb2DnUZv+0qsPyHpSWIPQEtS8jqhVLzed5HH
9PsA+gTJraLYh3aGbFsYwOtN2hcsjp0ou/v8zlcAYbopN6Sxa9v190pPARSn
a5WrY/OtW2Bv+g5Q4d//whK770HyCZNfAF08AQ022Kf2b1nZ8wcgeca1wBab
t91p+Ss2MvhdO2HiRDi++dd7LjLk8aylemNz/8j5KLqZDE7tWyfCsXuvaRwq
3EKGx7UDDhHYmQ6976VlyfDj1c/W49jralfMb1Mkwy5zgdOx2FyHDs4YaZEh
6LzHaCo254zhcJAZGSKjWuwvYneeHXP6ZkEGfq0t+wuwU2lHXx63JsPxs6wR
RdgcRZWDSXZkqP94IKUEe42r6NN8dzJsiHuyrwKbvX+huSOIDCevKWo9wGZ7
mHtj8wUyaNr0uD7HfqVPM359kQwvnK1+vsC+cXduLKeQDHwjclmvsJ1qDXh5
r5Ch317q/gj2zeuvg1mqyDAwWto3ge12YbPuSCsZPOVXa7zHVhfp7MtuJ0O5
jXbGAvbq7GA/2y4yPKk+MfUBu/p084WOPjJ4R9YkLBLrT/H9c2eEDO6v0y58
w64LL2vK+kSGpxfWiC9PY6L0Lztcty+R4UijNrBh7z788/Pab2Ro3yDvtiKN
2D8LmfjfeP2jEZmrsL33vE8KWk2BrLHhHg5s3p1qVtbiFHDu+93Ah80YGJrh
kKRAekBkFT/2g+1xUa1SFDjabVoogL3H8tlNkjwF/EXHQ9Zj1xuG8itqUEDm
9uIyUWw/9XsvV5tRoFFvzeVN2A29z8rrLChQMSToJ4kt4L8Q6WtNAXj1RWkz
9sPLW6Sb7Siwi2ZdKYXNtz4zMMqDAg49U+dlsO998+L4chjXTzxcq4jNnRU5
ejmMAu/mb94i7K2ac9P2KAVeVnTvVMJe59ezsyqKArVzeTnKxH4M6xT7p1Dg
dZI8hyo2x0Mug8kCCpw7UXFBE9vDWY779CUKOCU+ltHCrvlCnSCXUEBI2+om
YXeV8KT8Mgq4+g8/1Ma+VTjxzKmWAiPlph262M5xdQFPOyig5O+UT8KulOgn
R3VTYElmjg9hr3gwz6/8lAKOKuonCN/4LHkvdZACYYOf9wL2ct+0VcZvKFCu
XCJBwS4z8SyoX6LA5b4FO0NsdYVNJPSNAvSHAjcJ13ONDT38QYF7KRYcdOze
ftf1jSxU+FL2+T7hRVfH9MdrqEDn9BMwxiYFWke0baRCvS9Pnil2q+06EZNN
VIh7vHOWsLVW9+0nm6lwfnJA0wzb86fZp3ZZKqyzOdZF+ESC0b4uVSrQaG0f
zIl+OSSHPjoV7qo+XG+F7Xjs1+ftJlRQ3+PmSHjc/f7pfjMqeJJtcggvSun2
DFhTodxIW8QaW/iGBv25ExXSorV5bYh+jxXUhwOoEHVuz+R27M9vRbins6j4
eca+wR77TN5M64XzVDDV0LImrGZVHbnjAhWKtJ/FED5UZfG+oZAKzYZe04Tn
w6K6c8upsEXsY8lO7KkV06k2j6hQ1sHkcsSOu11FY2+mwpRqiQ7hzXsjf9a3
UuEifXo34V2dQvsVuqhwL3mplvDIKTOzVS+o8EHm6E4n7GfiN1c/mMfzk07G
OmMHPz3WGLRAhbd39a4Q5os1DZf/RIXo9qh2wjbTE4xzX6ng0T66zgW7q1yw
LXA5Ddp8VmURbtaJSJAVpoHIm0+Zrtheb41Jr0VpMEBpqiC8PE9g6exGGgS8
QJ2EySw3vJdL0SC2VX+lG3E+W97QRpVowN+zL4RwzQ6j5WdoNGhaHmnsjp1o
VhcvZkSDiD0D7oRdqHLsl01oEFM0F0J4mRrH2lpLGvQ3+BYTtuTtEXzhQIPB
7nM/CTN67eXF/GkgGuRQ5EGcx7bW8uIDNGiXFKslnN6grawYSIONNmVPCKtX
iqiTQmnAaau0QDg6Y9TAI5oG1qKDuruwRSx9bIrP0kCoSK6V8Lzh836FbBp8
ZWc8J9xgYGxfk0MDn6wjDMI+ivLOLfk0mEjcsNqTOH+c77wY13C/RC9jwuYd
h8MU6mkQ1UV7SDjSOD6/epoG4z4PMndj97ntcVFh0iDr5KELhKUOmwmXv6UB
s2/lVcLthTynLy3QIO7ns3rC/D/yEk59p4FLIfdbwlev1/of5DKENWM0khf2
98fn5ee4DWElr7oxYYtXETO+fIagPbl6O+GPK6m73IUMwct0rzdhfY8eW0tJ
Q9Dy/ZVMuJeXoaegaQiVkXeeEpaU6/h6RdsQWHcovCJ8GFXUbNYzhJnqpHHC
IvuDlUXBEB7Bik+EvZpZNq8xNYToERY+b+yvocJrGK6GwE9VsSK8acT0xaV4
Q1hu0HGHcPIjvRt2iYbwKmVPA+GPVxQSVqUYQunyTy2EHwVyqftlGoKUeW8/
YS/2vgzVXEPYn1M1R/iqmqNRY6Uh2NCcRX2I+6+w6cagW4bQpzsjQTj8t+5n
qVpDyPngKU3Y9InYpcR7uH+B3DbCb93Gflu1GEKB8TI6YaVk39rRIXx9l/j9
CWcdcEjLHDWEN3x1hwj/sTXxorwxhNM3LEII94pv5S2ZNoTEmR2RhA/VvPP3
/2AIVoo9mYSrxw5v+bmSDveDY24SFmvx+Xl9NR3GA7xrCMeX7ex356TDly2k
O4TtQ3SiH/PQYba9t4HwF45fw8lidFh6f6SHsK5W3BlhVTpcLRmfJTzoKayZ
p04HesPsPOGg9IrnElp0oBx9u0C4fOqFiKw+HR68GlwivPGMYqEmnQ71yG6Z
L3G+Pgxe3+FEh3eFC+sJXxTbb/XchQ5hczEihPWMWT84udNB6dXaDYSD87eq
e3rR4dMTLknC0xZRdw8G0CHcqnUr4Y5Suda0GDp0bxMgEd4zWL+HJ54OxkVU
IMy2zHbN2RN0YLDupxAmOR63uJBKh7z0UjrhylX9/aVZdCjSnLIkfMYrYqy1
lA7Vr2LdCKtk8sSYXafDivbdHoS77pVs7rlBh1gL5El4Jd9Tn8FqOqzmYXoT
DmvcMj9ZTwe95FX+hF029nxj7aeDhuHBI4Qb+QQOHX5BB5ahN8cIS692ZjBG
6OB3lRRN+P2n6cEeBh2kZu+cIBzz5PetvN90EFl9+zThmXraVh42I2A6x2QR
Nq9OLopbbQQO09rnCQvkC5704zcC4SLfi4SvBisF6MgbgaYhy1XCa/cFT5Ur
G0HSsEkp4UD3uy4SGkZwHBLL/+6/Kd1sFRiBRcBEJeFucTfZZ3ZGcHQX3x3C
agLF+cbORvDKdfk9wtlrZgXve2BLM+4T9vx8eMUlPyN4uDGzgfDn9rTxg9FG
IFLi2Eo4s7v0x8UUI0iPMWonLN/Xyt911gi8LLm6CLu9ZDWSK8UeVOoj/HV4
o8fOaiOwUckdIHxqTC88vt4IRjZ9GiTcMnO47E2fEQx0eA8R9nh7qmndiBGg
uKgRwt/f3RgxmDECk4GE14SVl5jrcn4YgYGe/QRhr1+bKUvrjKGSZWD67/Ww
uQVvlzKGQimWWcJtf2SPGGsbg5Dh4BzhL98/RZLMjaGjL+L93/9vqT5e3cMY
VO8tfiBs/yEpRT7YGMx/GywSjp+zPSmRiMdfcFgiXD0jfk7wgjFkn6F9JTw5
PnuBs9IYXJav/E6Yb7SmaFmTMWjLX/pBuLdZ1sr6vTH4LJb8Jpx6PfdHnogJ
rD23nHUP9opj0bY6h0xgzZGqFYTZ2rTLLp03gYyKmVWEl/EtsHI9MoGmpE+r
CbO6XXEImzUBj8M1HIRZrrndGOc1BfEhzrWE72w6cfHIPlPQWsm1jnBgzo00
3kemEGFRxk1YaEK0g0fIDDxzD/AQfrA1kZ0nwAzUzbP+ekb3WI5JvRnUkZb+
msc0UCGGyxx+1SvwEl7S28Ry3Nscut3m/+bDir394ffNoTD03l/Tp1f9rFhr
ASueF/915UUkNelmAVejc/96pcy9nKgKCyj8efavXW9o8mz4bQFFC8l/HSCy
/0mErSXYqwb/dVR8YfRwqSX4q3j/teBt9/TDPyxh66LrX19nbMjlMreCd8ec
/loyjt94VYkV1LTs/Otz4hyf//yxgqGS7X/9f0mSJbY=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$60594#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k4lN37AHCkUrwIyVqyFEKSfZlzz2pmUBQlyZZUsoVQCIW0IZUkibSR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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60594#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF1nk4lO33AHCkkoQkRWRfk2Rf5z7MDMOMrUiLkKReW7KLLFlC1mhTtqIF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          "]]}, Annotation[#, "Charting`Private`Tag$60594#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13k01P/3OHBJJWQvSyrZiZJ9f15m7GMLhZCkyE7WSpaQFlEkW9asIWQr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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60594#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.79364161512011*^9, 
   3.793646483923757*^9, 3.793707632937484*^9, 3.793707665481339*^9, 
   3.79371767378432*^9, 3.7937181764586363`*^9, 3.793718269643299*^9, 
   3.7937189620789137`*^9, 3.793719542208098*^9, 3.79380139537661*^9, 
   3.793801475793778*^9, 3.79380157169277*^9, 3.7938016392311277`*^9, 
   3.793801743200708*^9, 3.794507026949277*^9, 3.794507497452175*^9, 
   3.7945075430115433`*^9, 3.794507664410883*^9, 3.7945131115971613`*^9, 
   3.794513180396125*^9, 3.794515033842832*^9, 3.794515317968289*^9, 
   3.794568644328187*^9, 3.794569007350191*^9, 3.794576052234805*^9, 
   3.7945766878219852`*^9, 3.7945781417693043`*^9, 3.7945784308398447`*^9, 
   3.7945793633708963`*^9, 3.7945794922603283`*^9, 3.794656660528961*^9, 
   3.794668111605742*^9, 3.794668339423633*^9},
 CellLabel->
  "Out[1496]=",ExpressionUUID->"5ad16666-359c-4dc1-bb87-b78bbbbea81f"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4G.pdf\>\"", ",", "figoneshot8nscritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4G.png\>\"", ",", "figoneshot8nscritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7946682233114223`*^9, 3.794668228645316*^9}},
 CellLabel->
  "In[1497]:=",ExpressionUUID->"f7270eb1-83fd-4fab-ba37-6e0019979859"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot12nscrit", " ", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x12ns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x12ns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x12ns"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x12ns"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x12ns"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x12ns"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "12"}], ",", "2000"}], 
          "}"}]}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793394861836452*^9, 3.793394918159622*^9}, {
   3.7933951496126957`*^9, 3.7933951633752604`*^9}, {3.79339523317878*^9, 
   3.793395327131968*^9}, {3.793395363113092*^9, 3.793395454093955*^9}, {
   3.793398236334831*^9, 3.7933982401612463`*^9}, {3.793398273947652*^9, 
   3.793398297786425*^9}, {3.793398587977316*^9, 3.793398589049642*^9}, {
   3.793398642868155*^9, 3.7933986473815727`*^9}, {3.793398766872898*^9, 
   3.793398769091921*^9}, {3.793398847935656*^9, 3.793398887738555*^9}, {
   3.7933989372257338`*^9, 3.793398938788555*^9}, {3.79339898752773*^9, 
   3.793398989638323*^9}, {3.793399423963974*^9, 3.793399443278512*^9}, {
   3.7933996196258163`*^9, 3.7933996224000072`*^9}, {3.7933997698848143`*^9, 
   3.7933998152795763`*^9}, {3.793399870324162*^9, 3.793399874653573*^9}, {
   3.793399955092331*^9, 3.793399981729393*^9}, {3.793400297337214*^9, 
   3.793400299363748*^9}, {3.7934003321033993`*^9, 3.793400385420542*^9}, {
   3.7934018012048273`*^9, 3.793401888718988*^9}, {3.793401932418544*^9, 
   3.7934019352989807`*^9}, {3.793402009236326*^9, 3.793402049607609*^9}, {
   3.793442209711054*^9, 3.793442344238595*^9}, {3.793442922320374*^9, 
   3.793442937773024*^9}, {3.793442988076605*^9, 3.7934430062331343`*^9}, {
   3.793443077052331*^9, 3.7934431164279118`*^9}, 3.793443181492978*^9, {
   3.793640604305517*^9, 3.793640631235282*^9}, {3.793640926091655*^9, 
   3.793640928013129*^9}, 3.793641015622568*^9, {3.79364137194876*^9, 
   3.793641374383918*^9}, {3.793646495357765*^9, 3.7936465071467323`*^9}, {
   3.7937076359784517`*^9, 3.793707636791189*^9}, {3.793718926058593*^9, 
   3.793718934593286*^9}, {3.794507416067397*^9, 3.794507417746408*^9}},
 CellLabel->
  "In[1499]:=",ExpressionUUID->"6604a171-3630-4f80-adce-38bf4554cd3a"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF2nk01G/UAHDrLyFbyFbJviVm7Ms81xhjZhBCJFu2SrZQFCLbVNZsIWtK
krVsaZNsKWuWkrKULdkilSzvvOe8b80fM+dzvvPce5/7nXOe+z1nDjj7HHFj
oKOjG6S9/e8nxW2mt3G2Bkf3fy8mfSHfUcFU9P/G5mVkPxS8/ddGnUMPcgSr
/9ra9efTZMHmv/54iKofL9j/1/l8pjHXBL/89WWWh9JXBVf/2uZYQcXSMhP8
v9m2L9sZ7uP8a0nzhZmXsbx/HdiliTJWBf96TzX3J3r6/X9tF/fH8gv/P99y
nXzdqvDPCnyPHsXa/DP+vFMaX+U/q2VbF6UeEv3rEw5F9sWf/jmKIpyZOfvP
RWpJ/ddW//kbx0UjL9YDf33+uYkmRu2f40R/8D6J/+faCf033Tpifz1Iurwc
b/jPa+XP+I2P/LN6sOaJ9pP/XL/70Fpj8j8/IgiJPpj55+ESawPflX9e50rz
UNz6Z62PnDUlu8X/uuEcM6UQ989Pipb8U1P/eYRdMfNI3j9v+J15xlXyz7po
iiX++T8/G/qQE/31nz/pCr7U//HPW4VHZ+jpJP4a59uLucT3zw6DHDY6ov98
Scc4dF3un5+ztLWdh38e82aaVzGSAOnLJ0TMF48gugE9nhUrCUCDrdVStkVI
VDtMvcpJAr4US+1TozYhKHhi53NGAnJfHCyp0H+LnHasXz54XgKebd/CWRqP
oXAv9btz4RJQqNUu33p1BuW/DXhzL1YC8k3DDETFllGj5oPlk+kS8PWct1zM
wzU0lrfIL1UgASmtb+KGFjcQ3X8Hdb7cl4DIVWy7/jQ9iHp6nLhVKwEMtcL4
O4XMoNd3N8bphQTcsyVMh9/bCc4ak/f3vZEAsxmtG3Y/dkFErljvyKAENP3E
4pnx3NDkkSN87JsE+NSePyN1iB8ezp4547BG27+Sy3u+2wJw+5TWYxc6SVDO
1B/PUhaGaPchW29eSdDaTS9zhSwKJGfurEgdSQj8PUO6dVAKNMdHZ68QJUEM
exYj3CgNck7lmglmklAisnTpiaUssDsYvc9wlQRcVVedgIkCdB+LFiiPk4Q8
0qp03SslaHxncephuiTUuCYvV7koQ6W1WH19viQ49s+O3vqlDMlWz61fVktC
ZctR/mleLBw1/53+boSWn88s2l9UFQx72qY+TkkCU56Tc+VNVdAwTVf7vCQJ
UjebNFx51UDQBDs4zyQFlqWBC7zbajBC8uJjpNXNRj77Qve5BnS2abuxqEuB
8SONtnF5TXhGZK3ZpScFrQ3SvudvaEIe4a6lgJUUjBtXLzJ6aoEzjKccDJWC
pF/cDKwcOjCjbsVj00mL1z3r89oIwQ8pXc4yL2nw3Ht3Yp5LH3AT+LZrQdIg
yM7qLmOmDzE5pLBTkdLwsvPEe7okfeDntVwUz5QGboavwTncBFCjP9Od1SwN
U/vPvvgjYgBBHzISrwjLwJXLrgp3rQ2hMT3X0F1KBtpP3uzLu2UILEdub+sr
y0B4lVip34IhZLZX+GwTZeBb1eD4wyskaKhpNT3vJwO5cw2CG21k2Ehc5XR9
JQOCe16RnAKMgWC03qbXLwPRdo0bAV3GEPcfXfj+URk4w/ygI03WBPaGsi0N
r8rA0t0Xu1g+mwDOQ6zHXFQWGovDev5zMYUwglkSCpQFPgnRLX4Tc2jftiLt
jZCFXVLDCbhIc+B6fJzuT5ws1NQtJTM3mEO+8knf2luygOTSrgTJHoHGfZfM
DnbRzLk3SpTLAhh+3+cSlpSDoJm6qZVNSxDuxK+gQ3JgXWt7NEbLClQK3g+4
asqBb2z08ceBVuBG3nGz3EQOeFfmv/OsWkF7prMk/rwcDCdnr+evHoVELUGt
021yEOM3+TOc/xgUc1SKJPTKAfXhD+I3+2PQOEHcfvBBDhKVS19yFx2D79cC
mjcW5YDjgoPJdQ1bOPqh+3CSgDzYX5gejnM/DiIhMS51p+VB48zn9VfT9qBq
tpc44i8PKrNtb+O1HeCwRLUM/SV5cLEtEZVIcoCwN+PzlGR5uL7noGCXtiNM
iOgGfWqQh3nPuan8w05w7+lKHDO7AvAdCI3/03wC1Ladai3KFaA9g26vHasb
GJs0RhjUK0BULiv5gZ4buNzcb6repADh7GAYecENktQ/TQsNKgDmfNTkja9u
MOtzXHBiUwHU+gffZfW5Q/aYVYivyUG4+Cp3LqThFNA3UfDx3w5Cc99Ma/I3
TxDgKuEIWzsIlhuvJSVUvEDRYecHXzpF8D6TEaMT4gW2623+lryKYG7e4M/A
4Q3VGIM7wjqK0JQubDah7gPuhYilJFYR7rUOks71+cKbKJWuVrlD8J+vkIvW
WX/Q4nzNcF31EOj/7FJjL/CH4swT6sfhEETU2SRI9/pDZHlC/qLVIdDboeis
gQkArXczfgKXD0HieHln1c8AKJbP2eMxdAgs8A3XPRPPA342ovI/vBIQGe2N
7s5dgP1Jc7/vLShBWwWLj2t0ODw7EXbvwYoSfJ757/Xe/HBwwO4+9viXEtzr
S4nragiH7EGt+jcMykC9eMqWZykcBPZeO7/IrwyZE7s6dtheBp4SmRUVpAwz
jAPzLXIRUBX85JYuQRlG23owoYQIMDMxO0IkKwPLxW+XhB0iIHEpsMraQhmY
XrgOslyPAHb1Np+LJ5WBNyJc+sqPCGBudvv2PFEZnsXfiZWsj4Tbab9vtqcq
w5A8w8uO7kggnIw36s2krVeXTjSYjoQI1pqSiUJlKMcWRdbxRcGWGdNp5npl
oLvNeMzbNwp+fbw1SRlThuljpYKaItFwo0ItzWJSGbDq9tdrlaJB7XIHwe4r
7fpW7P1fhGg4J/G90GtVGSyjGnpbPaPhu4eecxILBm5MPT3o8yga5n6OfhpQ
wsDbw4PbgsQYqD2Z2ERRwwCpg52twzoGwodwRc+1MXATS20TOx0D/HU5XveI
GCj7EbP86loM4M8f3wixw4BfkIdD/6sY2DXFOrZ8AgM2a3+Uyt/FwDurhpfu
JzFgJ+DCJzsdA96qgrFmfhjQ3R16douBClmrg4ISVzDQ+OwZG5caFdxcYzYz
4jFAYc7f90GPCkr9quO7UjBQoDknqmdChdaHqcU/czDQLNZE+uBMhevihDjP
QgwIYbsFOLyoYJey4jNejAH3fOOD789TYdnviPrrhxjo5h+dU71KhScT9MLw
CAMGA7zNrdepEHOkaqv6GQYkjmG4FjKpYN7kNCHbjIEvKhUe9wuoIILhas19
hYGldQbvrWIqTBc8v7e7GwNPdO9UT1VQ4QG3T/yVfgw8Stz13qWWCqTlTku/
UQzUB8QdFG6iwu4ToRrTXzAQaLwxaNlGhU89CiJ2XzHA4uJoLPaGCvdgZLtn
kbb+trl7ZA8VAipjPxv8wMC7Te/NwH4q0AaOtoZ1DFTaWnzdHqICa9LXkkN0
WCitv8Ms/IEK/duZCbeZsVDYpa766iMV8nzIfoJsWAijpIWyjlHBY/SXVQIX
Fmrsc6Y/jVNBxbRYk5EfC081D4UQP1Nh+5n13iBhLLBxyRH0vlChQ3EH/bwo
FgR4vEjdNKfl1n45IYWFNaaA9CWanTjc2wflsYCUH9veoVn+El+pkTIWFAjR
XfO0eGvzzYmNalhQFt4v3zFBhRf2Af6qOlhoSxm4p0XLH9cpbl2ihwX32B+R
aJQK1rpvtfYbYiH0/KmVdyNUECuL2JdqjIV4OTJxxzAV5kUwDDuPYMGmjeFz
xyAV6uPGJ0OtsTCi5Kcs8ZYKERtJr77bYUHQKCBzdzcVTDyh7KQzFtjXJyMy
O6ggMLKYNHISC2T521a1LVSYMMoLMPfCwjERh8sejVQoe3zYptUPC+HB+5Nr
G6gQJL+lrR2EhVPHHYVuVlNB/2bZ/spQLNR1pZYKlFOBg82eUTISCzwzah8O
3aXC7a+POzgSsBC7mXPsYAYVvG+YinukYOHP0pVq7SQqqBM+B7dkYKGp52rf
LJXW3xzWgyGFtP5+WeWXof0+Uym50UPFWBAa/Z79yJMKDj+VP2HKsaAyonpn
nvb7XjY7ljhbjwU3FkEVOEyFhs1v04RntHo6Zmyc9KkQVRIO+S+xkMDvLS2l
QdsvU/Hy0S4sLCZsMhaJUgFXt2bR/BkLB42e+yXMxwCL67XS/bO0fnGU3VsZ
jYE+rn3MwQu0/Vd9TWLuiwE3D4Na5d9YiNinLYOtiYG4vakCeRwqcFFyRrc3
MAbeRyp/vKCpAtjpSeHthWi4pdSiOoBTgTo3I5vikWjw/GiToERQAXOTpDGO
jmigUw9H04dVIOLFqKnA7WiQ+tpVYOmqApXu88U6VtEQYObpfihRBfLUP4m/
KY0Cjr13F798UYF172BRSc1IgKORHz/PqsCV1Ec7j4lFgl+i4+uJBRXoymPv
82OLhEF6gbtjv1RAREy44PjHCMiduuIwwq4KGK2Vw8LhEaBY6dH5VkUV8G9M
E3ibLoOJvuL9pihV+Eh3frhUNxziTte450uoAaXn4c+8cxfhK5RdYZNTAwbF
vfXr+ItgKHCn5PwhNYiJbOQI5boIDG2pC8ZaatCb6mO5cf8CXJAIOP/bVA3C
7mYJ0k0GgfsoJuZIMM3puXsmHANBz6ryDlOfGpSclVdfCw2AXIXiNp8hNagN
qBFtNw+ADcb82eERNQj8T5p1SDIA6h8kHqyaVoP3Dq9Fyrr8QZHLp8Z+Uw0q
85zp9cX9QeT1wZZaGXXwzuGPtXh3Ftbg/pdTYeogMez5ln/KG57cnrsZGKUO
JzySmK/f8oYIFgWLmKvqoPNTdTDE0Rs4ekpfFKaowzsX3sriYS+QcizP/XRX
HQJ2h/QaD3rC0dAqG8sedRDIrZzOn/AAkfFlTpcBdci/7yEqWuQBEwRM29lh
dYjNzCvZ5eEB3uwPVRO/qENiHstVzMppiLlZzdPxSx0OO9Np3GQ9DTWP6t6g
AxrA8Il1MtPkJFzc+yvysJQGJNo4hQ3uOQlwWUPbXl4Dzp0kvwyecIc3pEf3
LqpqQGV5Y+JWkDt8GWqIqSFrwA07zoh3JW7Au/YU5P004Ju7zHjgAVcIwDRX
87/UABcB/pebR0+Au4po/vV2DUizNdNdlD0BNmohsexdGtCTcFWMvOkE2loq
zgzvNSDQYzkYe8cJGPC3ORcWNCCmuNcld8UREs2jPFqENCGE1WyY54w9hFuM
WYGoJjCrJh5w3GsPflY6eo8lNeHuN34b9x47OHpsdU+VkibE/ZKSzNewA5ET
ri3ZRE0QVLfF3eQ+DiW+BNEAP03Qd6Fwhn2xgWy/fLbFQE0o6OoKHyqwgfiA
jbXToZowf+y6+YCjDfgGVXc6XtGEk5NZPY8/WoN6uESwUa4maLsRIznHj0Jz
ItOgWIcmCA8FR5YxWcFoeXNs7wEtyEsvUWCpM4eeeaZvGGktmBE6JRFINYdG
BQPjVAUtqEt54uVoQ5u/S1rYrdW1YFcKQ96NP2bgXNQaP2KsBWcLC2SuGJrB
VE574nSgFm1OPeC6Y9YEBkdYlkihWnCYrTKWN8ME2oTJZiURWmDB9+jmiqEJ
bZ57xeUVrwWVXt3X9pcYg0dax/Xvt7Tg6bYg369AI5iPe5Oy2akFZrfoKvg0
yPDpNfuqw1st8BMZbnFaIUEXq4ll4zstUB4p8XOqIEH5lU7eyM9acOGIgfd5
WRL4RnWlsfzWghvKBVxdkoawGtxzY7eENihrzGm26BrAH4/+m7IXtUFbn8uZ
bkwPLNXsryuGacORlK9lfA/0oJR+KgYbpQ2Lmd3bOVF64JDx86xugjasOlTf
YJTXgxctQiTzW9pwbqiphTkUgCp6YjWoQxuy79kub5/Gwdjc7GxotzYUmjon
pgnjQKPObzSiXxsi5G4oL3fqwleTqI64T9rQ4J+ivaKiCybBd/Pzv2vD1Z3i
5xbZdGD34Lxxu5AOqPsK5mBHNMGz4Dy+c78OXFWwSzLP1IRmz231PgkdkHTl
jBO01oTzjNziI4o6kGFgrlLQrwHvlVR+L+J1QG+Qxct5SB3yYi/e2XNGB9LA
wsZoXRXk9XZsuT/Wgbfn9vwpvU+bE0ruS79r1IFbmFxW/kAMqPCamZNbdaDt
470wbn0M6Exn3Jbv1YHY41X2j0aU4XC8nNHSlA7k19VCAW0O9ntvknGBRxeU
p8WTOQwPwRr++4uve3Th24Xbw60LihBcmj53fK8uLB3yGzl3QxGiwkZxOBld
cN23rFs2dxDSJc9OMuB0wf87w2G1PAV4dDYVE3daFzzeO/9OUJID3AcNu01v
XXhUyrMdMSULTYSP0d4BuhDi13ONmCMLHXuk3puF6QJzcFU/ZpcsjDytC+NL
0wXrQOVg5zVpoGP98Ca3URdS7rpKWn+ThCj/sDXOVl3AiEqbE8olYedHcdHL
r3Wh29rl2aivJPBUevq7DOqCSk1tl+AvCZA4uiUo800XOlOCW09zSIDhrQMn
q/bgwFBymLJsIwYqGRxSrSI4GDjWn2UnIwaiCX++DB/AwfntqGzDXwdg/cKA
M5MCDhTeH+i7kXkAysyvOlgDDlbcV3q3xkVhN/2y1eYpHOi2ji+XcO8Hup8f
eXm8cUB9Etd25Pk++Pat462UPw6anHLC33rtg9Z3t83NQnFww/2ygXXnXrhQ
aWNSeB0HQhZmtQfTRWDUsZFAbsABq985en0TIXhjVcbo8BwHX79ZsobtEIJ6
o6wmv2YcHOdbU/BvEoRk9QDI7qLlTxzJDdESBANOGZ3FCRxUsPWbTWAE4P6z
RGwaG4KHi69enNbnh8C9jmLjdgja1i61vxniAWczpaMjJxDIJVUMPy7igcOR
9NeG3BFc4z2nIXeeB6RmC5c7fRGINFz7EcbPA/3VM40NUQi6L/qbzNtxg5Kx
n2NqKYKCV6pawducIBKmn5JYhSD/pP6dvaWcsOMBb9u1WgSMp7NMMo5xwqc9
dYqXGxH4pr4w4ajjgLjPfza9+hEERqPe5uBdMHMxOttwA8HTa+acWXJs8PWo
/KkCOoBcjeMW3Z9ZwWlpN8N+RoB3BLGHT3JYwUh8UlWIBUA3MPpp3W5WELtK
zeHiARCX6jz8e8dO6LF847kpCVCW9OGaJtcOUPhmxTZkAnAK5yRkmcoI9ZbG
z6+ZAShbVd/8YccI+k/x/jgLAJeQqzZYKUawTTj04Y4NgHQyM39oAwNcVdp5
P8AF4MEvj0yRr/QwFfCEwnMBgJItHCvuSgd+Hx9stQTTxhjb2tdtqnSwaXDv
wYVLAHci2OMXdtAB7550oXHamPOH/1TmxePbSP+Rz9eKBIAg+qtOgVubKH9T
7JrJbQCLi4oUwtk/SMFdEEd/F4BlPuRqvvgfVNfF+b36HkB6UWbUu8F11JW3
cUykgrZ+M/VGL1pHm3qDsnOPAKSKV68XCP9GtjFXX13pBph+lpBY/msNTS2E
her0AYR0nG0sqVtDZ63PKy/1A3Stqcg6Bq6hKzIumdbDAK0y609nfv1AtR06
p6UmAWbUBmoMmX6g3ZxLLM3rACIGYqRgrRXU9/QalbwJYOL8VadsxwpK9pT8
r3sbYKk8Sc9t4Dvi6bBlHGbSgwxclKOzH83RLZuLHHowt8tB2evBMuL6k/Vd
WFwPekRTDO+Sl1DPPdWzBZJ6QOf0gLtg3xJKsulZlJLRg4YPTdsCM4uIs5Z5
XvmgHiw3rNm6wyLiOOs7baiuB+9238Fp/ZlH7NMGI/5GeoAnPLabuzGH3qSN
2f420YPjSrr29KZzKI4Q/P6SmR74fMWcGvpvDrHdqhy8aqUHnUMTco+DviJW
e+HePEc9EFZ0UJB2m0Usb5daXvvrwd2FQByr4zRien6zQjxbD+ZNnY5dfP0Z
DesQSKO5enD4TNv26+TPqKLh21hWgR78uB+d1mj7GdnW6vLw3KWt3+uoGftt
AlWVjQbQ0c6pwcelt/32TCCHbHGtj220/NV1w7+vjCEVoTd9GR16oKA+llx4
bAztzAg4Y9mpB6IDdp79cmOoOqUl+3WfHoQZTQxczRlFbLEntx99pJ2DSryP
T2t+QvUX7jenr+hBBLZZ2iLvA0r4aWF/ZE0PWhju62DMPiCXcxs/dv3WAz1n
keEV+g+0/plIR2/pwZmL+zx4Tw0jt1OLV/134iFyRLDiCu494rHGmprtx0Nq
kQMfiWcIzfR/mGYTw0N2h3Gfes8genokKrxNAg8VbcaHJxMG0anDA1U4OTzU
nln38eUYRM8MAnkPquLBUdWqdwf/ADqj8vj9TiM8iAR4sAYZvEWNPQOl9SZ4
iJLmDCRxvkV8XkthJ83w8PAEvqTyfR96fkdSqsUKDynOP0P0fPvQ7j1JfuFO
eGCQX/GH273o8W9Xtp/n8GA7rIk5ItWDuNLDPt0JwgOfU29u/3I3csNkVVkG
46F1n2wuc0Y34jzTbf0gHA/san2SDtNdyGVE87ZXLK3+M7aL6dc7EdtzDt0v
+Xjwwgb9vMH9Gjkdl+VKKcRDBkysBrd0oJqf+p/1ivBwoJJtv/rFDuSodOFq
3n08dHA/VpOdeoUeFnwesK3FwyNHp/31be3oeFS9d+9rPHhg2FUdKlpRpehb
vfAuPLS/METJPq2I+ek876FePMT5eeZcVGpFFT/EHscN4iHsKcbUqboFMZ6M
30Eax8OrnE07w+ZmdJ/snP9sjXa9bPxlE8NLpKJwAId+48F6LCBytKcJPeMY
+/D8Dx6a33r/Ds1rQj1v7fe8oNMH0wHaQxeuCa3aH0t4yaoPD/cHedZcfoFw
fmYh7fv0YcVTpFRtfyNqs+QUIh/Qh0sVYiUDs8+RmXpX3StxfcguDHYWSn+O
nDeMVjpk9EFuup+suPwMUWMMPTox+nDXA3tRveop6snC2fQR9eHLspAn1vox
Oha6+eMIWR+i1BtfOXA+RhOOT1LeGunDgbzJ38T2BrQqodXdb6YP8tf/DBJ1
GpBghSpxyFYffOQc771VeIScXyqojHjrQ1CEw1CWYh36MSfENZWuDxOW9Pmm
xQ9Ras50W3amPrwUs900832IsKbVYRbZtPh3rr9b0niIzj4wWWws0Ifr9wZP
//fmAZoPCu+6WaoP7WMm+Sd+V6FJ5qk48yZavVFZBTk+lSiq7gGBpUUf8Hvv
6n2CSiR+OmzjWZs+0K1c+FLEU4lOvBHwVOjUh8KzNtJpPhXoY7KR0Y53+lDb
UHn5FFc5GthftfPpPO37avojQ2H3UUBv6Av/JX3QahYufqN8H+2OpFyQW9GH
i1odBblfSpD51OeZG7/04VMhY0ePcQnqLOVv92MkwMxrlxwF6XuoRTMkRkaQ
AKmXql/X0d9FrnMk3KgwAfJyEq6ebCxCjDl8a2n7CLBSd0+sO6wI6dFVuDFK
EAAVbl5/QleEnraOEz4pEkC+9gZvN+sdVGNhyJhKIIDR0trHEd1CdMWoPlrE
kACfB5+P32ItRHb6six3yAQI3sitnx+6hRiwbLtqDxNg636b4a6AW+gwTzf/
OxsCiCi8a7Z4UIBmeo7KiXgRgF/lFsOmQT563N5WetuHVu/NAM8YoXyU0Khx
6KAfAYof/0xhGs1DKpVCKrhAAnBjC5IyVfPQ5cRPuk6XCUDYMDsqOJ+DhA67
m99OI8ACb8zgicibaN5g6K1CBi0fwW+7RPMmatQlHa3JosVj/FhZs5SF3A/K
HW/NI8CHms081hNZ6CH7guvMPQIcDRCwSKRkIuPX54IUnhHgefseuVl0A4WR
ovOqp2j9+dBuueN+CupzOGWnNEsA+rvNiCMoBUmcMxIsnSNAPCHxVL5BCuoo
4E4pXCLAReUCouNEMuL9kxOTvE4A41DZdV6xZFRcVuvly2EAJ+SPeXTVJ6H1
l5ly37gM4DNWdqEqPgmZDIdMn9xtAKb32ZiZXJLQ9//0TzgKGMDHbvlLyxxJ
SMep2/KwmAFEGJVYpg4loB6eGW0FNQMou53JJuobh8RkX/+6q2EA8dzEuz5S
cegcKq8R1zaAEu0WJa+PsUjIM+CQMBjA3NbD624msci1hU6clWIA6aK5V6+o
XkO/AgVZZ+wNwK5jspZd6go68JHyrjDaAIKJH34UXYpC15q0K6yuGACD7Kv9
5YQo9P2uQsyOWANI8pApdmSLQk1+HCpnkmjxGCLxT7IikStLXyLmpgFMxWVw
Kr2IQMXYY4YvKg1gmKu8pUj2MuISpOzzf2gAX6g+N1R/h6MLW1o/JGoN4M7A
z/wjr8IR5ZVI4ZXHBpDww+64+plwNOcwtmXaagCP3j8J1PcIQ4rXTtZ++mAA
Pe7yVPbnISjdxyY+6ZMBbEYffDbqFYK2Lcmu+HED0FOkYAr2hqCe/fI8RVMG
oCy4b6soLBidrVnw8lo2gN9e6d+STC6i6rFzkhv/EaFMqamvlSsIibS6b5Tt
JIJEskVe+ZtAFH3f+q0jOxGUfhSrUa4GoqPnNS+/5CaCe2NeSzZTIPrJtjly
TYQIzGeeulYwnkda6lGpghgiJHM9untNPAANOguq5agQYWWux8prwR/5J5QP
iaoTISp156neR/6odPKdkIwOEbyeKh/fe8Qf7Us9WKBGJMJOb/uQ5it+iGF5
sMzClpaPIlZiynEW5Yp4mg7ZESFGdr6FOO6LtEn0y7aOROi+kyf1vNoXBeTJ
qzi7EgGNLjPtt/dFUybhDb7eRPh6iFGy3c0HvS6RbYuPIMJ6kzC27osnOjX4
7BR3NBHe6wpnmmd4IiYGS9Y0KhEO3SAkNBp7ItyxSybZcUS4/YVXSqT+DKrc
8fZtSToRzg5/Uvp2wwOluoaMtZUQwV7e7MKPgFNIKYk7wqiMVv/1o/5m2FOo
83GReHcFEep1jocRv59E/+3udR+sJkK0u2Mno99JFPRCcv7LMyIEMFrovQxy
R3b7un/TvyVCpfP0FatCV8Qh6FfzeIAIRXJ0ZdXurujFbr6z594RgTHXaVeH
nCuS2nl8ZuYjEUjUXxF7alzQ4srUYPcMEZ67ROnp9jmjiFdbD3O2iLCqz85e
rXgCqTQX+FjTG0LVy7zV85tOaPoZQZ6byRCGFy4KLr1xQsbV125F7TSEh4Ys
AszeTogvj//6GV5DyPpvq8f/rCMqDlD01pQzhISrNguWfXbI1qdXdkXBEE4O
uK9uXbZDuzwCJksPGcIU76PX3hg75OfYYCeqaggUH9mFvLTjSJtCNNoBhmB+
XZOB5GaLuvY7yAxYGUL/1T0nK2RtULgQ/ZcEG0P4wO12uXbSGmH5bueRjhtC
fPyaZ+Qta5TB+pX/iRNtvdNknfc+a+T84xxz4RlD2Pb7LhK7/yj60RE/4XvZ
EJhNOsQ/EC3RCNvAqY1IQzh0xXtrmscSNRmLLNLOZBjp/GBZMGqBkrpK/uTG
GoJdEPc5wWALJNfXxtuZRts/ZTZif8MR5PCe3lC2xBASsWR3l6PmiCBE7qwu
NQS6z69ZF+TNkfzxJAuoMIQTI4r4IXpz9Gtkn5N1tSGolKWdbik3Q8lj2hei
nxnC+9apLK5dZqh1+tz98T5DIFcf5GypNUGlMk+VvQYMQdZCp7rUywSlnGaq
/zVkCAvRbGHmkibIaS65mfOjIaTenYvuSzdG6wsVH3WnDWF8+IHNgwgjdGht
ljPrjyE409vzzIaSEb+6crrkliHIjwXsLgQy2ggMEqmiIwGrhYmWEBMZdfz+
T7admQQ3V9FvFE9Crpvi+DVOEsxJK+icLjZEGUwOAUckSJB4WHQQw0BEWy57
VHulSFD6fj22ptcAub7s+WEqS4L56+fn5gsMkFKEfqCJIglMTNnZtvQNUPu2
zEWSBgmIfHtX2+IJ6Of6ShjOmASHut56MWjoIzvbMnh6mARJBY12pzn1UdMj
d3odcxJ0Tw4IkqfxKCHofYTmURLse3Fhyy8Dj6TWnkWrOJHgR1PRWV86PDq6
fDVWLoAEV1fStrmnAT0x0ze+d54EfQM7e5lbAYlVbrDLXCDBTtkiX787gBa8
fRIkL5HAUMxGqNYNUPQ3y+uiV0iwuxF/qGsIoa9GHEfyrpHgQUpVNT4HIbP7
bTz74kkgSD47WOyCkIiHVqpwMgmij31eIK/gUPX0/hv82STo5Er2H92LQ0KG
763TckkwzX2hb+yrLgovShbgLaD1c+55cne9LjJ2Y87iLiKBntbP657WuujL
xNds9koSSAF77O08HUTB37aPfUCCMQWV9g1/HVRZYL+PtYYENT9noxBZB4U4
9eTtaKD1X3o7JGpNG+3+VHOLoZkEE0vdJ9nttFECe2hoXSsJnLfs6itUtBGr
NsHG8xUJfE/bL7lzaCOGjL5dg10ksLep5+du0UKXWjNnrvWSQHuEh5nplhZa
X3V6ifpJUPt0bJg1XAt9N18MuveeBOGZgzqWSAt5h9daOIyQ4HXKVnu6qBb6
Wh6quHuUVt9cps48gxYaZ2P/EvKFBC7VcsMDHZrITuvtM+VpEkhLijKdqtRE
705lZU7NkiB05Qofxw1N1NMiY2q2SIL14uqFtJOayHh1UZb5OwnEkwJrA801
UbtYHVPDKgmm+svcvHQ0EcH80qj3TxIYBFpvnJfRRM/DDBrE12n3MzDgYiqf
JtIqZ097t0GCz/1MYy2Mmqh25K1P/Dbt/iaxHGRb0UDlms6SP5nIQNrvEdrb
r4HkTsnSle4gA3mlLfxImwYqSl8admIlw4xE5pnpBg0k1lJXw7eLDGLVH3WT
KjRQzsqlpA5OMmzkp/00vqOBBMSIZ8J4yOAz15ixN1sDpZrtIqrwkcGj4Bw1
MEUDcYX1i87uoeXT/cFldFUDxZXd/JMjRIav76qUz4RqIJYR58Eje8lQ2ZqL
G/XRQFGsclU7RMmwZVMRV+6kgeg0l2OfiJEBMzHoO2aqgYJP1ruflSRDdTUL
hOhqoLW0MD0pGTKMimmYXpXVQH7NRJEPcmRgDbNZ4eDVQB4HBnoJSrR4FM3D
BV/U0ZRpdulvDBmuOI6VP+lQR86XXKjlqmTIuW/wy6tCHR37sKwjoE2GVaxA
ZkWAOiKlcRTPGZDh0Y6L9iGLaqj55UBEPokM8h8qDvO+VkPwPdveyogMihdw
PSF31JC6qfzu52Zk8HfAvhs5qkY7j0iXko+TwaRHgFhUqopuqXMeM3QgQ896
FVNSmCra5z6I3XAiw3QE7k+UuSrif+k66+ZOBpsfW5/Lvqsg5tDLlppnyTDu
1rDQLqeCqpe//X7uT4b0USPy0XUscnW3ySOeJ4PoJCe/3issajY99NUimAz9
8q8/Et2wKErsY5h3NO16tylbQzoGMbVr3C/MJMO54iyW81+UEMPuJXqOJjIs
b9E9+nNPDj2gHr+b2kyGTP6I97HqcrTnt1Zj4TYylDUfsLFskUVNkzk3ZN6Q
YX736r5n4zIoot7ooP4gGW52uufg90sjeoe7NkFfySAicaMqtE4cVfbxbG19
I0OY7gUducPiyMnwUmH0IhkCSo9OdE6KoUYlq4XkVTKceKylKCcghsIZGaPK
tsiw55vs9ahroojunkPFBA8FLu3zrrB3Ekat34a88/go8PNNd+3be0IoTslc
0U6AAn3Oct5mPwXRnnr9soG9FOg+LkoZyhVAim0y99tlKCBWcXF8iZ8frbLe
8oiWpwDTWkLlWDAfajgsLIdXpMCr6Nua1M+8yGBw173HWAoEBoeWjDXsRnaT
34vKcRQ4kBN3fN9Vbtp87el+Ro8CizvNTfcycqMZz0lJGQIFpGs9HArDuJD/
6tDtAjIFLiclbh2j40TXGJ/eSrWkwJ8TObBflw2ZGao5m1tT4PliS4yeDSvi
j604wGFLAftZaOUJ2olu8dzKpzpSoJw/Ijm5ZQd6dICae9GDFm9P6M6GdCZ0
yY3OQd2LAusvol7+N8iICPcu7F31oQBXS4xmoSAj6lHyzPY6RwHvN50NN8vo
0Qwyz3IKpwCj9snAYI4tXHlkx7G9kRQYz3i4ea57AxfQpi84HE2BjAjCZfOM
P7jtw2oZFrEUYJ3+gDfW+43jdxBOJ6ZTYMsziKF2fhU3UpBqxZhJgYnb4S17
51ZwtyZ38TXepEANfi9b8eJ33EEvulTNAgpcyHk81rxrGfe98oLFWiEFZs24
+6Sll3D1q995HhZR4FcZkTs7YQFHCJm8rlBKAd5kEher+hyOtdHBfLacAjzW
Xa5vcmdxPYzvuIqqKMCRLfLq6O4Z3PHYjsT9dRRICXcmMotN4vyyKuJ5migg
axp9VrpgFFe3kUVtaqaAv4yC1ZTuR9yGQ8xlvzba/fxhC55LwziquP25vjcU
GKxvve+aNoh7E03yieimQMgQbk6M2o/jmcGexvRRQFCjphLF9+GyS1ntk4co
kC0ulWFT0okb51g7ih+mAN7lTFOiQgdO6uy42fcRCsi1Zv540N+Kq1StJxyZ
oNDOz1z/bymNuB83CnEMkxS4mjV4QcXiMU5rPUHjwTQFdiQJC7Q21+Banrkp
8MxTgC6I4XPfbBGO9YC5VNMiBTTJWkXFTVk4s0gdUb/vFNCTZdb8efIyrpiU
Md6zQvn7f9T/AZzXlB4=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$60868#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k01F/4B3CkSCV7CSF71pixc9/2bRhbqOwkLcjOlJJCSmmRZK0UkShF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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60868#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13c81V/8B3CkkspOKTJCZmRc+54Xrr3LCPdaSWWUnZlRJA3aUiJKGRmJ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60868#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13k8VF/cB3BJkSh7kT3LENn35X7GbmZsWZIkJIlCkjZLDCJCWVOhaCf7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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60868#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFmnk0lV/Ux5FKUUnKFJlDZveaOV9c8xAZEpIkocwaJCHcSqKkkgjNQiGh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          "]]}, Annotation[#, "Charting`Private`Tag$60868#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k4VV+4B3AkhChpQCJTZgrnIFlf8+wgJPOUpFIZwqGBolQoCZFoUMmQ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60868#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3c8lu8b95EiFZGUlRFCRGWv8yN7z0LGbSVkRxnJHqmQJImyKquoKEVC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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60868#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFt3c81f///29VkuxEUlnHHtn7eXMOx95EhTIqEUoUlT1KKSpJGREaVjJK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          "]]}, 
        Annotation[#, "Charting`Private`Tag$60868#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[169, 7], 2000}, {24.142857142857142`, 2000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 850}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7934430926665297`*^9, 3.793443116729176*^9}, 
   3.793443193686583*^9, 3.7934690595887623`*^9, 3.7934851458564987`*^9, 
   3.793485626542159*^9, 3.793529275638933*^9, 3.7935297623217793`*^9, {
   3.793529802940392*^9, 3.7935299218475113`*^9}, {3.793530270676573*^9, 
   3.793530283999229*^9}, 3.793531393229205*^9, 3.7935321096505136`*^9, 
   3.793538240605304*^9, 3.793628682380995*^9, 3.793631362438917*^9, 
   3.793632431638509*^9, 3.793632610898789*^9, 3.793632892708564*^9, 
   3.7936351358708353`*^9, 3.793640073838176*^9, 3.7936401129967937`*^9, 
   3.7936402180988493`*^9, 3.793640631982995*^9, 3.7936407377176723`*^9, 
   3.793640928449429*^9, {3.7936410162773647`*^9, 3.793641029251762*^9}, {
   3.7936413750464907`*^9, 3.793641392337468*^9}, {3.793646510319355*^9, 
   3.7936465390417213`*^9}, {3.793707637189578*^9, 3.7937076659865026`*^9}, 
   3.793717675819016*^9, 3.79371817725329*^9, 3.793718270093568*^9, {
   3.7937189318878202`*^9, 3.79371896262079*^9}, 3.793719542672554*^9, 
   3.7938013957691107`*^9, 3.793801476167865*^9, 3.793801572070702*^9, 
   3.793801639616461*^9, 3.793801743696622*^9, 3.7945070273361683`*^9, 
   3.7945074182241364`*^9, 3.7945074978560762`*^9, 3.794507543814783*^9, 
   3.794507664822262*^9, {3.794513101049498*^9, 3.794513111994809*^9}, 
   3.794513180768571*^9, 3.794515034247113*^9, 3.794515318478898*^9, 
   3.7945686448942738`*^9, 3.79456900774892*^9, 3.794576052906413*^9, 
   3.794576688275329*^9, 3.7945781427540216`*^9, 3.7945784312991457`*^9, 
   3.794579363913293*^9, 3.794579492656502*^9, 3.794656663238213*^9, 
   3.7946681118461447`*^9, 3.7946683404536743`*^9},
 CellLabel->
  "Out[1499]=",ExpressionUUID->"cc7f82dd-63e4-405c-af2f-c329f1ba0841"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4C.pdf\>\"", ",", "figoneshot12nscrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4C.png\>\"", ",", "figoneshot12nscrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668235220455*^9, 3.794668241027172*^9}},
 CellLabel->
  "In[1500]:=",ExpressionUUID->"bc230842-7d08-4db8-9a16-29c777d8d30d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot12nscritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "solns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x12ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x12ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x12ns"}], "]"}], 
      ","}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.793641626778944*^9, 3.7936416332225246`*^9}, {
   3.7936465444535303`*^9, 3.793646551353149*^9}, 3.793707642036746*^9},
 CellLabel->
  "In[1502]:=",ExpressionUUID->"961aa4a2-9d99-47e0-baa3-9b9135ac7b2a"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1nc8le//B3BKpUh2VpFkZWXPc73PcOxVyCYZlaiQUcqWTUsiGUmFJCEt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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61186#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k0VV/YB3BTKUkZSqjMMpN53g+u8d5rKFISEpKpMqdEyixUklCIUuZE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          "]]}, Annotation[#, "Charting`Private`Tag$61186#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF1nk41N/bB3CkkiRbQkrZQkQle87NMJiVspSyJElCsmQpQrZUllJJCGmz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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61186#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13k4lN8bMHCkqJQ1RWTf1+z7uTGYGcYQEiFLqZRdRWUrpA2VZA1Zs++0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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61186#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.7936416375070543`*^9, 
   3.793646552383129*^9, {3.793707642764163*^9, 3.793707666631822*^9}, 
   3.793717676570807*^9, 3.793718177758046*^9, 3.793718270395116*^9, 
   3.793718963117494*^9, 3.7937195430345993`*^9, 3.793801396066884*^9, 
   3.793801476471346*^9, 3.793801572374198*^9, 3.793801639901389*^9, 
   3.7938017440868063`*^9, 3.794507028000188*^9, 3.794507498249361*^9, 
   3.794507544530623*^9, 3.79450766515619*^9, 3.7945131123952303`*^9, 
   3.79451318107617*^9, 3.794515034588677*^9, 3.794515318962038*^9, 
   3.794568645348548*^9, 3.794569008082696*^9, 3.794576053252626*^9, 
   3.794576688614456*^9, 3.794578143569438*^9, 3.7945784318205347`*^9, 
   3.794579364251568*^9, 3.794579492987228*^9, 3.7946566656982393`*^9, 
   3.794668112040599*^9, 3.7946683413870373`*^9},
 CellLabel->
  "Out[1502]=",ExpressionUUID->"a73d3afc-bca7-469d-8310-8e9bdfc7fe5e"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4H.pdf\>\"", ",", "figoneshot12nscritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4H.png\>\"", ",", "figoneshot12nscritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7946682506048727`*^9, 3.794668256220242*^9}},
 CellLabel->
  "In[1503]:=",ExpressionUUID->"889b6c4e-f135-4438-a018-39faa55266e6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot20nscrit", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x20ns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x20ns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x20ns"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x20ns"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x20ns"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x20ns"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "20"}], ",", "2000"}], 
          "}"}]}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0Gkow3EYB/CRs4jGorxhuVqUHGPMTI4kRebIUc4h97VXrhwx2pIzcs2R
F0hCzqWViUxWrohQKNNoWCRH/t/fi6dPT317+vY4ZZfFCw1pNBqTGuiv3OgT
hGlDZQ47w9B3aGkdMg2LN2HXmosSMjj3alg1mnMC5w22b6BupSMokfLF3ZgL
WQIeHwpZnDDoEdmQD2f7x4nPu2ml8NxPS9x7uayDRq/Mevig+22DvIlPCWRz
3HpIPiiFyLorH4TOJcvE2/M/NezWFBzBBZPqR3h1cEDMi+N+w+i3R1oSZXvG
vimkPyWYwUx9Nh16Ja8yoGifFQyPJ4uIFrHNodBW5BkF36SuX/DdwM4omXIl
V2oO+V0a4k+nmw0UV/jYQ72CvVyIfhOmO7CRH21ZRDkiD7CCkqomBjwT7drB
xblxR9i6IfOAvW2aARVlzA9vCB51eMtguU8N8eNrSg55rU1KFbmXrocR1dNE
tSar9pBypnOsDlrnKWK16DVzQUxtER6/Yg8JP4Hca/FpZQT1v8At4j8M5A00

  "],
 CellLabel->
  "In[1505]:=",ExpressionUUID->"0a8690b1-c110-4a98-a10d-aaadff8adf61"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF2nk01G/UAHDrLyFbyFbJviVm7Ms81xhjZhBCJFu2SrZQFCLbVNZsIWtK
krVsaZNsKWuWkrKULdkilSzvvOe8b80fM+dzvvPce5/7nXOe+z1nDjj7HHFj
oKOjG6S9/e8nxW2mt3G2Bkf3fy8mfSHfUcFU9P/G5mVkPxS8/ddGnUMPcgSr
/9ra9efTZMHmv/54iKofL9j/1/l8pjHXBL/89WWWh9JXBVf/2uZYQcXSMhP8
v9m2L9sZ7uP8a0nzhZmXsbx/HdiliTJWBf96TzX3J3r6/X9tF/fH8gv/P99y
nXzdqvDPCnyPHsXa/DP+vFMaX+U/q2VbF6UeEv3rEw5F9sWf/jmKIpyZOfvP
RWpJ/ddW//kbx0UjL9YDf33+uYkmRu2f40R/8D6J/+faCf033Tpifz1Iurwc
b/jPa+XP+I2P/LN6sOaJ9pP/XL/70Fpj8j8/IgiJPpj55+ESawPflX9e50rz
UNz6Z62PnDUlu8X/uuEcM6UQ989Pipb8U1P/eYRdMfNI3j9v+J15xlXyz7po
iiX++T8/G/qQE/31nz/pCr7U//HPW4VHZ+jpJP4a59uLucT3zw6DHDY6ov98
Scc4dF3un5+ztLWdh38e82aaVzGSAOnLJ0TMF48gugE9nhUrCUCDrdVStkVI
VDtMvcpJAr4US+1TozYhKHhi53NGAnJfHCyp0H+LnHasXz54XgKebd/CWRqP
oXAv9btz4RJQqNUu33p1BuW/DXhzL1YC8k3DDETFllGj5oPlk+kS8PWct1zM
wzU0lrfIL1UgASmtb+KGFjcQ3X8Hdb7cl4DIVWy7/jQ9iHp6nLhVKwEMtcL4
O4XMoNd3N8bphQTcsyVMh9/bCc4ak/f3vZEAsxmtG3Y/dkFErljvyKAENP3E
4pnx3NDkkSN87JsE+NSePyN1iB8ezp4547BG27+Sy3u+2wJw+5TWYxc6SVDO
1B/PUhaGaPchW29eSdDaTS9zhSwKJGfurEgdSQj8PUO6dVAKNMdHZ68QJUEM
exYj3CgNck7lmglmklAisnTpiaUssDsYvc9wlQRcVVedgIkCdB+LFiiPk4Q8
0qp03SslaHxncephuiTUuCYvV7koQ6W1WH19viQ49s+O3vqlDMlWz61fVktC
ZctR/mleLBw1/53+boSWn88s2l9UFQx72qY+TkkCU56Tc+VNVdAwTVf7vCQJ
UjebNFx51UDQBDs4zyQFlqWBC7zbajBC8uJjpNXNRj77Qve5BnS2abuxqEuB
8SONtnF5TXhGZK3ZpScFrQ3SvudvaEIe4a6lgJUUjBtXLzJ6aoEzjKccDJWC
pF/cDKwcOjCjbsVj00mL1z3r89oIwQ8pXc4yL2nw3Ht3Yp5LH3AT+LZrQdIg
yM7qLmOmDzE5pLBTkdLwsvPEe7okfeDntVwUz5QGboavwTncBFCjP9Od1SwN
U/vPvvgjYgBBHzISrwjLwJXLrgp3rQ2hMT3X0F1KBtpP3uzLu2UILEdub+sr
y0B4lVip34IhZLZX+GwTZeBb1eD4wyskaKhpNT3vJwO5cw2CG21k2Ehc5XR9
JQOCe16RnAKMgWC03qbXLwPRdo0bAV3GEPcfXfj+URk4w/ygI03WBPaGsi0N
r8rA0t0Xu1g+mwDOQ6zHXFQWGovDev5zMYUwglkSCpQFPgnRLX4Tc2jftiLt
jZCFXVLDCbhIc+B6fJzuT5ws1NQtJTM3mEO+8knf2luygOTSrgTJHoHGfZfM
DnbRzLk3SpTLAhh+3+cSlpSDoJm6qZVNSxDuxK+gQ3JgXWt7NEbLClQK3g+4
asqBb2z08ceBVuBG3nGz3EQOeFfmv/OsWkF7prMk/rwcDCdnr+evHoVELUGt
021yEOM3+TOc/xgUc1SKJPTKAfXhD+I3+2PQOEHcfvBBDhKVS19yFx2D79cC
mjcW5YDjgoPJdQ1bOPqh+3CSgDzYX5gejnM/DiIhMS51p+VB48zn9VfT9qBq
tpc44i8PKrNtb+O1HeCwRLUM/SV5cLEtEZVIcoCwN+PzlGR5uL7noGCXtiNM
iOgGfWqQh3nPuan8w05w7+lKHDO7AvAdCI3/03wC1Ladai3KFaA9g26vHasb
GJs0RhjUK0BULiv5gZ4buNzcb6repADh7GAYecENktQ/TQsNKgDmfNTkja9u
MOtzXHBiUwHU+gffZfW5Q/aYVYivyUG4+Cp3LqThFNA3UfDx3w5Cc99Ma/I3
TxDgKuEIWzsIlhuvJSVUvEDRYecHXzpF8D6TEaMT4gW2623+lryKYG7e4M/A
4Q3VGIM7wjqK0JQubDah7gPuhYilJFYR7rUOks71+cKbKJWuVrlD8J+vkIvW
WX/Q4nzNcF31EOj/7FJjL/CH4swT6sfhEETU2SRI9/pDZHlC/qLVIdDboeis
gQkArXczfgKXD0HieHln1c8AKJbP2eMxdAgs8A3XPRPPA342ovI/vBIQGe2N
7s5dgP1Jc7/vLShBWwWLj2t0ODw7EXbvwYoSfJ757/Xe/HBwwO4+9viXEtzr
S4nragiH7EGt+jcMykC9eMqWZykcBPZeO7/IrwyZE7s6dtheBp4SmRUVpAwz
jAPzLXIRUBX85JYuQRlG23owoYQIMDMxO0IkKwPLxW+XhB0iIHEpsMraQhmY
XrgOslyPAHb1Np+LJ5WBNyJc+sqPCGBudvv2PFEZnsXfiZWsj4Tbab9vtqcq
w5A8w8uO7kggnIw36s2krVeXTjSYjoQI1pqSiUJlKMcWRdbxRcGWGdNp5npl
oLvNeMzbNwp+fbw1SRlThuljpYKaItFwo0ItzWJSGbDq9tdrlaJB7XIHwe4r
7fpW7P1fhGg4J/G90GtVGSyjGnpbPaPhu4eecxILBm5MPT3o8yga5n6OfhpQ
wsDbw4PbgsQYqD2Z2ERRwwCpg52twzoGwodwRc+1MXATS20TOx0D/HU5XveI
GCj7EbP86loM4M8f3wixw4BfkIdD/6sY2DXFOrZ8AgM2a3+Uyt/FwDurhpfu
JzFgJ+DCJzsdA96qgrFmfhjQ3R16douBClmrg4ISVzDQ+OwZG5caFdxcYzYz
4jFAYc7f90GPCkr9quO7UjBQoDknqmdChdaHqcU/czDQLNZE+uBMhevihDjP
QgwIYbsFOLyoYJey4jNejAH3fOOD789TYdnviPrrhxjo5h+dU71KhScT9MLw
CAMGA7zNrdepEHOkaqv6GQYkjmG4FjKpYN7kNCHbjIEvKhUe9wuoIILhas19
hYGldQbvrWIqTBc8v7e7GwNPdO9UT1VQ4QG3T/yVfgw8Stz13qWWCqTlTku/
UQzUB8QdFG6iwu4ToRrTXzAQaLwxaNlGhU89CiJ2XzHA4uJoLPaGCvdgZLtn
kbb+trl7ZA8VAipjPxv8wMC7Te/NwH4q0AaOtoZ1DFTaWnzdHqICa9LXkkN0
WCitv8Ms/IEK/duZCbeZsVDYpa766iMV8nzIfoJsWAijpIWyjlHBY/SXVQIX
Fmrsc6Y/jVNBxbRYk5EfC081D4UQP1Nh+5n13iBhLLBxyRH0vlChQ3EH/bwo
FgR4vEjdNKfl1n45IYWFNaaA9CWanTjc2wflsYCUH9veoVn+El+pkTIWFAjR
XfO0eGvzzYmNalhQFt4v3zFBhRf2Af6qOlhoSxm4p0XLH9cpbl2ihwX32B+R
aJQK1rpvtfYbYiH0/KmVdyNUECuL2JdqjIV4OTJxxzAV5kUwDDuPYMGmjeFz
xyAV6uPGJ0OtsTCi5Kcs8ZYKERtJr77bYUHQKCBzdzcVTDyh7KQzFtjXJyMy
O6ggMLKYNHISC2T521a1LVSYMMoLMPfCwjERh8sejVQoe3zYptUPC+HB+5Nr
G6gQJL+lrR2EhVPHHYVuVlNB/2bZ/spQLNR1pZYKlFOBg82eUTISCzwzah8O
3aXC7a+POzgSsBC7mXPsYAYVvG+YinukYOHP0pVq7SQqqBM+B7dkYKGp52rf
LJXW3xzWgyGFtP5+WeWXof0+Uym50UPFWBAa/Z79yJMKDj+VP2HKsaAyonpn
nvb7XjY7ljhbjwU3FkEVOEyFhs1v04RntHo6Zmyc9KkQVRIO+S+xkMDvLS2l
QdsvU/Hy0S4sLCZsMhaJUgFXt2bR/BkLB42e+yXMxwCL67XS/bO0fnGU3VsZ
jYE+rn3MwQu0/Vd9TWLuiwE3D4Na5d9YiNinLYOtiYG4vakCeRwqcFFyRrc3
MAbeRyp/vKCpAtjpSeHthWi4pdSiOoBTgTo3I5vikWjw/GiToERQAXOTpDGO
jmigUw9H04dVIOLFqKnA7WiQ+tpVYOmqApXu88U6VtEQYObpfihRBfLUP4m/
KY0Cjr13F798UYF172BRSc1IgKORHz/PqsCV1Ec7j4lFgl+i4+uJBRXoymPv
82OLhEF6gbtjv1RAREy44PjHCMiduuIwwq4KGK2Vw8LhEaBY6dH5VkUV8G9M
E3ibLoOJvuL9pihV+Eh3frhUNxziTte450uoAaXn4c+8cxfhK5RdYZNTAwbF
vfXr+ItgKHCn5PwhNYiJbOQI5boIDG2pC8ZaatCb6mO5cf8CXJAIOP/bVA3C
7mYJ0k0GgfsoJuZIMM3puXsmHANBz6ryDlOfGpSclVdfCw2AXIXiNp8hNagN
qBFtNw+ADcb82eERNQj8T5p1SDIA6h8kHqyaVoP3Dq9Fyrr8QZHLp8Z+Uw0q
85zp9cX9QeT1wZZaGXXwzuGPtXh3Ftbg/pdTYeogMez5ln/KG57cnrsZGKUO
JzySmK/f8oYIFgWLmKvqoPNTdTDE0Rs4ekpfFKaowzsX3sriYS+QcizP/XRX
HQJ2h/QaD3rC0dAqG8sedRDIrZzOn/AAkfFlTpcBdci/7yEqWuQBEwRM29lh
dYjNzCvZ5eEB3uwPVRO/qENiHstVzMppiLlZzdPxSx0OO9Np3GQ9DTWP6t6g
AxrA8Il1MtPkJFzc+yvysJQGJNo4hQ3uOQlwWUPbXl4Dzp0kvwyecIc3pEf3
LqpqQGV5Y+JWkDt8GWqIqSFrwA07zoh3JW7Au/YU5P004Ju7zHjgAVcIwDRX
87/UABcB/pebR0+Au4po/vV2DUizNdNdlD0BNmohsexdGtCTcFWMvOkE2loq
zgzvNSDQYzkYe8cJGPC3ORcWNCCmuNcld8UREs2jPFqENCGE1WyY54w9hFuM
WYGoJjCrJh5w3GsPflY6eo8lNeHuN34b9x47OHpsdU+VkibE/ZKSzNewA5ET
ri3ZRE0QVLfF3eQ+DiW+BNEAP03Qd6Fwhn2xgWy/fLbFQE0o6OoKHyqwgfiA
jbXToZowf+y6+YCjDfgGVXc6XtGEk5NZPY8/WoN6uESwUa4maLsRIznHj0Jz
ItOgWIcmCA8FR5YxWcFoeXNs7wEtyEsvUWCpM4eeeaZvGGktmBE6JRFINYdG
BQPjVAUtqEt54uVoQ5u/S1rYrdW1YFcKQ96NP2bgXNQaP2KsBWcLC2SuGJrB
VE574nSgFm1OPeC6Y9YEBkdYlkihWnCYrTKWN8ME2oTJZiURWmDB9+jmiqEJ
bZ57xeUVrwWVXt3X9pcYg0dax/Xvt7Tg6bYg369AI5iPe5Oy2akFZrfoKvg0
yPDpNfuqw1st8BMZbnFaIUEXq4ll4zstUB4p8XOqIEH5lU7eyM9acOGIgfd5
WRL4RnWlsfzWghvKBVxdkoawGtxzY7eENihrzGm26BrAH4/+m7IXtUFbn8uZ
bkwPLNXsryuGacORlK9lfA/0oJR+KgYbpQ2Lmd3bOVF64JDx86xugjasOlTf
YJTXgxctQiTzW9pwbqiphTkUgCp6YjWoQxuy79kub5/Gwdjc7GxotzYUmjon
pgnjQKPObzSiXxsi5G4oL3fqwleTqI64T9rQ4J+ivaKiCybBd/Pzv2vD1Z3i
5xbZdGD34Lxxu5AOqPsK5mBHNMGz4Dy+c78OXFWwSzLP1IRmz231PgkdkHTl
jBO01oTzjNziI4o6kGFgrlLQrwHvlVR+L+J1QG+Qxct5SB3yYi/e2XNGB9LA
wsZoXRXk9XZsuT/Wgbfn9vwpvU+bE0ruS79r1IFbmFxW/kAMqPCamZNbdaDt
470wbn0M6Exn3Jbv1YHY41X2j0aU4XC8nNHSlA7k19VCAW0O9ntvknGBRxeU
p8WTOQwPwRr++4uve3Th24Xbw60LihBcmj53fK8uLB3yGzl3QxGiwkZxOBld
cN23rFs2dxDSJc9OMuB0wf87w2G1PAV4dDYVE3daFzzeO/9OUJID3AcNu01v
XXhUyrMdMSULTYSP0d4BuhDi13ONmCMLHXuk3puF6QJzcFU/ZpcsjDytC+NL
0wXrQOVg5zVpoGP98Ca3URdS7rpKWn+ThCj/sDXOVl3AiEqbE8olYedHcdHL
r3Wh29rl2aivJPBUevq7DOqCSk1tl+AvCZA4uiUo800XOlOCW09zSIDhrQMn
q/bgwFBymLJsIwYqGRxSrSI4GDjWn2UnIwaiCX++DB/AwfntqGzDXwdg/cKA
M5MCDhTeH+i7kXkAysyvOlgDDlbcV3q3xkVhN/2y1eYpHOi2ji+XcO8Hup8f
eXm8cUB9Etd25Pk++Pat462UPw6anHLC33rtg9Z3t83NQnFww/2ygXXnXrhQ
aWNSeB0HQhZmtQfTRWDUsZFAbsABq985en0TIXhjVcbo8BwHX79ZsobtEIJ6
o6wmv2YcHOdbU/BvEoRk9QDI7qLlTxzJDdESBANOGZ3FCRxUsPWbTWAE4P6z
RGwaG4KHi69enNbnh8C9jmLjdgja1i61vxniAWczpaMjJxDIJVUMPy7igcOR
9NeG3BFc4z2nIXeeB6RmC5c7fRGINFz7EcbPA/3VM40NUQi6L/qbzNtxg5Kx
n2NqKYKCV6pawducIBKmn5JYhSD/pP6dvaWcsOMBb9u1WgSMp7NMMo5xwqc9
dYqXGxH4pr4w4ajjgLjPfza9+hEERqPe5uBdMHMxOttwA8HTa+acWXJs8PWo
/KkCOoBcjeMW3Z9ZwWlpN8N+RoB3BLGHT3JYwUh8UlWIBUA3MPpp3W5WELtK
zeHiARCX6jz8e8dO6LF847kpCVCW9OGaJtcOUPhmxTZkAnAK5yRkmcoI9ZbG
z6+ZAShbVd/8YccI+k/x/jgLAJeQqzZYKUawTTj04Y4NgHQyM39oAwNcVdp5
P8AF4MEvj0yRr/QwFfCEwnMBgJItHCvuSgd+Hx9stQTTxhjb2tdtqnSwaXDv
wYVLAHci2OMXdtAB7550oXHamPOH/1TmxePbSP+Rz9eKBIAg+qtOgVubKH9T
7JrJbQCLi4oUwtk/SMFdEEd/F4BlPuRqvvgfVNfF+b36HkB6UWbUu8F11JW3
cUykgrZ+M/VGL1pHm3qDsnOPAKSKV68XCP9GtjFXX13pBph+lpBY/msNTS2E
her0AYR0nG0sqVtDZ63PKy/1A3Stqcg6Bq6hKzIumdbDAK0y609nfv1AtR06
p6UmAWbUBmoMmX6g3ZxLLM3rACIGYqRgrRXU9/QalbwJYOL8VadsxwpK9pT8
r3sbYKk8Sc9t4Dvi6bBlHGbSgwxclKOzH83RLZuLHHowt8tB2evBMuL6k/Vd
WFwPekRTDO+Sl1DPPdWzBZJ6QOf0gLtg3xJKsulZlJLRg4YPTdsCM4uIs5Z5
XvmgHiw3rNm6wyLiOOs7baiuB+9238Fp/ZlH7NMGI/5GeoAnPLabuzGH3qSN
2f420YPjSrr29KZzKI4Q/P6SmR74fMWcGvpvDrHdqhy8aqUHnUMTco+DviJW
e+HePEc9EFZ0UJB2m0Usb5daXvvrwd2FQByr4zRien6zQjxbD+ZNnY5dfP0Z
DesQSKO5enD4TNv26+TPqKLh21hWgR78uB+d1mj7GdnW6vLw3KWt3+uoGftt
AlWVjQbQ0c6pwcelt/32TCCHbHGtj220/NV1w7+vjCEVoTd9GR16oKA+llx4
bAztzAg4Y9mpB6IDdp79cmOoOqUl+3WfHoQZTQxczRlFbLEntx99pJ2DSryP
T2t+QvUX7jenr+hBBLZZ2iLvA0r4aWF/ZE0PWhju62DMPiCXcxs/dv3WAz1n
keEV+g+0/plIR2/pwZmL+zx4Tw0jt1OLV/134iFyRLDiCu494rHGmprtx0Nq
kQMfiWcIzfR/mGYTw0N2h3Gfes8genokKrxNAg8VbcaHJxMG0anDA1U4OTzU
nln38eUYRM8MAnkPquLBUdWqdwf/ADqj8vj9TiM8iAR4sAYZvEWNPQOl9SZ4
iJLmDCRxvkV8XkthJ83w8PAEvqTyfR96fkdSqsUKDynOP0P0fPvQ7j1JfuFO
eGCQX/GH273o8W9Xtp/n8GA7rIk5ItWDuNLDPt0JwgOfU29u/3I3csNkVVkG
46F1n2wuc0Y34jzTbf0gHA/san2SDtNdyGVE87ZXLK3+M7aL6dc7EdtzDt0v
+Xjwwgb9vMH9Gjkdl+VKKcRDBkysBrd0oJqf+p/1ivBwoJJtv/rFDuSodOFq
3n08dHA/VpOdeoUeFnwesK3FwyNHp/31be3oeFS9d+9rPHhg2FUdKlpRpehb
vfAuPLS/METJPq2I+ek876FePMT5eeZcVGpFFT/EHscN4iHsKcbUqboFMZ6M
30Eax8OrnE07w+ZmdJ/snP9sjXa9bPxlE8NLpKJwAId+48F6LCBytKcJPeMY
+/D8Dx6a33r/Ds1rQj1v7fe8oNMH0wHaQxeuCa3aH0t4yaoPD/cHedZcfoFw
fmYh7fv0YcVTpFRtfyNqs+QUIh/Qh0sVYiUDs8+RmXpX3StxfcguDHYWSn+O
nDeMVjpk9EFuup+suPwMUWMMPTox+nDXA3tRveop6snC2fQR9eHLspAn1vox
Oha6+eMIWR+i1BtfOXA+RhOOT1LeGunDgbzJ38T2BrQqodXdb6YP8tf/DBJ1
GpBghSpxyFYffOQc771VeIScXyqojHjrQ1CEw1CWYh36MSfENZWuDxOW9Pmm
xQ9Ras50W3amPrwUs900832IsKbVYRbZtPh3rr9b0niIzj4wWWws0Ifr9wZP
//fmAZoPCu+6WaoP7WMm+Sd+V6FJ5qk48yZavVFZBTk+lSiq7gGBpUUf8Hvv
6n2CSiR+OmzjWZs+0K1c+FLEU4lOvBHwVOjUh8KzNtJpPhXoY7KR0Y53+lDb
UHn5FFc5GthftfPpPO37avojQ2H3UUBv6Av/JX3QahYufqN8H+2OpFyQW9GH
i1odBblfSpD51OeZG7/04VMhY0ePcQnqLOVv92MkwMxrlxwF6XuoRTMkRkaQ
AKmXql/X0d9FrnMk3KgwAfJyEq6ebCxCjDl8a2n7CLBSd0+sO6wI6dFVuDFK
EAAVbl5/QleEnraOEz4pEkC+9gZvN+sdVGNhyJhKIIDR0trHEd1CdMWoPlrE
kACfB5+P32ItRHb6six3yAQI3sitnx+6hRiwbLtqDxNg636b4a6AW+gwTzf/
OxsCiCi8a7Z4UIBmeo7KiXgRgF/lFsOmQT563N5WetuHVu/NAM8YoXyU0Khx
6KAfAYof/0xhGs1DKpVCKrhAAnBjC5IyVfPQ5cRPuk6XCUDYMDsqOJ+DhA67
m99OI8ACb8zgicibaN5g6K1CBi0fwW+7RPMmatQlHa3JosVj/FhZs5SF3A/K
HW/NI8CHms081hNZ6CH7guvMPQIcDRCwSKRkIuPX54IUnhHgefseuVl0A4WR
ovOqp2j9+dBuueN+CupzOGWnNEsA+rvNiCMoBUmcMxIsnSNAPCHxVL5BCuoo
4E4pXCLAReUCouNEMuL9kxOTvE4A41DZdV6xZFRcVuvly2EAJ+SPeXTVJ6H1
l5ly37gM4DNWdqEqPgmZDIdMn9xtAKb32ZiZXJLQ9//0TzgKGMDHbvlLyxxJ
SMep2/KwmAFEGJVYpg4loB6eGW0FNQMou53JJuobh8RkX/+6q2EA8dzEuz5S
cegcKq8R1zaAEu0WJa+PsUjIM+CQMBjA3NbD624msci1hU6clWIA6aK5V6+o
XkO/AgVZZ+wNwK5jspZd6go68JHyrjDaAIKJH34UXYpC15q0K6yuGACD7Kv9
5YQo9P2uQsyOWANI8pApdmSLQk1+HCpnkmjxGCLxT7IikStLXyLmpgFMxWVw
Kr2IQMXYY4YvKg1gmKu8pUj2MuISpOzzf2gAX6g+N1R/h6MLW1o/JGoN4M7A
z/wjr8IR5ZVI4ZXHBpDww+64+plwNOcwtmXaagCP3j8J1PcIQ4rXTtZ++mAA
Pe7yVPbnISjdxyY+6ZMBbEYffDbqFYK2Lcmu+HED0FOkYAr2hqCe/fI8RVMG
oCy4b6soLBidrVnw8lo2gN9e6d+STC6i6rFzkhv/EaFMqamvlSsIibS6b5Tt
JIJEskVe+ZtAFH3f+q0jOxGUfhSrUa4GoqPnNS+/5CaCe2NeSzZTIPrJtjly
TYQIzGeeulYwnkda6lGpghgiJHM9untNPAANOguq5agQYWWux8prwR/5J5QP
iaoTISp156neR/6odPKdkIwOEbyeKh/fe8Qf7Us9WKBGJMJOb/uQ5it+iGF5
sMzClpaPIlZiynEW5Yp4mg7ZESFGdr6FOO6LtEn0y7aOROi+kyf1vNoXBeTJ
qzi7EgGNLjPtt/dFUybhDb7eRPh6iFGy3c0HvS6RbYuPIMJ6kzC27osnOjX4
7BR3NBHe6wpnmmd4IiYGS9Y0KhEO3SAkNBp7ItyxSybZcUS4/YVXSqT+DKrc
8fZtSToRzg5/Uvp2wwOluoaMtZUQwV7e7MKPgFNIKYk7wqiMVv/1o/5m2FOo
83GReHcFEep1jocRv59E/+3udR+sJkK0u2Mno99JFPRCcv7LMyIEMFrovQxy
R3b7un/TvyVCpfP0FatCV8Qh6FfzeIAIRXJ0ZdXurujFbr6z594RgTHXaVeH
nCuS2nl8ZuYjEUjUXxF7alzQ4srUYPcMEZ67ROnp9jmjiFdbD3O2iLCqz85e
rXgCqTQX+FjTG0LVy7zV85tOaPoZQZ6byRCGFy4KLr1xQsbV125F7TSEh4Ys
AszeTogvj//6GV5DyPpvq8f/rCMqDlD01pQzhISrNguWfXbI1qdXdkXBEE4O
uK9uXbZDuzwCJksPGcIU76PX3hg75OfYYCeqaggUH9mFvLTjSJtCNNoBhmB+
XZOB5GaLuvY7yAxYGUL/1T0nK2RtULgQ/ZcEG0P4wO12uXbSGmH5bueRjhtC
fPyaZ+Qta5TB+pX/iRNtvdNknfc+a+T84xxz4RlD2Pb7LhK7/yj60RE/4XvZ
EJhNOsQ/EC3RCNvAqY1IQzh0xXtrmscSNRmLLNLOZBjp/GBZMGqBkrpK/uTG
GoJdEPc5wWALJNfXxtuZRts/ZTZif8MR5PCe3lC2xBASsWR3l6PmiCBE7qwu
NQS6z69ZF+TNkfzxJAuoMIQTI4r4IXpz9Gtkn5N1tSGolKWdbik3Q8lj2hei
nxnC+9apLK5dZqh1+tz98T5DIFcf5GypNUGlMk+VvQYMQdZCp7rUywSlnGaq
/zVkCAvRbGHmkibIaS65mfOjIaTenYvuSzdG6wsVH3WnDWF8+IHNgwgjdGht
ljPrjyE409vzzIaSEb+6crrkliHIjwXsLgQy2ggMEqmiIwGrhYmWEBMZdfz+
T7admQQ3V9FvFE9Crpvi+DVOEsxJK+icLjZEGUwOAUckSJB4WHQQw0BEWy57
VHulSFD6fj22ptcAub7s+WEqS4L56+fn5gsMkFKEfqCJIglMTNnZtvQNUPu2
zEWSBgmIfHtX2+IJ6Of6ShjOmASHut56MWjoIzvbMnh6mARJBY12pzn1UdMj
d3odcxJ0Tw4IkqfxKCHofYTmURLse3Fhyy8Dj6TWnkWrOJHgR1PRWV86PDq6
fDVWLoAEV1fStrmnAT0x0ze+d54EfQM7e5lbAYlVbrDLXCDBTtkiX787gBa8
fRIkL5HAUMxGqNYNUPQ3y+uiV0iwuxF/qGsIoa9GHEfyrpHgQUpVNT4HIbP7
bTz74kkgSD47WOyCkIiHVqpwMgmij31eIK/gUPX0/hv82STo5Er2H92LQ0KG
763TckkwzX2hb+yrLgovShbgLaD1c+55cne9LjJ2Y87iLiKBntbP657WuujL
xNds9koSSAF77O08HUTB37aPfUCCMQWV9g1/HVRZYL+PtYYENT9noxBZB4U4
9eTtaKD1X3o7JGpNG+3+VHOLoZkEE0vdJ9nttFECe2hoXSsJnLfs6itUtBGr
NsHG8xUJfE/bL7lzaCOGjL5dg10ksLep5+du0UKXWjNnrvWSQHuEh5nplhZa
X3V6ifpJUPt0bJg1XAt9N18MuveeBOGZgzqWSAt5h9daOIyQ4HXKVnu6qBb6
Wh6quHuUVt9cps48gxYaZ2P/EvKFBC7VcsMDHZrITuvtM+VpEkhLijKdqtRE
705lZU7NkiB05Qofxw1N1NMiY2q2SIL14uqFtJOayHh1UZb5OwnEkwJrA801
UbtYHVPDKgmm+svcvHQ0EcH80qj3TxIYBFpvnJfRRM/DDBrE12n3MzDgYiqf
JtIqZ097t0GCz/1MYy2Mmqh25K1P/Dbt/iaxHGRb0UDlms6SP5nIQNrvEdrb
r4HkTsnSle4gA3mlLfxImwYqSl8admIlw4xE5pnpBg0k1lJXw7eLDGLVH3WT
KjRQzsqlpA5OMmzkp/00vqOBBMSIZ8J4yOAz15ixN1sDpZrtIqrwkcGj4Bw1
MEUDcYX1i87uoeXT/cFldFUDxZXd/JMjRIav76qUz4RqIJYR58Eje8lQ2ZqL
G/XRQFGsclU7RMmwZVMRV+6kgeg0l2OfiJEBMzHoO2aqgYJP1ruflSRDdTUL
hOhqoLW0MD0pGTKMimmYXpXVQH7NRJEPcmRgDbNZ4eDVQB4HBnoJSrR4FM3D
BV/U0ZRpdulvDBmuOI6VP+lQR86XXKjlqmTIuW/wy6tCHR37sKwjoE2GVaxA
ZkWAOiKlcRTPGZDh0Y6L9iGLaqj55UBEPokM8h8qDvO+VkPwPdveyogMihdw
PSF31JC6qfzu52Zk8HfAvhs5qkY7j0iXko+TwaRHgFhUqopuqXMeM3QgQ896
FVNSmCra5z6I3XAiw3QE7k+UuSrif+k66+ZOBpsfW5/Lvqsg5tDLlppnyTDu
1rDQLqeCqpe//X7uT4b0USPy0XUscnW3ySOeJ4PoJCe/3issajY99NUimAz9
8q8/Et2wKErsY5h3NO16tylbQzoGMbVr3C/MJMO54iyW81+UEMPuJXqOJjIs
b9E9+nNPDj2gHr+b2kyGTP6I97HqcrTnt1Zj4TYylDUfsLFskUVNkzk3ZN6Q
YX736r5n4zIoot7ooP4gGW52uufg90sjeoe7NkFfySAicaMqtE4cVfbxbG19
I0OY7gUducPiyMnwUmH0IhkCSo9OdE6KoUYlq4XkVTKceKylKCcghsIZGaPK
tsiw55vs9ahroojunkPFBA8FLu3zrrB3Ekat34a88/go8PNNd+3be0IoTslc
0U6AAn3Oct5mPwXRnnr9soG9FOg+LkoZyhVAim0y99tlKCBWcXF8iZ8frbLe
8oiWpwDTWkLlWDAfajgsLIdXpMCr6Nua1M+8yGBw173HWAoEBoeWjDXsRnaT
34vKcRQ4kBN3fN9Vbtp87el+Ro8CizvNTfcycqMZz0lJGQIFpGs9HArDuJD/
6tDtAjIFLiclbh2j40TXGJ/eSrWkwJ8TObBflw2ZGao5m1tT4PliS4yeDSvi
j604wGFLAftZaOUJ2olu8dzKpzpSoJw/Ijm5ZQd6dICae9GDFm9P6M6GdCZ0
yY3OQd2LAusvol7+N8iICPcu7F31oQBXS4xmoSAj6lHyzPY6RwHvN50NN8vo
0Qwyz3IKpwCj9snAYI4tXHlkx7G9kRQYz3i4ea57AxfQpi84HE2BjAjCZfOM
P7jtw2oZFrEUYJ3+gDfW+43jdxBOJ6ZTYMsziKF2fhU3UpBqxZhJgYnb4S17
51ZwtyZ38TXepEANfi9b8eJ33EEvulTNAgpcyHk81rxrGfe98oLFWiEFZs24
+6Sll3D1q995HhZR4FcZkTs7YQFHCJm8rlBKAd5kEher+hyOtdHBfLacAjzW
Xa5vcmdxPYzvuIqqKMCRLfLq6O4Z3PHYjsT9dRRICXcmMotN4vyyKuJ5migg
axp9VrpgFFe3kUVtaqaAv4yC1ZTuR9yGQ8xlvzba/fxhC55LwziquP25vjcU
GKxvve+aNoh7E03yieimQMgQbk6M2o/jmcGexvRRQFCjphLF9+GyS1ntk4co
kC0ulWFT0okb51g7ih+mAN7lTFOiQgdO6uy42fcRCsi1Zv540N+Kq1StJxyZ
oNDOz1z/bymNuB83CnEMkxS4mjV4QcXiMU5rPUHjwTQFdiQJC7Q21+Banrkp
8MxTgC6I4XPfbBGO9YC5VNMiBTTJWkXFTVk4s0gdUb/vFNCTZdb8efIyrpiU
Md6zQvn7f9T/AZzXlB4=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$61459#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k4lF/YB3BbEaUsKVFkC9nN2Dlf+76mpCRJUpEl61SWCoVokUokEZFE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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61459#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13k4lN//P3CkEkXWspV935exVObJjH0b+zaWJGFEJCVbSqiU0kqJNrJF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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61459#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF2Hc41W/4B3AzQvYekXnsvcfnbZ3DOY5Rikp2ksoKRdkUJVQqlFAapIxU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          "]]}, Annotation[#, "Charting`Private`Tag$61459#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFmnk0lV/Ux5FKUUnKFJlDZveaOV9c8xAZEpIkocwaJCHcSqKkkgjNQiGh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          "]]}, Annotation[#, "Charting`Private`Tag$61459#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13c4V+8fP3CksrIbSMneZL2R3E97vO2dbEJSSoQ3lVRaorSUWZKyE6VC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          "]]}, Annotation[#, "Charting`Private`Tag$61459#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3lczN8X/yshUrShkva0Kq0zbfOammnf93UmIS0zSoqitO8rkqSEkBah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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61459#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFmHk01N8f/+2EyJKs2dfsZGeeY8bM2PfITtKC7FEIU0QSpaRISVoQiooI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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61459#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[225, 7], 2000}, {32.142857142857146`, 2000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 850}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793443144245936*^9, 3.793443173348229*^9}, 
   3.793443209441594*^9, 3.793469059897922*^9, 3.793485147612919*^9, 
   3.793485628506813*^9, 3.793529276031761*^9, 3.793529762565795*^9, {
   3.793529803230294*^9, 3.793529922140222*^9}, {3.793530270960762*^9, 
   3.793530284504855*^9}, 3.79353139532828*^9, 3.793532112019189*^9, 
   3.793538241081479*^9, 3.793628682718582*^9, 3.793631362738474*^9, 
   3.793632431936298*^9, 3.793632611471447*^9, 3.7936328930369263`*^9, 
   3.793635136477975*^9, 3.793640076054871*^9, 3.793640113444213*^9, 
   3.7936402184188337`*^9, {3.793640708734174*^9, 3.793640738153433*^9}, {
   3.79364093528004*^9, 3.7936409965058403`*^9}, 3.7936410297184362`*^9, {
   3.79364138168408*^9, 3.793641392771151*^9}, 3.79364657367558*^9, {
   3.793707647189581*^9, 3.793707667424821*^9}, 3.793717677413086*^9, 
   3.793718178336245*^9, 3.793718270759697*^9, {3.7937189465911293`*^9, 
   3.7937189636698503`*^9}, 3.793719543515883*^9, 3.7938013964348793`*^9, 
   3.793801476824193*^9, 3.7938015727493267`*^9, 3.7938016402503147`*^9, 
   3.793801744571207*^9, 3.7945070290943193`*^9, 3.794507438437231*^9, 
   3.794507498694736*^9, 3.7945075449917593`*^9, 3.794507665556529*^9, 
   3.794513112818922*^9, 3.794513181489854*^9, 3.794515034998704*^9, 
   3.794515319441284*^9, 3.794568645735371*^9, 3.794569008563019*^9, 
   3.794576053691139*^9, 3.794576689040523*^9, 3.7945781439439*^9, 
   3.794578432226119*^9, 3.794579364746234*^9, 3.794579493534186*^9, 
   3.7946566690060587`*^9, 3.794668112310658*^9, 3.794668342679858*^9},
 CellLabel->
  "Out[1505]=",ExpressionUUID->"fc676658-96c2-49f6-9ac5-5f93735ca9bc"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4D.pdf\>\"", ",", "figoneshot20nscrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4D.png\>\"", ",", "figoneshot20nscrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7946682659416018`*^9, 3.794668271296969*^9}},
 CellLabel->
  "In[1506]:=",ExpressionUUID->"bdf37a25-b21f-4f63-96f3-6412f424ae82"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot20nscritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "solns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x20ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x20ns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x20ns"}], "]"}], 
      ","}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.7936416596344843`*^9, 3.793641664167588*^9}, {
   3.793646587897244*^9, 3.793646591046516*^9}, 3.793707651970573*^9},
 CellLabel->
  "In[1508]:=",ExpressionUUID->"52ba00a2-a15f-4d95-b184-6889d8184c50"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1nc8le//B3BKpUh2VpFkZWXPc73PcOxVyCYZlaiQUcqWTUsiGUmFJCEt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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61777#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k41N/3AHBbJcmeNZF9J9m3e5gx9q1Q2ZKQVAhZkqKyZkuS7LJWSEVZ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61777#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13s0lNv7AHCkqOQWSlIIUUQqkvI8wpgxMyaXSnIkKSIqVCpEbiUhHEdC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          "]]}, Annotation[#, "Charting`Private`Tag$61777#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13c41e//OHCkEsooiVLKLit7P5/2XiUaEpJQRkIqM5E0KCp7ZHMOh6xK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          "]]}, 
        Annotation[#, "Charting`Private`Tag$61777#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.7936416699497128`*^9, 
   3.793646592258191*^9, {3.793707652489849*^9, 3.7937076680067263`*^9}, 
   3.79371767779669*^9, 3.79371817872689*^9, 3.79371827108375*^9, 
   3.793718964189681*^9, 3.793719543883092*^9, 3.793801396721732*^9, 
   3.7938014771106052`*^9, 3.793801573036935*^9, 3.793801640552423*^9, 
   3.793801744926989*^9, 3.794507029842862*^9, 3.7945074990304337`*^9, 
   3.7945075453935823`*^9, 3.794507665904826*^9, 3.794513113176043*^9, 
   3.794513181790862*^9, 3.794515035318347*^9, 3.794515319808216*^9, 
   3.7945686460654593`*^9, 3.794569008894444*^9, 3.794576054081661*^9, 
   3.794576689403699*^9, 3.7945781443433857`*^9, 3.7945784325699463`*^9, 
   3.794579365063566*^9, 3.794579493994594*^9, 3.794656671592911*^9, 
   3.794668112531769*^9, 3.7946683438023977`*^9},
 CellLabel->
  "Out[1508]=",ExpressionUUID->"2bec0feb-2bf7-4de4-a5a2-baa59eec897e"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4I.pdf\>\"", ",", "figoneshot20nscritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4I.png\>\"", ",", "figoneshot20nscritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668280613037*^9, 3.7946682851924553`*^9}},
 CellLabel->
  "In[1509]:=",ExpressionUUID->"8a488acd-9675-4724-aa86-4106afaf60a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshotinfnscrit", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2xinfns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2xinfns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2xinfns"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "solns"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2xinfns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2xinfns"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2xinfns"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "10000"}], ",", "2000"}], 
          "}"}]}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0GcoBHAYBvBzmUWEi/IFWV2U7OOck5GkTmZGmYfsdSUzIysjM7LOSEIS
spNyIuTKigiFcjriXCQj/+f/4e3XW09vT69ZYk6IkMlgMCzIQFfJaleoj9xb
bLLdD5365legOTNzDbYtW0ogi3MvhQWDSSdwRmXrBr4uNnqEE19s1LiQHcrj
QyGb4wNt/StS4VT3MPV5JyYbnjvLqbsvl2VQ9c28HD68/tZB3shnE3ThWHfQ
vEcUlX2X2wstshaot+d/UtguSzuCs+qFj/Dq4ICaEsz9hoGKR0YEsSFuTwPq
P4Vpwnhloj60j1xiQdEe2xMej2ZQtQXV3tBQZBcAFc1WX/BdxUg1kriY3KwF
+W0y6k+rtQGsz3M0hspNl4V09BvR2IaV/ECdDOLAupsubCqoYsEz0Y4RnJse
NoW1q2Jb2Fkn69knBv3w+uBRo4MY5jqWUD++xtYhr7ZKsk/vxSqhX+E4VSpL
KD0kTrYOlUG9lE2BHL0mL6jRNcLjN+xevieQe11/mu9H/ue+QbVzMC5qISrU
9YrhBFO3HF4KbKj/iYEarg==
  "],
 CellLabel->
  "In[1511]:=",ExpressionUUID->"18951ee6-0c58-4876-8b38-cfbfa77dd756"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF2nk01G/UAHDrLyFbyFbJviVm7Ms81xhjZhBCJFu2SrZQFCLbVNZsIWtK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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62051#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k8lF+4AHBbkWRPRNn3NWbsnIexjjGWLJUl2VLIknUkZF9KZQkRIiIh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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62051#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13k0VV/cBnCkEmXIEKEM1zxmuPeinCfzfJHZvUKaSJnSKCRSkX4aJVGK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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62051#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13k0lV/UB3AzP4qMhWTmXvM8c/Y133tdlyiSOUkyJ0PJPGeqKIlkCClD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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62051#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFmnk0lV/Ux5FKUUnKFJlDZveaOV9c8xAZEpIkocwaJCHcSqKkkgjNQiGh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          "]]}, Annotation[#, "Charting`Private`Tag$62051#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k0Vt8fL3AkJBFpkCRjxsj0INlv8/R4EKIyU0mGMnsoUikqpEiGUpIi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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62051#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13c81V/8B3CkkqyMMsveK+vea31e9rpcMwn3SlJpCZXE14qUjFSSSKWJ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62051#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3c4Vm/8x60iySxlVNZjr2Sv+8MzPDx4zGggIykppDTIlk2STSTKCKFS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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62051#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[70085, 7], 2000}, {10012.142857142857`, 2000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}, {1000, 
          FormBox["\"25\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 850}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793443144245936*^9, 3.793443173348229*^9}, 
   3.793443209441594*^9, 3.793469059897922*^9, 3.793485147612919*^9, 
   3.793485628506813*^9, 3.793529276031761*^9, 3.793529762565795*^9, {
   3.793529803230294*^9, 3.793529922140222*^9}, {3.793530270960762*^9, 
   3.793530284504855*^9}, 3.79353139532828*^9, 3.793532112019189*^9, 
   3.793538241081479*^9, 3.793628682718582*^9, 3.793631362738474*^9, 
   3.793632431936298*^9, 3.793632611471447*^9, 3.7936328930369263`*^9, 
   3.793635136477975*^9, 3.793640076054871*^9, 3.793640113444213*^9, 
   3.7936402184188337`*^9, {3.793640708734174*^9, 3.793640738153433*^9}, {
   3.79364093528004*^9, 3.7936409965058403`*^9}, 3.7936410297184362`*^9, {
   3.79364138168408*^9, 3.793641392771151*^9}, 3.79364657367558*^9, {
   3.793707647189581*^9, 3.793707667424821*^9}, 3.793717677413086*^9, 
   3.793718178336245*^9, 3.793718270759697*^9, {3.7937189465911293`*^9, 
   3.7937189636698503`*^9}, 3.793719543515883*^9, 3.7938013964348793`*^9, 
   3.793801476824193*^9, 3.7938015727493267`*^9, 3.7938016402503147`*^9, 
   3.793801744571207*^9, 3.7945070290943193`*^9, 3.794507438437231*^9, 
   3.794507498694736*^9, 3.7945075449917593`*^9, 3.794507665556529*^9, 
   3.794513112818922*^9, 3.794513181489854*^9, 3.794515034998704*^9, 
   3.794515319441284*^9, {3.794564067595448*^9, 3.794564081635975*^9}, 
   3.794568646464917*^9, 3.794569009315996*^9, 3.794576054547822*^9, 
   3.7945766898090973`*^9, 3.7945781447547503`*^9, 3.7945784330282927`*^9, 
   3.794579365451996*^9, 3.794579494458177*^9, 3.794656675095166*^9, 
   3.794668112785726*^9, 3.794668344893652*^9},
 CellLabel->
  "Out[1511]=",ExpressionUUID->"55e0f99d-bd21-416c-8b77-773d98f86655"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4E.pdf\>\"", ",", "figoneshotinfnscrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4E.png\>\"", ",", "figoneshotinfnscrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668292172844*^9, 3.794668298102275*^9}},
 CellLabel->
  "In[1512]:=",ExpressionUUID->"d3da8008-af84-4d6e-8532-4b0d49d480eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshotinfnscritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "solns"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2xinfns"}], "]"}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2xinfns"}], "]"}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2xinfns"}], "]"}], 
      ","}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.7936416596344843`*^9, 3.793641664167588*^9}, {
   3.793646587897244*^9, 3.793646591046516*^9}, 3.793707651970573*^9, {
   3.794564095058695*^9, 3.7945641010495043`*^9}},
 CellLabel->
  "In[1514]:=",ExpressionUUID->"c727e3e4-5383-4f11-b205-0fc8d5bb74a8"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1nc8le//B3BKpUh2VpFkZWXPc73PcOxVyCYZlaiQUcqWTUsiGUmFJCEt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          "]]}, 
        Annotation[#, "Charting`Private`Tag$62369#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k8VN//OHBJEUWkLCmyhYTshPNiBmNmbCWVhCQpQihUtuyVJZVkyZIl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          "]]}, Annotation[#, "Charting`Private`Tag$62369#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF1ns0VGsfB/AhIknuIZJLLh3iSOSS58eMMcaYQRQOjlCcRELoIlQoRUi9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          "]]}, Annotation[#, "Charting`Private`Tag$62369#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF2Xk01O3bAPAhlQcJlUIeKtlF2df7su9biRYkSUV2SUVGslTKFKlsjSXC
zJAolZCIEg2FlKRN1lCJRL2Xc95fjz84n3Ot9/2dsRxrPAM27+WkUCji+Gn+
q9XegbbawQoDyv9/cBmLBr4VSSH/s+rVyxk3RfL+2rqlqyxTpPyvXbym7l8Q
qf/rN8rxxmdFXvw1fYV93GmRj38dzX1T5pTI97/etj27ZHyCC/5n3j/Rrub/
Lv3r9Y5fBh6eWf7Xh1u1yeXvIn+9slywl4ND4q9vvTd++kxv7V93WkRPnDX/
zz9Y1cI2m/+z5jHt3U37/nPlMuUftRf+8x0TUcmygf9clT8ekpKy7q97+DZc
2Xz1P88G+1YLFP1nfdLPfbbmP1d3vc6MHfrPNdyNjWEg9dd9/lyjatZoGGHa
rV1IKB2GQt+2oj3W3anYq0IkdaM0b3igBSjqd5UMCGRXuQb4zud7G0txmBGP
xTPRSmFoVz8z3+82hOqnWTBMRUtNZuX8dCS12mUT+1LRm/JMSvm3k76rY8LS
2egLCxvP57sSyiIlvY/F6O/rnd2lPIhhe0GcxwN0pPPwSNceUueTKbZ9BE3r
kOqi+ZKbg76+7j/QD0OEiwL8SN5+nXt7KOuBEi4S0701gMR6d+3wX74eqD+z
x29kBJGwT9eKQv5Fb/JNzk0PJt5eoTPhsph/gsH5OCuEuHwwsjq+CT200QDy
Q4mFp2BajB7m+zSaypQdItrv3g4mmGHclD2RXhdG5D1Y2uccMK4TLlQHh4nY
24hTyTswLte8xufcYcLnbt192Ws+3iR4rO8wmesRkcvyR7+9q9eoEU6+7BwI
zw1HM+nq686Hk2fbY1exErE+2nhloOMRUvtyy/6bqWhn4wMit4+QUpe1lZV0
zI/tmzCWPEoubK1xeViO3kFrYc4eJc6OP1Nf9mC+9udrsq8jiDm7sf9NP8bd
1RtkdkQSLftUjQ/j6H0rNk29jiQitqqdo1zSQA1VVH72+TjpsfBbsUBJGuBr
o9PpJCppadTdy60pDbVWl3yzu6mk2oynYomhNFB+uAtPSUWTqyYFTqu2Yr2p
4XLHmmjiCe+SlSKx3v0pxHDGkAHNrULbWjC+4oTuwINY0n1rnadbF8bjaRsV
JeLIE/WvNzzfYb+72o45kXGkWDXJ0W8SzSe1Rs4gnvgrP6adEJcBqmD74eaW
BDIprb+U6ScDINY1LiCXSAzeGzWeDpeB2pE+/Y+5iSQu0yJqf4wMULiep5hJ
niXCy53G1l3BfKfdxo3i54gGh++ztHoZoB+arl4mTCPHqwLjw59h/rskq/Ht
NPLocBhxfiUDkqpXruRl0YjLl+gSwXEZ6Iv7sCVT/jwJf305KUFMFvr8bBYK
2F4gtalZ5t7SsgB7x78PXbpAuDfn/THeKAseViJ+pR8uEIclRbfX6GF8n8WM
p0oyudJUEvDHTBZqOQP0Fx5PJu9jKmTeOMri+2E44VZ+MpEn997edZUFybAv
l6IfJZO7FY/sw4LRattaBRanEM6gp4udInG+bkRLo0wKsVJsr9mYgO4Q4Xxg
kUJe57xRHs2UBSrlut+eMylkNun7Uq/HWO9LT+8RukhMrGcaDV9gPCjvlrD6
RZK4iEKVeIv7tJ7q8HO5SMQjecdffUfX6g54ZVwkBj5r2Y6SctB3KIMuIZNK
okwcaOSwHNQ2BbVf0b9EOH8WC4itlwcP5o/N9nuuELEWo29EWR7oS+rWtJ+4
QtSyuzu8tOWB2huQaphzhey1XJzOskUL/hD81HeFNF3xXG8UhvVPe56quaWR
JB0RnQON8iDJodZV7ZhOVkfE7bl9QAHoq4sGg+QyicYfj1tbWIpAN6zf8sCC
Tmxsa0+YVioCNeD1Ko+tdLInXcJes04RSkO/DX7bTSc0zd7Pop2K0Deh/XTm
KJ0MBuwUeT+H+WI22+MYdJLRtzUi0FYJ2JP+mulLsglHnZXR2RElKNXt/vdr
YzZ5elKt9ZG8MlA5r1rzSeQSnaXNnOfVlWG8L3H/Ivlccv3Kbs2doAw0S7f+
SbVcEsM6Rx/bqgweCgcUKqww/+VA8KpoZXB429pfcQjzFTJX+nQpQ+nHVtum
x7nEaPBE6SIjFVDRP+Ac5JNHJGjDPwu/oH+X33mQdI1U744qLPumApJuLN6m
S9eIu+qy7femVYAaP7Gg8eo1ktGpU/mUcyOUHsqhlJRcI6vET4eNCW8EB+3m
1zLPrhGhItlvagTtuzqnji+fLKzfO1KTtBEopaqLm07kk7yLP9ObUjaCpGC+
xtipfGKy76x125WNoKLHerb0fD45wVNR9D4X693vbdW/mk9+O3AdWFiJ9d37
nazu5ZPpNzmfrPo2Qp+V8saNX/PJ8NTb3g6VTUDXdDfavrOA3NqXVGelsQkc
nOesDT0LCLXLIL9GdxOwO1wOrD1QQIRvZ/oVmm0C2vuqmWdhBcQobOdshCvG
TbPUu88XkLTvnSJSCZvAo9ott/BRAbGYaHEKfov9l/0p8le4TpbtjtT6/HET
jNe5FMRuvE562YqrXYc2ASXmTnSq5nUSWnrmg+kkzj8y/fma8XVyNcAyWIRX
FQTEFv0bsfM6+TFan1SroQrjywNseU9fJ3lD957wn8O4gwjlzfvrxP+S/Tqf
ZFUIrP74cs3AdaJp8uFYw2VVYDeWh+0evU6eZPIoReRi/ejVFW1T18mEw/ak
wUpVoOy09w/mKyQGt39sqf+gClCm1v9ArZB0x2x8c0RbDTzmRvdURBeSHJUG
9Q4DNaj10HB0jSskB99sO6diogZ0+reM36cLCUWTSj7bYbzdyVM9pZBID7Vm
O3mpQamqnejB/EIS6nDQWzkJXZYpyvmkkPCLF4x9/Ij93z2w+7KkiIBzzJsP
g9hP0bOsTrCIBCftan7/RQ36dMpOJq8oIp0cqwr6ptUg0Lo2Wl68iGT1J7j3
8KlD7XS71gbFIrKh1KfluZo6UG8cD0myLCK2xhuK606qA/vVdWZrdBE5HsFz
5cEpdehrLf+lEVtESiv642rPqQN95VKxjIQislz2qmf1ZXWg+Vzvdk0qIj18
AqJ3GeowHmBUVJlRRA52TiTceIH1l7Yo9NwqIokHKrzpUhr4PH0LPg0UkSFg
JvDKa0Cfk5q48kgRMV91rShMWQOocQ/0Do0VEc7GlC82Ohjva4mbmiwiR6RC
w37aa4DDKdeCF5zFxPvtprjNxzRAYBfX129ixcRwa+k1rnYNgB+zfj3WxSRL
8XpjQJcGsLv0XR7YFZPZBfTBVz1YPxRnn+tYTCrLkpRufNaAWlZguLtLMdkg
EFDhNqeB9683c8OzmKxuVmq4JasJKlJRm9jhxeQHFH/cH6UJtJ35InM5xaQq
bzj98ElNYJu4fnW7VkxOcCtuiTulCZQ0voSqgmLCz2Y8yE1GH8r+GswoJtK7
WFm9BZrg4X38d31FMXGOvLHNia0J9N+rav80FpOKO7efkjVaQPnnKfQOFZOj
4tMxdtJaICmTUTIzUkwgWkvXTUELaMtqxFaMFZOnFncKj6prQalM3Tfjb8Xk
Y9fduApLLQjUG3156lcxWf7jPigEa0Gf9gfOSl4GCd1UXy78EPv5pQYXyTOI
t5ok/XyTFghE5AuUKTLINo2IM3ytWsBeUHnx9gYG0dVR8+TsxnnuzW5VmxiE
0yhv6Zcv6LLba5k6DJLkeNKnQVQbaHocJkpWDFIUaCIZGqwNkv0Ul1v7GCQj
mM47dlgbIM+56/gBBjkbOvvjQCS6QC/K1JdBAsPLW3YlYL2Xu22LP4NoUqWO
WWdpw7hLyKrGQwxSn8TVufaJNgg8T1i4N4ZB3rLqz7St0YHSkn8eO2cyCHuU
a2STjA6oxKmH92UxSK2iqU2Kog54aCSm7qczCL2ogc9FUwdq6zRkQnMZxDP/
0dkeGx0I/DDQEF7IIP2ZTUmfD+vAOBeXl3YFg4wmPk2ea9EBEH6endPMIL3N
fN/dn2NcTVht7imDtPLYOtW+1AHKtZS9zq0MwkpoWR7zQQdo7YoMrjY8z8nW
i9w/dUCgS2HCoZNBvh9jX1ompQuBZw6cLuxjkF8+L9LljuqCgJDyoz3fGcRJ
w+38hihdkFTc7kudZBAGR3+c6kldYPulcmb8YBD3y1NB+ud0wYE5yMOeZpAH
DaIWjjm64CF3IEVhjkHiJXd/D3+iCyond+29sZBJlnWO2jSJ6gF1Svb77xVM
cjA7zKhFQg8E/v1d8EuYSeoP/tFsl9IDSeor36mVTBK2QHBdzwY9cIibkh4R
YZJuFbWfY0Z6wI4diH4iziRXzxy9ttJXD0qLOmJ2rmcSBcPFv73vYX9nl+gX
qkxSWlQs87JWD1QU2gob1ZhEbbmDo+UjPaAf9Oy6o84kep8v5ym04fz1nGbp
mkxid1beerwf+/nwnd+syyTB3baXjwjpQ6lBd12yEZPcCUrZlHhAHwQ8Wb3e
Dkxi8FrLdc5fH2ivXc/qOTJJncmbWP9QfRi3UdoluJlJnqyU7naI0gf2nscB
lVuYpOf+7agVF/VBMmKB+6wzk1B4Xj/Nqp3vRza4ujGJec6afTdWGkDgszCP
6AO472V+6UerDQAe87JUfJhE8tyvj6/WGICAeuPmt+iZIx2eXIoG0Desmqdz
kEmYjqfcXcAAqJaHwgf98b45JrbO7TfAn+eyPrKhTPJ2V62J5V0DoCvHxSsf
Z5KnW5kL3GuwX7bs+yfoSuu0uuB6nLdpJn9vFJNc0AyFjFbMPxYbdIXKJKZL
ZfXG3mM/iSKRmRNMUlydpHqRl0BfoZACPZ5JDovvWvvOlcB4mrZADI1JPB1U
nHt2E5AsUODmOY/3G8NxussbvSOESkNLD+ZOtAQSgFkynX6BSV6UD9TePYn9
7E7zMVOYRMUmeFcKgwBF//zg7ctMMnA0NsN8FuPp3v0hdCYZclbYn00B6BuU
aBpGe4wv45RYAOCR3aCxJ5tJrNd9UhflBqCfS7jvkMMka0/FZwoIAdCqio5L
5zEJ2+npwbn1aN0t+vcLmERxZCtvly2AgH+zWDoL78PJpua0A9r62xX+EiYx
vm8UYrAFwOEf5+xo9I5zyq+vbQOofedu613KJKdU/ikO3YP563tk5MuYpD+0
ykroCJo3zDGjgknoc2tP2+YBBKb1NytV4TxvEQOOAgCK5IptyejbrUu/lhfi
vlVlx6bRrVdnt68uAZDsGT394D6TzBl2yg3fAVBZbdZhV4Pz4049TniG8b7z
4c51+LyXjnPXzwCMq9/oX93EJO33T8dbzgFQUw7pBKIvHFy/6NkfvC/TtQYP
0UJPdix4xWUI7KEA5/2P0bENc2P8hiBpcuw56wmTCPxK+yq2zhCoe61MlFqY
hO+zaU+ItSHupyX1tQ1fPxf7dvy0NQSH71W8eu1MkmhyrPu4A/b7c4QRi+bN
Ke08tdUQSrsvi656ziQ8bmJtV3cZQt85w1LtF0zC/Xy8oTnEECjFv6cCOpmE
qya9ZF2GIYzzrS8pesUkr/RMLN5mGYIKTaVsAl1yd6QvLRvn+dr5ar3G89/S
FxIqwHjzH0oD+gbzbSilDPe7Olb3qodJ3DPW6bxpxPmFrOHpXnyeR4rrU7/h
+fj4mjg+MMm5qS1um38YAjy7IQnoPYdmJ5f8xH3MPLWOo/mDbGVif+N5xj5f
+4neu3/sVMg/RjCelU8d/Yj35aJq7yBhBKV3v/s97mcSX7V73f9YYxycp7YM
MUktu4NRaWsEgQVON06hV/iNR+1zMAK25BG1GnTNtfXSDVsxnsN9SW4Yn99K
WjDVwwjoOgLPf6Hv/fTinTqE/c+qbU0dxfus4df/SDeCWrX9k3nj+HrfKSeQ
nIv1WZy6L9AVU8YfDPNx/pO9DgsmmGSXypFTV4uNQLJux7AH+mb2h44dtzB+
kDIg8pVJdp6s9G9rNgKa5oRUzDd8P1t60qt/GEHfMtd3qj/w+4/iGgPyE/eR
bijZga7m73td8wvzuZW2R6PZz91WPqAYA/t3vH4r+rvb9nMPeYxhfOVmB+8p
/P4Y7BDR9K8x9gu+nzSN+WkG29rNjKFWwiuzaYZJtkfOTW62xPzqSb5h9Ptd
VcnPrTHfNW3nkl/YT0rn2QsHY6DxFac6okVK1M26dhiD5IvW+Jdoz4eKaj3+
xkDRY4T2zTLJ5LCoQH8qml1u2/2bSVIyPzdmXMH97rGCZtCq9uVRWzKMweO6
U4jYHyYJKrMdq802BvqrfwXc0KPh1NZ0Bs5XzLvZi/60sD/Rsc4YAtVyHr6m
sEiHxI1/7o9iP6OTs/c5WSS0LfJByDj2W7pe9DV6WYzVEflvOP9+scg02rH/
w8Claey35VP1xgUs0sIQbgpeYAL0nj3XctEN2hFxsiImUJvoMBfNxSIVW8wX
pJiYgGRZ0Q25RSySYF0Zu9rcBAQcDVMM0a7GctzXLE2g1Ht813Y0pyrvklt2
WD95qSwBbSf0TPjlNsyPEDbtRw+wneVX+5kAe/2gbuZiFhG183bMu2gCtE7S
NcPNIlEWsVfL+zHfhnnmCC+LtLvvd1UZNAFqlOeXM2ipQ9YijGETcCj7SrLQ
T7IFk3PHTQCejrDq0Mt/ZcZdmMF9Av7c5+FjkevMW36B/KbQd2d5ySU0W2hA
V1HDFFSoNxyuLWGRtXLN0wVapkDzPZFXgT5EWBXrdDGuMDTQgBY9GKosBlhv
XGvcj/ZqoKzjsTKF2tytxtL8LDJ9WIRnwA3ju9PDc9Fr3li9zI01BXr4CH/y
UhY5XadbsjUB+/N/ac5Bfy1QjFt8xhSozXfCy9B1wfxqvjTMX/Yjuw3txd2e
tCndFDxsv6gtFcD9VbebPyjF/iNwMB694fS+W72vsZ/m8fSDgiySGrDtLK0X
40eTQo6i/zhZehm9MwW28079BDRbQkEovx/nrXbPz0UHVXzx85vA81WxnnWj
y/sOrZ9dZAbjm0ISjYVYREfzZIrIJjPwUAbhJctYpNNTRCNTzQwCNTiDV6FD
zrG6JDXNAOq+1a1DMz69FJXVMwOBMxdNdND/pihla5iZQW2HVJM3mnOik7ll
B/ZTl+u5j24ukms8ewJtO071Ws4i+zur9wvGmoHDhsOp/mguTieei/FmIDnG
lROONth+3DYj0QxoAurpiejSxc+fF6Wi30+sKEeneEX0NRaZAf2inC3HCnw9
/vvsJ8dzMyj91fkjBc0vElxxr8MMKCOH87LQD5atCDr00gyoTyLNr6Ol/9k5
MPAG99EWD7iHHvvW3/lswAxUOj9bv0OfePz7ZuZvvJ+0bXoKwvg8Qjf4a8ub
g8qkBFclekdAm9w3RXPw+KB+sha9xCf0E0PZHChDD381oYN33XWVVDeHWrBo
60brWplZLwZzKHXlFv6FbpVwl+3Yag6SQuqL9VayyOSTs+8Do82BfXxj5W10
D2/H/tkYc6CNfCmtRtfZrB6Lj8P6R705DWhaa9GvrDNYn98R/Bwt3964vOWi
OdA/rnv4Be3ezWEuV2QO4xZaslKrWOTR50PF79pxn6DbcBrNkL2/0a/DHBwa
wgJo6OQDXJXTXTh/wPxyKtpj+EL90jd4vqsSL3PQM19K3uh/NgdozhO4h1b+
Mbg07Rf2F1+0dwh9mcs9dLOUBVAu87aZiLDI7z0r1dukLcBBTE3ZCu31kD1p
L2cBNC2zBHu0ygnjw7YbLKAPZBR2oJv+yB610LIAekKPagB6auZblIGNBYx/
X+Z4Ge08ceqMfKgFeOws/9GPrnIwtikMw/5CQXeH0WtLZ/lkj1hA7ZncI+Po
L/4B59Yfx/qGA0M/0bEjTuclE3Cey7GLfKL4+v8scUk4wwLYEuWCG9HLeity
OOstADjs74Whz/FFRt5+hPH85bbH0Dy6JtsOPsb44wWvotCcl9uXdLZaAHUo
/FMC+qvjWHhhN+637/DDNDS7QdbeYQz3u3Am+z46kZn+K1PUEugDRsspYizC
3ePZuVncEuA4xyou9Eke+RuLJS2BVlO1kht9bF+ld9B6S6gtMuYVQPus6Wgz
UbEEgVHrhxJoi4v814dNLUFyC1+kAXphZLSTdpAljAtYrTyCLp8Y+VkTgvni
5V4RaC/vbVfNwnA+bZQVha63Vx7acswSArl7tOPm5699E+Ufi/kVXPLJaK4m
reLcK5ZAaQsMY6A5l41z8Ndh/9NCXT3osvidBSn1lkD1eFf/Fu05+8hGrNES
+oKGSt6j6z5lXpJ9ivNyKiMH0CcqrZWMO3HfWznT39Ac7gXbwocwHnLFn2c1
i1AK3UveC1kBpaXMQx39aKTL/+oKK6D2RqlooRNVHDe4rrICtsu6OR30ykpj
Zoe4FTgEcJ0F9IZG2eImWSsI5F17yhrt+ulrPsvACmiis1Me6Dtr4rOO+lgB
nIxqO4U+vpfirumH/Y75WyaiTQqPiH8PwHj7cPU5NFvlYIbfISsQOHg4Jxk9
QBzTPKhWUBpEs85EC7uLpZqlYj2HmEwpOjit5KxQnRWMB8kveYG+PZsWX1eP
8bhzSp3oWfe46OBG3Fe13volOn6d26H2p1agsiUvugedweBxu9CF/VWCn39E
N1TvVRQaxfvI6RSaRK/6INYsuMoaBBqG+JaLs4ib6eKGB6LWwE5/P7wCnVPw
tTpIHOO3h5pWohUPPi5rW2sNDgfUIsXQhpNhaeeVrIG2w+nZWrTP4vYDgsaY
HzomuhF9XyGBW9DfGijxa7xs0BovVrZcCMR4SN2oLbo0ouD88hBr/Hny4ZD9
/LyWR6Krwq3x76nc6M3ohICFShInrGE8fU38NvTmmycclVKtoXaixtoL/Vkn
Ms2yGve5l/38KNrjA9+u5lqct/qFSgT61ZmMdbYPrSHQoiwxEv205x7DoQn3
5QoGKrrs+Ey1SzvO4/lzKRYdUXf4w95+7DcVyU1DC1oFK57gtwGKq8DCPDT9
wVJeHUEbUBkdcLqGVtFmDk4ss4HxHbty89F2sgP5u0Vs8PeH9XqF6NOL3NcY
StmA5CIRNxaa66GlMEXHBjwMX7pWon/orqEc32sDAqIO7s3o2JvVver7Md6Y
EfMUvVzB9f6ojw2wZVgFLWhV0UtH3QJxXtT6kWfowGm+Sb1jWD+X7P0CPVg+
PfiLhma8XvsG3aPEfn6kygaoH4PqR9FXhwUjF9TYAJ0RWP4F7Vm4RfrsA5v5
/0/kjs3XS3WF0x9h/QGBqIn5/cR6xRvZeJ6xZIXJ+fvgGdm3/BPm82XsnEWb
9S+eZS2xhdJ3XyR5/sXnmUWkPrrbwnjxnj3r0N+Oflu8e7ctUM5vF5dCa7gU
DL/ZYwvU1KzOed9buvRm137M5xQxl0Y/ovYaNgfbQt+ejxJy6NeekbvK4myB
vTXyxgb0Ipl7aVSWLdCOTG/XRlsuCDg+V2oLAklmf+ad+Hat59GbtqDS+CtX
By14+bRcaCXWX80a1kWv/mdH5b46nP/9VYgBetPwdIddpy0E6nbuN0a7lWgI
iv9G16wcskHf2jHNz6bYgaSO8WlbNP+iu3wxC+ygVLRLzg5d66rPPchtB9T3
uvvs0Wt5TP6UL7MDj825rxzR/V6OozZydvj328lsZ7S/6MHHEU52QHlwqHgX
mhqbHd1TZAfgPTETgF5yeLHVbibO4zLyC0Sn7fcT6i/BeUqab+d901o7d6wc
832X1wXN9xdsq+essQP2w/sxIWjrLAq33HOcV/9jMgwtfHvXuUO/7MBhUWhq
JDr3eoPzzJwd9NnvmJu3SpqCRBTFHkrf1O45Pn+fkVMlCQvtQeARv3IUOsI4
qS19qT30PWbWUNHvn1Uvr1tnj7/PbW6OQTMHxNP5bewhcGdMxil0QmasR6+d
PdRe0eE4jfbaPLqe5WgP7NJTe+e9uqqq1NbFHqgHxhTPoE8n7XyU6In5XN23
EtH7Na5M8ByxB0kHjTtJ8/d5crnF4nx7gKWTxy6if2tFLOm6jvYR7Zh39+iH
9vxie3z/vVdKRdNcbrqZ3cD9D2/rnfcf+c0hsVU4f6hd5zK6py0pa8Fz3Ne8
+F0aujJuas/zDuyn/lQtHZ2iu0su9yWeN/NU/Lytr20oN+rFfttfKmSg74a3
PI4etAdK092ATHSqknqS4wju/6a8Zt5B7zOc1oxhvYfF0iy0rM3Bt7Xf8X5l
dZjz5uJ4kUebwvqiS7/m3Veh6+Mxg+edy7K8iq7yyVVWmbMHlSa/S/O+JME7
+ecPumrBp3n/H0Ij5hA=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$62369#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.7936416699497128`*^9, 
   3.793646592258191*^9, {3.793707652489849*^9, 3.7937076680067263`*^9}, 
   3.79371767779669*^9, 3.79371817872689*^9, 3.79371827108375*^9, 
   3.793718964189681*^9, 3.793719543883092*^9, 3.793801396721732*^9, 
   3.7938014771106052`*^9, 3.793801573036935*^9, 3.793801640552423*^9, 
   3.793801744926989*^9, 3.794507029842862*^9, 3.7945074990304337`*^9, 
   3.7945075453935823`*^9, 3.794507665904826*^9, 3.794513113176043*^9, 
   3.794513181790862*^9, 3.794515035318347*^9, 3.794515319808216*^9, 
   3.7945641023703012`*^9, 3.79456864676711*^9, 3.794569009626143*^9, 
   3.794576054882169*^9, 3.794576690157279*^9, 3.794578145127552*^9, 
   3.794578433466691*^9, 3.7945793658445272`*^9, 3.794579494745161*^9, 
   3.794656679727227*^9, 3.794668112940106*^9, 3.794668345927599*^9},
 CellLabel->
  "Out[1514]=",ExpressionUUID->"2ca82935-0ea3-433e-a1a3-2bba5415651d"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4J.pdf\>\"", ",", "figoneshotinfnscritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig4J.png\>\"", ",", "figoneshotinfnscritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.79466830774368*^9, 3.794668313801715*^9}},
 CellLabel->
  "In[1515]:=",ExpressionUUID->"a04b8ff4-cd6e-4e14-9041-e75f9ed3d46f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot incidence with seasonality for one-time interventions (Figure 5):\
\>", "Subtitle",
 CellChangeTimes->{{3.794656397958331*^9, 3.7946564220195312`*^9}, {
   3.7946565090204067`*^9, 3.794656509257448*^9}, 
   3.7946566222229557`*^9},ExpressionUUID->"75328225-bc12-41b7-9f26-\
18aad7055651"],

Cell[CellGroupData[{

Cell["Plot characteristics:", "Subsection",
 CellChangeTimes->{{3.794656432475219*^9, 
  3.794656436002179*^9}},ExpressionUUID->"92848e1f-1917-4ed7-b7af-\
63a21d27e186"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"line1char", " ", "=", " ", 
   RowBox[{"{", "Black", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line2char", " ", "=", " ", 
   RowBox[{"{", "Red", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line3char", " ", "=", " ", 
   RowBox[{"{", "Blue", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"line4char", " ", "=", " ", 
    RowBox[{"{", "Green", "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line5char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Black", ",", " ", "Dashed"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line6char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Red", ",", " ", "Dashed"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line7char", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Blue", ",", " ", "Dashed"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"line8char", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"Green", ",", " ", "Dashed"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prmax", " ", "=", " ", "800"}], ";"}], " ", 
  RowBox[{"(*", "800", "*)"}]}]}], "Input",
 CellLabel->
  "In[1437]:=",ExpressionUUID->"4061a4f1-0e33-4531-8b79-2376bea03048"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Four weeks:", "Subsection",
 CellChangeTimes->{{3.793442276145667*^9, 
  3.793442278863884*^9}},ExpressionUUID->"ecb70777-d2bb-41e7-b249-\
0b5f5ed51d66"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sf", " ", "=", " ", "40"}], ";"}]], "Input",
 CellChangeTimes->{{3.7936403438253593`*^9, 3.7936403471896343`*^9}, {
  3.793640381348299*^9, 3.7936403977456293`*^9}},
 CellLabel->
  "In[1446]:=",ExpressionUUID->"0884ce52-d3dd-48aa-a1cc-b2fccef92966"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot4scrit", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x4s"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x4s"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x4s"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x4s"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x4s"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x4s"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "4"}], ",", "1000"}], "}"}]}],
         "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7936404543772306`*^9, 3.793640470827922*^9}, {
   3.793640511433079*^9, 3.7936405164159317`*^9}, {3.7936405863378353`*^9, 
   3.793640588977378*^9}, {3.793640901850996*^9, 3.7936409110413313`*^9}, 
   3.793641022966834*^9, {3.793641344008607*^9, 3.7936413515934067`*^9}, {
   3.793707401383143*^9, 3.793707402397493*^9}, {3.793718374029681*^9, 
   3.793718374520513*^9}, {3.794507314747593*^9, 3.794507317008933*^9}},
 CellLabel->
  "In[1447]:=",ExpressionUUID->"3d8caa4a-e329-447d-92fe-a2463acefc30"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF13k8VF/4B3BKRUkRihIVkj1msd/PzNh3smdLErLMSIposUWFksqaNS0S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          "]]}, 
        Annotation[#, "Charting`Private`Tag$56705#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k0VH/4B3CkiCJLC0XSYJJlyDIzlnnP2LNMY4kismSdKUm0yRJSsqQN
EaJSZMkSbSRFpagsLZaSxDeFiFD85nfO75f7zz2vc5/z3Oc+n/u59/NZ57HH
dhcfDw/PXV4env89b9418Kp2sMKQ5/8OfiPpwB6ps7T/96as1Iwyqbx/tnzR
cStTqvyfHb0m76dI1f9zl/pxowSp1n/OXs6MPSnV98+RgmVKJ6TG/9lpW07x
yCg//t/Cc5EuZrKi/6zA+jHwKF7yn0NfUmip41L/vLJcrJuXd+0/u5yase9b
Me/LXl+eP1GZt8ry6up4p3kzQnaeW14yb50Mx6tn1eX+2d316o787nlHb16d
ljY476s6ya0nx+c9JHLIkiO07p9DaqwpmjrzPiX3S/Jewrwre42amvXl/7nd
PHI0wWzeE0UPVljZzlv3MMW90WfeVRLqE7Up8642lpa7NTDv9zccTQLH5j29
7Jy/2uy8qV2iFTck1v/znf0LN+cazvve1ZF9Z8/Ou3OJWppt1rz/BAU8WHZj
3ga0fsGEmnk/6PiQGfPfvLsNpB4Z/Zr3bO7WAV4ewj8bBr7SPLp83q7tIk76
cvM+qm8VNq087xrBhoYQzPvjbv7vWpYE5KWcyGAO29J42ujiYw4ExDtbaUxs
u0qT0wvXLd1JgNqJMYunsXU05Nxz2RNAwJOWXbsPMd7QdgpMR6qGEJCb/NQx
evNHWgRH99q3CAL637zZfiFmgJb9JrjpejwB5x8tLx+RGaXVUm6N+pwn4Eu+
l5hU4QTtY9bwCsUcAlJczN7Gfv5D41mkqt9XQMDoRMGfW128kGP7u1+uJKAt
uiDo0LmFoL++FrvzIQGUns4Ck3OL4UH+UiDbRMDS9VFdQe+WIuqS/KvOdgKK
DyZcYKiLoc4/c/W2IQJoDo53A0VXoGwwIMB1goCfnLSwxCOrkOdLvevJo4DW
nVG7Z3lWI8a7Y/tuSQVoODZJzSrIwdxDLP2YvgJMTqQWBAwqgPKpZzDOVAF2
rbeajfcqQXlnESVxiwLI3gOeqtNELHG1fJfqpYAcHvrgiY6NaN4Ws6rolAJ8
K54vMGCTUPvWzrfsvAKkwtM3tM+QUOIoX1WVzb2+U+ZCaYwGUhxqHB+VK+Dx
rgvml09o4lhrwrXGBwqo1pLhYfNvQrCdy+SLRgU4Eyo02w9twlbW1Pm3nQqY
5jlBqnTWgllLQ39XvwIaQ4pKK55ogcw8r/N5RAEVM09j/NW0IWW9qf07vyJo
rqJ6HePa6DTnLF+gqog7W8f2W3jq4kWD3i5BXUXEltm5na/WxQNToYqldEUs
k21JFhEhI8v4mv0qB0X8KgviCN0iwwOfzqiGKSI/u+fguUEKBnQdxJ1eKCKy
uzjOSUUfvxQNRG9ylJDaOjfrogMY9jIaTh5Qgof6nWoJZyA20zzc95gSns3U
KHeGAysk7YfXpylh1fKcvptPAR3egOb0eiWQlO5aZrvSceBDalLcaiIyV6WW
nk9ioPb8JTNvRSLeyf/ijahkQNA2b85Igwi5X4tfpXcxkNZYvGfOlIgri555
+qkY4U7FE2ZIEBHtWeVpVXVG4NvbJGAfRsSjw531t78YYbPK6xqNOCIqwov4
mgWM8eFyl/r3TCKy/0aHRlkY40/SuKjXUyJkLQQi3OuNYWw53UBvJWLDcx7B
c5+McWoRT8TaHiKa8onemDWGTJjwyPtxImb5NUfldExg6C/fwpLbgG8qVYyP
2SYIN96STAvdgFObqqOTfEzBN1WwbLWCMpqFOXULW82w+gVjjKaujODUfk7s
gBm0ct61eVGUYdHW9Of3HzPsshC4WGStjD2X8zbdVjBHY5qHAiNEGe11IocL
Q8yRRJWi+jUo44Ct5fDoCgusORLredtvI+TlMqw07TZDZ25npV2RCvzG1et7
aqxgZV0bZVKlAvffKbLZr63geXEtU7dOBfuyXzU7f7FCsm73V+l2FThGJozV
C1ljcI+zVO9fFTjItri5OFgj46PDkUBrVZxrvp6WMGgN3rrNjIQhVRyTTZvy
WcrEqmU3RMInVJFCL/Rmr2VCzXXxh0AeNYRMPEz102Bi+3TDPntJNazSEJu0
dmCiXNPkymp9NQhO9Brcy2DCO5cmeCNeDdrHeaeWLt+Cpmitl0+U1cEbZ6+2
IWsLqKLP+U5rq2NtG1PJOX8L8tPcdZ2hjgjiX+vjpVtwrCgxe9hBHUqntw+/
eMSNfzsQtCpSHaFblklIDHDjN2au9O9QhyaBPbFXnYUVlZustHrVkV+S0wIy
C9F4FjE7pA6R196ii+kslNyYCbbgJSHMjXwixpaFr8OmSUWLSGCLnS6gOLMg
q51yXWIJCdJ9YrxfPVmIryF2d60g4WgoQVJ1Pwt1/MG/GWtIWHOUr/pxGAu/
LWrE89eRYKKR4+YYy4J6kpDqUiUSHPpUTs4lsuDd6mAWpELCsEJK04VUFjKl
ctw7NEhoK+XLo+ay0Oo6dFhfl4TrVHfRjiIWGINRJYsY3Hyb+jmPGlk4qPby
WYAZCT3XHk/9bufWv0/qS4sVCQrvpN3HvnDrnS2WuuhIwm1/v1+LF9liSrwr
Sp1DAu2/iJCb1rYgOREzzwaR4EbM/PVzpy28M/fdngolQTxRnF4RbItWJaGh
R1Hceu335p3PtEWJvq6DUyoJhQNNBzaM2+JrZNSe+5nc+JWSZ0qF7CDb8OKE
fC4Jn8rlPsWvs8MplteDoZsk5Ce0hCttsYOv92mlyEfc+1XPPswoscPa5G9T
13+QcKZ09pbyEXs8cA+/fmuMBLpDVGTRWXu4bpLYdvc3CcsV9Sa23rRHRju1
qolPA+8i6gLEeuyxSuZkyPAKDWjknnIWNXaA+A3imBZNAznrbSQOSWzFwvpd
QzVJGljhvJ5vWb0jvk32dLeRNPGNdD9NxNkZef/dfSaSuAm957o0hbrdISJz
bbivTwsDsoFBZgu8ga3Huj4PamFxbdgwQdwbQUluz3t/aKHPy9duRs4b7byr
rn38rYX63amOKYbeuNQf59q5RBvCIfcFvA96Q63E/8UbLW0sro9uOvHdG9ZG
agV10do4vH9p08+XPjh6RCjt4QltMJaZ6JV1+qCkoj+2NlEb+1HQ5vufDySJ
WR4PUrUxE75WvmyhLzqXLJO+U6iNlQ18E7V6vmC3j8aVtmqDIjFsl3/FF6f8
KryzCTrQpdY7de/xw3+4GSesrIPrUtR0yTA/mK26ciNEXQdZfF95qSf9wNdw
9ocVVQcJuoZ3WXl+OEgIDpli6iBA2kqqtMMP3j2asbaHdcDZpe4nrueP+krl
/PsROsg7Gb93o5k/5BPlnxFjdVDu1piuYeePLn1xkblkHbwrCWnjD/CHffro
uYKrOiiTyE95lObPHdeSK/yvufE1j48dH/PHJZX8hj0dOmjNNvfxmvXHnwXZ
g+87dZA8yrigsjgAVbeSVEu/6kDdzSD4qGwA1JbtqdjxVwe7314xUzAPwJrn
qo8ribrQKSKG+14IwAQK+nzDdXHrc+seWQU27uV9uxgarYtyihKpUIWNKEEV
u9gTulh5ZWaXghYbIi2FD3PP6OKk/oHhdww2FN2KLnVf04XjVMW0hRsbW8NK
nexbdCH7sf2p3lk21nwaFfVs08XfhMJnh9LZ6DXWbNj7XhcfL5YczstmY/eS
Mu2kPl08L2ytuV3IRuzFcvFnv7n/4ZCo+M5HbFRU326irSNj75/Zcyt+sHFI
5vcxG0UyJk7bdcz8ZAORZL0dG8nocPik93ySjSbz6uuHtMngFbhmT+TloK/j
TmyFBRkGnq9EPohzcENvxqDehoyhmi9ly1ZyEJil9+u1Hfe/fpxkTlrNwR/v
e54jO8hwn/AhqK7nQHLiPjYGkTGp0iAmo8nB+22zk5RQMt5wXl3K0eYg+75h
sfkRMmQ2b/krSuFAJaZGxjuWjJ6DXzbcoHHwc2CuNTieG5+V+quNwUGVFU4d
SyaDsGg64ZsJB8aSD6ez08l4SeaVa7XkQOgA763iLDKyO4xWXrPhoOUD3e9B
Hhl1zrvbPVkcuOTWdXwoIuNTVfm19K0cBGvWl694RIauRXrwXzcOvLXksk83
ktG2I3O5pQcHTjpH4pe8JKPsOOXcUS8O9KhaHnzvyEjOlaNf8OXWq59sHdZN
RnvO8wNH/DmQNRwi//7MrW95S64ZmwM+Rp7ojx9kUN5F/Ze0h4NxI54Z33Ey
NAfDxZbu5eCLiUv/5ykyzg/tYwQGcdBuVvXKdY6MOcaiY9X7OGi0kLz/jp8C
fqvutwPBHNyxDMy3F6KA5pNrMbufg0LrpjPNohRYjP95PxXCwSUmMXzzcgru
2aakfAjlIIkV7f9YmgKNXqGQ3AMcRNh9dIAcBeATiWcd5CDIQZ9+V4GCCHGj
ji9cezmmquhspCAxiLVz5yEOtm4bX1lKooAv6uPGh1ybO29ZoKJDwbayWJrg
YQ4oOwp/XNWj4ObA7lxtrpXdBN+vo1PQkxztacH1GnevxxmmFIT09sUbcS3i
WVuy0oqbT/ImkcA1z641GSksCkRcpk2+cfP/9D5wfKkjBcTRweFUrj/7tgbF
uVDwfnGapirXrf4k1wUeFFR0EqTzufU+YZ+yOOpDASP7xq3FXFftHtCaYnPz
xZsJ2nKf90agsVxwEAVX3qxSiuT2IyMoW3g4lIILJXqrL3D7lRD8Z8IvjAKO
04uRM9x+Hg1x6u2L4ubn/VYWyu134IHyF25xFPztLQ1kcMfD49Cy6vcJFLzU
pG0a546f/RF2nsMZCm4rlQgkBHKgG0E4bHmJAvHgweXBHA6IURHeT3IpeF75
wLsugAPp6E4W/ToFtoIxfyf9OJg9fpaoW05B72AjXcqbg5ETIxK3qimYiKoS
W8h93z7FW82p1FAwph/GfuvOQX0Sf7v8MwruKPgL6OzgoPL0zoeZzRQk7+D3
r93OQf6Ze4Wr2ijwbXTM0HTiIP5C8DGRjxRoWohUvLTlwDarjzT9i4LB/ROp
X0258ycHa/bPUHCg/rzzLSMOtHMzBEZ4qNDzrwrdBQ5WXbPv/iJMxVzeG74Y
7vzsKaqPf7WOCsGxrOoCZe78+s4/pKlEReOFWdGXihzUqphYnVWhojjmoMF7
ee78vvF4iaMuFdMbBYNKpLn9u/okodOKio6NXklbF3Pr+bLoh4EtFVK5EUNP
+TkwIpjZZDlSkUqnP1Xi4YBwuUHEw4MK588/HXIn2OjPbEz6GkrFkzetEhm9
bLR3Co6Yh3HrW7m0eVcXGw2rLbbciKKi2WBTnfRbNnf99nQZJ4EK1+bg26Yv
2PA/9+z0z8tUsIJmi69XsvH9VNOZvy+oCP1d6X8rho3u50vGXd9QoeY3dFcv
nI2XQtb2tW+pGLwU0lt6gI2iuBeSxz5TIR73a82uADYCo1+eE5yiIu+Eu8l/
TDbGD7dckCDo4YqUleHx5WzM+Lde3HBID24J/jbPzgTAXmfHabVwPVQ/KztX
FR+AQt7+2E3Reij/7a+fdiwArqmTew0S9cDRlhLS3BeAh4+lzVmX9WCw0n5L
PSsAx+Xcxw8804Oy78PUyCUBkGj/btUorY/RQwHWSw76YyNdYNb7rj5WR3e9
btzkx11fFii9reX69oJ0ZaIftCS3sCye6GPu8Vj2sTV+0P+amrfxlT5on6UH
Vi/0g02CsuVIP9eSulcG2nwR9M469aC4ATJ3O0QtDfFF9d6zmqf8DPDlnMpq
+1IfmF1e51O60hCOPXEzM1LeCJVxk//kQkPbJd6buZKeUBlyEO6wBgS6OCf1
sRMSoiOC9dNAg8tLYYWZ7Xh9/+Rxi7+A413N43++bkcKW2FR8xzgs30zoad1
O8SfbV/wnp8OG3WllsdFXMc8/jssQke1RpOglOd2LJtJ/7l6PR1rEjQXv3+x
DUu+mnTus6QjMCmj6kWBE/hrLhavz6Dj0OUPlOMntuK9vrF5zyU69tCdnzaH
bkXxnaGP6Tnc+NsJAQreW7G90kBc/BoddYp7OycZW1F6syeY5xYdjYv+yFL+
OsA1Yz21q4GOKZ9ZGeVgB1QdLKg/P0bHeHqB6fUAewRo3X232JKB/zSf2gtG
2KK2pa2wypqBa3e9Ryr32mI5ZyTcZwt335nCGQn0tEXNFQXFxw4MaJ/8uFDA
zBYSK5ODInYysF8jrOeOiC3uTnkJT+5nwP3YhSm9bBaEa0QM+rIZiJtYF77/
+RYUWHhkP5hggPo0/05KlA20VNYZ0qYYaOvZ8+Y52wYPRD5+qJlhoK9W7eVy
Rxu0vNmx8iGPEYhXhPQ6N9pgfMe2xEdCRpA3P1So0W4Nw6AtRxpljTAbt6l2
XNUaLemGTq9NjWAX9+NC/KAlfn2TXtZ/3giNvsahpxItcDbza0NGmhFqZout
5Q9bYBOzPNwuwwif3I8WNfpYYO8t6+HaHCPwOx1sN6Vb4PuBiJcXC40QdHSn
psAvc3xZ2H+Kxd1HCxmPiZx0M0fb2tLF978bQfImy1IDZqiwM1tw1tgYhl2e
0wxVE8RZVsWsMTOG2vpVYWmyJnAx2iB4hbuvDlq6J3JG1AR8m4SXVtoY4+jB
sf5PP41hI9684q2TMb42Ci/TrTbGQMtW5TUcY+hHHFef5uaRtvFm5Z0zRrvl
mTNZHCOEm8dklfdz890zF3PtoOO1q68LadAYfv/t6499Tgdhv6VU4Tdj7FKV
PVtVQ8ezHLEzuSPGSAkJ3KaTT4fkTGZsyrQx8suSitMP0pF/s5ITKGKCxvKd
V+dk6GgRH9BT4e7j1wbFL13EAdZ1bX6bG2OCfJn68H5jQ5ys0yt2iDOB1JyE
9DF1Q/y8phIrEG+CV7IZTJK0IeqCRLQCkk1w8WOM2b1hA3gJvk7SvMiNr6w5
n3rRAPmbtpk9LDFBqrJstf2EPtRO+lR2fzCB9RbngoDbeqDqRp+V0jTFicUH
yt57UdDuIaWTqWWKSy0xf+ztKdiXWNQhp2uKReVuF94bUVD45a00Ud8Uic8T
Lwqsp0D2rGqOjqkphNcefvH1Exl8o+037babIoHwzabKnYznNzY0JESZ4qRY
90o7P124yDZP8b4xxSrJ02YG57Xx61lCb2CkGabVrqQHr9JEKr9rsC3BHMT3
8T11WWqQ6K64zFdvDi12cdbHzxuwMCzSnrLXAoz9Uk15HAXwXHct7hXfjJye
RPkDL9YhKL04QbxuMz5esmO5PVmD+xvjBMV2W2IkNBS7eVdCbHOQSpSIFShb
agUsvMSR/VBUmCpmBZU5cZFWljhIlJuDoxJWoGkY8rFp4rAhDlx1l7LCJ5Zi
bp20OE4ucl1HJ1jhpMYrptBrMfA/sljBQ7VCyOYNN+cYYpjQW8dzdJcVVrsu
8d+ltgydqi1vDt6zQoKq7sUw+yXI+iYWtqDGCoXJrg/f6C6Bx3U7xYSHVjg7
IlJpuHoJBgkdB7KfWGEyku+nba8wJlZ3yzS0WOHM4Ax/8F5hiAkN+Uh+scK6
M2E5KWeEYNov8KdoqTWU5y5sE/sqiJJLNEKfqzUkhk0M4p8uxNihMQF3d2vk
8Nw573BrIXQcr33r8rSG45FYaF5ciLuiomUdvlyrHPOX5yzEk4hu+vMga6x9
HL2jS2whPniEud2KtcZj/ru/Kl35sUjpbnpEkTXIe3411CxcgB3FOmIys9aI
vp58JvY4Dyq3/xZp4bFBX5WLi+g+HogsurPk2AIbfFfl9y9w5UGti4HgoKAN
2J+ObpTR4YG8kPFcuQQ3XuumU9PzOVq/F+u71QYbPPJjXRJKmaXtlmY/PWJv
A55l3n3u1D+0J49VG9S5363XiRvoMiv+0NbuHa7v3WaDjzaK5/+MztBaGoJq
zd1s8InfqV3xxgxNc//B25L+NpDy3rdbac0MbbI59kphuA2ChhjjTxZN0yJi
ciI7b9hAdqbJ4uevSdrSUIHN7jdtMMXuGt/wdpKW7ssR7y+2geiJRJeIO5O0
MktK7nC5DcTk+gZPhE/S+sVe1fPV2OBPz6FICeFJmuUlHsENb2yQu1rdrFRp
grbitlvi/hkb5Je7Xj+zf5yWm/946/RfG9jFLP7k6DxOI6VvXBvOw0TC8d3r
denjNIuwyeK4hUzc4LyrNl06TjtilPTqoigT77+Gpl27OkbrbX4gWbeeCaXm
7Q+2d/+k3RyQuShixYR+ifOVFe6jtLjMmJ3dNkysO/17lG02SvOy/a5QxGLi
2kNH0V7VUdqae/dKrB2ZKBbbcY84M0I7meT85JQHE6HyCaeVLozQfHXSRoUO
MpEVWSN65fowTT5a0lzgKhPPbd1eE5uGaLPkI0s78pnY/ynBWzN7iPbu++fX
VwuYiFoYu3lf8BAt2bFsh2kpE4fUKMfTZYZoc8q2+2LuMUFMDywPC/pG63yV
dGnBGyaUlX//2K34H60qdtLzTRsTPaQ9x7v+DtLO6rltyH3LxMvGV6MRbYM0
yytq5YxuJiSND0fsihmk3Tnw4mnkIBO3EzZ7ZH8doJ1X1U5iDTExYbTYp6R2
gLa3N8N+3TATbXcmHo+lDdCIVuye2nEmfkaGt0tYD9D4eVvzkieZ4L+0UXlE
cYD2sULPf+c0E07ixDVzPAO0e/656qS/TDQt9QjDh6+0C2uFf83NMTFDMxcu
r/hK+x8drpNd
          "]]}, Annotation[#, "Charting`Private`Tag$56705#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13c81V/8B3CkjEhmZkb2vNnr3s8L17xmEZUkReLeEhoqGSFCpBJFlIZR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          "]]}, 
        Annotation[#, "Charting`Private`Tag$56705#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13k4lN//P3DKrsiapUXWsY9dkvs59l1EVPaIlGUmpIVUtha0ikpIpchS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          "]]}, Annotation[#, "Charting`Private`Tag$56705#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k0Vd//P3BTESWkoijVvUimutzBdJ7XPM+UeUwici9SqSRRlKHyLmkw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          "]]}, Annotation[#, "Charting`Private`Tag$56705#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k4VGH7B3BbEUUooSiZsUXWLDPD+WYZu7HLUpZkN1MSabWnxRZJhZQs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          "]]}, 
        Annotation[#, "Charting`Private`Tag$56705#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3c8VX/8x42KCiFkZsu+99plnBfX5lqRSskoZNxrNbSsEhUaKiUZKUVJ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$56705#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3k4VO8f92UJZU+yJFmzL2PszHnP2MYyxhqRiFDKNrSSpGglIam0p0WF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          "]]}, 
        Annotation[#, "Charting`Private`Tag$56705#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[113, 7], 1000}, {16.142857142857142`, 1000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 800}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793640458833197*^9, 3.793640471714593*^9}, {
   3.7936405058523483`*^9, 3.793640516880765*^9}, 3.793640597711855*^9, 
   3.7936407366379633`*^9, 3.793640911618548*^9, {3.7936410235115643`*^9, 
   3.793641027674835*^9}, {3.793641347904949*^9, 3.793641351939537*^9}, 
   3.793641391018841*^9, 3.7937074041497383`*^9, 3.793707482239932*^9, 
   3.7937176692801247`*^9, 3.793718171232469*^9, 3.793718265669512*^9, {
   3.793718375547583*^9, 3.7937184398442802`*^9}, 3.7937195381015673`*^9, 
   3.7938013830681458`*^9, 3.793801471994153*^9, 3.793801559055183*^9, 
   3.79380163548042*^9, 3.793801738604952*^9, 3.79450702094456*^9, 
   3.794507248573786*^9, 3.794507279453725*^9, 3.794507317668684*^9, 
   3.794507492705566*^9, 3.7945075384100113`*^9, 3.794507660361253*^9, 
   3.794513107526164*^9, 3.7945131763562183`*^9, 3.7945150291774063`*^9, 
   3.794515313026443*^9, 3.794568639270858*^9, 3.794568998395685*^9, 
   3.794576043095365*^9, 3.794576682118445*^9, 3.794578134103972*^9, 
   3.794578425858356*^9, 3.79457935761025*^9, 3.794579486385169*^9, 
   3.794656486203816*^9, 3.794656556183004*^9, 3.794668113161092*^9},
 CellLabel->
  "Out[1447]=",ExpressionUUID->"c87b8ab0-bb03-4ef9-b701-e85abbded926"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5A.pdf\>\"", ",", "figoneshot4scrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5A.png\>\"", ",", "figoneshot4scrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794667900939253*^9, 3.794667922299102*^9}},
 CellLabel->
  "In[1448]:=",ExpressionUUID->"e8f7ed8b-7af6-40bd-be0b-3376b58c2be1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot4scritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sols"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x4s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x4s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x4s"}], "]"}], ","}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
  3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
  3.793641549374053*^9}, {3.79370742192045*^9, 3.793707428476225*^9}},
 CellLabel->
  "In[1450]:=",ExpressionUUID->"9af44a9f-0bcf-4cfb-b50c-ec6354af8729"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1Hk0VW+4wPGjKJUfGSo0GSKZkwzH8DwOmc6EKElCKSkSElKGUJQhqQwp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          "]]}, Annotation[#, "Charting`Private`Tag$57017#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF03k4VV/UB/BLipApGZPQoMHsR5TWMsR1R1ORzFF+ipCkUoZSElFpElIk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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57017#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF1Xk0VW/UB3CkKDIlUSpTpTITkdrbdAfXdZGiktQvEpGQIcpQJJWhpDKF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          "]]}, Annotation[#, "Charting`Private`Tag$57017#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF1XlcjO/3P/BKKklpQSVEpL20L3SOlqmmmhFRSJsk0SJtSBstKIWkon0j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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57017#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.7937074825857573`*^9, 
   3.793717669652536*^9, 3.793718171603578*^9, 3.793718265966525*^9, 
   3.79371844033608*^9, 3.793719538400247*^9, 3.793801385339682*^9, 
   3.793801472289188*^9, 3.7938015618457212`*^9, 3.7938016357626*^9, 
   3.793801738929451*^9, 3.79450702131807*^9, 3.79450749314021*^9, 
   3.79450753881437*^9, 3.794507660648489*^9, 3.79451310787087*^9, 
   3.794513176673102*^9, 3.79451502956105*^9, 3.7945153134771338`*^9, 
   3.794568639563764*^9, 3.7945689988957376`*^9, 3.794576043479067*^9, 
   3.7945766825373497`*^9, 3.794578134470708*^9, 3.794578426178759*^9, 
   3.794579358155855*^9, 3.794579486676691*^9, 3.794656560443585*^9, 
   3.794668114391468*^9},
 CellLabel->
  "Out[1450]=",ExpressionUUID->"691bba3f-88f7-478c-8362-57dfd07b0db5"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5F.pdf\>\"", ",", "figoneshot4scritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5F.png\>\"", ",", "figoneshot4scritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794667931141877*^9, 3.794667936513927*^9}},
 CellLabel->
  "In[1451]:=",ExpressionUUID->"f0ffb3cb-0211-496e-981a-d9dc6926a625"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"figoneshot8scrit", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sols"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x8s"}], "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x8s"}], "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x8s"}], "]"}]}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sols"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x8s"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x8s"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"sf", " ", "*", " ", "10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x8s"}], "]"}]}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#", ",", " ", 
              RowBox[{"ToString", "[", 
               RowBox[{
                RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
           RowBox[{"FindDivisions", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
              " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}],
                 ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", 
            " ", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                 "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
              " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
          ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
        "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
        "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
        "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<No intervention\>\"", ",", " ", 
        "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
        "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
        " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
       "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Opacity", "[", ".5", "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"importtime", "+", "2", "+", "8"}], ",", "1000"}], 
           "}"}]}], "]"}]}], "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.793640548791997*^9, 3.793640579046043*^9}, 
   3.793640618867655*^9, {3.793640919037943*^9, 3.7936409215073757`*^9}, 
   3.793641019556532*^9, {3.793641363983626*^9, 3.793641366798842*^9}, {
   3.793707412283104*^9, 3.793707413066648*^9}, {3.793718393317738*^9, 
   3.793718393741166*^9}, {3.79450732784756*^9, 3.794507329446725*^9}},
 CellLabel->
  "In[1453]:=",ExpressionUUID->"268c9af6-6346-4aad-a405-8aa01a4e12db"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF13k8VF/4B3BKRUkRihIVkj1msd/PzNh3smdLErLMSIposUWFksqaNS0S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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57290#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k4lG/UB3BbkYQsWUqyS7LN2M3MN/syY2xDi0S2GUmRFiERUpEWCWUJ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          "]]}, Annotation[#, "Charting`Private`Tag$57290#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13c81V/8B3BKWWUVGSl7i7j2uC/3XntcM4pUJCVZV1EhCiVCkaSUhhJl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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57290#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13c4lX/cB3BFhYyM7Oy9x7HH/eYc89gyiqwkTTKKcCQjFVEoiSSVUqGi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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57290#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k0Vd//P3BTESWkoijVvUimutzBdJ7XPM+UeUwici9SqSRRlKHyLmkw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          "]]}, Annotation[#, "Charting`Private`Tag$57290#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13lUTG/8B/BSKu2rJEmamZL2bVrnvqeS9km7pBJaZhQqlFSWdpJdRQsh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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57290#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3k8lO/3/xXZE5ISyk6yjGUMY7lfZsa+S1GyJJRKtqlIZUkSWZI2JVqk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          "]]}, Annotation[#, "Charting`Private`Tag$57290#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFt3c4Ff7//2+FhMKxyd4z4xzznDvOOdmjKFR2ktGwknEikgYaKmVFNEiZ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57290#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[141, 7], 1000}, {20.142857142857142`, 1000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 800}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.793640561309989*^9, {3.7936406007279778`*^9, 3.793640619274135*^9}, 
   3.7936407371030693`*^9, 3.793640921932763*^9, {3.793641020095443*^9, 
   3.793641028238113*^9}, {3.793641367539876*^9, 3.793641391818853*^9}, 
   3.7937074830909*^9, 3.793717670054027*^9, 3.7937181722671413`*^9, 
   3.793718266342307*^9, {3.793718394333028*^9, 3.793718441377398*^9}, 
   3.793719538749505*^9, 3.7938013857599497`*^9, 3.793801472627562*^9, 
   3.79380156230402*^9, 3.7938016361038094`*^9, 3.793801739331431*^9, 
   3.7945070218180656`*^9, 3.794507329916999*^9, 3.794507493977282*^9, 
   3.7945075391533537`*^9, 3.794507661009301*^9, 3.794513108229198*^9, 
   3.794513177028054*^9, 3.794515029968554*^9, 3.794515313985587*^9, 
   3.794568639941785*^9, 3.794568999427291*^9, 3.7945760439020023`*^9, 
   3.7945766829305067`*^9, 3.794578134862224*^9, 3.7945784265767937`*^9, 
   3.79457935881396*^9, 3.7945794874268*^9, 3.794656562305559*^9, 
   3.7946681154949703`*^9},
 CellLabel->
  "Out[1453]=",ExpressionUUID->"f9aa0df7-c660-4fe8-bfe9-037dbc0c98e2"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5B.pdf\>\"", ",", "figoneshot8scrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5B.png\>\"", ",", "figoneshot8scrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794667949577261*^9, 3.7946679587524776`*^9}},
 CellLabel->
  "In[1454]:=",ExpressionUUID->"a063cd9b-4583-4e4e-a4e5-6e105ac71ed3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot8scritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sols"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x8s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x8s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x8s"}], "]"}], ","}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.79364160744447*^9, 3.793641612397052*^9}, 
   3.793707444101577*^9},
 CellLabel->
  "In[1456]:=",ExpressionUUID->"a97e7159-9454-4065-bb95-6cf35b455ac6"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1Hk0VW+4wPGjKJUfGSo0GSKZkwzH8DwOmc6EKElCKSkSElKGUJQhqQwp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          "]]}, Annotation[#, "Charting`Private`Tag$57602#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF1Xk4VVsfB3BKGSMlUSEpIdNFpLrWrxzHmY+pUiG5piiVoRChMiRSQjJF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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57602#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF1nk4lO/3B3BESbJEWUKSCtmSnZwTY5kxDNEuSSrJnjUSRZREpZIURUj2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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57602#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF1nk8lO/3P3CkCJElhUKS7CQ7OQdjGTNjKYoWVCpJJdnakJAlS6IwlhFF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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57602#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.79364161512011*^9, 
   3.793707483425294*^9, 3.793717670403764*^9, 3.793718172855899*^9, 
   3.793718266664559*^9, 3.793718442500621*^9, 3.793719539045751*^9, 
   3.7938013880313177`*^9, 3.793801472911708*^9, 3.7938015645783987`*^9, 
   3.793801636391767*^9, 3.793801739620564*^9, 3.7945070222936783`*^9, 
   3.794507494472044*^9, 3.794507539441723*^9, 3.7945076613143806`*^9, 
   3.794513108527729*^9, 3.7945131773343287`*^9, 3.7945150303039513`*^9, 
   3.794515314430607*^9, 3.794568640244478*^9, 3.794568999832246*^9, 
   3.794576044305722*^9, 3.794576683350511*^9, 3.794578135235751*^9, 
   3.7945784268994493`*^9, 3.7945793592556353`*^9, 3.7945794877294283`*^9, 
   3.7946565640594263`*^9, 3.7946681165738773`*^9},
 CellLabel->
  "Out[1456]=",ExpressionUUID->"b0290a0f-173b-4f5c-8254-848592487ef2"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5G.pdf\>\"", ",", "figoneshot8scritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5G.png\>\"", ",", "figoneshot8scritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794667968781125*^9, 3.794667977027738*^9}},
 CellLabel->
  "In[1457]:=",ExpressionUUID->"781e1714-914a-475a-bec7-3c06c55120f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot12scrit", " ", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x12s"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x12s"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x12s"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x12s"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x12s"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x12s"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "12"}], ",", "1000"}], 
          "}"}]}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793394861836452*^9, 3.793394918159622*^9}, {
   3.7933951496126957`*^9, 3.7933951633752604`*^9}, {3.79339523317878*^9, 
   3.793395327131968*^9}, {3.793395363113092*^9, 3.793395454093955*^9}, {
   3.793398236334831*^9, 3.7933982401612463`*^9}, {3.793398273947652*^9, 
   3.793398297786425*^9}, {3.793398587977316*^9, 3.793398589049642*^9}, {
   3.793398642868155*^9, 3.7933986473815727`*^9}, {3.793398766872898*^9, 
   3.793398769091921*^9}, {3.793398847935656*^9, 3.793398887738555*^9}, {
   3.7933989372257338`*^9, 3.793398938788555*^9}, {3.79339898752773*^9, 
   3.793398989638323*^9}, {3.793399423963974*^9, 3.793399443278512*^9}, {
   3.7933996196258163`*^9, 3.7933996224000072`*^9}, {3.7933997698848143`*^9, 
   3.7933998152795763`*^9}, {3.793399870324162*^9, 3.793399874653573*^9}, {
   3.793399955092331*^9, 3.793399981729393*^9}, {3.793400297337214*^9, 
   3.793400299363748*^9}, {3.7934003321033993`*^9, 3.793400385420542*^9}, {
   3.7934018012048273`*^9, 3.793401888718988*^9}, {3.793401932418544*^9, 
   3.7934019352989807`*^9}, {3.793402009236326*^9, 3.793402049607609*^9}, {
   3.793442209711054*^9, 3.793442344238595*^9}, {3.793442922320374*^9, 
   3.793442937773024*^9}, {3.793442988076605*^9, 3.7934430062331343`*^9}, {
   3.793443077052331*^9, 3.7934431164279118`*^9}, 3.793443181492978*^9, {
   3.793640604305517*^9, 3.793640631235282*^9}, {3.793640926091655*^9, 
   3.793640928013129*^9}, 3.793641015622568*^9, {3.79364137194876*^9, 
   3.793641374383918*^9}, {3.793707449793639*^9, 3.793707450610125*^9}, {
   3.7937183978205547`*^9, 3.7937183982066517`*^9}, 3.7945073426895533`*^9},
 CellLabel->
  "In[1459]:=",ExpressionUUID->"025a056b-682b-4830-be6c-6359e4d0f323"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF13k8VF/4B3BKRUkRihIVkj1msd/PzNh3smdLErLMSIposUWFksqaNS0S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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57876#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF2Hk8VF/4B3BKUWQvFImQZDfDkMxnhuy7mSglu1EqlYqsFbIULSqUqFSW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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57876#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxFl3k4lW/Qx4kiRGixJLKeI0S2Y32+eOx7iLJL0iZbllOSRNFCqCShTUrS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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57876#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13c81V/8B3CiyMwssrOz5zU/L+517RkRUiEJKaLMrEgLlSQNSQMNslJk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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57876#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k0Vd//P3BTESWkoijVvUimutzBdJ7XPM+UeUwici9SqSRRlKHyLmkw
lAZEhLxLQmQoUoYmEcpQmadS6nc/a/2+vc8/Zz3W2ud11uu19z77dTZ477Xd
ycPFxVXEzcX1v7vpzqGXVcOlOlz//+LTWxPSI5lK/J8pGWmX70le/2uz5tfF
VyRL/nq779yjs5K1f/1B5YReomT7X2eutIpLkPz019EC9+TiJaf/eodTVuH4
BB/+z0J/ol2N1i3/a7LN6NCTU+J/HdHCINKmJf96dYloNzf3+r8u69N7/kJr
4193GkdPJBr959mCylXmtv+ZFsnwatj1n8tXqMxWnf3P/+qvkSke+s8VN8ZD
U1M3/XXXUuWLthn/+Rc7sFIk9z9rEwMCiY//c+Xr91div/znxwL19ftA+uuP
wXwjamYk3BjKE59SW6vD1cEUm3Ig4cvWj83Zyxp0ZDSjaEWeJPDKl6w5ZvxT
B1kVrnsDSUhR9w6/3LuW8OSfj1baR0LOJoJQL6EQR4NoN78eJcGO4iDXfdyQ
yGwLe377FAmkhyoXRrQciSpG8cSu8yRkC48tnW3wIT5mjK2SzSLh/ZrafQoW
IQTXYiWtT3kkmFYHR4rsOEDI7Anwyi4jYfF5TdFTjccI5qubcZ7VJIzS6yXI
LxIIb/rnvHXPSehUt5TWPXmWOHZ148uuThIC9iwbSx9PI7L5PGfTe0lYqSuZ
meqXSdQEXFnr9I0EBaGhsGByDnFvODDQfZaEhPg5FXOfXOK6v8ZDHy4yEs5U
q8gSd4nUQQGh3YJkVMl9buyuvUfE+r12DhYno6dddHfZ8/vEvs85uaHryLDe
IhOX5FlB+PmGze+XJ+OGnKIfqa6K2N6va3pkGxlHjiQ8mrz9hDD2Fk2P0SIj
peZqSXH/U4LR2zN80pCMA5e7ynwjmggFzwJGkjUZvnGrDJ/ubiHW9hyKP+dM
RoM9jeubx0tiqbvZ2zRfMlYk0lw+V7YRC12Sm68Gk4FNhiYX7TqJUZeh/df2
k+HpMRaRs/4t8cIpVqLgNBnFKlM7Hnj3EFVv7PzvnSfD+bnom8GgXuLu9o3l
5ZlkrM21lVE17ifOOjze/qSEDNm5wYYOx0Eipj3xZkMlGY+yRZzOnRomwuxc
55obyFBciPHL6/5KONr8OP+miwzTcubmqb3jhFFr/cCHATJqE+P5Zp5OEHSr
89T+cTKCVGP5FylNEZIWlM4RPlnsont9+UaeJbqMg1byKsmC2ay+xL7+F9Fc
r7lTgCYLFxnhKc9zv4lKQ8HSZUxZyEq/ac6nciFD/6a9hIMs+qcznpPIPPBG
7zmlw7LoHMniJmwWw+5xYf+2E7KYJSkYbNnDD32dIxT6GVkYD/UpIFEAZK21
bbo5slC9q9EQ3CuIIZqD2I5mWaz4IMBX0rIcb8s2ebu9lsUOvlWN3adE0KQ+
WeTdK4tWG9H1/BRR5FGSbYJmZGGUePHu0ngxBKs0phyTlsP7B8+1j9quxIys
9vI7QXJo9yl8Zmi9Fjp9uvUJ++VwNlZ9r5KCFOKuGEf5x8jh2FhApMViaawS
tx/bdFEOIvNldQJ160DlDnyRXiuHgujVd5KVNmD/+7Tkk2vlkTPZ88xunIRf
ydPLfRvlsWqI0b9rqRL0zebrme3yuG1CkedOVcLpxVxH1/fIQ8bjn1faUsqQ
Piw0/m5aHoFfw+0uKatAJ2Bjq43MZvwMn4DHHVVE6VunEBGbkRth6tI/uA08
P/JE1pIVYKIbGTeRSsPaZt0pQkUBZ1NNciQ/0KCW9bbDl6EAiSWnVh0n07HT
hP9SgYUCchu0e2Tu09Fw0Zusu08B/zSJnjv6gYFkDUmN3fUKcMt/Z7GBpgWp
Q3E+93dvAffSFoZtCqBuLW3YFboFx3NTynrLAUtSiTz3kS2osp68ndYLRD3v
HTE9uwW4flj+CIWJPint/d0PtiDtaXKp8lsmbj+aOr1oqSIyq0ZWuivqgfrH
s8yuQBFmTmtnWqYMYG5RdcygXBGtpx1dB2UM4XNpvRWtRhEFi4MfK1kaIoXW
PbimUxFb+ZrCDG4bYnivi2TfgiI8PA0P3/QywuWPDodCLJRgzOx77//eGNw1
prqJ35SgczQ0MmTaDBIiucJRs0pIdBVrK5czh7L7kvchXMq4e9BXgupiDuf5
+lB7cWUUHW5Wa60xR8k2g5y1Wsrgjv6ediLVAn7XCIHcU8qIJI2S5HSt8Py4
WstTBRUE5Qndv+hjA43lz3jOqKvglGXMb6UYG9y66EVzgQpytz5Z/SnbBjEF
SZljDiqQaREaLe3jjH8zxJaIVgHXvSchEz62uLXlyuqA1yp4wHSZfLnHDrrD
x+4u1lXFoZSJTL80B6xP+frj9qgqqOVzEyMOzqj0irpdPKWKmb0nlCwjneFO
WeH08LsqPm5S3d2U6YzLnRrlz3m2Ypp9PGjVN2dISCfsG1u1FUkC52R/xLhA
LFd+So3Yiu99a7Sby12xqHbnt8fJW6Ely0vUqnvg61xPd4fqNoiM7ItJZnjj
+peHTcJJFEx9e/jcUtsfwResNgWco0D+2uuOxQ7+oOn3R9alUaDwVOX0gz3+
aLoiqHToGselEz9XXPbHhLVT8nA5Ba8Ofv95Yt4fOvdn7Wr7Kehnqxdple3G
25itHw4w1LBr7ZYhEblAZKvWqXfoqOH4P8LW1dqB2PNhR5KqvhoUUic0dtoH
got2lBi0VIOyEU9SXHQgZL+0ZNn7qsF/6OG43PtAhFnv8VNJVsOvVR9c807t
gbD0zbFPn9Tw9ffDf/t7ggDHmA/9w2roCFJ6JDMVBHayx7O+UTWsDxyuMFsc
jE5uiZsfv6vh5i++3gDFYFwdOOnetVQdLqNkwYaIYCjfDWhuU1OHv3IX10vB
vbDQU86rOa6OD1H8q7xEQnDkkODF6nh18PaduFggEYK7pQNxVUnqOMWyFhyX
CYG4fIZ3ZZo6pp3at1tuDUHXUpE1D/LV0SjhsX6fTQj2dE6cLGpXx47w65Pu
ySE4vbvUL5NERbD4qiQBbha+4M5JIQUqhGJK8hkCLBhJ5OTuU6EinZmd6bSc
BZ761FFzDSpM6n/f2ynNwgFS2L4fVlR8yqpm5NNZ8OvZFmcbSUVTPM3vYyAL
tWUKtx4dpSKy5YLEDIuFjUkbm+TjqCi70e8zF8HCBy0x4T8pVBz6Vn28NoYF
+/SJf/JuUGHdQFGMSmeB6XA3h+8VFVzCbB7/WhauKt6q3/uaigPlyc8sG1n4
xZs5/K6LClIZQ2djCwvlxclKRYNUXO+amUl6zYKyyN5StwUqtLfuPHFkmIXT
g36vG3hoYLZqhjeOcPKtdP9BEaDhEplczjXJQk6QpbbgChq6SFNiavMsSD1T
qiuTpyFid9Js/hI2DmaTBzco0/AwTjXYaRkbrw9IL0mk0FDhqTA1IcLGWfll
Fj46NAj92Cs6uJqNJXHf2pfb03DgsMXKXhIbfm6fZg860aCjVx40IsdGrVqX
xIA7DSMbRPI/K7BxtP+Za8VuGqTevHx6UZWNWeR98o/ixJ83/bpck42K618v
RRynQSP9rZ2tNhvHBBTt4uJpKOuw3BBDsCHcml997RwN8Rqeg4V6bLRTRvYX
p9HwYly9O8+AjfQLSqrVV2iYdN1JPW/EhqxHwdXumzQYlhzjp5qx8a1m1GEk
n4aUjwFHv5qzUSyrsuxXEQ15w43OyZZs6IwWRkpW0JA5wEfPtmGDz3Z8m3w1
DRl8I1qidmw0lap+oT6l4YGd781gezYcDxftsG+lwSP+fdG0IxtSvRPLfTpo
SFhyzFF6Bxt9+tvqWe9oiNrst1vNiY1bt9hHjvbQcJ7nxAjDmY3gpffUkz/R
QCro/6zkwoZayNS3K8M0xBhEOoi4sjHfRrmeP0oDf5850ctxFS3M5eEUDYuD
/G5kurERd6lErOk7DUcKXyRZurNh/me68c0C51zb4bDwhWMxH/XoQR46JD43
zIZ7sPHmaTh9lp+Ou+0/o8Y4vqpQNsa3jI51OY+vbPdkwzdp9sYKMTqutH+2
L+BYYZLqvnE1HZU1RO4Ux+MOESu3StGxPOBDtpwXG6X/3n9ObKDDfHpW35Tj
g9LfYyxl6SD3iV1w4RjRdE23LXSYlNzP+J8Xf94/GahKh9/XwJ3/G//c+N/b
B9XpUBIoG/1fvLP5PzzjNegwPSWlO8153w4RDYk0go5r2iS/Qo7XhR18cUOf
jjjfaS8njj+9fhBXakLHpzet2pOcfHI1f2rXWtLxSlWc5yDHIRmaM6/s6PDl
kbw/zqkHlfdQfu8OTv79jJ2OHP/yq/AZd6OjKeCleB6nnjVNv9b88aajXkmj
ZZRT75PK2q+W+dPxqKbl4gaOxWcfYQubDpvC2gR7zvy9c/o9x4ig4928QK09
Z34zH+kUGh+iw0VpOVWfM/+KsY+l/eLoOBQgPjLuwMbk0J/2sFN0VCwOMizg
rJ9yc5yOSaGDckeD24WzvvTFq+cz0+m4zc2uPWbNhuB+7uLCDDrSt2zvX+Cs
z9b3zN2V1+nAZnqKvwUbrtdqXr8voOPIuP+TpaZshG2rLVn1hI6t8/Pvz+hy
9qOaTOaZBjp6YtddcgenntRDp5a20PGmUjVKQocNTQ01b563dKRszp23Y7DB
o3t9+egoHVGCz69+VWZjWo/rp/80J96Xm36bFNn4bOA60P+DjtnNz3qMN7PR
YCL+6C0fA9/iR7e6bWIj2eZ4QN0aBpbwq+y+s4qz3+0+OkCGge8uCy32K9hg
O2gxH5IZkMljH/2ynLN/nKZXF6kyAIEPa3oFOPvHy7fusiEDL4IPHV74wUJu
iL5MGJuBhMld2YvesnCZnSk0FsHA5saTTZfaWUgM+zW7+zADfSNyVza0shCy
v6TZ4yQD55UHr/56ygLtKCnS7CoDNxffzpi8x/leJ/N1bmxiQE9yf+dUAgs9
BbWnXm7QwJufZOlfSiy0jvB92ybH8cqkunY5FqoUDcxTFTUwYDP1KHMDC5m5
dUu30zSg2UZevGIlC943niZ2mWtgXQjR4PMzBANXGpIHIzTAo9Bw73ldCEZO
Pz+30KwBY6mFsjDbEPwMaL+0+aAmlsl1ib/KCoY91e2McpQmzIv/ZY6eCUY+
90Ac5bgmAoXuVv2JDoZ72hxLO0kTu9NqHXm9g1Fdt8bYJlsTPeqXrM9sCMYJ
Ga/p/U2acGPu7f96NQgrOkfMG9Zood5MJrz43B5sYfL/9nuohc5FXUXlQQEw
yt6wq2i1DrYF565Oq96JCGmPjb2uBAyWP9otc98L3taqjl1eBKIf7t3FvOUF
yxjuhNd+BEaW5rwIuOgF2eFrE80hBFqUdeY6I73QXjJU9eA4gXfO5cYrmV5Q
NWd7pOYTeFGiuUGl2RNDB2MvG/0iwG2xbDH3Gw8ofnMQem0BwGTxjsF4V5Tb
mz9OsAaulnrFHg92hd4j3VAdO2BXbv1Vmp0rnJNU3ufsALJOXkjtkXJFvOqS
vDAfYNHF2OPUIhcMhFWYih0AItRSaFzdzshc2JhgcR3Q6n0f9t3ICSuWjwvU
zgO2u5kFYa6OePUo4YTJAhDeekLgm5Ejzu4hL37xh2PrwT3hFEeINTnzvuNj
okpPiF4pyHFs3cKYMBN1cmdnZR84QORn+uTaTUyoHxfxt5BywNJBg65QMyan
fy71KR6xw/N/Pjr/sGCitzo+xvm9HU7rR749Ys2El5/mmRWNdhDKvtsZ78DE
et4mm/LrdhB0W/syw4OJ5ceiA5+52kGgbbzuWSgT6z6bTQm32oLv8aXCTZeZ
sB5XvVNTY4N3WvrGPVeZmJ+kflxdZIPCB98+pmcxYZT/b0hUhg2cy7TFxG4y
McGWDo09ZIOiOz1hXMVMpLCvHg6k2cD98iaND/VMCH6x23vurjXKD+TVnp9i
IqDS5FC3hxWS5uzcbGeZ6K6jvBiGFXzCf80s+8HElaJtdqs2WkGYZSEX+5sJ
S1fXyFefLLHTfyw+dIkuvvwp29weaAmx7RQr6/W6mPxhKvEpygKBag/fLjHT
hUJx6nDQYzNUtXbkl1vogsxzhHfguhlWBo1H7bLWRU9gW97BBDM8ziHL1jno
wvnUQa0fDmZYsTqFfdRTFwsT1cHGo6Z4+MNXaC5cF50HO16sJplC6LGw9qdM
XdSUpPo8uWYMT5fNIueu6SJMuXZr+mljlM7p9TNv6EKEOGqSEG4MD9UD8Rl5
ujB8IDxaamSMe1n9Hc5lupz/YxkafcQILsfLg18+00XtgUbnNi0j5Jl4Z1bO
6oKtOldZNmIANcUNOsQPXUS8PXep950BKoU/vn/8U5fzEU9sWd9ggNY2t9XV
XHqI0DQe7sg2wLSbU9ITQT1wfbjTLOtkAB229aGGdXowFKH9Mm3UR2u6zo5X
hnpYmRy6T+q+HpwOL8zYmuihsUK3N/GGHvo8Ks61mekh/UGWo8h5PUyTNF60
W+thv0uzlHG4HiQL1Q1fO+tB57owI1pND95PFNW6gvVg099eI8jJa+brGpEB
znN/ailTvHVMpF4ZrL98UQ+js9JNmqVMUKxKouwuc+LdcKXG5jDBKrYYq8rS
w7rfxVHmcUyM7D/acilfDx3LavNyjZn4vGjgtE2NHnZkRkqmtgId64uWPBrR
Q+T6flvZtwTCXh6uDh3Xw6mFB/2FjwisiDE9oDClB3WxA93bswnYDPQPXfiu
h7biN9E8ewg0569qYPPqI/5i5JlKLgJ1jENx8pL6nP4pP6hYRQeldka8qfr6
kBIe+vdythZOmpXHShnpozprgc/otBZc9TYL5JjoI8cvnCywTws8FKFlZZb6
sBAXPNxiogVLsRer3uzQR+gl+nX/SU0MtToqSAXpY+mFk28rjDSxxtLP5vo/
+uikshUIHg2MGLxuU0zTx7jvseDUUQaqtI0dS9P1YTAvGrPwjgE/JQWXpxn6
cMlTfixYwsC9paO+Q7f1kb3qnMjyXQyYPwvfr1ipj1P2pcX5rZxz1Dg2o2RA
H2fbLure5vSZr9z9XVWH9SFK9w29kcnp+8LNJPO/6iPavYFUkkxDU5bouWvj
+jARGa7hCqZB/OeVuLPz+hDrc/rjuoWGW3fKgkKEDRAk6r9c7DYVrWJDmopU
A5iLNRpMFapj4+Zn32/SDZDBOxLanamOcKKgdJOmAWCfN/v6jDrW7AlTWQsD
eFEOPZwJVYdvHdcmQVMDLG4QS3xHV8f3CEnBITcDdOluy9GsU8OGD6ZvrsUa
YMy59sXoIAUJNZqFDicNkLzyj4DPWwombyrG8Z8ygOUg7/DnJgpq2MJqgSkG
kApc7bS6gAJfgVfJ2y4ZQHjr6rVy4RTcojgZVd81gEsGr9rXRRQoJ+wq635v
gNhjs0UJW7dBg3Y8VXKbIbb9YUTeuqOKTm9J6hU1Q1iMpz7gv6aK0KSC1zI0
Q7xYNGcXkqaK/M9v1shrGUK6MNbfLUYV61KVsqiGhnjDqurLcVIFz0TnHTtn
Q9QW8fQP8KviWe7m+sRjhlj/Mzi+ukMZrute/OBuM8Thc0dv6ZxRhLAku/Rh
hyF4vQU7rhxRRDXnkA9/Y4g+1qfTy/YoQnaJy9DQB0O8qrtAXWekiLGpgc4X
Q4YItPRM5/69Bccaf9+78tsQH7yzBv4N3oJbYcrBDAUjBAtnnPdzUcBMU2Jf
SLQRzJ7MFy64yaNLqMP/V4wRjEv4FPqt5FFjLjV2Is4I79Xk1rUx5ZHSkvvz
6ikjjMk46b0iy0PhVb148z9GUDIblDMflYP7W26jzblGqJXwTtwULYeng+F5
va+MEGp5FkIFskjjcw+zJRlD50GsPWsjGSu6S7N5ao1BuWGWvIa9EYsOR9sz
WCbIGLEyqOhaD67b7oV9Yqaw+r3lycKjtWCnFyaK1ZiiXmwisadmNR5tOSkg
GmyGsCOnU+IIcYiashWPCZuDfLt3L9NQFF1KrW0HKszB7xhg6FW6FHevEqRP
7hZonDA939vCD7dCqqj0bwsM8t01FYzlxdHYrOiuXEvIks9T9n7+TSyL4Df1
umOJuHImj33jbyLdP0hsoNASwr0rz5vc+U3cM2NcGyuxBF3q4ZJd4b+JAdGX
tTyPLaG5M1kgcPFvwuwql8DmNkt4/SOSdX7LArHqvkdS+E9LPObn2rTv2E/i
zpD0JWFzK5wz0o2b9fpOnLwS69ltaYWojYrqDKPvhK/tCLnAxgqyOnc0UhS/
E1IVFXcttltBW2NWO3JujkhIdnl62tsKfY4KHfpJc4Q/9eKE4AErPM+zq7n2
eJbYeFzcmP+GFUQkef8x3zpD/KYfWvb6lhXcHH/sWCY5Q7wd6X91I88KlIGb
33q5ZoiU7ffcDIuswB0SfeNp6zTxR8E2NLbCCg6kbESxpomul8lXedusULZT
8+7NsimiPG7Op63DCoonn1zOyZgiUjU9Nl97Y4WbZH76/ZNThFmOcolutxW+
fvWeEXeZIh7sb26MHrZC6Fqqyb9cU8R5JfVkm29W2KvTl2X7ZZJg9V223zBm
hfRwM8qftklC3nxPT9W0FWJnQtrP3Jwk+Ljbr6fMWUHNL7oh4swk8bFUM8Bz
nlM/7ifPQiIniYqAayqqC1bIrlfvPrRzkriwXmjmzx8r7C5/++eS1STx/wBa
iqOO
          "]]}, Annotation[#, "Charting`Private`Tag$57876#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13c41f//P3BFkbJlK+OQZGWdc5Bzd47svQ4yK+s0lFSkUDKz0pIGKSpE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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57876#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFt3k81O/3/6+SELJlL2VfZhhbGMs8mBnZd1F2SpIlkm0qSylCWihE0aaQ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57876#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFuHc81f///28V2StbZe+R7RzO82Yee0RSKSNRREhK9glNURqSIqWFkoRK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          "]]}, 
        Annotation[#, "Charting`Private`Tag$57876#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[169, 7], 1000}, {24.142857142857142`, 1000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 800}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7934430926665297`*^9, 3.793443116729176*^9}, 
   3.793443193686583*^9, 3.7934690595887623`*^9, 3.7934851458564987`*^9, 
   3.793485626542159*^9, 3.793529275638933*^9, 3.7935297623217793`*^9, {
   3.793529802940392*^9, 3.7935299218475113`*^9}, {3.793530270676573*^9, 
   3.793530283999229*^9}, 3.793531393229205*^9, 3.7935321096505136`*^9, 
   3.793538240605304*^9, 3.793628682380995*^9, 3.793631362438917*^9, 
   3.793632431638509*^9, 3.793632610898789*^9, 3.793632892708564*^9, 
   3.7936351358708353`*^9, 3.793640073838176*^9, 3.7936401129967937`*^9, 
   3.7936402180988493`*^9, 3.793640631982995*^9, 3.7936407377176723`*^9, 
   3.793640928449429*^9, {3.7936410162773647`*^9, 3.793641029251762*^9}, {
   3.7936413750464907`*^9, 3.793641392337468*^9}, 3.793707483819921*^9, 
   3.7937176709745083`*^9, 3.793718173467409*^9, 3.793718267006864*^9, {
   3.793718398618573*^9, 3.79371844300532*^9}, 3.793719539392353*^9, 
   3.793801388464744*^9, 3.793801473275423*^9, 3.7938015650299273`*^9, 
   3.793801636731715*^9, 3.7938017399793653`*^9, 3.794507022829624*^9, 
   3.7945073432354803`*^9, 3.7945074948428907`*^9, 3.794507539781345*^9, 
   3.794507661646035*^9, 3.794513108950261*^9, 3.794513177725816*^9, 
   3.794515030674335*^9, 3.79451531481456*^9, 3.794568640585038*^9, 
   3.7945690003655987`*^9, 3.794576044730104*^9, 3.794576683761204*^9, 
   3.7945781361323843`*^9, 3.794578427242117*^9, 3.794579359596012*^9, 
   3.794579488160967*^9, 3.794656567113922*^9, 3.794668117661565*^9},
 CellLabel->
  "Out[1459]=",ExpressionUUID->"8ea309fa-731a-4e80-afe2-581a9389c2a7"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5C.pdf\>\"", ",", "figoneshot12scrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5C.png\>\"", ",", "figoneshot12scrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7946679942177362`*^9, 3.794668002984524*^9}},
 CellLabel->
  "In[1460]:=",ExpressionUUID->"368eaa77-4c0d-4dea-aaec-edb776e8fbac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot12scritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sols"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x12s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x12s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x12s"}], "]"}], ","}],
      "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.793641626778944*^9, 3.7936416332225246`*^9}, 
   3.793707454354916*^9},
 CellLabel->
  "In[1462]:=",ExpressionUUID->"88b5f297-e507-4122-933e-7fe6b28a3431"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1Hk0VW+4wPGjKJUfGSo0GSKZkwzH8DwOmc6EKElCKSkSElKGUJQhqQwp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          "]]}, Annotation[#, "Charting`Private`Tag$58188#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k0Vl3UAHCkeMuQIRnyljGEVDJWZwvPPGSoVKKERMZMKWOmFEpSmaIM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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58188#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13c81e/7B3BKEUJokCSVkCJ75brIOMdZRkMqSSopkpWS0TArVCoJEZIt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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58188#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13k0lP/3AHCkCFFooU3Kkj2RLLkXY52xRlS2pFJSkqSyh2hBkW1mGKHF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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58188#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.7936416375070543`*^9, 
   3.793707484256727*^9, 3.7937176713672237`*^9, 3.793718173936474*^9, 
   3.793718267309087*^9, 3.7937184438951387`*^9, 3.793719539712245*^9, 
   3.793801390904216*^9, 3.7938014735562353`*^9, 3.793801567236689*^9, 
   3.7938016370086107`*^9, 3.793801740330552*^9, 3.7945070232745743`*^9, 
   3.794507495114111*^9, 3.794507540052476*^9, 3.794507661952422*^9, 
   3.794513109247881*^9, 3.794513178032401*^9, 3.794515315334182*^9, 
   3.794568640881857*^9, 3.794569000979068*^9, 3.794576047574548*^9, 
   3.7945766840868073`*^9, 3.7945781369714823`*^9, 3.794578427563827*^9, 
   3.794579359945434*^9, 3.794579488714509*^9, 3.794656568813261*^9, 
   3.794668118700159*^9},
 CellLabel->
  "Out[1462]=",ExpressionUUID->"382dcf5a-79d5-408d-acd0-4dc27cc73c49"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5H.pdf\>\"", ",", "figoneshot12scritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5H.png\>\"", ",", "figoneshot12scritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668011101901*^9, 3.794668018134688*^9}},
 CellLabel->
  "In[1463]:=",ExpressionUUID->"b9d41b6d-6f14-4b48-869d-1e2f98561bfe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot20scrit", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2x20s"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2x20s"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2x20s"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2x20s"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2x20s"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2x20s"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "20"}], ",", "1000"}], 
          "}"}]}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793394861836452*^9, 3.793394918159622*^9}, {
   3.7933951496126957`*^9, 3.7933951633752604`*^9}, {3.79339523317878*^9, 
   3.793395327131968*^9}, {3.793395363113092*^9, 3.793395454093955*^9}, {
   3.793398236334831*^9, 3.7933982401612463`*^9}, {3.793398273947652*^9, 
   3.793398297786425*^9}, {3.793398587977316*^9, 3.793398589049642*^9}, {
   3.793398642868155*^9, 3.7933986473815727`*^9}, {3.793398766872898*^9, 
   3.793398769091921*^9}, {3.793398847935656*^9, 3.793398887738555*^9}, {
   3.7933989372257338`*^9, 3.793398938788555*^9}, {3.79339898752773*^9, 
   3.793398989638323*^9}, {3.793399423963974*^9, 3.793399443278512*^9}, {
   3.7933996196258163`*^9, 3.7933996224000072`*^9}, {3.7933997698848143`*^9, 
   3.7933998152795763`*^9}, {3.793399870324162*^9, 3.793399874653573*^9}, {
   3.793399955092331*^9, 3.793399981729393*^9}, {3.793400297337214*^9, 
   3.793400299363748*^9}, {3.7934003321033993`*^9, 3.793400385420542*^9}, {
   3.7934018012048273`*^9, 3.793401888718988*^9}, {3.793401932418544*^9, 
   3.7934019352989807`*^9}, {3.793402009236326*^9, 3.793402049607609*^9}, {
   3.793442209711054*^9, 3.793442344238595*^9}, {3.793442922320374*^9, 
   3.793442937773024*^9}, {3.793442988076605*^9, 3.7934430062331343`*^9}, {
   3.793443077052331*^9, 3.793443173022769*^9}, {3.7936406472978*^9, 
   3.793640665968298*^9}, {3.793640705579446*^9, 3.793640707850029*^9}, {
   3.793640933155513*^9, 3.793640996078887*^9}, {3.793641378889105*^9, 
   3.793641381201693*^9}, {3.793707457526559*^9, 3.793707458707697*^9}, 
   3.793718353427245*^9, {3.793718402938336*^9, 3.793718403333542*^9}, 
   3.794507352297159*^9},
 CellLabel->
  "In[1465]:=",ExpressionUUID->"8ab1dd75-39eb-471a-a631-84e8f9ed862a"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF13k8VF/4B3BKRUkRihIVkj1msd/PzNh3smdLErLMSIposUWFksqaNS0S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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58462#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k4VG/YB3CiSGVPVFK2kN0MEeaLGTszlgkJkd1UlEgSIaHQrySUUFpt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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58462#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxFmHc01X/8x62kYcuKjOyRvcd9ci8X18wsZRZKiGSVcQsRIS2pUCmFKCMV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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58462#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxFl3c8ll/4x4kyskciSbKzN+F8eB7zMYuUkCSKKCsash5SGQ3tgUQJISNR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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58462#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k0Vd//P3BTESWkoijVvUimutzBdJ7XPM+UeUwici9SqSRRlKHyLmkw
lAZEhLxLQmQoUoYmEcpQmadS6nc/a/2+vc8/Zz3W2ud11uu19z77dTZ477Xd
ycPFxVXEzcX1v7vpzqGXVcOlOlz//+LTWxPSI5lK/J8pGWmX70le/2uz5tfF
VyRL/nq779yjs5K1f/1B5YReomT7X2eutIpLkPz019EC9+TiJaf/eodTVuH4
BB/+z0J/ol2N1i3/a7LN6NCTU+J/HdHCINKmJf96dYloNzf3+r8u69N7/kJr
4193GkdPJBr959mCylXmtv+ZFsnwatj1n8tXqMxWnf3P/+qvkSke+s8VN8ZD
U1M3/XXXUuWLthn/+Rc7sFIk9z9rEwMCiY//c+Xr91div/znxwL19ftA+uuP
wXwjamYk3BjKE59SW6vD1cEUm3Ig4cvWj83Zyxp0ZDSjaEWeJPDKl6w5ZvxT
B1kVrnsDSUhR9w6/3LuW8OSfj1baR0LOJoJQL6EQR4NoN78eJcGO4iDXfdyQ
yGwLe377FAmkhyoXRrQciSpG8cSu8yRkC48tnW3wIT5mjK2SzSLh/ZrafQoW
IQTXYiWtT3kkmFYHR4rsOEDI7Anwyi4jYfF5TdFTjccI5qubcZ7VJIzS6yXI
LxIIb/rnvHXPSehUt5TWPXmWOHZ148uuThIC9iwbSx9PI7L5PGfTe0lYqSuZ
meqXSdQEXFnr9I0EBaGhsGByDnFvODDQfZaEhPg5FXOfXOK6v8ZDHy4yEs5U
q8gSd4nUQQGh3YJkVMl9buyuvUfE+r12DhYno6dddHfZ8/vEvs85uaHryLDe
IhOX5FlB+PmGze+XJ+OGnKIfqa6K2N6va3pkGxlHjiQ8mrz9hDD2Fk2P0SIj
peZqSXH/U4LR2zN80pCMA5e7ynwjmggFzwJGkjUZvnGrDJ/ubiHW9hyKP+dM
RoM9jeubx0tiqbvZ2zRfMlYk0lw+V7YRC12Sm68Gk4FNhiYX7TqJUZeh/df2
k+HpMRaRs/4t8cIpVqLgNBnFKlM7Hnj3EFVv7PzvnSfD+bnom8GgXuLu9o3l
5ZlkrM21lVE17ifOOjze/qSEDNm5wYYOx0Eipj3xZkMlGY+yRZzOnRomwuxc
55obyFBciPHL6/5KONr8OP+miwzTcubmqb3jhFFr/cCHATJqE+P5Zp5OEHSr
89T+cTKCVGP5FylNEZIWlM4RPlnsont9+UaeJbqMg1byKsmC2ay+xL7+F9Fc
r7lTgCYLFxnhKc9zv4lKQ8HSZUxZyEq/ac6nciFD/6a9hIMs+qcznpPIPPBG
7zmlw7LoHMniJmwWw+5xYf+2E7KYJSkYbNnDD32dIxT6GVkYD/UpIFEAZK21
bbo5slC9q9EQ3CuIIZqD2I5mWaz4IMBX0rIcb8s2ebu9lsUOvlWN3adE0KQ+
WeTdK4tWG9H1/BRR5FGSbYJmZGGUePHu0ngxBKs0phyTlsP7B8+1j9quxIys
9vI7QXJo9yl8Zmi9Fjp9uvUJ++VwNlZ9r5KCFOKuGEf5x8jh2FhApMViaawS
tx/bdFEOIvNldQJ160DlDnyRXiuHgujVd5KVNmD/+7Tkk2vlkTPZ88xunIRf
ydPLfRvlsWqI0b9rqRL0zebrme3yuG1CkedOVcLpxVxH1/fIQ8bjn1faUsqQ
Piw0/m5aHoFfw+0uKatAJ2Bjq43MZvwMn4DHHVVE6VunEBGbkRth6tI/uA08
P/JE1pIVYKIbGTeRSsPaZt0pQkUBZ1NNciQ/0KCW9bbDl6EAiSWnVh0n07HT
hP9SgYUCchu0e2Tu09Fw0Zusu08B/zSJnjv6gYFkDUmN3fUKcMt/Z7GBpgWp
Q3E+93dvAffSFoZtCqBuLW3YFboFx3NTynrLAUtSiTz3kS2osp68ndYLRD3v
HTE9uwW4flj+CIWJPint/d0PtiDtaXKp8lsmbj+aOr1oqSIyq0ZWuivqgfrH
s8yuQBFmTmtnWqYMYG5RdcygXBGtpx1dB2UM4XNpvRWtRhEFi4MfK1kaIoXW
PbimUxFb+ZrCDG4bYnivi2TfgiI8PA0P3/QywuWPDodCLJRgzOx77//eGNw1
prqJ35SgczQ0MmTaDBIiucJRs0pIdBVrK5czh7L7kvchXMq4e9BXgupiDuf5
+lB7cWUUHW5Wa60xR8k2g5y1Wsrgjv6ediLVAn7XCIHcU8qIJI2S5HSt8Py4
WstTBRUE5Qndv+hjA43lz3jOqKvglGXMb6UYG9y66EVzgQpytz5Z/SnbBjEF
SZljDiqQaREaLe3jjH8zxJaIVgHXvSchEz62uLXlyuqA1yp4wHSZfLnHDrrD
x+4u1lXFoZSJTL80B6xP+frj9qgqqOVzEyMOzqj0irpdPKWKmb0nlCwjneFO
WeH08LsqPm5S3d2U6YzLnRrlz3m2Ypp9PGjVN2dISCfsG1u1FUkC52R/xLhA
LFd+So3Yiu99a7Sby12xqHbnt8fJW6Ely0vUqnvg61xPd4fqNoiM7ItJZnjj
+peHTcJJFEx9e/jcUtsfwResNgWco0D+2uuOxQ7+oOn3R9alUaDwVOX0gz3+
aLoiqHToGselEz9XXPbHhLVT8nA5Ba8Ofv95Yt4fOvdn7Wr7Kehnqxdple3G
25itHw4w1LBr7ZYhEblAZKvWqXfoqOH4P8LW1dqB2PNhR5KqvhoUUic0dtoH
got2lBi0VIOyEU9SXHQgZL+0ZNn7qsF/6OG43PtAhFnv8VNJVsOvVR9c807t
gbD0zbFPn9Tw9ffDf/t7ggDHmA/9w2roCFJ6JDMVBHayx7O+UTWsDxyuMFsc
jE5uiZsfv6vh5i++3gDFYFwdOOnetVQdLqNkwYaIYCjfDWhuU1OHv3IX10vB
vbDQU86rOa6OD1H8q7xEQnDkkODF6nh18PaduFggEYK7pQNxVUnqOMWyFhyX
CYG4fIZ3ZZo6pp3at1tuDUHXUpE1D/LV0SjhsX6fTQj2dE6cLGpXx47w65Pu
ySE4vbvUL5NERbD4qiQBbha+4M5JIQUqhGJK8hkCLBhJ5OTuU6EinZmd6bSc
BZ761FFzDSpM6n/f2ynNwgFS2L4fVlR8yqpm5NNZ8OvZFmcbSUVTPM3vYyAL
tWUKtx4dpSKy5YLEDIuFjUkbm+TjqCi70e8zF8HCBy0x4T8pVBz6Vn28NoYF
+/SJf/JuUGHdQFGMSmeB6XA3h+8VFVzCbB7/WhauKt6q3/uaigPlyc8sG1n4
xZs5/K6LClIZQ2djCwvlxclKRYNUXO+amUl6zYKyyN5StwUqtLfuPHFkmIXT
g36vG3hoYLZqhjeOcPKtdP9BEaDhEplczjXJQk6QpbbgChq6SFNiavMsSD1T
qiuTpyFid9Js/hI2DmaTBzco0/AwTjXYaRkbrw9IL0mk0FDhqTA1IcLGWfll
Fj46NAj92Cs6uJqNJXHf2pfb03DgsMXKXhIbfm6fZg860aCjVx40IsdGrVqX
xIA7DSMbRPI/K7BxtP+Za8VuGqTevHx6UZWNWeR98o/ixJ83/bpck42K618v
RRynQSP9rZ2tNhvHBBTt4uJpKOuw3BBDsCHcml997RwN8Rqeg4V6bLRTRvYX
p9HwYly9O8+AjfQLSqrVV2iYdN1JPW/EhqxHwdXumzQYlhzjp5qx8a1m1GEk
n4aUjwFHv5qzUSyrsuxXEQ15w43OyZZs6IwWRkpW0JA5wEfPtmGDz3Z8m3w1
DRl8I1qidmw0lap+oT6l4YGd781gezYcDxftsG+lwSP+fdG0IxtSvRPLfTpo
SFhyzFF6Bxt9+tvqWe9oiNrst1vNiY1bt9hHjvbQcJ7nxAjDmY3gpffUkz/R
QCro/6zkwoZayNS3K8M0xBhEOoi4sjHfRrmeP0oDf5850ctxFS3M5eEUDYuD
/G5kurERd6lErOk7DUcKXyRZurNh/me68c0C51zb4bDwhWMxH/XoQR46JD43
zIZ7sPHmaTh9lp+Ou+0/o8Y4vqpQNsa3jI51OY+vbPdkwzdp9sYKMTqutH+2
L+BYYZLqvnE1HZU1RO4Ux+MOESu3StGxPOBDtpwXG6X/3n9ObKDDfHpW35Tj
g9LfYyxl6SD3iV1w4RjRdE23LXSYlNzP+J8Xf94/GahKh9/XwJ3/G//c+N/b
B9XpUBIoG/1fvLP5PzzjNegwPSWlO8153w4RDYk0go5r2iS/Qo7XhR18cUOf
jjjfaS8njj+9fhBXakLHpzet2pOcfHI1f2rXWtLxSlWc5yDHIRmaM6/s6PDl
kbw/zqkHlfdQfu8OTv79jJ2OHP/yq/AZd6OjKeCleB6nnjVNv9b88aajXkmj
ZZRT75PK2q+W+dPxqKbl4gaOxWcfYQubDpvC2gR7zvy9c/o9x4ig4928QK09
Z34zH+kUGh+iw0VpOVWfM/+KsY+l/eLoOBQgPjLuwMbk0J/2sFN0VCwOMizg
rJ9yc5yOSaGDckeD24WzvvTFq+cz0+m4zc2uPWbNhuB+7uLCDDrSt2zvX+Cs
z9b3zN2V1+nAZnqKvwUbrtdqXr8voOPIuP+TpaZshG2rLVn1hI6t8/Pvz+hy
9qOaTOaZBjp6YtddcgenntRDp5a20PGmUjVKQocNTQ01b563dKRszp23Y7DB
o3t9+egoHVGCz69+VWZjWo/rp/80J96Xm36bFNn4bOA60P+DjtnNz3qMN7PR
YCL+6C0fA9/iR7e6bWIj2eZ4QN0aBpbwq+y+s4qz3+0+OkCGge8uCy32K9hg
O2gxH5IZkMljH/2ynLN/nKZXF6kyAIEPa3oFOPvHy7fusiEDL4IPHV74wUJu
iL5MGJuBhMld2YvesnCZnSk0FsHA5saTTZfaWUgM+zW7+zADfSNyVza0shCy
v6TZ4yQD55UHr/56ygLtKCnS7CoDNxffzpi8x/leJ/N1bmxiQE9yf+dUAgs9
BbWnXm7QwJufZOlfSiy0jvB92ybH8cqkunY5FqoUDcxTFTUwYDP1KHMDC5m5
dUu30zSg2UZevGIlC943niZ2mWtgXQjR4PMzBANXGpIHIzTAo9Bw73ldCEZO
Pz+30KwBY6mFsjDbEPwMaL+0+aAmlsl1ib/KCoY91e2McpQmzIv/ZY6eCUY+
90Ac5bgmAoXuVv2JDoZ72hxLO0kTu9NqHXm9g1Fdt8bYJlsTPeqXrM9sCMYJ
Ga/p/U2acGPu7f96NQgrOkfMG9Zood5MJrz43B5sYfL/9nuohc5FXUXlQQEw
yt6wq2i1DrYF565Oq96JCGmPjb2uBAyWP9otc98L3taqjl1eBKIf7t3FvOUF
yxjuhNd+BEaW5rwIuOgF2eFrE80hBFqUdeY6I73QXjJU9eA4gXfO5cYrmV5Q
NWd7pOYTeFGiuUGl2RNDB2MvG/0iwG2xbDH3Gw8ofnMQem0BwGTxjsF4V5Tb
mz9OsAaulnrFHg92hd4j3VAdO2BXbv1Vmp0rnJNU3ufsALJOXkjtkXJFvOqS
vDAfYNHF2OPUIhcMhFWYih0AItRSaFzdzshc2JhgcR3Q6n0f9t3ICSuWjwvU
zgO2u5kFYa6OePUo4YTJAhDeekLgm5Ejzu4hL37xh2PrwT3hFEeINTnzvuNj
okpPiF4pyHFs3cKYMBN1cmdnZR84QORn+uTaTUyoHxfxt5BywNJBg65QMyan
fy71KR6xw/N/Pjr/sGCitzo+xvm9HU7rR749Ys2El5/mmRWNdhDKvtsZ78DE
et4mm/LrdhB0W/syw4OJ5ceiA5+52kGgbbzuWSgT6z6bTQm32oLv8aXCTZeZ
sB5XvVNTY4N3WvrGPVeZmJ+kflxdZIPCB98+pmcxYZT/b0hUhg2cy7TFxG4y
McGWDo09ZIOiOz1hXMVMpLCvHg6k2cD98iaND/VMCH6x23vurjXKD+TVnp9i
IqDS5FC3hxWS5uzcbGeZ6K6jvBiGFXzCf80s+8HElaJtdqs2WkGYZSEX+5sJ
S1fXyFefLLHTfyw+dIkuvvwp29weaAmx7RQr6/W6mPxhKvEpygKBag/fLjHT
hUJx6nDQYzNUtXbkl1vogsxzhHfguhlWBo1H7bLWRU9gW97BBDM8ziHL1jno
wvnUQa0fDmZYsTqFfdRTFwsT1cHGo6Z4+MNXaC5cF50HO16sJplC6LGw9qdM
XdSUpPo8uWYMT5fNIueu6SJMuXZr+mljlM7p9TNv6EKEOGqSEG4MD9UD8Rl5
ujB8IDxaamSMe1n9Hc5lupz/YxkafcQILsfLg18+00XtgUbnNi0j5Jl4Z1bO
6oKtOldZNmIANcUNOsQPXUS8PXep950BKoU/vn/8U5fzEU9sWd9ggNY2t9XV
XHqI0DQe7sg2wLSbU9ITQT1wfbjTLOtkAB229aGGdXowFKH9Mm3UR2u6zo5X
hnpYmRy6T+q+HpwOL8zYmuihsUK3N/GGHvo8Ks61mekh/UGWo8h5PUyTNF60
W+thv0uzlHG4HiQL1Q1fO+tB57owI1pND95PFNW6gvVg099eI8jJa+brGpEB
znN/ailTvHVMpF4ZrL98UQ+js9JNmqVMUKxKouwuc+LdcKXG5jDBKrYYq8rS
w7rfxVHmcUyM7D/acilfDx3LavNyjZn4vGjgtE2NHnZkRkqmtgId64uWPBrR
Q+T6flvZtwTCXh6uDh3Xw6mFB/2FjwisiDE9oDClB3WxA93bswnYDPQPXfiu
h7biN9E8ewg0569qYPPqI/5i5JlKLgJ1jENx8pL6nP4pP6hYRQeldka8qfr6
kBIe+vdythZOmpXHShnpozprgc/otBZc9TYL5JjoI8cvnCywTws8FKFlZZb6
sBAXPNxiogVLsRer3uzQR+gl+nX/SU0MtToqSAXpY+mFk28rjDSxxtLP5vo/
+uikshUIHg2MGLxuU0zTx7jvseDUUQaqtI0dS9P1YTAvGrPwjgE/JQWXpxn6
cMlTfixYwsC9paO+Q7f1kb3qnMjyXQyYPwvfr1ipj1P2pcX5rZxz1Dg2o2RA
H2fbLure5vSZr9z9XVWH9SFK9w29kcnp+8LNJPO/6iPavYFUkkxDU5bouWvj
+jARGa7hCqZB/OeVuLPz+hDrc/rjuoWGW3fKgkKEDRAk6r9c7DYVrWJDmopU
A5iLNRpMFapj4+Zn32/SDZDBOxLanamOcKKgdJOmAWCfN/v6jDrW7AlTWQsD
eFEOPZwJVYdvHdcmQVMDLG4QS3xHV8f3CEnBITcDdOluy9GsU8OGD6ZvrsUa
YMy59sXoIAUJNZqFDicNkLzyj4DPWwombyrG8Z8ygOUg7/DnJgpq2MJqgSkG
kApc7bS6gAJfgVfJ2y4ZQHjr6rVy4RTcojgZVd81gEsGr9rXRRQoJ+wq635v
gNhjs0UJW7dBg3Y8VXKbIbb9YUTeuqOKTm9J6hU1Q1iMpz7gv6aK0KSC1zI0
Q7xYNGcXkqaK/M9v1shrGUK6MNbfLUYV61KVsqiGhnjDqurLcVIFz0TnHTtn
Q9QW8fQP8KviWe7m+sRjhlj/Mzi+ukMZrute/OBuM8Thc0dv6ZxRhLAku/Rh
hyF4vQU7rhxRRDXnkA9/Y4g+1qfTy/YoQnaJy9DQB0O8qrtAXWekiLGpgc4X
Q4YItPRM5/69Bccaf9+78tsQH7yzBv4N3oJbYcrBDAUjBAtnnPdzUcBMU2Jf
SLQRzJ7MFy64yaNLqMP/V4wRjEv4FPqt5FFjLjV2Is4I79Xk1rUx5ZHSkvvz
6ikjjMk46b0iy0PhVb148z9GUDIblDMflYP7W26jzblGqJXwTtwULYeng+F5
va+MEGp5FkIFskjjcw+zJRlD50GsPWsjGSu6S7N5ao1BuWGWvIa9EYsOR9sz
WCbIGLEyqOhaD67b7oV9Yqaw+r3lycKjtWCnFyaK1ZiiXmwisadmNR5tOSkg
GmyGsCOnU+IIcYiashWPCZuDfLt3L9NQFF1KrW0HKszB7xhg6FW6FHevEqRP
7hZonDA939vCD7dCqqj0bwsM8t01FYzlxdHYrOiuXEvIks9T9n7+TSyL4Df1
umOJuHImj33jbyLdP0hsoNASwr0rz5vc+U3cM2NcGyuxBF3q4ZJd4b+JAdGX
tTyPLaG5M1kgcPFvwuwql8DmNkt4/SOSdX7LArHqvkdS+E9LPObn2rTv2E/i
zpD0JWFzK5wz0o2b9fpOnLwS69ltaYWojYrqDKPvhK/tCLnAxgqyOnc0UhS/
E1IVFXcttltBW2NWO3JujkhIdnl62tsKfY4KHfpJc4Q/9eKE4AErPM+zq7n2
eJbYeFzcmP+GFUQkef8x3zpD/KYfWvb6lhXcHH/sWCY5Q7wd6X91I88KlIGb
33q5ZoiU7ffcDIuswB0SfeNp6zTxR8E2NLbCCg6kbESxpomul8lXedusULZT
8+7NsimiPG7Op63DCoonn1zOyZgiUjU9Nl97Y4WbZH76/ZNThFmOcolutxW+
fvWeEXeZIh7sb26MHrZC6Fqqyb9cU8R5JfVkm29W2KvTl2X7ZZJg9V223zBm
hfRwM8qftklC3nxPT9W0FWJnQtrP3Jwk+Ljbr6fMWUHNL7oh4swk8bFUM8Bz
nlM/7ifPQiIniYqAayqqC1bIrlfvPrRzkriwXmjmzx8r7C5/++eS1STx/wBa
iqOO
          "]]}, Annotation[#, "Charting`Private`Tag$58462#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3c41f///1WKRGZDIesg2eugOHfr2OvgHJskWYcy2qUSoUKSSsNICoWQ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58462#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFt3c81f///68Skuy998re+9zOOcbh2BERIVFCSKXMo8jISCUzlJQRQlEJ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58462#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFt3c81f///08pKiMjmZGQTfY8j9uxx+EglYaZVDJKISXrRFJWU1JaVFJk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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58462#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[225, 7], 1000}, {32.142857142857146`, 1000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 800}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793443144245936*^9, 3.793443173348229*^9}, 
   3.793443209441594*^9, 3.793469059897922*^9, 3.793485147612919*^9, 
   3.793485628506813*^9, 3.793529276031761*^9, 3.793529762565795*^9, {
   3.793529803230294*^9, 3.793529922140222*^9}, {3.793530270960762*^9, 
   3.793530284504855*^9}, 3.79353139532828*^9, 3.793532112019189*^9, 
   3.793538241081479*^9, 3.793628682718582*^9, 3.793631362738474*^9, 
   3.793632431936298*^9, 3.793632611471447*^9, 3.7936328930369263`*^9, 
   3.793635136477975*^9, 3.793640076054871*^9, 3.793640113444213*^9, 
   3.7936402184188337`*^9, {3.793640708734174*^9, 3.793640738153433*^9}, {
   3.79364093528004*^9, 3.7936409965058403`*^9}, 3.7936410297184362`*^9, {
   3.79364138168408*^9, 3.793641392771151*^9}, 3.793707484796719*^9, 
   3.7937176718273373`*^9, 3.793718174359255*^9, 3.793718267674151*^9, 
   3.793718354085444*^9, {3.793718403764099*^9, 3.793718444527411*^9}, 
   3.793719540078828*^9, 3.793801391339316*^9, 3.793801473892439*^9, 
   3.793801567695167*^9, 3.793801637363703*^9, 3.793801740733006*^9, 
   3.7945070237922163`*^9, 3.794507352829672*^9, 3.7945074954424143`*^9, 
   3.794507540402739*^9, 3.794507662318475*^9, 3.7945131096016617`*^9, 
   3.794513178382044*^9, 3.794515315816852*^9, 3.794568641239588*^9, 
   3.79456900171702*^9, 3.794576048210988*^9, 3.7945766844837017`*^9, 
   3.794578137423251*^9, 3.794578427929243*^9, 3.794579360343011*^9, 
   3.794579489358379*^9, 3.794656570725316*^9, 3.7946681197854767`*^9},
 CellLabel->
  "Out[1465]=",ExpressionUUID->"418d9e9e-26f4-42cd-8d06-a129beda72af"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5D.pdf\>\"", ",", "figoneshot20scrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5D.png\>\"", ",", "figoneshot20scrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668028065477*^9, 3.794668035724876*^9}},
 CellLabel->
  "In[1466]:=",ExpressionUUID->"2f70505f-8939-452a-ae76-71875b521487"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshot20scritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sols"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2x20s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2x20s"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2x20s"}], "]"}], ","}],
      "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.7936416596344843`*^9, 3.793641664167588*^9}, 
   3.793707464001343*^9},
 CellLabel->
  "In[1468]:=",ExpressionUUID->"de020040-d931-4bcf-a435-4634c84b763c"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1Hk0VW+4wPGjKJUfGSo0GSKZkwzH8DwOmc6EKElCKSkSElKGUJQhqQwp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          "]]}, Annotation[#, "Charting`Private`Tag$58774#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k0Vvv3B3BKkWRWkRIiVLgSkextyDM/j5QSQjJdRRkjmVNSIQkpXc1l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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58774#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF1Xk0FF70AHCKiEJo0YpKiEiWotyLwTDDEEXKUgkpWYrIHqINRSUhsmQf
ZAsh2YqQtQWVbaYU2inye79zfr++/hjnc+599913Z857Ekdc9x5bwMHBsY58
/O9/w2PsF7UfSjQ5/u+PS2e121uxWPh/77gbl/BALO2fac/7ihLFiv/Zwv7X
o+ti9f88oBCuc1Ws+5+TlzMuXBIb+edg3gdbLop9/2fLAynMqS9c+P/mnw8+
pL9e8J83m06wn1wW/eezbbsg7rvYP68sXjbIybnhn0uHdFrbd0v+cy81+MtV
/f/8M796BX3vf1bz3XW42fE/l4so/Ky9/p8fUlaLF7H/c1XG1OnY2I3/3L9k
2+29d//zrMeJaqHs/7wHxniv1vzn6r43iWEf/3MNb1OTF27653enuD4r0/7X
E200SW7g6NES/raPOLlJyfmYIohrBKoV2hHzrqeObdUETKk65HqCuDjnjOVf
XbDj+R0s70XMTnfdMkGHIBe1++NBxG3dy2u/mULtrqIvjjeJVSe5j81bQp1z
4poDn4ifSfhrG5+ABx9OnLD5Sbx5PIop7gJpTuqVRzk2I0fii2SRmVMQ5tBn
dUp0MwYt4l5Cs3EHr9H07NPriXurx5eYe4CD/Znf3tIkf0lMhoLRabAY1jYM
UCLxY8tONxucAeqRZfEhu0l8PCTwk4En7Hr/9kOEHnGa8u8CIy+QtcvfFWlC
PMq1d1u1F6x563cxxoqst8pXVpvzgiU2tFdx9iTuO/nlIZyFuX4xmaRTJH5r
aMnVsLMwcZDtnepNfK1X4GLbWWg/ELYq/wqxlL2by3FvqH1p5vTgJln/9uQx
kUpvKLCQLC9PJnGDNFFrQR+4vq/G4kkxiZsdanOv8YH9pjM3X/YTv2R1zKn7
gn5H09jAGMlvnOVee9cXdjJuqg5PkbiQmpg8tx+IGe3o/cwlhUHUhbEfev2A
r5VT6puAFPm+UmfPavvDb8MOz+lVxBGWZTVMfxh/mtQwJ0n83bWreH0A9FNd
li+UJ6aUitKiAuCH1B7BPJctyBEe8LG8NBw0h7SbLnlvIfOkcbbzRcCFRGqg
U8gWxMTXTjdsI2CFqPnkxtvEW3Vf7eC/CKqcJ9rj60n+3uMc1c6XIKDKLdy7
ndTjTPGzrr8EjWe9YP9rki/UXc9cfxksJoKZy6ZIftv5x6d6LoP3m7ioiDXS
WKvPOu9Iuwq1N5P0HaSI7xrcyMu+Crx70+Z1thMveeqYwxcJJkuzyyR2S2MQ
xpcdPhEJt5uZrvN6JD7+RetFayQMhZRsGTAl8QIeLzfBKJCFyrcVh6SR45aS
aq1hFFSUNDK8PEj+iJFWUF0ULHBv5TH3l0bk1JQe+hsFhnKdNdsjSH7JlbHm
ddHw5t6AwudEaXzXo+D83ioaZqO+C9o/lcbkv+Nlzr3RQKH9btLqJvFD9QvD
f0TDlUUcQRveEq9VoZWKXoN1/vxTr7+T+sK7jfTMroGms2SHqbgMBmldS/zb
cQ0CKSbRcFYGaxfriKU+vw4LZnKE1myWRYw5UR/eEAtrnmt/AwVZDFrXsubh
UCwop7zqsd8li3aU4KCh+Vg4ZsBzJ99IFsVpF6PWqt+A5ttHNmt7yeK7n7ei
t+TfgCh1MfXjTWR9R+la19ibsNbvwtGy41uxVkb3QZ9lHKjO25Wa5cthss3Q
rT9Vd6A1VLmtUVYB3cJL53xHkmFD9PhM1oQiCn2scREpTYXqw4FZRd8UMWj9
6sQHNalgs0PkQOW0IqJCj6XR01RI6FUvb12wHYVU4n1d+lNh1bpLXpMrtqOJ
9e57dgvSQDhb+psybEdF74v7RI3SgLv+2KeaqO1Y0NpzpnYgDcZ/vR3sUVRC
u0tHfmZ/SodSx6g6Q1UlFOrpmT35Ix2C+jQzajSU8J3an/XSf9NhRVmiS5ae
EgbFZdZfFMwAba+Ds36HlFCRJ23m9/YMiP/eK7YpgqzPbJeN88wA6pfn5h5v
lXDqjeRY768MSPtY+UwgcgcKBdU5qX+4D6duMTY6x+zAAt1vG2HqPqhRhn0b
4nZg0NrrmzR/3YdniXzyfqk7cMpWhHsrdyZ8MTkQ9aF8ByarbM+rFc8EzbKf
ZvXDO1DR0PXz4P5MeBWyfcBnlzImfxL/yFmTCQLr7k+OjCijm/45pYeBWYD7
QwaGPyijnZWZOH9YFnhE2bYMTSjj1K7UMctLWdDLuer+u2llVNQb5GXHZkHS
WIRN/xIVNBnVmunOyoJtBc7Pu5RVsLbtscqnziww0tmWUxeqgtEZpds2S2bD
leMlDsmbVJHjOM+AY0k2fMS8CH5ZVUyO/CUkVZEN+qvSs70UiM1O47vqbFjQ
FDtBVyeWF06mNmeDz6YzXjMMVbSTvNH44XU2OLxVurDXVxWjp6+3uc1ng9a+
gnSuTlWcio/ama2bAz8xZ8QpUA3tKrZUhzflQFXa+J2zoWoo5FLmsr4lB87z
yplduKiGQaUSlkVtOSDQkfs4NYbE9zawXvTkgJRtftLgfTVU9OpXmRrOgf3+
hZbmHSS+wudOznwOlDwsawWJnZi8umVym0ounFGqL17xhNjuyP3xuFxwUBZP
vta8E4Puc+lvTMgFS1W/y0vaduKUzAkzy7u5oKGufGTBq53I4bT/UUV6LizQ
ThOcmCDrT9tJHC7KhSjTUOeG1bswWWJVhGpLLmS7UcTPeOxCE7WY6BV/cuFt
fv3lFxLqGOQsMrXDPA86PnN9UtqijrhF/3zb/jyoldOlx8qp4zuFdAXHA3mQ
nN2wxEJNHRXX1Q1ft8mDIxmNV/vp6lirlMfucsqDscTmKNZZdTRJKV3/1y8P
Pl9pjZl7TuLCpas40/Lgj3P3HZlzGij+JEdJ5nMebNXi+etQuRtrB/4Gtznk
g/49CcfClZrYYe693e1VPpxdZyv5/hAgx5f5zJM7mXDERHF//2HAaNif3raL
CcYhnJf6HADtfN9KKmowQepD6pfnbiRuZ5z2ZQ8TuovZtRWhgIo6Pq2ndJig
SPewjc0FfJczDXuNmbA2UCcmqpDEq1Ju5jKYwFMk2nSpFDCo0s17kSkTBleW
bQuuJbbc8q7cjAlXhv/MuXST/PoLe1cdYAL7XFiC/iygm+iP/XVHmfBx/1an
FA7EWueF+cuPMcFuSmTBhoWIipyfbzs5MIG2cVRlNS+S91Byx9LjTKitet5+
iw/R7nDfextnJqjuLz2+fCmSejulC04wIXcyaWGMIGL08plFnC5MkLwYnigk
jNgR3xZgeooJcZJuapGiJD96S4uLGxMEqixf8K8k9aRighM9mDAzIcPNsxaR
47HP7VkvJnSYt56c20zyWYyjNYFM0JsoXuRLrnOOaAWjr8FMqApPTJ4m1/XU
RVcXqVAm3K841f1NAVE8yYsnJoIJAeLLdn/cRdYLvr8WfI0Jcp/28fcZIeIe
Hqv2VCaUm9NrLpkgmlBt71hmMEHnkfZpTTPS/3u3i6OZTLCKVHiTbknmoRX+
iC+fCRcVF+ecOUrm8STDOqycCWNnqgyFfRALZoK3G7cxwWOg6G+DL5L3SjVl
7QsmzOlmFfkEkPOpdvNOdTFBdOXN1e9DEJM16VwZr8h+D10/MiNJvz5SCSaj
TEiek7xklEbq+QVi/hzp10FMk/M+IlWu4edxjgIoaxP8WpxFzuPu+nSeswDa
7s4eWMtEjHP/FazMXQBzWr0y4w9J/vMfK5/wF4DVhYtPI9pJ3Goq01esAEQE
p3jrfyPulBipuq5WAJ2PLoUbzCGy10iJeuwqgOsnNy9qnyf9jP1mm2sUgPAz
q4WvubSwgGErsxmIwxrmJgW0MHnEYGRKrwCE/sR/XbNRC3nvvuXfbVEAHVkq
7imbtbDjwzhr/4ECiLbsmJSS1sJmwYhaz4MFIFjK/Xm7vBYGTcherrEtAAF3
N5a+mhYqqumcD3UqgCUs3f7TNC10stV69OZcAbTeeGc1Y6SFESPWt9X9C+AK
xfdVgAmJh91amBRYAPz3Cnov7iP7Dyrle4QWAJ/1mhd3bbVw6vBqT/PIAuDt
mmpoOU0cvj9rQWoBcNXcYW5M0MK4rU71Fh0F8Ho3hfo2SQtfXrvumtRVAMyK
T+/iU0h/7CUSn3rJ/Er3CAvf18Kd1LnXCQMFUJj39gxHETn/zIbwfeMFYJOw
UX2gifRvvfOZEm8hKK9u7Yx7pkXe74U/vvAXwuK4MyfMn5P1OfK6DwULoTim
IaGlk+QLZKbZrSwE/suO8w8HtNDkoudF0S2FUO6TU3/zmxaiX6yDJLUQIn+Z
We/9SfpPyjJ3oRfCUc/ZH0tnyDwYY6WPTQrJ/Iy2hP0l81h5UDn8QCEcc5q8
eHqxNk47d8WHnygEYYsdDJMN2og+MSEe1wrhhHLlq8U0bbSU8X+eMVoItR09
ueVG2hg0xT+rMl4Iy12mAh1NSLx7l9eLqUKoSd8s1bBPG1ft3PtEfrYQRFZG
ewTZaeO7A9EzASJFUDljz//LUxsLjIaLkihFIHQzcDDdWxu9T98Z4qAVwTGl
+EJzX23cuSHCzN20CARPtFsUBWljs4+Ln79NERzt35XmcpnURymmnk8R8NcI
7BlJ1kZxcVZMVWER2B2UEYpJ1UYOlqa7yMMiKPmlM6yVQfqjnOw5V1sEtoo+
F+/maGO0yrJe3/YieJAy3GNVqo3SKxftoE0UwcHQ8lMvWkh/Y86eOgoPIMfg
SHL1T23MbFxk1FXzAJTlJDRhhszrdN74WPMDqBZ496bmD5lXS8bQ0s4H0NFl
vfIxhw5SG7OCbo48gO/WByKf8Omg0yZ+oVt8xaDpYeLXvF4H3/X7C/lbFUOT
ueBqAwkdDOIyHn1tXwwmam1lTzfqYIfLhk/GrsVwZJb27Zm0DpbzNxmfCy2G
8Av6zs+VdDCTV+neMLMYOuI1LTv1SP1nXMHy/CVwwH/ux14DHXSrOMq3aGUJ
DNlWxXTRdJAjhId7WrIEvm9Sb+82IfX212+R0SgBMaaKXp+VDkY/x5WNJ0vg
yBM55f5TpD+d5Bvrekrgx/hqobGbOsi7VjnhR2UpxCaymhJu6yDe6/KpbS2F
HYziQLMEHVQU7AgpGigF9yKjydoUHZwe2Bq0lKMMPnsHtd3J1cG42cddmXpl
MMo9dsW0jvg49De9KYPQsiIKb4MOrnKTFt0+WQYbjwfOVjeR9cHWHk0LyuFw
66qTcs/JfiqTCv6y5TBwnUbjeUnOv/1hxkq/cujZULj40Wcyb7p6t4P0Qzjz
wv/x6SlyPrXjSV2aD0EkxNBH9psOCvnH6p7Z9xBMx4bZt6Z1kK0uOLY35CE8
z13R7LGQgkLel59de/8QGnb5XZAWo+DLT/a5gZkVUGKmvzCWQkHMqowJOFoF
EbTysLX6JF9nI8sssAoO6cjwphtQMIjZwGV/pwoW7OBfWmpMQTfZEWPV7iow
Fm5f8dKSgtSBdX5M6iNgd+yXXetCwamqeb8De6qhsrkpN82VgrU7QhqFrKsh
snangrwHBXnj+7j5/KtBuWC1suZZYvEupfpH1RAcNbjHLpiCzfTjevbaNbDa
2ME07QYFD+3i/2YjVwufdfu65OIoOH136IiDZi3U7qHuL4mnoHKvT+x1k1pw
kJc92HiXgh3CvgpWnrXwYMmEPTuLgv2yjn9ya2uB3uLpLVdNwdgr8ma3bB5D
IDXsbvEYBXOX3sLtD+ug08bpkOIHCtLv2wx2tdfBJk+aWO44mcfzBrWUsTp4
lrIsJnWKgp82Sy98JPoERP8kXrj+m/TzQYky7/EEMvNKXdwEdFGan3fHW7V6
6BBma8ip6mJm/dHW8yMNICnTMn1/py6OsIr9xjgawRPySzZq6OKZ2oeBvusa
YfXJMwprUBeFrg5Jq1s0gn0Dx0Y+Q12M1hC+IvC8EabPivGxrXXRfpPLhFpd
E0gMGL5MDdNFLs7HzWFdT+FSnQZzX4QunryXMr1v5il8vS93geeyLlIX3d58
bMMzqPMQUD4RrYty3DqlePIZ2PN2Rind0cWq8mTPCd4WyNxxQP9xgS5SSvxt
FY1bYdslx9LBN7rY3UH/psXbDupqobFiSnqomr//T+LtTug9IqaaqKyHdipH
BvcVdcLpyPw+cTU9/ElzPL+ppRNyR1+ult6th2c4eC255zphfax8iqqeHn7d
MHC//XAXLPjSm2dmpYdc3RrPzBW6oSVbpunqeT0s3rdC0f1lDxxa3z7D2aWH
ihxjnSl7X4GAmEdJZY8eOn39tdPS/RU8Flnu7vlSD6c09yuLRL8CqcUH2ewB
PUxLj1l24/krmPw21tvO1sMFHv4qldTXcP7p3weJf/Xw1FJh/y3wBjLPbDu1
S1Yf0yo+xKvKDMCPZ1eH3IL1ccFm779xJ99BP3+P02yIPvJ6utHafd5BHX3t
JLmj0OLUqqI/F95BdFv2n6TL+vggwN1ANeUdyHY2iT6/oY8jnw4sUeh5Bzav
OPVlsvUxOmjOSVTjPTSyPHPed+rjXZvbL3/MvYdc6UfbXXr0MeLSYE754iGI
Oc5VPt2nj/qnOFxOLR8Cu/Hr9YID+lg9ae1TJDcEvyeYA3tY+igXX/433moI
FH5+EIz/o4+cg0kJ7x8MQRyXzZm9m6gYySl7/e/BYfh7dKXKCykqdob/nOk5
Ngz2Tzp+MGSomFF/t/Su6zAontc5a7SNio4anDJ8IcPQPC99jrqTiv0bHFvU
s4bh1+9vgZp0KnLeX6nN/20Y9n+5eFn2DBWXmA/b+vuNQJWJDj3Li9RLOhlw
L3QEJAtml0j7UNG0S8C64soITJxyjdwcQEVtLtdzdQkjEPbJ/Jp4BBUb5M8s
V6kagWLWhlsrEqi4/nEpO2d6BEQGS+4tqKfi5hg+C1mnUYhc4u9f1kjFxp7I
fVTXUeDToFiefEpFetWQuaXXKCyI61za20ZF0QCVOOPQUfhqOumd9Yr0/2qa
7+bdUehokGaYTFLRSj597m7XKNC/T8pwf6XiZ3qm+NirUWiWLOOq+E7yN720
3vBuFGoCdSs2/qbigO9X1xOfRiF/15HNv7gMkCOe/8cJrjG4knfnT+JqA/R/
efDFeqUx4O0/0rt3nQFeO9ehe1dtDEL5ZAt5xA1wTc/5vyJ7xsDXsdzBfbMB
lm8fC3+tPwbOEj0vKIoG+FEjZ/HgoTGg3hDIHNc1wLt3nPe0h44Bt3+w+S53
A5ROcqrtbx2D4i+fZmpOG2DalvNjdR1jYO9geVfPywBnCrV7k7vHoJ6h8NHM
1wCTWt7TKf1kf8mBwFNhBlh1e1R26/gYcDXvzEm9bYD1Gvt+hvKwoHh3mols
ggGu96s7PMHHAvtCwZ8FSQa4O/jXWRMBFtTHj2F1qgEq24i+/ivKghCX2N6X
eQYotSD+I7ckCxaITHEK1Blg5PIvL5vVWVAUfvB+bL0BXq/bL/VkD4u85430
NU2kn+8Jk6XIgrrRxFvSrQa4z81M+rIeC86X0+R1eg3Qr0IohmXKAk6b+5be
Hw3wXQrn2DlHFnBk2TCHhA1RdaGzpHUkCxo/9Z26u9wQT6nO8bZFs+CKoum2
Q6sMUW78yu+dMSxYWa6T17POEI/8ubJj7hYLtjVJ5zRLG+LeNBFXTGHBodGv
Gfmahhg/2SbxqIhF7t+TDie0DFEnclF1dzEL2CdHN0tTDPHLZgEFVikLTn/v
S0sxMMQHFkcezVaw4NLCR/dizQ1RrKKjebyOBQ8lwpPOORtih9fZgOEXLAg4
xmGj5mKIh8pmCvO6WEDJ8ln33dUQa7/pnzjdw4IOxZMJLp6GKGD7Pu7LS7If
mMbbBRnipcBNCyvesmCFzZqbejcN8fKCZ80hn1jgEc+8KlxniOuarjnsXsiG
stn48Lp6Q3SpqvsVwsWGWZsLwR5NhpgcK27ezM2G8I3Wnp2thrgsRvWKPi8b
EnL5rK/3GeKw0Y1n4kvZ0FB9TE74syFmti8fpKxgA5+EqVTdpCFGL1G5emgl
G0xCdot7fCXz1tX1cV/Fhtf6IqKdv8i8vOgbY1azYaKj9s+1BTQU7GvxKV3P
hlXDa1qWraKhT+HzK+el2GCty9PweDUNHadWLHLfwoZ7979Wu6+j4deaexus
pdkgd/Jp0QtJGl5si6Ftk2WD1g+v+GvyNJxuKd1SIs8GZ57O48t0aPjUPyHy
gDIbHm2N4F12iobF2WHj4sgG1e6Vz6+70fBUafuKOuICv/vXRE/TsKfpQ9Vh
LbLf88bVq7xpOPGIGpGgzYYIV275Dedp2Lbioz+HLhv2PjhvKn+ThtVnzxWH
GrCh5aDwCmYciccHigsasoHCde+14h0a5gi+1ogjVtv3+KhyMg3TVxpfzaCx
Ye2veU+NbBr2n7j/9YERG1jq/vEG1TSsUeWCWFM22A0vsW2ppaGVg90C/r1k
fpcTNho9oaFh+MC9IOLW/spck2Ya5t3UuOBkxoaigN/VFp003PdTfOPWfWzw
qzs7fGyMhlkZGsP+lmxYZughd16Ajm45FV+O27Ah+bEgv/oyOp6xzjreTKy4
K+/DFxE6TsXdGt5sywZjaXbGYTE6LomeYQ0QX1pkI6G1iY5Fg9a+2ofZwPXE
YAWHOh1lbJ8Mvj3Khhh11vey3XR0yGMlKtizQbIotMsV6Jh32TIsgBhTaqLf
UuiYLE3pFTvGBv9AFf4aBh0H3jAq9BzY8FNDgiPgGB37fWX3+jqxIexB9aCK
Ex1z6LLR1cSiWw89+uxMx3mT5Ss5j7Nhx+pb56zd6Kgu0rUolNhtesmP3b50
XGgxfTfYmQ0fiqc//Imm49lHG6jWJ9nQL9/R5VNFxyMvvn1JcWXD3fFl/gtr
6KhyINK1jfhIlpnU1cd0VN1+9Nxv4g+b+ryTG+l42MJgt6kb6W/N4LqmDrLf
HvXoGeJlfJ8cRUeJ207aqXqwobtJflkSi45mgZuUDhHHhblWbPlI+n31NCWY
eD3ntyUak3QUuhJh00IsNz1TeHiGjhuGzztanWaD3hjPbP5SI+S4kRHieIYN
i9MM0ncKGaHyqx0p4cSthy8b1wkboc+Kfuf7xGYDAik9K43QI6eJe4zYrnu5
3qyEEVY7CLvberLBt25jtIGqEb60P9qq40V+30mwacTGCG+H5mf1nWXDt3Pf
eA4fNsJ+azp9gljV4v74wFEjtFdULObyZkOloOCDPicjfKov16tI3Bg0qNXi
YYSGO9JOXyB+c8TftuiCEfKGHr26xYecD7brKFw0wnOL1JrUie3WjErlXjZC
jZKuNiPisS76RHq0EVJLjhqcJp6irPW/HW+EzwSqZiqJF22pjA/KN8Llu1eX
UM6xwWCha8BcgRFKuPdz7yO+8lbyyLkHRhgd0bX1GPGyuEsyZ8qN8KPDn+lQ
4rWLrcod64ywZ41rah2x0vh0j3GvEZbs7Liu6kvuE6bqsnV/yfxWzYYs9GND
qdW0QAeHMRpWK6gJEQssqlgSstAY3T62Nawlrj20h/cDrzFyhsx6qRBL8lHm
i0WMcVamTPkY8Zi96We6jDH+WKbhWk2sKSQyPr/VGB22beB5SnyrsptdtM0Y
PUT0g7qIqcKWI6uUyfqjNSvZxNk1Nm9GNI1xvcXgiKA/G06tPvnUz9wYj1yz
07IibmyQb1KwMMbVFgOiR4k3uE/WDx0wxpd5N9tOEHc0edRSbY1RKvDVDz9i
JU+fMlFnY3RstFyTRPyr/UJ6biCpx66Yf0Ns4ktNtT1vjPzelRbDxJlSfCnC
Yca46KpC/EdiK/+rCd6XjNFaxvHtNHGVbGwM5YYxSuY+chcNYENQWEpwf7Yx
albwsPWJl57lMTycZ4yqY5XxRsTxTi7CY0xj3L7q0R4z4ge0XamTxaR+g+E+
G+KxZS/qF9SQeQ4LtZ8mpiVx8Mp0GWOo3GfBBOKXUQ4deT3GuHd+6+tkYvvg
1jill8ZovHzLrXTiAPs4md0Dxlgc+OZDPnGBrCKNwTLGp2vnf9QSryizjfT8
Y4zVYnaNQ8SpmQ37f88Z4yCPROsYsWL81g2BHAxkmOc3fiQ28P/FjOBmoOBI
fvxXYj+dqBd3BBmoWWn6mDOQDUPt1aJ1GxnYmZEvsZ7Y9fGmAT0pBvb+ZgZL
EM8WXUpvkWagrKvay03Ey2/uV+2RZ+CeCK3jW4mphyYs2GoMvCwtvn4ncR57
3R0BOgOl1vWxGcQRiWF2g8YMvLs7R8iM2H7v5835pgx01Yndtp94bVVVgZEF
A89NSxkdIr4UdbDxyhEG9rl0r3IidlK9/YXPh4HwecWCAGLKOEfZa18GLt30
Mi6IeEOyk192AAOVnO23hBD3Lt7JYxjKwIVp2nIRxLoDvWsvRpF5GPb0XSOW
DBWl8mQw8EBlYGsq8d+dfkv7MhnYUJM+nk786vNwZ0YOA/2EhbgyiaMtHljr
FTJwu/SseC7xvOze02FVDMyp0FhaTNz/IippYRcDKTnpNXXE5Rd+He3qYWD3
xjbfeuJYDVuZ1JcMfPfNTamRmJa+rVh7kIEHpZyinhJXeD9/GvyBgXLM+sUd
xDflVaJMPzEwt9Lzzgti96EEc4lJBm7atVa6i1iafvJt7XcGjopcUOol5uLs
Tov+xcDUMseCPuJ3JRrOdr8ZqHXAV+YVcZVzqoLiHAP/rOlIfE18awP/j/l5
Bi7e6Lm0n/h/AAsqSY0=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$58774#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13c81e//P/BDlFRklEgRkjIzsj0ve55zEFEJiRSJkFHGkRGyssc5HKth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          "]]}, 
        Annotation[#, "Charting`Private`Tag$58774#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.7936416699497128`*^9, 
   3.793707485144012*^9, 3.793717672169283*^9, 3.793718174752056*^9, 
   3.7937182680018597`*^9, {3.793718430471394*^9, 3.793718444976821*^9}, 
   3.7937195403741617`*^9, 3.793801393609724*^9, 3.793801474194271*^9, 
   3.793801569935988*^9, 3.793801637647945*^9, 3.7938017410853558`*^9, 
   3.7945070244257717`*^9, 3.79450749572329*^9, 3.794507540675671*^9, 
   3.794507662632415*^9, 3.794513109923526*^9, 3.794513178687973*^9, 
   3.794515031986408*^9, 3.794515316140401*^9, 3.7945686415543633`*^9, 
   3.794569002111548*^9, 3.794576048750243*^9, 3.794576684867744*^9, 
   3.794578138053644*^9, 3.7945784282282667`*^9, 3.794579360714518*^9, 
   3.79457948970118*^9, 3.794656572635048*^9, 3.794668120937303*^9},
 CellLabel->
  "Out[1468]=",ExpressionUUID->"82eebf89-6a66-4294-a74f-a3aeafff7d93"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5I.pdf\>\"", ",", "figoneshot20scritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5I.png\>\"", ",", "figoneshot20scritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668044598477*^9, 3.794668052201713*^9}},
 CellLabel->
  "In[1469]:=",ExpressionUUID->"d6a0e754-6cf7-4194-abfa-07cb5fdafb57"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshotinfscrit", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol20x2xinfs"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol40x2xinfs"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60x2xinfs"}], "]"}]}], 
      ",", " ", "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sols"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol20x2xinfs"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol40x2xinfs"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"sf", " ", "*", " ", "10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60x2xinfs"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "prmax"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"1", "/", "sf"}], "*", "#"}], "]"}]}], "}"}], "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sf", "*", "10000", "*", "0.000089"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", ".5", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"importtime", "+", "2", "+", "10000"}], ",", "1000"}], 
          "}"}]}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793394861836452*^9, 3.793394918159622*^9}, {
   3.7933951496126957`*^9, 3.7933951633752604`*^9}, {3.79339523317878*^9, 
   3.793395327131968*^9}, {3.793395363113092*^9, 3.793395454093955*^9}, {
   3.793398236334831*^9, 3.7933982401612463`*^9}, {3.793398273947652*^9, 
   3.793398297786425*^9}, {3.793398587977316*^9, 3.793398589049642*^9}, {
   3.793398642868155*^9, 3.7933986473815727`*^9}, {3.793398766872898*^9, 
   3.793398769091921*^9}, {3.793398847935656*^9, 3.793398887738555*^9}, {
   3.7933989372257338`*^9, 3.793398938788555*^9}, {3.79339898752773*^9, 
   3.793398989638323*^9}, {3.793399423963974*^9, 3.793399443278512*^9}, {
   3.7933996196258163`*^9, 3.7933996224000072`*^9}, {3.7933997698848143`*^9, 
   3.7933998152795763`*^9}, {3.793399870324162*^9, 3.793399874653573*^9}, {
   3.793399955092331*^9, 3.793399981729393*^9}, {3.793400297337214*^9, 
   3.793400299363748*^9}, {3.7934003321033993`*^9, 3.793400385420542*^9}, {
   3.7934018012048273`*^9, 3.793401888718988*^9}, {3.793401932418544*^9, 
   3.7934019352989807`*^9}, {3.793402009236326*^9, 3.793402049607609*^9}, {
   3.793442209711054*^9, 3.793442344238595*^9}, {3.793442922320374*^9, 
   3.793442937773024*^9}, {3.793442988076605*^9, 3.7934430062331343`*^9}, {
   3.793443077052331*^9, 3.793443173022769*^9}, {3.7936406472978*^9, 
   3.793640665968298*^9}, {3.793640705579446*^9, 3.793640707850029*^9}, {
   3.793640933155513*^9, 3.793640996078887*^9}, {3.793641378889105*^9, 
   3.793641381201693*^9}, {3.793707457526559*^9, 3.793707458707697*^9}, 
   3.793718353427245*^9, {3.793718402938336*^9, 3.793718403333542*^9}, 
   3.794507352297159*^9, {3.794563762721336*^9, 3.794563795298415*^9}, {
   3.794563946197773*^9, 3.794563968193676*^9}},
 CellLabel->
  "In[1471]:=",ExpressionUUID->"2e93c11c-531a-43e7-bdc4-7c24f8c7e05b"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF13k8VF/4B3BKRUkRihIVkj1msd/PzNh3smdLErLMSIposUWFksqaNS0S
FZKElHbZipSliCiKbN9K/Ob3ev1+mX/m9X7N3HPPeZ7nPPfcTR6B1nsWcXBw
VHBycPzvt/GeoZa64XIdjv/7cDFEmb0iKcT/WzU7NfOOSME/mzR23M4SKftn
e8+ZB8kij/+5W+kEI0HkzT/nCFnEnhT5/M/Hue9sjReZ/GcHx9ySsXEu/L9X
zB93Nti46p+lrL4PPTol+M8HX6sTqZMi/7y2jL+Hk1P8n51P/7H5LLzgPM+B
l0/kFywvdO/eKYcF00PczwuVLpiSaV+YoiTxz7tcC12u9iw42nh9Wtrwggsp
Z96cnFzwCF+Yif/yTf8cUmumrkJZ8GmJKcHqhAVX9DFeNWlt/ud2w+PjCQYL
nr5ZI2xqvWDqYfVdz/YuuHKN0nRd8oLv6YpK3B5a8Pvr9nrMiQX/Xn3eV3Fu
wRrdq8qvr9nyz1UHlhjn6yy4unBsf0rKgrt4FdOssxc8G7SvZvX1BWsTg9wJ
tQuu6fiQFfN1wT3aIo8YUwuey7cb4uSQ/GcdZovKEaEFu7bzOWhJLPiIlmnE
b9kF13I/fRqCBX8M4BolmUiiIDk+0+KHNcHxliYwYSuJUztNt087FhISmkep
t9wloRg/YfQ8tp5AbrVz4D5JPGneExBGbyPcl/0+rhAiifwzz+2jjT8Sx/yp
V74dk8RgW5vTxZghIqct+NW1U5K48EiobExsnKhTvz2+94IkBq568ovcmCY+
Zv8Qls6VRLKzwbvY/lmCY6mC1uciSYxPF83e7uaEhJ/vrrwKSbyNLgoKO78E
tNYrse4PJaHe21Wkd54HHmoDRRtfSWLllsjuoM6ViLy0uaWrXRIloQkX6Ur8
qPfNWu84IgnC1v4+c5Uw7gzv2+c6LYmf/mkRieHrUOCtcX83hxTeuEcGzHGs
R4xXh1OAoBS2278SmZOSgKEHf3qUlhT04lOL9g1LQf1T73CcvhR2vLndpMva
Cln3m+qJllJQ8xrarfBbBryuJp2pnlLI5aANx3fIockxZt3N01LwLn+5WNtP
GXXvdnjfuSAFkaPp29r/KKPUfnNlZQ77d3exi7ditiPZttb+UZkUGvZcNMyL
V0HUm4Qrz2qkcI8kxuHHpYrgHc4zjc+ksFOyXKU9TBV2Vr8uvOuSwm+OeOWK
nSQYND8d7B6UwrOQm7fKn5CgZnGB0j8mhfI/z2N8FckQMVNtH+WSBuG6SrNj
kowuQ3+hxQrSqLKbOGC0m4rGp5p7uKnSiL2zw+3CPSpq9JeXr6RJY/XG5jN8
fGrI1r1is85WGlN3gvyX31aDBz6dU4iQxtWc3tDzw+oYotoKODRK43hPSZyD
vBampLVXFftvReqb+TlnCqDTR3968tBWeChV3VuzE4jNMjzqHbUVL/7UynYd
BYQFbX5sSduKdUK5n4ufAxTOfU3pj7dCeet9kxxXGg59SE2KWy+DrHWpty4k
0TGbNLnK87kMljhm7jq9Vg+6Jr+f0t7IYG6JqPVfmh5OL+U4Jt4rAzJN9dEN
Pz2IRawYez8pg4tnc0We1+tBx3dzs5XENuhMjAQvCdLHUV3LM8TBbVBQTYwY
6TLAol9Fq9dLyUJ6/bLbjwaNsb6RPkEoySKr+PciZ2ETkHI733qqy+JOid4H
VX0T7DFalnHTTBYCd1Y+yys0wbM0Dyl6iCyYg+vFIn1NkaQhouHzVBaauwcy
9syZYUN47O67PnJIo6589bTIEmRLMf2u/XI4a9WjdeOpJcwly2Q4j8hB5L6E
5u1+Sxx99WnUOFkO/EXyrZs3WKFvg/ahnio53H8wsPJiohWuPZg4vYRXHn4H
vOdbQq1BmXev2HFTHp9y5hQzfGxgalYXqVcpj7GvUBSMt8HuDHELar08+Obe
Mouv2uAMteeLaLs8HmT9V4IhGwwH7hTp+ysPl5LJy8Petsj8aBvONFMAAoov
azDtwFlvTE8YUUC4RiRf+AUHvIomvX4iqwQOWTv9eC0XiJ/59uvad2VUbrAz
XG3siW8zvT1vlVVw5SjVYLbNBxV7k+qNKSrQDVSKN/rmg2MdOoW1mioI+Xm3
6uQiXwjfzfK/pq+CmkbrO1+UfUEP2Tkb7qyCjRHHBzgTfJE+2S4iGacCftJm
QyZ9HwzHG22CelVwmFr0YEmOH9bsilD78lkFi2OP+qqU+6GnWX6D81cVJF6h
Dxu+8ENw6al+vSkVVCqQJFQm/ZAdaBQkskIVYdc8m0b0/TE9+jipjqIKrw49
ldov/ij4ev8FX6Iq5g6uO/ZUMBABFy22+J5TBS/HVm4D6UBQdfsPN6SqYs2j
I/JXqYF4kbVcITxfFWq2R5z4nAIxbumYNFypilynPrPdWYHQuTu943G/KmKH
L3jP8jHB7XnyhviwKjIlnhypEmaidfXGJYe/q8KAoXR470Ym9vjqVWz/pQqe
xoL7CQpMnBZLWZfNR0I4Z7AGtwkTnVHbu0PVSSgaOngqK5KJPOUG8lsdEtY8
X+qgHc+EX7dDorIuCaq2z71fJDHBQT1GfDEnYWD1l8miTCakv77OtfEkYe7X
N4mT5UyMXfD4XeJDgqDC5SNn7zNRxZi2XhFIAu90YEDMQybMssS46kNJeHdi
6R2VRiaCLf28lJJIcHFtvJjTz4TO3/makyns8Rc9Mls+zMSy6+fWDqaRMPOn
ZsrtOxPpi+8/yywg4eDL7x9e/8fEwwoeueVVJNQFDTHu8bLAJ3blx+fPJMhV
DVXfVmYBdlHd/cMkMCO8riWQWAhKcnvZ952E4HN3nezUWGjnXHfl438kvKSF
fyklWLg0GOfaxUuGXYBcUbwZC83ie0w/8JMhndhb22LJwiJHmsZ7YTL2lSpa
LbNhwevlL6F3EmQMH1Zv1XBiQbHUt7GNRMabfZzV9XtYcB/Wv9+qTgZfW55Y
iDcLyZu3XGvRIWNDjUWL8D4WplM+RDcZkqG0b0xEgsmCzOu7Qa/NyBixDimI
C2LBaVmKe6M1GdM88n49wSzUhJpqvXQmg557NtMqlIWx2zKyL3aR8eSVPWfg
YRY2j3Cte+5FxjGn3tTQCBZiXR9MPGGSUa9g42Z3nIXKi2mfGg6Q0aPZmiAT
xcLX5gNNj8PIcNRW/f4lmgUzhmJRfTQZaUW1DMU4Fo6EL097GE/G+MfDauXx
LJSWD8bWJZLRmq7luu0UC33f64Nrz5ERq/2i7ORpFgRlsj1qUsmwVxjV7Exg
QX/XYcsHWWScee0/IZjEwqF0e53qPDIOxwh+0D7DQhfvatGqG2QkNUyp2yez
86c/suzeLTJQ9rjU4Bw7f0efTd2tIOMD96yDVAo7f5UF/RX3yTi/cow6xnbB
+LGW8jp2vqx1dlw9z86nrEttWQMZK/ZGl5pdYLH3h3rxnRdk5Hxws/3ItkaW
UMbtJjLmiAAD94ss+LWPx916Qwa/pNnpRrYvrXodUtpJRsPa9G0yqez8G173
LOkhg6vopyST7UWRsdY3+8m47z8ZdZlt0n0PFA+x4/FDy/QZ216TOoo3RslQ
f+gT9Y7tVIX1G4p+ktHOWqfUzvYLrxme6zNkpJ4dtHnI9mx228zVWTK8S1m/
09hW7CwZuMJJgaqrvZQ72+4Cp9sKl1LwSZb8YQ3bySbeDy+voMCj8OqmcvZ8
H0frlhSspqCr03OOwfb0A4msfCEKrj+hhdWx1yszM3syT5SCvuz6bFm2nZQ7
D+WKU9Ay4hsayY7XaZ9yrxxJCh6RavifseP5FcVxK2QpSE9uNxtmx99g3eXr
IUpsd8jITrHzU/Aj89UnEgUZG8XLvp1lx+NpyndTDQoORm759YqdT/dLp1dX
EhRwbcxZmsbOd82BaJUtehRs4J0ftkhkIVQyOOSXBQUWJrzeR9j10/5nX6qn
LQXrWxPFptn1RWrbXdXkREGbcGaPA7v+xo7vmLu8hwJ/vfnKXnZ9mjuaSPDv
o4C71Xl0Mbt+i5QZ9HAmBeKb93qtYde3V69KrPVhCqpcrgRNhrPjUyF79cEx
9vyWcMk/CWPvj8TNL2RiKciJNQuJOsRCt5YA3/wZCooSJnke7mfBJn38fFEh
Bcm/ShnGPizcZg3fFb5BQcXd5PQwLxZWGX3qPH6Lgk2YFb24m53PmWYxh2oK
1GTKPqe4sECzLb3M1UqBZeHFhsvsfnFJ/urTwA4KQluystTZ/WR2cc7w+y4K
KqtjzaqM2PvxdpLCrS8U2HMEpUbS2flfHVju8pcCqZAnydtVWdjwUqGhQoYK
IS3S+438LITlSX3ZpEgFCX/fn2L3u45QMZ4EVSq4UpsMvixj14fMSrPdOlQU
lr976zPHBE/syJtVNlSENR58m/OViWkUffY+SoWEpvzE91omqgu+ZRyMpmJu
XSZKq5iI5JbfERtPxd1X357vZvdzvuYbD/PPUeGdzpzIvc7u9243L/VcoUKu
/5BDRAoTdhG3HGyaqTjbMDPVsIeJ8nt3XxGb1HB+0No7by4QYWL/RZlLq0F2
oue50HggcFxN00VODWpfq1cG9wfileG9a2FkNfS60/h/Pg3E546q2HIjNdyK
EHr/KykQgtMPIBekBj2+Esu9GwIRrPK4TPiRGvZMdtcpywTAiySRc/aZGq5k
eOYLrQ2AAyX8FO9rNZhH7EkZXhIATQ2Sx6JONTw221js1u+PRfSCVd+/q6FV
ZWrZ6Sx/JFlF+zaIqoM/7Ox28VX+uM7UlQgOUkd8wJ2piaF96L35+FTLJg2Y
ystp3I72wR/fNxnbwjTRfsb5dNgrT8jRls153ddCe8vub4WP3FF6vWjruzot
5IvaW7nccQdJ0NLK6IkWTAbT14rnu0PrS2qBXIsWujxF+x9HusM8QdZkbFAL
WiUjhul0dwR1mqWGCmhjNO3o5sE4N9xjpaic9tHGI28bMn+eCwzyNu29tVYH
48vtXaY2OIGUyif9ZIMO3Laf0JLgcoJE4p/P7zfpIO6/CTX3b474HfrWg0te
B5sCdx4Ur3JEsVW8qz10cC37HS3dwRFrOMdt/3rr4MPal88i0hzQ61ana1Sl
Ax7Siol2WXu8si1e7Fqrg2fLs9dnCNqj0iS9PuixDvu5OJqzf84OydRgZL7W
wePi3rhdrXbQWyWj9aNPBznlVweUDtuhqCZJ9fwKAl+D3JOSmm1xUMxt8ydn
AlekD2UKn7SBh6WyXdcuAs5S7/srQmxgHsV5ssOLQE0dLcFntw2kh/PHG5kE
eoSM3y3RtsGbsqG6qmgCfCRHPpHxHVA2DXJLuUHguwBtItt5B4bCYjINZgns
yvz6sRfW+Gon553LAdC7JeQqlKzhPrZmkfhi4AfpiXvWRmuYbBkgi3KD/R7k
7nxp1gqb409krRZgl6nJEMXnnhWabV75/ZUCHjYZK66jWEF+xHZFhxnwl+xp
HqNpiUob09qTloCgppmyiJwlGA/o+3V2sB9b6abytaKWcEpU+nDZAbBOmPWM
nLRAvDJPUfBuoKP1UAA12AKDwdXGAqHA5ctq2uph5sj5u/mkWQGwLHL91cps
U8h7iehwXgEKUvztZaJMcff1qp9l14Bs65ZtlV6meJ0967ihhL2e7+vuUhVN
8ZfWvu3bPfZ8Dv1dfqfGBE6x8c/jmoBPIjIBRwaMsWbVGPfj3+zxOn4knDMy
QuuDkyeM/gJ7tYdcglSMkOwntbRpHggLCW/zWW8EgRdOi99z0bAoOsE0b9QQ
AjENf3/w0UDn3veUcs4Qq/+k/1y/hYbElszYd30G4P2i17XfhIY1G5aV2Z/T
x6vzH51+mdHwvt/y5Iaj+jite7jziCUNKcnX+WZ89bEir7Q93paGI/y5DSN0
fSx3Wd+S7UbDzSnBmHcTeuBuG2t4uZ+GUaV20iVHPXDVZpRsyaTh3sd7ccYk
XbzX0jXsvUTD4WshhhKbdFFSNfIxPZeGofjldrx8unCq0BYQuELDUqk/Y9JD
DNwq7g3muE0D75UJ+u4sBlwzt2h0P2Vf/6lk/NMKBipDix5fmKCBT5hfz/A/
9rpmdrhYT9MgzbifUfGFht0HZqdW/qKhsGnZVrUO9v9YZltj5mio1WNGBFfQ
sMf7R/x+Hjp4nAJymg7QIGCvamEpTsfyK5QTszPAPtL9Th4TOrbX8atd5AHq
mt/eqDSjA1193NwzBIT8x47utaTDVfCsP+cHArWXpaQbbOkQtdOas84nsGbt
maBj7nTUPnOZ8iMTuP/Lc8XMAToU09LnnNx0sKKWT/tzDh3OljaRks+14L5z
2+pz+XTQN2nOlJRqoXyG0U8rpMOuuq3cLlULbsqh8dlFdIQGj0dN7dXCndz+
t04VdPDq7jwTzK2FndGVAS0v6bh6+9l+F3NNFBl55NRM02HdXfRudkQdJPlN
OsQvOry0BLw3daqjhu/jh9o/7PudX2Tt1KCO5jaXtQ85GPD28mjjvqSOSRfH
xEfLGTjZr99ta6kOnSDL8GcbGViv9MY8s1INzek6Dq36DHjeS3WlXaTCMeLv
lLURA+IHT1g1xFDR51Z9rs2EgTftYd1OwVRMSmo0vbFkQK+FFVRlRYVICVm/
w4kBzqW3AoxWUuHxSJ7UFcDAPO9MzvkTFEx9E109eIEB5RO/HVzjyEjJ+vI0
M40BrWchbXkHyVC1KDu6I5OBnMJfKr/Y52jWbbMfdbkMZGfTjT/okTF66Njr
jBsMfCIUwoK4yBhYMnjaqp6BfZKPPnVGk/BW/BbPg1EGzmXYj0+dVUVwS8TD
/WMMPFDxOWgWxX7PizIOlZ1goKmSolcWrAqrwf6hi/8xwHNKyLfEXhWNN4Sf
BS3WBVXE+q7jRlU0qIfHyojoQiMnzNH/pgrKdxgsTtHVxSbnbmuBzu2IM6mM
2WCgi4GKzg6exu1wZmzjvmyki2faypW8D7djkeqKlRXmusgQMN5BurYd5gJN
wu8cdPFxWbE/T9h2DDXbyW7w10Va9dD9WrHtEDX3sio4r4vpiCgebn9lHDWM
yS4b1MVnZ43ccUtFtLp6OysP64KvUeu6ko4iJA+YiNz4pgtx79KJCDlFvMjl
P5c/povH5+zmjZcqQvBPVmzyb10oTCb+LahWwNXiCn8mnx6CA7eXG8oroFlg
SFOeooddO2vXNgvLY1O38bv8GD28Wf9ed7OQLE7Wa5bYxunBszhGN5NLFj+v
yMcuO6WHmlm9fMnJbagP4iPtO6MHbZ8QPfe2bfDkbk1SydAD+1R/5njyNlxV
dTR4WKoHHneffrc126B4cm9Fzwc96O6UCeMUl4EGNTpFREUfe84YHld0kka7
hwgli6SP48f15gvMpLE/8WaHBFUf83dfZkrSpHFj4J2ojJY+eje5cxMy0tiY
opBL0f9fb3TrnZbCovH24h1O+rCNYnA2nJfCy+vbniZE6kMhgyrQ2ykJ541N
vzjb9NGy/YmBUegWTL1I6GMeN0Cr2E8Bh3YJpHK5BltLGuJj5KBfgL8Y1vSU
5y16bAivmNWy4w9EsCTiuI06ywh505Gv8rYKg+Oaa0mfgDFGJmedPm9cg6D0
kgSBemP86b2+MlN8NR7IxXHzB5hAWEiCbDe4HPzGQfKRfKZICzh7SMFjKboU
mttCq03RcW/t80uci1B6iZD87GqGQz9XN1A7ZgmXEgq/2JwZ5HQMKy7XTxMV
Tv/xNXOYI3kxr7bj9WmCb2kVb9RiczxJWbZyY/I0UeeszT3MbY5w0cK4D7um
ic3LdefL1pjD+c6x71KLpolBT6tR023myE5ctvc/vSkiQNTvebiNOR4KNbck
v58gjsXkHu+6bg7Z5zYyptRxYuXBZca7is3RX2m8PEdynEj39hcYLDGHhJZV
9CKBceKOiXr+jzJzDLdMKk+MjBGD/C2PF9Wa48YKh/nI/DHC5BIH97Y2c7xA
1lLHNWOE8F23xAN/zFE1qtAb+2eUyL/aYPf7rzlS60fiGjpHCeV0OfGjHBbY
tFzUR6JylDCKmCmJW2KBsvT4YtkDo0Q4I6klY5UFhrv/WJ8ZGyH6mmoE67dY
oG7zyospI9+I4iGxDD5TC+TwjK8ifg0TcVkx7j3mFtBJX5vk1zFMeFqPSt20
ssApG8Gy++XDxIbq6lIzewt0Fx58UBM0TJxM2vnktIcFuvaoB9p9HyK8KWnj
y0MtYOOt7/jw2xdic7Sg4bJCC8TJcUcJzw0Qc2rhKzuuWiArcN6d+nGA6Bzt
by0ssgBPyO2rB+sHiDP2d1z0b1nggMvqg/YnBoh5Wev9MdUWeBERdCpdYIDo
akm6tLjNAteUyCYSSp+JytiZ3W1v2devi7qANZ+JFE23bfnvLKC+OyPr2Ew/
YXJZsYzeYwHTOfVh57p+oupQ4/PjwxYgeTjnHdvRT1xQICdZjbDHP5ixPkWt
n2D1Zdps+mGBaNU8rgaxfkLG1K+3jn0Oyqw9u+fIUB/Bxfmm4MwMO76SuleW
vu4jPpZr+rr/toBrYeZU0Z0+oto3X0n5rwVSdTMsA9L6iIviK6bm5y0QME9U
mh3tI/4HIsKE3w==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$59048#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k41N/7P3BK2cqSJSqFEJJ1xpLtOZaZsc4YJiSSpFIpQqmkJKEsSaKS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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59048#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF13k8VF/cB3BbMfYlssYMsoTIvn/MjHVmUAhZQouSJIQWpSyJilSSCq1U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          "]]}, Annotation[#, "Charting`Private`Tag$59048#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13c0lm/4AHBFpbKJKPu19x7hul7vy2vLSshIQoOQhBIKUUYDIYUoe2Uk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          "]]}, Annotation[#, "Charting`Private`Tag$59048#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k0Vd//P3BTESWkoijVvUimutzBdJ7XPM+UeUwici9SqSRRlKHyLmkw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          "]]}, Annotation[#, "Charting`Private`Tag$59048#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxF13k4lO/7N/AWlSSKFlLZhchuUMx7hhi7WQyyZksqSgqVIpGUlKSSUEml
QpJE2bKHlK1FIbKlkCKlPNf3OJ5fH39wvI65zX0t5/m+7lvS3Z/lNWfWrFnW
5Nf//pp5DbwsHXxoMOv///AYrtrdKZpA/T9rpF5MfiCa/s/mDe25V0Tz/tnO
c/JpvGjFP79XOW4YK9ryz2nLraNiRHv/OZz3wboTot//2d7havboGA/+z4tm
wp1M1gr+syzz68Czk8v+OahRl3rxu+g/r8xb+mH2bPF/zv9oWP9ik9Q/tzHC
x2JN/vNEVvEKC9Z/phzU3Vqz7T8XCKtMlMb/58dGqyRyB/7zk4zRvQkJ0v/c
wb/hEiv1P08H7Chekvmf9al9vLEl/7m4/d2VyKH/XMJbXb0fMv/c5cfzRdNc
BhkDd5aNa4oZzGqlCY3bymBIravh2uIaA4mNRyj33WQwVz5v1VHGbwNcfeLk
v0MGZ7Tc9yV3i1HdFvwKV94vgxvSVKpWngY1bBfl5ucwGbA1bNd9OGZMTWsO
rL99UgYyRSoXvmziUkt1c8e2JcrgmsAI/0SNB7UrdWSF3FUZvFtVsV/Rcjd1
1nzlTb13ZGBW5ndwiX0IVWKn79Zr+TKYn7hx6cnao1Taq5tRbmUy+KpTLSL7
IobqrvPpztp6GbRpWa2hR8dTj6ZIvexok4HvzsUjSaMXqdd43CaSumWwnC6a
luCdRi33vSLmMCwDxUUDgX6yN6gPBnfscJmQQcyJSRULj0xquo9ekccsWcSc
LVORo+ZQE/p5F23nk0Xpuk+1HyoeUCO927f4LZNFZ8vS7fn1j6j7P93I3LtW
FjbrJaJOuz2hensG/gqWl0XGOiVvmcpSql0P3eywuiwOH455+u32MyrDfWlS
xCZZnClPycvtqaLqdncORhvLIiS5I98zqI6q6Jale9pGFp5RK4yrtjdSxToP
nTi3RRY1HMqsYdeXVH4X8zcXPWUhHEtx/FTcTP3TIaqQ4icLSBubXmK3Ub86
DgRfD5aFm+tI0A3xN9QXDpEiWadkkasybl/o3kktfc32eZAoiy31S1/37+qm
5thJFRSkyUIskyWhyuihxtuW2D3Lk4XcZH9NK7efGtESe7OmWBZPry1xOHdy
kBrIdppsqJGF0p8I7zsfPlO5zKnE1x2yMCugKYz7j1JNmqr73vfJoiL2BM+P
qjGqjnWids+oLHapRi6YpzxOFbXUaPvCI4dtOluHhmUnqB2MXcvnKsuB1qC1
kFM9TW2o3ujFS5GDo4TAuNu5v9RiY76Hi2lykFvzuuGu9iykGt3kiNjKoed7
ar2M7By4o/uccqgc2r5cnU1lzge7JLtH/bgcJmQUN6/fuQBGBoc1dM7KgTHw
URGxvJDdJNZMvyEH1Ry9Gr9uPgxQbIXsG+Qg/J6XJ69REG/ypd2d2+Vgz7Oi
9sPJJajT+nbfvVsOTcyl4gs0luKORhxz1w85mMReyuE/IQQ/ldozR9esw7vC
ev0w1nL8kNMXvLdrHVo8sp8b24jB4CO9OiZ4HeIjtfyVFVcj6grjiE/EOhwd
8T1oOX8NVizjjEhfWoclv/IreSvXQnv2jhdJFeuQFb7yXpyyJILfXYyLFpPH
jW+dz9mjMpiO+y7oWSsP4XeOK7v4lDFn6s4SMVlFhBk9bMnVp0B7xi2fnaUE
nbgrh2R2GaL+mGZjlaIKzi69cEZxnhnEz3yeuv1VFRKnxnTOLrdB8dYjt3PH
VcFv3C+zTsIGLhrCDkU/VaFxfsPJfEUbJLfpFdTPUcOhMv+yMqoNRNbE7B9Z
oYb43l+NJ7bbQChTflyTqoY/1wfrPxTZYF6F13BJnBpkJjpiTzgy8Xmy80Or
qjq43YN+WlEs5G+LKzfTVseblsuezXEshLUbZJRsVIe891S+zyUWVjy6suu2
sTr2rDhrH3KXBfp+x+lDTurQs1jcrfaKhaTvbaIy0epQ/rDg6m8xNhhjDZyA
TnWYNW1bWHuLDeGtoTr9veqoe18ZYHKfjQ9NSqudhtTxaJ7wkSeP2QjMOdmz
+Yc6VgfK7Y6pYyPV3zRAdJEGvEy3aT/8zMbEl4q4Um0NrDh5IZqmxEH6UFGd
wGkNyGhezVqSwYHfBWtp33MacJjyz6Xc44Bi1HOw8qIGGudHidjmcVB3hU/5
0HUNzBJM+xVQzsGYjUPcYIEGIkTr0vQ+cGDwaIJd0aOBAPUWwwlhW7yJUHsf
oqsJv2aFsgXBtrimWqnVaqCJQq+tlO+httj53v60qpEm5hbevtUWYYtZlDBq
v5UmXngmB4bG2UJuqPEqx1MTchLXTrEybBFos9NbJU4TPKoLeEVf2UJgzc2R
3l5NZC7ed1xAigtwI973DGrCwTc6apscFwFxrs8/ftVEZ4FW9iNFLtpmi9zs
+qkJqlbGEX0NLlL6ol06+LUwNtKm1GnIxYYc34ZmTS24xevqHPTgwm3QuOiV
rhby1Z2Xm2zjIl5K+vZLAy2sHdaT5dvBxUTCu2MvGFoYf7Czc18AF8UhFpue
O2mB1XG1oSeMC0vDDXfKj2khybB9+6pkLg4f4rtUdkIL8nv3djukcpHzsC+q
9LQWAjqOpZ25xsUy+VT34otaeJPWM91zi4sO/iWrCu9qYdvLRC+ph1zsbBuL
vt+ihZmWOdkzz8n4BRv357zRQtTsHSfyGrloYmR6Zn/QAlMivc7tJReaRe64
N6CFKgWx06ltXEynNk/emtaCiYnKnvwuLk5tf+idJqONu5FRPhbjXAzhXvQi
RW2o/jbtvvmDCxORG5n7VbSxs08heGqSiznVCV8t9LTRUmyx5Mg0FyEygfun
rLWxtXP7lmXz7ND2e8dFT1ttyKWaakousINms0fhiy3a+FsRYymz0A6j4ey/
N7y0YZBYz1682A7enepRrIPaOJIYa7xjmR0q8hVvPQ3TBqvxUa7iCjtInZaq
k4/SxhehAye6Vtrh/SYhgZkz2mhf7n5KRcwOnKSx83cytPHLdOawo6QdcvcM
PlpxVxuxKgrtjVJ2EDTtfhN+XxupNZKVOjJ2qJtsWmP/RBuXfVYFj8rZgWab
c4PnlTZ4L7u8HFlvhxSlW9X+7dqIvOC+R0TZDtNz0wbfdpDr14a0UjbYoSA3
Tvl+vzbiv3J4HFXtsCLmuPXqL9rYW2Pb4aJmh71bj+w5/k0bw1Zd8Q7qdtiw
xP+h8x9t3I5YmK+haYdT/d7tNXMo+FLeoyKsZYehYpcpDV4K6pqKrw0S39hl
pc8nTIHVga+xByl2mLPZ2HWfCAU/Mg4LU3Ts4LbaILxrDQVaFVF3B4lXP1eu
zJenIOzbPg1NPTscuCbbL7mBgpiEixvqidtD1iyM1aBA2TTTznEj2Q/m8vU/
dSgYfM142E0cL7/Y0sOAgrEdS61cN5H9meHxbzSk4P2hY/ItxFbt02d0TSkY
D5k2h74d7mZ9z023ouDTOt3S68QLo4ZbBDkUeJn/OvWX2Nu5d+KAAwVyt2ce
2xiQ/dTsEOlzoeDdvIXWScRS/C16TE+S43Jt7HfEYT3PnZ5sp2CoUa5JmGqH
D4XPDq/zp+B2ReFzQ+KN8UVp8YEUrKtnWu0gvrj9QfmfEAqWZ95xjSGewJ1e
nyPkftLRC64SP0n/fDnoGAXZueXJWcRHeZXYUScoeG0yNpRHzNi5k+/8aQrM
frv9fEAs0HS37Po5CnI/uTy/Q9yi8SU49yIFBeI6vsnESReUVcuuULCwXPdd
JLHb7139L65RYPkpR8aHWM41K+XDTQpUrw1Z/G+8w+Vfbb/cpcBlqeaWlcS5
ciqLp+9TcNj8LauXzDc4xr+C7xEFnYay+pnEBl+zD4o+oWAOX/ba7cQ8rFF1
+TIKTHm6/0gQ1z1UHdKuoqCn5Fb3S7K+3ND79pwmCiqzs1+tJV7dPSbo0UqB
z9/aL4Vkvz4aqVfveUvBMkNVBRtiP/4HWnG9FKAncbX3//Z/9/jwlUEKRB0C
PvaR+vjVrJF+9ysFD6ase92Ioy7nCdX9pODDSPUj6NrBYuZ77es/FNS66l/I
IPUm5KEV3j9HB0oqOxrnEaco5o/wLNYBv2SGa462HR4+flRPldSBdnnCi3wN
Uo9rfkZYyemgLaVmwwDpB4TrbHRerwNHI8k1wsT1jMe3D2jpIHRddpkt6afe
9sKoh6Y6+JEuOXhayQ6ZG3/rV1jpIMhbKDyW9Ofu1I0/XrF18F3ErytSkfSn
9xOPUWcdjITGC3nK22HZxFOsD9CBeUTFknZpO7x1+DupG0TGx0vPSSd5kPbU
IJtxSAef2o8yd5K8UIosWeMdpYOhyAP5g2vtYLSs7Fdakg7ucYParojaIVC9
Im/FMx34mGV1jf0vrzQl0s7W6IDvu/8BGr8d7LUPneRv1MGGRXWJMXykXvU0
3ee8IfNdmxO6kOTfHHq64NevOuirXCJTNMNFHPOYb+UqXXzer35kYoSLMHaX
LSR0UfV7ePDjF3Je2W6iFcnqor2wL7D2Mxdch+8r76vqYvXMOaHIfi5Wb/Ws
TDbWhfP2uYcffeAic7eRRGCALgL4na4ureciOSBt0UiQLqgTDenptVzEBk5P
bA/VxbK1Pl7q1VzsDs5rcI3WxYdnwZsNyrmghMkcNE/RhWtWU4JIARcVcTxt
UnW6sFrKEeoi51FnVsXJl5J6qJJysp4JJOfLF55h9XV6GDtxYdkict6VKm22
SFDSQ9rNhh9C/lykZVby21H0ECC7WG3ldi7cM6piOyz0IPogM+abExd9V2ri
+oP08Ozxvpxpct5+OVV/7k+DHs7R9EauCHLx27flssKBjTgy43F0JsUW62kL
/noXbYLjxI7BBU85MLkmue3+SgO8Prx41t5qNoLWuEp1O1ERF5zhE/6DBXcb
VW7HViokPlyIifjGglXE7Jh2byqyjrEyjo+wIDd4faxhNxUxD6xazw+y0JI3
UFp4jApf/zP2de9ZULUIcE24S0XsqRm+xCoWBg5EJptMU5FjMlJRTZ7fhrjr
fa7OAkLraNcXX2DBbVR4jvhcQECy/pltAgvm0p+0VvECbFOnluHTLEidOH5l
iRDw9eTnndrHWGji1O/8Q15niiLyX+n4s6A0bLuo3RLYKj5lvsCEhQKORUmM
DTC7/6iupxELhk/pew3YwAX/bUsqaCxsOa3y7oY9wGw7e/TUJhZOqC68E+gB
PDt0PRfqLPQFPjETCgESCtomKWtZSPsjFWOZDvjsLrfb9ZMJJW9Rg9k3gfFc
+c+KE0w8ahT8lncbGLEcuvx5nInG1GmH1dlARA/Xcf8IE39obQqfHwPqgwUH
7vcxsSXqRG30C0CfWnS0pJUJYcFR3opfgNdLb36jfCZePY05bvoHoHOp54/n
MRG/U3b+ixkynwCRHw25TAjVbZn7locG6hlNfY9s4sjKPyMCNPhwv8zPucXE
kt9J38Skaeg5LE9tvsxE022tPVdlaXix2yDFKImJM/ZNI3LyNMw5+qO74CIT
gvnzvqgp0xAfTVuZeZ4JgT27+00oNOyNdlLIjmOCv39zx15zGpIX7HUzOsZE
/fmuLVOWNFhIz4j1HmXilNHBN4dtaCgJjS2LCmdi0bWcthO2NNR0D9e3HGaC
z1nsZaorDQy+Ld/PhTDB2zxa+XwvDUOrnf6m+DNRE37SiLmfhtkPBhN2+TER
rSr3rC2Yhj8+S1dRdzGx4LRjaXcoDRednMaGfJmYb1pVOHmchh8hqzu8vJng
KbmcLZ1Mg62ZXO+AMxNvNxkxOlNo2HPLa85LJyayC4e7kq7SEDqv78IT8r6x
JV9fSOgmDWXSCoopDkzcv9cZOCuXhtMVmhMxtkxErY9e/CSPhqIvk69Pc5hw
uq2aEfSIBt79UlqJbDL+G+HtX5/QcKbVlJnNZMIlWVrvfTWZrw6P6CIrJjRX
1b+6WEfDZPXYA0VLJhZeDNzBaaDBSre50tKCibxzlcnPX9Fws6zUKsWMrNfJ
bTOP39MQ4uE/6WPCREHInYrEcRo2lrg/TKcxcXqS7cyaoEHEoanmN5jw2Df9
Y/EUDWMvd3G4+N9+Wa6L/EvDc9fjLcupTHj5jJzYu5COpQfLnYs3MaHXd0FK
hZ+OdX+zJNWIl3iiaEiAjsfdU/Y3NzLxxPXs8NZldKikV0mk6JF6stOwthGn
g7toRuChDhMDLe/6F0nRYXr86jZD4qesY2HVMnTsXPlWrZXChI9V630DRTrE
rRRWzSU2qA81+6VER1J3AyVVm9S3mVzPQxU61nrIVBkQF28OWqasRYcE31zN
aC0mEp6J3xug0HFitaiwOvF2Ws3mdD062iamt3ZqMrFMXzRIDHSMd5haGREP
FZYJttPpyGnF598aTJTq+N6K30yH4m7JyXziHZpFbxaa0xEZKLaF8r/Pm1rv
FljScWGWx6M/6kws3zV6ZJsNuX70uks1se/CRewVbDrUKtysE4hLbsjKVdrS
kfJH7IQnMVmaqb32dHissV+kQ7z9w5Z6KUc69qRfaBUgLj6wL/WlMx1PhJ37
B9TIfFeeCQhzo0N7WBFVxD4PMjereNDxIiuiM4P4qXWlyAcvOg51DFbEEAsN
d34+5UOH0kTnyB7ibdG/ijfuoKP50ICrE/ETmeXxQ7vI/ccil5kRLy1T8bq0
m47GFr3FG4m9nc10GHvpmH/rhKkKcdGU56LJfXRMf/5eI0e8JPHIhxvBdFyX
nImRJPZST7rPOUjH11rFOHHiwsa8Y3MPk+/z+tUiQSy444VdbhgdWvtHHWWJ
PRcMKW6NoGP5oThpZeLH13n+CkbRsfWnw3odYgGIvyyOpmPRzlcBxsQeHbrp
u07SwWN/cMqOuCCYE7T6NB1U/fbincSLl/ubPT9Dx71kn/JjxO73T6w5cI6O
5Jr7c9OIH1mmj8on0nFTRyasmJh/qPhZ+0U6mqrltLqIt0a9SYy6TIfGw3HJ
eWT9F5UI6Pemkfq72ZpqT+zmqLDk3HU6Pim4qhwnfjhp2EPLoMN5QfJ4AbGr
asiJ1Dt0vG4UWSlH6iOv/pyTVRYdIpSGwK3EC7dnqfzJoSN8Yg1PGvGDqz2t
W/LpMA4KzZMj9cdr8PfWwsd0fMif1eJH7PxW5FBBER0rzBZKFRIvELaSWlFG
x/tt54y3kHp2PFbg9/I5HUI+Q5dLSf3nSDTTwhrpGFk/KSpF+mXe0y/LVF7S
4bjJsTSKOPuHVNGpNjrsqEIRDqTf5m6LXcDoJuMb9ayVIf1pP/fW24keOhjH
2/akEt9LLb93o4+OhlUOemtIP9u9nmTPHaajOz5MTor0+x1T97TiCToMzHtN
mAYkn5QkDahTdARufVH9lrhYoOtdyW86fnyZN+lN8qOp2Xll2SxDpBrpuh4n
+fLd2eH0Mz5D/OkZ1x2gk/4OsDlUs9YQy6vOqCswmKjmCK4ylTTE+t6+9e+J
bSiNj2qlDZHes7LinCnZ32nz8Tp5Q4Rt/VrPa87E8SgT3wZ1Q5hzbkkLkbxs
SjKwf2VsiJ539n/TSN46hP75wTI1xBlllZ2HSR5/dH1yrtncEH6ZOttduGQ8
MnovWmwMIdvptVDOngnRbC3j9i2GWDdmXNhM8t39mZJmh58hsG32vZseTPz4
vGpJXyL5/8DYW/L7SN5c6a9OvmSI2cxZdX77mdCwzjvCTjbEnRuejx8FMbEn
13Kk9Kohfgqr/2IeYOJLcFjj5buGCNW923DzCBOf5vWdYpYbgjc5509bDBOt
4vcXPv1C1iuieJHWdSYCX4aW7R01xFqeFz+b0kkeRJiFKI4b4uiM8m7/DCaY
fT0DF34aon5P/vcHt5louLuiJmCuESbW8Ao55jBRqXsoSl7UCMuGukLEi0n9
sk3mJhgZ4VCGroH/O3I+mhdErjYxAsVZejnlPTmfDBV4b5gaIc9u37tZnUzM
0Vi0ON/KCFtPByslfWTCSujFitf2RvDcI5ncM0jyvImruHqXEeIzaPdekOeZ
VVbezPTzRtC994f+eyULRxiRqXl9RqiWXbyB35EFyfdmr69HbsY5h5MjJZ9Z
0KMcSxBVN8a5gtYIzTg22txFta9oGoM+KPI65iwbe09ntUtQjFHKKdrVdY6N
u59er5LfZAzDH9fNTlxkY22C8lVtY2PkCWebvrzKxpyxtnvsLca4aCRqqJ3H
xvNMherYo8YoQFqY+ms2fNqKfZZGGmPg5/WWbW/Z4JnD4Tt/3Bgal4xfXu5g
w8DhsGXyKWN0F3fkzHSxkbOguTkz0RgP20PC8gfZSPA81FWdaYypizWrOn6x
4bT2xdTsZmP8YRy80yvGgYBowMOiVmNIKvidWbKWgzLh5Xv2vTaG1upTcnoS
HMgtdBwYeG8MkyFFiygZDkbG+9peDBhjaES8arYyB0dr/z648tcY4ju6647o
c3ArcIOfrqIJed5598nXiYMt/i8VxpVMICYY4g4XDhb7Bn66q2KCo8cmS4Xc
OAhwLXSS0DJBc0fewiwPDjaaGZsvALleqHVZsS8HjeIu8q22JhgNz/QxCObg
R13sx93hJtB9n8R/7gwHHYtafaYjTHC+qr206ywH5RarR0iPQUvwEd/6cxyc
acz8nXLSBHdohWYPz3Og+Kp6WcN5E2THJH5OTeLA5c1sE4VMEzxyrjCuvc6B
0SrThry7JqDHLh5/n87BesczbGSbYA1Dq/frDQ5+dqx1s8szQflPyfB5tziI
79oYEllsgrLAg6Lz7nJQ1b/vTvcrE3hZR3uaPuDgrvxTtV2tZDyFQ/Ml8jg4
t52n4Ge7CdQmr6d8I3b7HF8h+N4EHOn1ySfzOfj1Nfu9fr8JbldZWp56zEGX
yqRH7aAJrlkXiNILOajebTDEGTZBvceh/HHihG/1EzvGTKAxuc/K7AkHKhOD
gkm/TXDfYnRfRTEHKyhqibJ/TZB6f4BuX8LBdFDw6vuzGCjQ5CnqJ66bmq9Q
M4+BXpeFSVOlHOToWWWzeRnI970xebCMgwsHz2t18jGwwaX2yxSx5x9p+oQg
A6crF58dKOfAzGBHTbgQAxopXZoOzzhQO5JrtXg5A7/XpblUEv+dRXOUWcWA
RMl2tTMVHPTSoruzVzPwUIf31Vfi50dfbNsozoC+tHM/o5KDizwugSwZBjy9
XV1HiP96rNR6KcfAQY+Xm/WqyP2fNf2wVmDglphwcRhxnVRMfuN6BiIbVSrK
iVWPGgZZbmAgu0idM6uag8TuaUq9KgNlUut8dYmnkf/TTIMBe0OROX7E7mn+
j2u1GBB0XiqSQlwzI3+AocPA0ew1t2qJN7h+1KvWY8D6ACNrlDih+PLvzfrk
+j/JcsI1ZL/W2D6poDLgFiS3WI3YLVQg1JDOwAf5UWcz4qqOav1yIwakmfOW
uxIrbQr/CxMGGlT2bPAnjr+sV1JiykAQDzXjAPHkr/EjBhYMPBU4EBxO7LTl
Hp5aMbDptPLVCOLyx96zNzEZiCv3XP2/z+VFJcoL2QwwPyv2hRCfDn5zVJdL
1ptx8tcu4u/t8YYF9gxcEDlr60y8hWLBQ3FkgJVsMm5CXJo4r/KhMwOpU/0v
lInlJoojNd0Y+CUeMCBAfMo22PiBOwNTh87qfibz/5antkDdi4EvOz6WlBPb
L/tcnbONARnG7ODzxMV706NVfBkY2Rnj4kEs0+xsmrWTgStaq3YrEceor+RT
9mcg9I/F7VGyX9yxEycVAxkQ+skf6Uv8xMbQ4vZ+Bry6X0lIEEvlTPPLhzCg
QLnX1kTq4auf/2nZwwxQzy+JkCbmNMpbp4cxoMJ5FVBJ6qlQ+aOgdAQDjcOi
/u7EkcOcsxLRDHBE7h6JJfU4ZC7ASo1h4O1WlVgxYps71UJrYxkw/3b7Ujqp
59W+egli8eT7bCeu3iT1ntcvfmFFMgNZ4vOX7iH9ssrkjd35FAYMrzg/aiP9
FZYRL7LsKgNhTvk0CrGF17ykpRkM3O68+nOA9GPvx6Fk/hwG5u5ySRcg/WpG
T3c+mUvqxbZW0pz0d85V57V8DxkQr5vZdbSAg0NuTakLChk4sGuuTzfJA+EP
D6/NqWCgQulVohvJk9P8oaGPqhgY1M/vc8nlgG+jkf3OWgaaqubNtrvPwZyL
rxa3NTJQ1yF+XDOb7BdzJPj2GwZKPeqD0zM58AvLZ7t0MLA59GLR7ttkPbJC
Nwh3MuDAoN3TJnnWvYi/91AvAy2lO+OySd41Vcpb24wwcE9cbIaTRub3fURh
3jcGxp0OeH1NIf0i9Yin8DsDW9LveYZf4aDkyOZC6V8kL7JuSSeQfM3SdZed
5DEFRfuyy84EUk/3Lv++ssoUrluqrnyK4oC3w72NtcYUjGU0n5WRHBzjU7y/
QMIUdWZj1+kRHBzcVuC9R9YUm2L4vCKPcOAr2frSSNUUmPCvLQrigHFe4Nbn
zaaYd41yY8ibg4pnrUfTGKbQj91+KdeTA3xLdrY1N4X1T6Xeve4cUKzXC5fY
kO/7bR780fl/5xvjcLyjKZ7tlgny53AwLzSco7vHFEtn+O+TVEbe2PBUyV5T
/LUxePCSnG+e3vapxvtN4XVRsc12I7mftcoQ+6ApmtkItdAm45d6f8Qv0hTe
17hB4+s54KnRuXP9kilulL0zk19B9kd4dLZAuSmWBFX+VuhjI/e4482ECjIe
g6pNPz+yyfNilYVYtSkyRbZfL+1ko/zTlQvy9abg3xvTQ33DxtECc2XDNlOo
+7Xp/3zOxmyXm/bBQ6aQcq8XZeawMeu2S/ZHITNU7aEo3wlko2q43S91uRnK
tMXrduxm45Qqc4OTiBl+l8s8kN3JxsoCw3uta8zgo+S9J9KDjQ3V8ndq5M3w
IqFg6DuTPC98+paRZWCGRaFtv88rs/FY8njKAV8zbHa7PfC9k4WApOxYoXIz
XK5TLvyqxsKj6aTj5RVmCAoY5qEosTDtEhUeUG2GtlU7SkLkWDgu7bzvVb0Z
vAcYiV9XsZB8l885vt0Mf1sHLRPnslBZ7KUk9MUMasHsme5mJkR6xJ4vFTGH
vvio/Znd5P1xfTTvUj9zjKYNq8ZdtsFSswClowIW+HFp76PgWkt0KDc1hzyx
gO2F79F6VabISaHK9LpYYot55z6+H5vhnK29dM1fS3LuxAXFk/fesMir4R2Z
VghJ/uSRZK+PewNrLgtYWMO492R6kTEF0Vci3T5YWeN5WpD2QWUKPFlfZLOY
1ohLrEwzX0bB6idPciztrGEtcV9E/KM2YuIcq065W+NRg6XY2cPa8NG+NMYX
Yo2U5N7NNwq1IHVsGWNBhjUEPdL6sqia+KtzaHH7LWu0J42y4+U18eZLz6uM
O9bY2qW/6vhSTZyxe+BsfN8aEfN2lqT3aGBGkbU38ok1Rq8LZ+VEa6DjZVzK
3GZriKo0V/K1qaMgatKjudUa7NlmXJ5SdSRsdFW4/toa6nn+LMFMdZjf2JBH
/2CNDToj5xwOq6MwuKE2fNAaJwr2bilZp45EZa045rA1zG6Mco2E1LHnYzJH
csQayUpTBW+n1SBvsbOz9Ls1fux9e3fjKzXwzG5JPzNpjZMDpgbzn6qh6+FG
X7df1qh1C9D8eFMNT3yvq6j+scaktnjci3g1XBBf9GNmxhoelWJWjaFq+H+9
QOp/
          "]]}, Annotation[#, "Charting`Private`Tag$59048#6"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3k41O3797VJjH3JGmbsWcaedd5mxlhnUIqSNZUWRNqVpc1OJSF7aVEh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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59048#7"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJxFl3c4l2/0x60ykjKSkTI+H/Nj7/U5x/rYM0oqKylCGSmFZJNVVMhuWmVT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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59048#8"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 0.5, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, Epilog -> {
       RGBColor[0, 0, 1], 
       Opacity[0.5], 
       RectangleBox[
        NCache[{
          Rational[85, 7], 0}, {12.142857142857142`, 0}], 
        NCache[{
          Rational[70085, 7], 1000}, {10012.142857142857`, 1000}]]}, 
     Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox["\"Prevalence per 10K\"", TraditionalForm], 
        FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {
       None, None}}, FrameTicks -> {{Automatic, {{0, 
          FormBox["\"0\"", TraditionalForm]}, {200, 
          FormBox["\"5\"", TraditionalForm]}, {400, 
          FormBox["\"10\"", TraditionalForm]}, {600, 
          FormBox["\"15\"", TraditionalForm]}, {800, 
          FormBox["\"20\"", TraditionalForm]}}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{35.6, {
          RGBColor[1, 0.5, 0], 
          Thickness[Large], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 63.99999869387755}, {0, 800}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}, {
              
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793443144245936*^9, 3.793443173348229*^9}, 
   3.793443209441594*^9, 3.793469059897922*^9, 3.793485147612919*^9, 
   3.793485628506813*^9, 3.793529276031761*^9, 3.793529762565795*^9, {
   3.793529803230294*^9, 3.793529922140222*^9}, {3.793530270960762*^9, 
   3.793530284504855*^9}, 3.79353139532828*^9, 3.793532112019189*^9, 
   3.793538241081479*^9, 3.793628682718582*^9, 3.793631362738474*^9, 
   3.793632431936298*^9, 3.793632611471447*^9, 3.7936328930369263`*^9, 
   3.793635136477975*^9, 3.793640076054871*^9, 3.793640113444213*^9, 
   3.7936402184188337`*^9, {3.793640708734174*^9, 3.793640738153433*^9}, {
   3.79364093528004*^9, 3.7936409965058403`*^9}, 3.7936410297184362`*^9, {
   3.79364138168408*^9, 3.793641392771151*^9}, 3.793707484796719*^9, 
   3.7937176718273373`*^9, 3.793718174359255*^9, 3.793718267674151*^9, 
   3.793718354085444*^9, {3.793718403764099*^9, 3.793718444527411*^9}, 
   3.793719540078828*^9, 3.793801391339316*^9, 3.793801473892439*^9, 
   3.793801567695167*^9, 3.793801637363703*^9, 3.793801740733006*^9, 
   3.7945070237922163`*^9, 3.794507352829672*^9, 3.7945074954424143`*^9, 
   3.794507540402739*^9, 3.794507662318475*^9, 3.7945131096016617`*^9, 
   3.794513178382044*^9, 3.794515315816852*^9, {3.794563786965438*^9, 
   3.794563795665794*^9}, {3.794563885511486*^9, 3.7945639685701942`*^9}, 
   3.79456864202136*^9, 3.794569002539386*^9, 3.794576049294142*^9, 
   3.794576685342681*^9, 3.7945781385445642`*^9, 3.7945784286199512`*^9, 
   3.794579361044609*^9, 3.794579490125681*^9, 3.794656575493943*^9, 
   3.794668122054648*^9},
 CellLabel->
  "Out[1471]=",ExpressionUUID->"3b0f804a-dfb8-48e1-af42-844e7690884f"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5E.pdf\>\"", ",", "figoneshotinfscrit"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5E.png\>\"", ",", "figoneshotinfscrit"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668063376121*^9, 3.794668070417458*^9}},
 CellLabel->
  "In[1472]:=",ExpressionUUID->"158ac736-4b47-4614-9712-55965e81b866"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figoneshotinfscritcumS", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sols"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol20x2xinfs"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol40x2xinfs"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60x2xinfs"}], "]"}], 
      ","}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindow"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "\"\<Jan\\n2020\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Apr\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
               ")"}], "/", "7"}], ",", " ", "\"\<July\>\""}], "}"}], ",", " ",
            "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", 
                "+", "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", 
             " ", "\"\<Oct\>\""}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"52", ",", " ", "\"\<Jan\\n2021\>\""}], "}"}]}], "}"}], 
         ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "line1char", ",", " ", "line2char", ",", " ", "line3char", ",", " ", 
       "line4char", ",", " ", "line5char", ",", " ", "line6char", ",", " ", 
       "line7char", ",", " ", "line8char"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"amplitude", "+", "baseline"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<No intervention\>\"", ",", " ", 
       "\"\<20% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       "\"\<40% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\"", ",", 
       " ", "\"\<60% reduction in \!\(\*SubscriptBox[\(R\), \(0\)]\)\>\""}], 
      "}"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793641180339437*^9, 3.793641315838718*^9}, {
   3.793641443959331*^9, 3.793641448676724*^9}, {3.79364150849207*^9, 
   3.793641549374053*^9}, {3.7936416596344843`*^9, 3.793641664167588*^9}, 
   3.793707464001343*^9, {3.794563822721657*^9, 3.7945638288261623`*^9}},
 CellLabel->
  "In[1474]:=",ExpressionUUID->"4e2badbd-c7ab-4c43-ab1d-666d75968b76"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxF1Hk0VW+4wPGjKJUfGSo0GSKZkwzH8DwOmc6EKElCKSkSElKGUJQhqQwp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          "]]}, Annotation[#, "Charting`Private`Tag$59360#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxF0Qk0VfsXB/ArRBEZKpRZhkpJIhr2DpnuFCklc8QjY+KiQqUkMiRJk0ql
CJnqRUiKlCljuefcnuQR5TVRxv95a/0fZ63fOuuzvr99zv7tn7Kbv43HHBqN
VkWtf99WHv0tVQMlW2j/fwRM5AJ4sqnwn9ddS79cJJs1Y3pDZ+EV2eIZ27mP
PkmRrZkxseaUSYJs24wzF7FPxsn2zjhauEjjtOyPGe/ecz3/n68C+J9FpqMd
zBXEZ7zc+kv/szPSMw5tNIT0H7IzXlIsQfLxKc64tMfkddMmlRl3WER/TTCf
9UhexWKGzawNIgxd6zxn/UhqzUhVyqz/NJVTKuyfdfntfw6mpqrOmCu6+qLN
tVlPBPlULLw3683QJ5xQOeuKzu4rMZ9mXSlcWxuCajN+7yfwWY/+r7800lUE
gda+VfL7TsqZtbreHjqgtDHS4IELZWEFi76VWwCvlzv4+1AuzgnePbUNXITG
orVDKPff8tf4woAoX4M7g1GUG9sWVX23hirDwq+eaZT1hwU9pndDtfeVpXuG
KNcrHzFm+UDRgI+P0wjl5YOJ+Uq+kOVlVLaPthxpV1oypX77Qcz+Tns/6eUY
NVdQlO4UCCEfb907qEC5o2JQ1DYI9rsHj3E0qf2i526vYR4Euw/GVkd1qdxD
4mCdZTBYuElkHN9E5YPHI4csD4HhX7yBWDPKWXpjBcwQWOGSZ3h2O+WPAjar
K0JgKe/w6XP2VL19np7BZAiIOtHfprtTecTw1z8hFCa5slpX/aj8Qo9oQkwo
fNnbz7nJoZzcIXa6MRSa9sTI5MVTVncP8P2DA1VdO7yK0qh63gEPqTIOFNip
PHqUSeWWWdKO4mGQsrPS7lkxle9waAysDINd1r/TuriUu/5unjSKAK6F7yJ+
bXWkmZZK0xOPQkPtRg9hA3WMErAt4/BFQoXZ/JIFWynHJozpHYqEa6Z3bGV2
Uk79JnRJJwrc8K9z2kfUEb/ttsPl0dBvsFNydwP1vXhx+fOrj8NP9c3i9301
kHbq6KdHpadgS49xbRxHg5ofna9pfiycvGIR6XVcA/HKO6/zzrGwWNp2WPUi
5ZXb3q4TOQ36fD5NGTXUfps/aBXeccDpTk+MXaqJVeZ/H/OkJ8BE4g9x95ea
qNQ28uXQ9mSY8ztn4dLlKxAj2nuaB9NAf9qldEfeKtxuEFCnGngdXp/Qa3yx
Yg26sJJEnZZmg2LS4O+7X3SQU/rDV1yoAAZHeWS7ji7qfMt2ThktgqxPZfVi
Z9fhwrIQZUHHRyAmf2e4t1cPZXINHjoVlEP8HyX7M9X0Mf28DF+dTRWMYE6v
V6QBWmR8S/byqIZg3Zrixc82YKzcr3ttW2qAl1dzpkXZCEUvFR+6qv4Cxr3b
LmmFb8TXWbkKJp9rYeVWoan9ZZvQ9p2sYOCxl2B+Q9nzwZItqFa1fb+a1isI
lXdW+csBMNjOnHs6+zWsGtop0slELHBNLlwm1whS4v8I14whMu7K/6jLbgKB
ykv5qpe3IseftS0msRl89MrezqMbY+n3a+2Nji2QY+mWWTFijBa3ekPear+B
n4NyC/vSTPCsikTl5pE3ULLDnD/V1BTdTB/qBnS2QqRFzLXiPlMUTVk/f/OD
NlAmrLpuxmzD1AtPkw0S2sHI4ESqrK4Zzu1/+tgtugMcFJp+87WaoQN/gv9t
z074WZ/QExBtjitSff24zl2QLuAUbKNmgUFin3a1bX0LUmTJjTk1Fhg7L2d3
yKJ3IHgk2tYw0BKrGms/rhp8B7S7Tvk9klZYc1dRnS+zG4Iy8hMkq62wq814
Ti6DCw8nMk5V11jhj+XaGxTZXJhwOhkdVGuFC51iyCRrLpxSdTz05rUVLt74
IMJ/Fxcu5853TOm0wk95Nt9kXbjwvMJjleRnK+S4JN9WPcgFmQ9LX0nI0PGT
qm75vHQuPFkZKyzhR8eowBF+ZYIL+m1LGlIC6FiQoZwhyuNCweE7ydIH6dj4
zaJ95D0XbjS8kJPh0FGhfdyotpcLsf6C2orH6HiVl/rSbogLNkXHrLXT6Fjn
mqK+YZwLfxsdybCsoGNN4N+ho0sIkLAKWnVMjIGXW8/ZRDIJyHwqLmIkwcD0
DyvsNrAJ0DG8P/BVioGFKZpvh7cTwNLsv+0qy8CzQXQ7e1sC4uY6KW9VY6DA
wy5L+b0ECDyzXEwzYmD9XA3OXi8CRjYq0456MLAjvpRXHk1ATFEFud6LgUYO
kG52nADplQ5PPnszMPjNOK/xBAHr5C6EOwYwcKoyULH7FAEBv0R/bopgYNTo
tF9PAgEDxb8GxpMYKJnQR+ZeJICr3dwaVs7A8Nfrs9YXEHBtUOIIfyUDkzQ1
3SIeEOB2d4d6wlMG7grh/1pZSNWrdXIyXzBQht5wfFsJ1d9SUr62meonu/Cs
8WNqHvOHPKU/MvC94bJygRoCzPqEJvIWMPHT7r337ncQMC/L8taGhUzkiDy/
39hJwGvXM6xqSSb6+Xmf/9JFwA5C7Hr7EiZW1RNSK7sJcGlbZDahzMRs+gCZ
xiMgolo1yVKfiY8znm426ieg4Cqo9ToxUcZb4UbxLwK+h38XcnVlYtymcO+8
3wTo290ZJPYxsWfn8Po7YwSUiYsXdXox8UbIva7zEwS8iCK3vgpiopKKsLMn
jYRutyPOhSeZWJ93dKJbiIS5GmUZUXlM3D/kzhNfTIIlv//RyQLqf0orTAYp
x/NU3MKLmDiVs6Xi+RISJNLjtIIfMTHW8cNEqCwJy+bZP/KsZqKb4tj9lmUk
6A7+amd1MLFAQMvXXpUEx3x9CfkpJkYVLeh8voaEUvtfYs00Fp5w3Xz5vA4J
YnMfix7nZ2G9V6qn+1oSqhw2Cw8Is5A1NSo1rUuCynzT6WIpFubdtH6nqU9C
n7v1Z4YWC1NerW1lbSLBT+7Ay8O2LMwdCVL6ZE7Ci+fatWvsWGjlY7vpsgUJ
ioHDNT17WOhlb8hhWpLQXBtUZeHMQqcWsx33rah+D4U9lPZmIUNqKNeNScJo
08lbuZEsTCPGr2TZkBAVcz2ae4+Fda8Cp+McSFgQKmTlep+FATnPY2QcScjw
8pXsy2dhTR3P6RblIrrhzeFiFo7pfhZ54kT1K9FSM6eShcgvt6/XhQT6VZqw
VisLNZt3JUl5kLD4ofPZQ+MsTBqIUft1gISb2c93jU2yUCH4hV6gLwk6GSsV
I2lszB2yzBmgbHlkND9WkI0VQ2ENXX4kHDZJbLkkzsbqtQqj+QEk9DRVSFer
slGgCd2Mg0m43y9/SYzBRpvFxTfGw0mIvRLjQrLYmC5xPt4vggR3m8/L86zZ
qLCWbHhPeVl5eQHTjo2cB3V7nh0mIS5x74t4NzbGm8jmRh0lwUv/4tf5YWwc
qdzQw42m7ueEtIXQbTaarnvToRRLwtSGwws6s9mYVBimHEX57ecPb27nsDFc
c1M3STnJrsjR7AEbUy5OXs04TcL0CpuDMeVsdOnbFSFyhgRuS+JV/lY29lj/
lGtNIOHRydF9re1sdOKj3dM6S0LqRmetm11s3DKuURRJmX5rdbExycb6Exf0
VySS8JjT8DJ6gJrHIa1FYUkkpGmvT7QeYuONhMlTrygH9ly2VR6mzl+9LFw+
mQRNxgFe1Q82vmPzyErKAnxtWUmjbFwl1mazMIWE9yUbvV3G2JhVUmrhQrnc
++YanUnqvL/XPM2nfEFR5Of0NBsl4/vLpyj/DxGwLT0=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$59360#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxF1nk0lPsfB/AhLrfcEHWbilDWyjIYTP18viRkaWxJJSbZIpKErm2QtTTS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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59360#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJxF13c41f/7B/BDKiEyyig5RkhCZubrZe89osRJtpKQKHLsFcoonCNHOyMN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          "]]}, 
        Annotation[#, "Charting`Private`Tag$59360#4"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, {}}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, {{0, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
          FormBox[
           TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {True, True},
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> (FontSize -> 18), DisplayFunction :> Identity, 
     Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
        FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
       None, None}}, FrameTicks -> {{Automatic, None}, {{{0, 
          FormBox["\"Jan\\n2020\"", TraditionalForm]}, {
          NCache[
           Rational[90, 7], 12.857142857142858`], 
          FormBox["\"Apr\"", TraditionalForm]}, {
          NCache[
           Rational[181, 7], 25.857142857142858`], 
          FormBox["\"July\"", TraditionalForm]}, {39, 
          FormBox["\"Oct\"", TraditionalForm]}, {52, 
          FormBox["\"Jan\\n2021\"", TraditionalForm]}}, Automatic}}, 
     GridLines -> {{}, {{0.5, {
          GrayLevel[0], 
          Opacity[1]}}}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 63.99999869387755}, {0, 1}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {None, None}}, Ticks -> {Automatic, Automatic}}],
   FormBox[
    FormBox[
     TemplateBox[{
      "\"No intervention\"", 
       "\"20% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"40% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\"", 
       "\"60% reduction in \\!\\(\\*SubscriptBox[\\(R\\), \\(0\\)]\\)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.793641203155878*^9, 3.793641316106018*^9}, 
   3.7936413911673326`*^9, {3.793641450128614*^9, 3.793641457813911*^9}, {
   3.793641514659644*^9, 3.793641549701622*^9}, 3.7936416699497128`*^9, 
   3.793707485144012*^9, 3.793717672169283*^9, 3.793718174752056*^9, 
   3.7937182680018597`*^9, {3.793718430471394*^9, 3.793718444976821*^9}, 
   3.7937195403741617`*^9, 3.793801393609724*^9, 3.793801474194271*^9, 
   3.793801569935988*^9, 3.793801637647945*^9, 3.7938017410853558`*^9, 
   3.7945070244257717`*^9, 3.79450749572329*^9, 3.794507540675671*^9, 
   3.794507662632415*^9, 3.794513109923526*^9, 3.794513178687973*^9, 
   3.794515031986408*^9, 3.794515316140401*^9, 3.794563835964757*^9, 
   3.79456397550954*^9, 3.794568642380332*^9, 3.7945690029043293`*^9, 
   3.794576049770125*^9, 3.794576685780991*^9, 3.7945781390743513`*^9, 
   3.794578428929961*^9, 3.794579361332246*^9, 3.794579490422999*^9, 
   3.7946565772913227`*^9, 3.794668123021324*^9},
 CellLabel->
  "Out[1474]=",ExpressionUUID->"589c0b34-38cf-4617-9ff6-fb60da2a5af1"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5J.pdf\>\"", ",", "figoneshotinfscritcumS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig5J.png\>\"", ",", "figoneshotinfscritcumS"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794668084300685*^9, 3.794668089711461*^9}},
 CellLabel->
  "In[1475]:=",ExpressionUUID->"e444002b-4141-43dc-89f1-7c18c808d8ac"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Define key variables for the brakepump strategies:", "Subtitle",
 CellChangeTimes->{{3.7936320927682333`*^9, 
  3.793632103734219*^9}},ExpressionUUID->"00ff2e95-e28f-44db-8101-\
7110726850e0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dateticks", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Jan\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\\n\\n2020\>\"", ",", " ", 
          RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}], "]"}]}], "}"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", "31", ")"}], "/", "7"}], ",", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28"}], ")"}], "/", "7"}], ",", "\"\<\>\""}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Apr\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28", "+", "31", "+", "30"}], ")"}], "/", "7"}], 
       ",", "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28", "+", "31", "+", "30", "+", "31"}], ")"}], 
        "/", "7"}], ",", "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], ")"}],
         "/", "7"}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<July\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31"}], ")"}], "/", "7"}], ",", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31"}], ")"}], "/", "7"}], ",", " ", "\"\<\>\""}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Oct\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31", "+", "30", "+", "31"}], ")"}], "/", "7"}], ",", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31", "+", "30", "+", "31", "+", "30"}], ")"}], "/", 
        "7"}], ",", " ", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"52", ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Jan\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"52", ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\\n\\n2021\>\"", ",", " ", 
          RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}], "]"}]}], "}"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", "31", ")"}], "/", "7"}]}], ",", "\"\<\>\""}], "}"}], 
     ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28"}], ")"}], "/", "7"}]}], ",", " ", 
       "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}]}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Apr\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30"}], ")"}], "/", 
         "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30", "+", "31"}], ")"}], 
         "/", "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
          ")"}], "/", "7"}]}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<July\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30"}], ")"}], "/", "7"}]}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Oct\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30", "+", "31"}], ")"}], "/", "7"}]}], ",", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30", "+", "31", "+", "30"}], ")"}], "/", 
         "7"}]}], ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "*", "2"}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Jan\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "*", "2"}], ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\\n\\n2022\>\"", ",", " ", 
          RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}], "]"}]}], "}"}], ",",
      " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", "31", ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], 
      "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28"}], ")"}], "/", "7"}]}], ",", " ", 
       "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}]}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Apr\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30"}], ")"}], "/", 
         "7"}]}], ",", "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30", "+", "31"}], ")"}], 
         "/", "7"}]}], ",", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
          ")"}], "/", "7"}]}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<July\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30"}], ")"}], "/", "7"}]}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<Oct\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.793632640692789*^9, 3.793632685445394*^9}, {
  3.793632744520358*^9, 3.7936328793266993`*^9}, {3.793634107458564*^9, 
  3.793634107565778*^9}, {3.7936341556035767`*^9, 3.7936341972983093`*^9}, {
  3.7936342501744833`*^9, 3.793634377950547*^9}},
 CellLabel->
  "In[815]:=",ExpressionUUID->"6c8da3e3-82a0-42da-b25d-2e815c2938d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"yearticks", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<2020\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", "31", ")"}], "/", "7"}], ",", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28"}], ")"}], "/", "7"}], ",", "\"\<\>\""}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}], ",", " ", 
       "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28", "+", "31", "+", "30"}], ")"}], "/", "7"}], 
       ",", "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"31", "+", "28", "+", "31", "+", "30", "+", "31"}], ")"}], 
        "/", "7"}], ",", "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], ")"}],
         "/", "7"}], ",", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31"}], ")"}], "/", "7"}], ",", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31"}], ")"}], "/", "7"}], ",", " ", "\"\<\>\""}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31", "+", "30"}], ")"}], "/", "7"}], ",", " ", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31", "+", "30", "+", "31"}], ")"}], "/", "7"}], ",", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
          "31", "+", "31", "+", "30", "+", "31", "+", "30"}], ")"}], "/", 
        "7"}], ",", " ", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"52", ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<2021\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", "31", ")"}], "/", "7"}]}], ",", "\"\<\>\""}], "}"}], 
     ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28"}], ")"}], "/", "7"}]}], ",", " ", 
       "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}]}], ",", 
       "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30"}], ")"}], "/", 
         "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30", "+", "31"}], ")"}], 
         "/", "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
          ")"}], "/", "7"}]}], ",", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30"}], ")"}], "/", "7"}]}], ",", " ", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30", "+", "31"}], ")"}], "/", "7"}]}], ",", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30", "+", "31", "+", "30"}], ")"}], "/", 
         "7"}]}], ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"52", "*", "2"}], ",", " ", 
       RowBox[{"Rotate", "[", 
        RowBox[{"\"\<2022\>\"", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", "31", ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], 
      "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28"}], ")"}], "/", "7"}]}], ",", " ", 
       "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31"}], ")"}], "/", "7"}]}], ",", 
       "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30"}], ")"}], "/", 
         "7"}]}], ",", "\"\<\>\""}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"31", "+", "28", "+", "31", "+", "30", "+", "31"}], ")"}], 
         "/", "7"}]}], ",", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30"}], 
          ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31"}], ")"}], "/", "7"}]}], ",", " ", "\"\<\>\""}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"52", "*", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "31", "+", "28", "+", "31", "+", "30", "+", "31", "+", "30", "+", 
           "31", "+", "31", "+", "30"}], ")"}], "/", "7"}]}], ",", " ", 
       "\"\<\>\""}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.793634539483279*^9, 3.793634590732162*^9}},
 CellLabel->
  "In[816]:=",ExpressionUUID->"9fe2ef70-13fb-454c-b930-d7d1fbb80de9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ar", " ", "=", " ", "0.25"}], ";"}]], "Input",
 CellChangeTimes->{{3.793632109076126*^9, 3.79363211277901*^9}, {
  3.7936331278836393`*^9, 3.793633127947372*^9}},
 CellLabel->
  "In[817]:=",ExpressionUUID->"7afa628f-97d2-486a-8ab9-6fd40476cbb9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"imsz", "=", "700"}], ";"}]], "Input",
 CellChangeTimes->{{3.793633123776762*^9, 3.793633126128378*^9}},
 CellLabel->
  "In[818]:=",ExpressionUUID->"14594e26-5f8a-4316-8cbc-3e05dbc85af6"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot the continued rise in ICU cases after implementation of distancing, with \
prevalence, no seasonality: \
\>", "Subtitle",
 CellChangeTimes->{{3.793445775253668*^9, 3.793445791735546*^9}, {
  3.793461803106874*^9, 3.79346180437956*^9}, {3.793463026329142*^9, 
  3.793463027507155*^9}},ExpressionUUID->"fb792a7c-f381-4779-a818-\
b3e4fb688e55"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sf", " ", "=", " ", "0.02"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prmax", " ", "=", " ", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.793446122258461*^9, 3.793446135642728*^9}, {
  3.7934618271568108`*^9, 3.79346186369106*^9}, {3.793462009540318*^9, 
  3.793462018321295*^9}, {3.794657135293096*^9, 3.794657136402939*^9}},
 CellLabel->
  "In[918]:=",ExpressionUUID->"4c5d5961-717d-44e2-afe2-88af450c060a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbp", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60bpnsprev"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", "sf", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60bpnsprev"}], 
        "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", "sf"}], ")"}], "*", "#"}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"dateticks", ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
    " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Critical cases per 10K\>\"", ",", "None", ",", " ", 
       "\"\<Prevalence per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", " ", "Black"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", ".000089"}], ",", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevon"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevoff"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7934461917708607`*^9, 3.7934462838598347`*^9}, {
   3.793446322446604*^9, 3.7934463225391617`*^9}, {3.793446417493855*^9, 
   3.793446493716259*^9}, {3.793446527768334*^9, 3.79344668076748*^9}, {
   3.793446762278329*^9, 3.7934467828855133`*^9}, {3.793446951803142*^9, 
   3.793446955141111*^9}, {3.79344707334725*^9, 3.793447099371722*^9}, {
   3.793447159075315*^9, 3.7934471754116783`*^9}, {3.7934472158450813`*^9, 
   3.793447223477141*^9}, {3.79344729650998*^9, 3.793447304161545*^9}, {
   3.793447499123787*^9, 3.7934475264506483`*^9}, {3.7934618795755053`*^9, 
   3.793461889980399*^9}, 3.793462004628837*^9, {3.7934620364212713`*^9, 
   3.79346203990898*^9}, {3.7934624225659227`*^9, 3.7934624372262497`*^9}, {
   3.793538845392705*^9, 3.79353885312326*^9}, {3.793631496644718*^9, 
   3.793631523669509*^9}, {3.793631709352571*^9, 3.793631710201035*^9}, {
   3.794657145267626*^9, 3.794657146676478*^9}},
 CellLabel->
  "In[920]:=",ExpressionUUID->"45a3df58-5316-469f-a43a-302cb907a9f6"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEuXk81O/3/0+LRIsWhVSSJbtk386x78wYkSSRPRWFUKKFEilZEpIlW8iS
iFRkqZAlyszY15kRJYW06Pf83G6/7+vtH7fH7Xo+zznXuc71PPfDHpfT1m4r
2NjYPnGwsf3f7yEO+Y8eOs3abP//z8Yi+oyh90P4f7qEnfuEgHfFfzpMOlti
lXfjf5qh85VzyavnP51qnhj03Wv8Pz1P9iyd9frxn87qIZt/9VqF/0+/GHQ6
88yA9z+9Zs2P4LqU3f9p7TedGw0a/qcDrxXnvPv8Pz135Ymn1y6h//SxVScT
zpz+n9ZaPfz56qY9/+kFjuaUgoPC/+nNHhUTn73+p2XeZMnLXvyfdr0W1lye
+z/dvUZt7vni/3QpZ5FJ+729/+k2z5QEnsf/04y314esX/9P74pyC+id+p+O
Wbs7c1hD5D+d77V+WpgkglK0ueHwOCXthne/ld1cRXDlF8fKIv9y7UGJqUt5
QSKoN/Mpyc5pTPtXFLWNFSOCA8mDYkM7V8K2qebt0pkiqKb0rrpmtwAomD51
OfVUBJ/uFRvOoUmD5aPs4tJ3IvjO8OxusUIN8OK683NuQATjroZYya4whm33
5Xunv4ug0131Tc+22ECjXMfTybWiWFROdmrzcQK/1ycThneLos+Bzb2f7T1g
18F1Z+lKopiVdeEPV44vtDIekXvMRHGbRk3Vqy+BEBRiIt/uLIoOJwSeFFZc
BNH1zA1vz4liM3dGSdv6q/DhQeRM/U1RLI+41XX+QRSEKYi2Pc8WxUKtmb7C
dbdBuqnh0dNqUZzsFnb9UhcPNDuXqJIOUXxSAP/Of7kLkVNsngUTovg6QsdO
OykNDoQ+MMz+LYqjCRaZYv0ZMLxRW/T+JjHcsCnpH/ujbFBXOj96W0sMC1+K
pBQvFQDjDX/9DYoYelSZ5zwPLoaEw88eXPUSw80OKzpS75XCl7D5I0GJYljP
ozPDn1cBqZsTNM4UiuGN3uPZJZ8qwThHQcCnXgy3u5qrVAlVQ3bL6V6nGTG0
1nAb/8j+EkiOGyrtV4rjRc60b9NmdbD8tSiBwi+Otw0SY/iy6+EQ7xTZyEAc
35+n+f/yb4R1x1zbZO+L45KfRuzD1BaonltRuO+JOJ5VXCro1WwD94jMKOF3
4rj+63Q9beI91D0aNNw2L44hondnhnI6IWD+UP1f8334zsTV6otYDwzesKhs
+7MPVxTSkj4o90H0zumE5s0SaE09szy5uR9US2+crdsngfV89fk50/1w5+Mb
+QobCbyp54ECyYNgJKRbmFokgdTW1OvnxofhR/lwVOJrCTQ7VXRmi+EIZBmE
ed6iSmDBwk7n2pwR+ONdK3pllSQ6503x/jo6CqVPlTO8j0ii+bd/IT1VY9C0
wnz9jK8kuga/EN2/chzoVs4hpyMk0bPic2Ci+Tismoq28X8siTvVpMY9aePA
r5JZv/BaEjs6N2z+KDgBslcrZYN7JXG0fG6bztEJsNs1wnmRTQpnD1xYwd83
AT4nFgLYeKVQNvQb2/VtkxD+jHvssoQUTm9+L/3bahIeWSu/uGYthcIXpq8s
1k7CcmS0X9xDKQyf8dpXGsaALT0Zg1uqpfAwU5X5oJAB+/ZUmiW9l8IQWVHh
io8MsH4+LJq6IIXKv5rgmAgTPDgX7uzklkaP/Zopq0yYcOEgN1vGbmn0Djlx
Y+IEE3K+KtEfGkvjJZ6lW+eKmFCjaWYk7iiNa/m3yCq3MKE96lhFgZ80Lt/v
UTefZMLYp4A90pHSaOw3eb+OjQU/90bHPk6RRreU32tT+Vmw3i/jt3yJNOr9
Odg4Ks8C4ZdPPZ80SKNjI8dCuiELzA8N6z6blsauLkpY3EkWOOfMl6izy6Bb
vdCK3ossCJzj2vmCVwYtkt2GHseyIBqEboCkDA5o1d4Sus+CjBilxXptGfS8
9zL6wCMWPKWZuupTZPCd6yfjr09Z0CJ2rKvZQwavCs9LONSxYPBsgLbJBRk8
0cOXdvEdC77X3ShsvS2Dj781bnDuYgHnhgw+yxwZPPvtwre1VBYIOjyN6KyW
QeX81gfhAyzYn98yZ91OxLfotqJthAWG80NOH0dlML+YH7+Ps8BBd77NblEG
gxakbv2dZIHvLS51OrcsUv6OiM4xWBDRvzvviJAs8rsZ81AJnSKhtHVIURZn
tmPJU+L5kkDTS84mslj2elNHHGGvscHpy5ijLKbk9JmfJfxReQIc3M/IIp2t
drUzEc+M4423zEhZ5Cz/cseZiHdF4QOlE6myWONxtSXkAwu2/azImimRxVL3
exuetLJAyqBlo2+jLO6ovtvO08gCvDN0YY4qi1JerOCU5yw4OPSD5T8ji748
U0K25SzwluayW2SXw/LD/ltN8lmQ0Ky4/4+kHGZxNWROx7GgYItp+kWQQ+5H
CvsKIljw8pgTN7uNHM642ElUBLGA8StqYnWoHOZUSDx/e4QFsSFEUcfL4c3r
FkZJ5ixQ/LWVEVwgh0PUjvAiDRaELz1gznyUw34hu5ft24n6+UOf994uj4fY
/xyMesuE4edaC9eE5bGG48le4ydMqDifsfBQRh6P1l1jC7/PhMO/3RYH9eQx
wPbDipO+TMj7NfvT2lcenUYdh5t4mBBSQ1k6fV4eBbq3PexZZIBlSOVSTKQ8
yllkfLs0yIAfS+d/NafJ467fA1XvHjEAlzj+qL+TR8F/a/yjgQH0RcF/wsL7
USnqywp+x0korgr7BzL78bD5YTcmEPf33Oi/I6r7sXR4R9Et4UkQX8xju2u5
H+/Zj+w6w5gA/wWFFdzn96PYXNCVodMTsH7eePX37v148b2s/oHQccA5f+6G
CAX8+UWimpI0CksWRhJFtxUw+XzY6TdBo1BewG+UmKqAPfO3Os0cRmGv88vL
HmUKqLGmxDRKaBQ4Otf84h5QQJepy6JThSPQWpzCtFE8gCdvHDQeah4GW6+6
psnRAxghkDH+fe8gbGy6M9YxcwAvOvkLn/k6AG+F3Nirfx7AR+ucVBSeD4Aa
da1W9AZFzJoo5wmmDICgEaVCTl0RvzfOXZC81g+jIpNZQXGKiJZKBx1/0yE1
/Fmdc5oi1lgycne00sGm/8agaZ4ibpufmhFNpUNTvJzAzheK2EhNc7LSpEP+
iuC4eqYiUj9Q3bdH0ODYUbOSR98V8bdWaoaMPQ34a3a+j19WxFfv85+pydLg
ht9rTvetSviaN7wtvY8Keu8TxKx2K2HWxseOMhVU+LPPQ19VUgl3rc4+KRhL
hZPD3OFcqISJGgOvLxlS4fA9/gkVUyU8S26JsxengqG1uKmbjRKm76TaPltL
hQPcSiV3jiphrZHu09KZXhBq1N1a56mE9JS3lTbdvbAulBQ8c0YJp37EHn1a
0wtLSkcHBUKV8G+Z3a2x7F6Y/HJCz/iaEv74Tvf+GtsLH/KC8wPilDDMJNOM
eb6XuB/X1menKiGJXd9zwLsXCvkTz3TmKKG05+q1Aw69kPwhq/dviRLy8X5c
+mHZC1ejSzWlapRQjREzpaDfC776LzMPNSph0W7b2GyNXnD828oR2U48/7dA
i6LUC6aVtBNPqEq4wYFlZrm/F5RPMzqHR5Xw1CcN5wy5XhDeN6+0YUYJx1RW
3rWR74WNIytSNRaVMC2JxRF4oBf+3ONh82JXRt+whhsb1XqBab3LLYlbGYWr
TzlI6fRCD7d0SwOvMp48/iOz26wX6hvV5L7tVsbZ+TfXN9v3wuNQo4Rdksr4
Zkff62+evZCifHDJTFEZBycK+kKI/Ud+dTkarK2MOwRcvatu98LZfN+GXGPi
ecUZaml+Lxxzvrivx1oZnWfc7XwbesFcIOYmu6Mybv11dee/4V5Q6743J+uh
jA36r4Pd2akgFpNnd8RPGWOEpm6ViFDh39/Xe6oilLEbjgdy+1NhurIzcvyW
Mv56Vtojn0EF6unBz5tSlFEtkYd2pIMK5SNLT30eK2N14laeL8o0SE9ZsyPl
mTLmrPt52/00DaIpvOFvXiujnstSG3chDVyb5E2Fe5Wx2a714EppOpAuapdY
jSij4Xvdw95+dNBSMd8a+lkZKe7NvmI1dNhW4DHY+08Z+61ObXlzsA/exqSf
ublPBUV/Z9yeqOyHCoOi3hoFFdy7MzxKnG8AMperNZmaKjhrvKSwNXQAQnw/
cuiRVYj6V296RR4EaZt1qT+DVVAy6sx52DQMcTtCGo63qqD2u0etw9tGoXnG
ac7nkwrRv8bOpTqNwp9XBnsCR1QwuWv1P+/8UXB33RR2fVEFQ3k/PCtRGwPN
4nz14r2qmFDNWvhkOw5+YbFelbKqGFT8wVE3bRxyyf7Jr9RUcWfSs3sVw+Ow
aQEWuqxU0eiUc7ix+wRMaveWLZxXRXl3R+8J50kQ3PRi+F+kKk7DK0Hx+5NA
HsvauPaOKgpph73/9GkSaq+dOrkjXxVVBVaKkg0Y8M3eJk3kiSpa8oc/5Axh
gJi0eqvMS1Wcc/BQXlPMgLjO1RLYo4q7Tgx8fLWeCc1Zn+1MhlRRnPdquq8G
E/74d0VaT6liVDcE2ngwwZ3//rgrmxqe5nO4XVLNhLTPl7ec4lbDxZGUdJFh
JnS98NQ9t00Ndzdrsd6uYoGmi2JGlLQaVn04+TzXmAV+igIdd1TUsMZppeG4
BwtyOdiWU3XVMODr2jv2RH/rp05I51io4dZ73qVcmSzYVNjq8PiQGuokebX8
riF4ILTsRtVxNbQdjl2S72bBBau71XWn1HCa7MRfwmJB2Z5Q5rtgNTQ+8Yt+
fpkFk99dtndfVUPyg7Pf0zZNgWCzsWH/LTW03si5km/vFJCTZQMmUtTwQt96
5+8KUxDpvfXhlxw1LOg43qGkMwW1mr8+LJaqYfP1yY2TFlPwbcMwO3utGv6W
XFzBbT8FYiNN8lxv1NDM4O2nQpcpOPKk0GnLBzU8sFOpqcN7CuIi4mIFB9RQ
6icf50W/KWi2O/dClKmG7k/tFl4ETsEfCcdp2e9qCB9E4u6GTMH+P7o7VJfV
8FxaRvjm0Clwb99nqrNWHdduXGOrfHEK0jI2BJtuVcfPIglZXITuOvMjj7Jb
Hb+JJUndvTAFHAb0T0ck1fHyhWje8eAp0Nxet9pdSR3dbMOUlgKmwI+Vo3ga
1VGmdrPjoO8U5D6PPh5kpo7qR1sdU4l4+2/63blkq443k8uGVY5PwaZjdvU3
nNVR+PnCleeHp8BQQWs23kcd13haLMuQp+DCqr27759TRwMdT467hlNQ9onT
MveyOjqlGJssq0/BZP6XCyU31dFMNI7hLTsFVtSN3//cJdaLx3K79kzBszX7
vUyz1LEsWsjee+sURLufPThRqY4+c+z3TBZZ8CMxoVWhXh23KQVZphI8d7Tp
qU54qzr2nU1uU+plgbzIT5kdw+p4nJL506GCBfco/A89p9TR5fPv1jmiflZc
UReo/KGOqOi0kUnwbc/IBQ7yWg1cy2u3fSVRf8EP2IciFTQwr+q8yw0eFoy2
Cx/s0dTAf3toVdlLTDBf1mvdY6SBThumvfRGmbDLMbKq1kED1wv6tYiUM+G1
APftuasaaLemqnjCnAnrkrbqHO3VwAfFi9TNZxgQ0KRUVTiige9yi7sDDjJg
8IetzNJnDTzuYPQrTZUBZZR7/Alsmqh0JjfKcHkSbDftmnsnoYlbzlqcsrk2
SfC3eLbSBU18WrLUnHdnAg5cUV+9fo8WXhiu1+dMH4PLlq3JYlJaaPrH2N8h
bAw6+Y9Io5IW/vA9Qao8NganSkMpZ020sP8cdl/bOwb5A3WZND8tzA0Pf/6y
YBR2qRpp577WwkNFtVoB1SPANUM5B67auC5vz/CDj0Ng/2ycy/6UNvLHOQ9W
3B+C/CsB6WeCCB0z7s/pPgQGAnebcmK0cXFgPOrU4iCEG9G3rHuqjSfy7S2t
dw7CfOaxUupqwL3F7jY1Af2gf/Kb3txGwOAOCfpvHWK+VL3cyy0AaKTqdvX6
hn6Q78he1pYFpHKuGszJ7wPvP5PmObaALkO2hhdH6VD95tzwy2OAOawtCtfK
6cAZz+lP9QZsrzn2/dAVOuRISKZyhwGONZtp5YnTYdj2JMsvj7C30GwuFkqD
II1Phh7lgNKkwmdHrGmwUQgeHnkBuPx4w5y6BA20WTxORt2AjaqRmUb9VPj0
PrhWcxDQvGvyQ8YzgnfKR/kVCKwfNniYv5BEhbTzFT2C/wCLfvM5j9tTQaB0
A//a1Yi5ezzmH2hTwV244c0VLsSBb7mbMkSJfphwLnB5I2JFmnvQjw1U+Msh
LRrMi6hcd1C36FcvGAcPd38XQHwyL631idkLCZ8TLp8SQgx5zT4URuuFYUeT
/SxRROd1leTKtl6Q7vw7dFwKcZ9EWnTk614I0i2PHZRH7IwIs/9D8FNjhbuW
vTKBj1srFPdW9gKP+I7pbg1E1sr5CI6KXnC415FiqYMYZxpDKyV0LvdVk3eG
iDsG45ykn/XCXKjqTz1zxPe3l0yvvOwF7dnp3JdkxIioFXqv3vTCDZfMg2p2
iInP999hEfz2qefgqoojiDMU3mjuMYKHjLieyLog3g7VPSA73wunql86F3gg
rm7J0z7MRYVqqbM8IicRG88c8kgWpsKqdPFX6WcQ+cM07b9pUYHE03+SPwhx
l6ha0skjRL4v3xZMCEUUE6xM571IBeYP/dYNVxAdhie/fcuigqLHUnDUdSI+
fL+eu5UK4bTifatiER/UXffzWqBCm5lL78V4xIm2xjReURpsf7ktcikZkU5v
seSzo4GLfKuifzrikmw7JSSGBo+zwsa+ZCPyqX2z12+igeE1Jo4/Riy9FyOq
qEOHO0tpX49WIDZY/RnzuUqHwRPkdFo14uLZhusKBJ8HkGp+tzcS+eW6lHnj
eB/UvT71yKQFccUV1uf9T/tgndJe+8YOxMg8s+ZYrn54yB9TWU1HnHy70Sa+
rh9mo9FNcRiRq55SQtozAJrLP7aUTCBGD0W+/RoxAN2jjn4PZxE1QcZw6fAg
rCiSk77FoYP2+bfjZfiHwXLXOH3tOh2c2Ty/0vDQMNy7nRx1dZMOPvbrzGxM
Hgb5AHZGsKAOZkwMuVjvHAEn7e5MVwUdlDS227pOfhT0nUT9L6noIMem2NBt
fqMgGX7OMF1TBx0tcwKVy0dhoX7H515DHazLfH9ZUXEMYgxcFc0cdFA8wkni
74FxOONeyeF5TAedd6+T9TszDoeucdKuuumg6g52wR2l47D3XVHoy9M6yBbf
WVW7bwJqzOeb91/VwY37Q7Mk1xPfv5NG9yyjdFBkWyqPtt4kRMTeO3EiVgdH
cv0eswVNAqlTiycnWQe9fu4ucBuYBOVvt0br7+ugy9NvzfPrGSC4ebRiMEsH
1/eL+23QYgCDEmnPV6yD0Xd7tr5KYkCbP1VKqZyIpyirwbyeAeWJksvkKh3s
FRrZazHFgIu97VnR9Tp4inPDTIoKE1x/CgXkN+tg2WH+82MOTDDhP2vU1KqD
gTmvLZMuMmGrw/bp5Y86uG9YfUn9FRN+nfd6uaNPB1Xav7PLDBDzddrz26rD
Oiis6bgmmugvzS/WHz84oYOJJP1gu60sKBx0UjozpYNTot5tCTIsuP2vbM2t
rzroWcbnaWDAgkChVfTCHzrY8m1EzseBBbou+RcnlnXw8LFikL7Cgn1XfpFW
rNJFW9Gbye8TiPn+ofne3WsJ3WNsP/+QBXON6fMaG3QxqfZaYv4TFlAnZt8c
2qKL50KkLkzXseAlh15KAJ8ump5qU25uY8FD8USfOzt1saHZZkqd6Lc3jBna
JcK6qK99xpk0zILTXmqb2sR1sW53w/V1TBbY3IgeY0rrYi/DzTzgCwvUCwee
rlbQxb0hAem3v7NAqE3uurCKLnaRzItcif7OMXPpMGjq4sWGt2WLSyyYXt8j
fURHF19JvJuy+s2CLlmxf0GGuqjy5Xb8WUJXWgV1JZrp4teeDypev1iQ5tuS
XU7SRV5zTV+Vnyy4HCcY2HFQF9V2b88f/8ECz/JTxtOHdfE7f7HpuVkWWHbX
Caw9posf1hg3zE+x4MCPzTOibro4TNmQ4T7OAj5et1e63rqovmf2emc/C5aV
quKcTuui8tDtVeo9LBi3Xet6wV8XX58OvFfQwoKWcw7K94J18X2FWLsokT+b
nHsze8N0USF4c3gFkd/BD70PH1/VRYfQ0BjFXCL/MjZbGm/p4mJeLa/EdYJf
He60WCbq4lCldVPxOSIfUZ2XaCm6aBEllabnzgKBcfPZLzm6yGkmkFGHxHls
is4LLtTFdK0h9SppFsjCu6OrynTxwN8Il4HtRD2kGLznr9VFMaMc2+7PTDhB
0n6k/0EXx7zM5KSjmbAQesG5o1cXNyapLjj5MSG8sIbv8IAuNu9zvrJky4QE
DpVrp5m6eP8b3e2cEBNqa+VcU5Z18Y4b3yEdYl5YJ7Fn16ykHt480BQ6Wj4J
SbZOH0Pk9fCTlKwK/51JELp6P2a1sh7++vIji9tvEhSH+H8L6OihwGUFowOy
k3AkcTPVwE4PlwSpzQs5E1DEvupO6hU9VPo+eCEsdhws6JOrjfr1MJg752qd
3Si0fOxvrRrRQ4OvB0/oK42CYdeHuH0MPax8lXWub/Mo4NuXO7nm9LCsa0ev
cfsIKFYmKb1fo48U82PexoYjIHDH0I1yQB8riyD5k8Yw3L2pKdWoqo/KbTF1
QjuGYWuUwjdFbX28PvT7wu75IVgfvit0m4k+nniwkPnq7BCwnVpIoB3VR+Ng
Y7XH/oMwaZLb6HRDH+8UFH35E9kPxw3SbnTe0kf50RPPnM36YRjvkHQS9XGI
nvMzmKcfaCoX+4Uz9HHQfr20yP0+sD3gnxWfo48JOSOuDNc++CDr7bmqUJ84
j8DwVzJ90CZq+2PiqT5actPe8TTQwWSPeY3tc32Md1urXXOLDs2CuuFv6vQx
+IhdI9WRDnVbZNcVtOpj0FPzhffLNNDaKPKBv0sfX+Zre3V00aCGSyD5xid9
XFS49iQllwZP2DlEfEb00eYo9Q/9IA3k//5m9U8S/l7kSJ+Vp0HRz28lFtP6
2F97NkpwPQ0kfjACXn7TxyMqD10nP1Mh9+uAhtyiPvL/+NQ+1EaFvZ+72TP+
6KM/f1vjtlIqZEy+e8OzwgDNO47YJydSYefoq5uX1hggfT8p2C+UCikDTylz
6wzQ9QKlsdiDCttphfzHNxsQvCljesiGCgk9mUPd2w1w8OKVtRf0qMDTeTdH
f6cBLpfYLworUeFm680TT4UNsGS/h6utBBW43lzZL7bPAI1PHnywW4gKka+D
F5NkDFCufq/VNX4qrHx5+sWaAwa4Xfm0TyIvwQPVbleCVA2Qh3fTV/JWKtw9
vuQTrWWAaqJPYv9v/fH6m7bpugYYn/z3ijrxfmOVEJYZGaB+ZEWg4W4q9DlX
SDSaG+CP+COcr8SpMMdtvKWXbICzAwd9ChSowFnZ94dla4BFm7hruJAKu4+d
nvzjYIC9JtycTCsqKHOt7NzobID+yGdm6EIFi4qkamF3AyxzFHCWPEcF16OS
2UonDLDhS7v4vVgqhHC+jDH2NcDWkRifu/lUiCsnBzoEGGCwbXaHRBMV8o9M
OJ0KIfxFWG08OE4lvt/BJpfCDJDdzXl6JwcNpg9nCOZF/V98T6+mkmmwcrUi
R02sASq/u9Zof54GAiVvvrbFG+Bk3a6Ct3k0MFr59fXcfQNMZ29b1cZJh6PF
l4tWZxugSaLgR28tOvjbbUviyzfAE1n8Z9r96ZBVqOWlXW6AM0ffZP38TPD5
wS5rcpUBXrvz8EaLVB90/nPVdK0l9qek5HjuVB/8pcRsvNFsgDQqqSfoTx8c
+kN/+pFugKlTVIPXGgNwOvfUA+YQkd/Z0Zyt8QMQSVoR9XvcAEulj075zwzA
k4cSR/Z8NcDNAr2aIYWDsMEiaMXJlYZ4UkjBVlxsGEQXuafDOA1RdJO/ervj
MGhmPvh4Z70higyx2T5JGgav+eb8Z9sN8cLbNKMm7hFovM9rtUraECWele2N
/jcCfUYFqtv3G2JPWEpwrdYozH3TFJZUNsRWuZgiyQujsNvQdd4KDbHtyb2d
WkujEPKlPDXVxhBz3OYoA7NjcDvZMOKxvSEWXgyNTZUZhzxd+qn6o4bI1ahs
VOI1Dj1J7LoMT0Nk9v52Dh4aBzkgMRVCDfHyNmHOw68mYGq+o/LJZUPMVPYf
/fxzAnKLrCIUrxviRHD47ZX7J0FQwEpYOd4QuT8lOUekTUJvZ/tsZbIhXjv+
cK67YxLuXLN8pZJuiDVqXWO+7AzgnLc4olZgiKfWpir6OTGgofC9ZM1jYn+v
enY2RhN842KxpF5hiIZpa2MNKxnwo8M8SfOVIVZR12x/s5oJJZFtri8aDdF6
nabcK0kmeGuZH9BuMURVWZNhmgUTRh6ZdcJHQ+QT//7BP5YJac6t6XV0Q+yt
dJReLGTCIT6zkzrDhvgj3PRw+hsmbOlo0Xg9YYgvtN7c8BlhQnuEKZfeZ0P8
IhKU5UbwUJRmC7Vh1hD5Ky+V3NzIAv3vJnn6C4ao6exVztzLgn8F7wKafhti
V8X6neeVWVBzzETfkN0IRS4nV5sasSBg+7vNbziMcPWb5jOOtiyQbzceMVpn
hJTqrD3Vx1nw+erbkrebjNAhP36l62kW5GoYXzTZboRWc0HgFswC57k35i2C
Ruhnabm28RILBAuMdpgJG2FC6UDoNaJfU53esFrFjVB24yuOqpssiN9m9Mxc
xgjd0jSyDscRfPG+OfK9ghGe+JhrHRLPAq6rhgctVY3wvnzfhl0EjzWpN+/t
0DLCLaP+ixbEevg3gzkrPSNct0vGcTPxvkZ+U12nsRE+eLwm7ixhf+GowS2y
pRHqTh8bDyb8l/E2OX6gGKHMYdt+mcss8GnTl6bYG+FNh4LVySEsEL/S+Kv7
qBGqsgV21fmxYFRN/52NqxGuPEQtLfVgwf3ZhrsfvYxQbtGH1/cICw7l6bnb
njZC/oFfwWtILNhytEGx198IY/o+24bpsqB9q97KQyFGGG6/XXj4AAsMLutm
2EcYYWFmpu7FLSxgU3t9in7DCOdJ5tWt7Cyo/aqj5XDbCI+xxzcLf2WCgqMO
/UiqEYYsNOlvIM5/lypuPVZG+NMqynniwwTal1ejw5VG+Hs133EJG4I/cqDM
udYIbRw2SE+qM4FrC1gef0Pk+5TSNisOJizOaF13HzBCsXu7OLISGWBOcQiJ
GjXCk+pMx7UhDMh6FuRTxDDCJOJm/XUk1q88Ic19M8Kny6FaD0QYkMEnwX+R
wxiVH2t+MSmeBGO9rY8S5YxRwFM6b0vpBNxLnmptvGSMHU6R4m0JY/Dl75qX
jEhjFDrdYRl8Zgz0j4uWcsUY48Bq/3ZhErEucyyBlGSMn0XjZM5wj4Fuw8cj
/Y+M8dBT1xaly6MwNVM3873bGAvijPZN+I2Aht7djXvFTHBd7kS/0ptBUHya
MflEygST7Bc1j1weBFnxRy/095vgperZrZNagyDE/eKEu6YJdj/QkTtWOQAc
3aNvCqxNcI/LYy/1kn5gM5hOVz9kgs+bLPhyTvfDUuV8QKujCZJLX3eL7O+H
6RROkRlPE3wUMnurpYrgDRfZcPkwExxcE/7I9RMd2npU7OqvmqD2s6o2mSw6
NBnqyFrfMEHdX4L1b0/T4ZmkTf/ZRBMsabkg/ZqHDuVpjk9WpZpg5eyBYP1x
GhRu8LiRmGGCe+1LFUeqaZA+F6xaVWiCEdeCR3NP0CDZ9cpG4zITJCldTpo2
okHcp5hJaqUJ3pHzCYwQoxHzRNILr1oT7NEWGA1dQ4OrNQ8SftWbYHPhqwMj
U1QIlS44Ef3GBKeN72ZWd1IhML1cV/C9CS4NqB/cVE0FX55a/uIPJnheuvPR
t2wqeF1umtWimuDF2isMlzgquPxof9M+YIKcA3d1T16iwhF3arrTGPH+j6kg
Pn8qHKSOBMwyTTC6+Yz5CS8qWJp+Nr/0xQQLWyy9fZypYFz7Y+/mHyb4/fkz
A+EjVNCRXf6VtWSCoxzCV+7YU0E9Y82HA/9MsHQGH70mtOLmTQWNq0zxa4Sm
9DPiedmrAuEHuUyxbNOj/nNEvxdf2Gs3udEUA7KNT3KcoIKQp4zsOV5TXH00
6pxnIBUE6MqrOXeYYubY3UNZV6mw1Rz7k4VMMXLfGddnBE+tf2nyRELMFAeS
nRmPC6jAIU+5USNlirtHPtdF1VGBLeuIs9l+U3QpLJ0yp1Ph1xZ31X5lU1z7
Ly3wzwIVvkec3nhS0xSj/Px90rYRfLAYNPlXxxS3L6y4J69Gg0mvyy9ijUzR
WOXJWO1RGgz3RSfstjDF37zz6gbXaECzSDxRam2KrFSDnPflNGjbn8//wdEU
ycfr8r9uJvg0u2zW5bgpyrzyPx9nRIdXvM/ffPc0xYudPpr6YUT9LL0P4PU3
JeaVkJ9fF+lQeKLXPDfYFKcONl2fU+2DhwPDe1XCTDHM5KAxf2gf3K3/3nXo
hilekHzaM7mhH66yP63quGWKKVEeBuIO/eCrE3jfMNEUu876Tlx51A/G9T89
FTNMMa8wzSLfegAU2WssC3NMUftwq8v5wgEQ0jmvKFxoij95pmMurRmEn3V/
/22sNMW6k6/v6r0bhHG2VxORz01x9LVP1Xq5IejE8Na/daZIEZJ6JJo8BAV1
K+5+bjXF2V1kvc3qw3C4bo3smxFT7G5x/XpbfAQM2d5t0WaY4uOftWXjbiOg
gDeWKqZNUX8vv7Fgzghw161rylo0RVWpdReTREeh9tWmIxfXm+FF4bNJmpJj
sPPVjhtKambI/+DXN8s9E8D1r/90kbYZajyI9eM8MgEL2ukH9+qbodZxvvCL
iRPQ/lJozyYrMzxwr26F2apJqFke4bhuY4a3NmuaXVSbhFzt7OllezOklMkH
ipychIsvRZ9Nu5ph3yUX3zsEL3gvT94/7m2GK++igu7//f1ZO/8K/bQZSqvM
1SlKMUDupaTV2xAz9Ofh+dQQxgDB5c+KEG6GNTzVE9Z5BF9oFwtURpihxS4q
nfs9A4ZfyE1m3zZD1NLomdnMhLa/s60CSWYY9fKi2pYDTHimVV4Wl2qGN67n
XT9MZsLD0LN3OTPN0OTD6dKGk0yIe6EYGpZrhtM3eqJJ15lw8e+8y0KhGXpv
22K1MvP/+KPK+GSZGfKqKcoOVjHBNjRIdrzSDNNzzyyPtTFB94XaVodaM3Ry
+2HPP8wE2b+/lrrqzZD78XaxK9+YIKBVO2T8xgybuD/qihH9iiM0tOlVmxnG
BHzNWkPwxlytdqHyBzNcXql0S2YHMb//+Xe7uNcM95RZpaeLEvO+Zn2gyIAZ
5tSsOeYsy4LKC5ePpI6aYeH7cx4XlFiQXaunu5lphna+PpqL6iyQLMwyk5ox
w7i9zPBsbRaU3mM/qD9nhqJxSZFzxDyvfP3YUcdFM0z4lnVmSofon4GvPAL/
mGHpZN/XOELruu3yu8Vujucp4+1fgQVvKaEh+RzmyPVNZ5hLi+AN3f4r9dzm
uLvzJ52lyoIeeY2bdB5z7FornBZP9OvDu1OSvvOaow72CW+UYcHw+qUH63aY
YyKv7qnjxH7c/9gViAqZ4xcp/9C7giyYnqos1xY1x3/Zq2zKN7PgDI231k7S
HD/+IP2uWcOCn2/8m3zlzFHq7Wjgs99MWJ2jQM1SM8fhY+d/FhP5jomPG3mu
bY659pd/PeliwubLs1M9euZ4sKsnu6We6P9Oj/9yWJrj+HqThwYPiPO3WL9G
iGKOtx129VfFMEFS04dH7RARf+ZDN9tgJijzS+494WKOPoOfg/aTmFC7Jkr6
qoc5sq3aJnSe4APdBYbSfR8iPhGPVdwiTLDszjHuCDTH8F8DS9vmGeBxc8+p
A9HmaMHZYxVxiwFfzoefM79tjvnvWtiK/Bng7z0U7pZojld7co8a2zMg3Oh+
/N0H5hj47qTITyEGJLPzV/9+Yo6DXDrv2x9NwrsAnlWN/YS94owHD4omQOro
v3s2sha4bX9VpUDkGNjam17vO2CBor9VtnU7jUG4TWKgi5oFrrh8WzNcbQw+
mkpRfPUt8OxXs/jG6VEIU7FbF3PYAlPInU5GlFHo5im52BBpgRhV6RonPALL
3L98TGMs8JzW92T6n2HYt8bAoSvOAmPrGXnQOwyhf+kqQ2kWGHn+3ib3mGEQ
n+L49qvcArem0i8lzw7B+YajxxWGLFANgm5qPRmA3JcF5OpxC/RdAxlFpwag
s/oH4JQFNjbtWSsoNQCipTcELectsKFIl88prx9IhR+5Pv6yQOauPdTjHv0Q
kiu05MBmiet8P9u17OuHjrTKj17clihjpN23rbQPft1lb5zlscQw330vxAP7
QCTevPzcNkvMiDfbMqvVB8FRo7EReyzxbEx61+wHOjy8KhO6TtwSN+yzFTTP
oEN7WNCJeGlLFBMqYGQT/LE3cINxpoolBlzjtLq6lQ6WfvbK+7QsUZJ3KkN8
igZBPg9FSnQtcYjnY/bfehpkeXzdrGxsiU0N3Nqb0mjw3kWd/YWFJY6Y2Cqc
DKLBT8eIr3oUS1xBl9y0w44GwvadAy2HLFEifdeJvao0MLfZ0UY+aonVHZFv
Y3fQ4JyVew31uCXSs+ffu7IT9k3L8p28LDHe6jxvEYsKbQZ/kiZPWaJdv4/c
iR4qLKBRxEl/SywL8ZXOr6fCHs07Z38EW+LxLtzlWUYFc5UB5/NhlmigHc5e
SvBKoMI+0ooIS8y/dOH+1WQqZMic1Y66YYmHWYdHWLeo0LrvpTTPbUsUX/80
eSyKCrc/5GqrJVriX02/namRVLC5cIvkkmKJMwe9xJIjqMAnFuQS/cASQwKs
Nw8Q6/0dx/wrHloivK9V9LlB2A82iRwosMQzs+J5Rrep4LZXIZmjxBL9GjPP
+BH+Jd8LPJKrsMSVL+wzPmdR4UvgytpD1ZbI0PDf/qyECuVC0+8vvbRE6YaN
ltSXVDjX0jP0qIHYn0zfPwuCzzT9X3zrfmuJUksPZgXGCR7Zlbvy73tLHK/x
/4i/qND4JpZXrNsS9zw6y1W/mQZRfufEraiWKPgwjfe+DA02NxmbZY5aYlLZ
+oVT3jT4dGq/YwvDEneh42rPGBqk8gmc/j5tiRaaMnYNpTQQ8fl8x2DREjPt
+FTy2OjA5O15eOqPJcrpv7I+IE2H4le1lXfZrZD/+u7xfYfpoLwlls7itsIg
MX7DQy/o8Ks2cHrzJivUWFu9OmmO4BV3p2WNbVb4k7Kb30CyD4xr5IVjhazw
4ZCCIFtmH9g7d3spKFkhpL42VC7qh13ctecd1K3QZaDT2XC+H0YrHt68ClY4
xF+2fwAHwJszsOyTiRUeMedRezw0ABdK+JZCjlrhyxd6PMaaQ4D27NwPjxPx
jbRl/bw3BKtXTgm+97TCrms/Eqx+DUGs7XPcfdYKT+oWB1xwHoaMv47XG65Z
oUHKsx4+tRFwzTNMmY6xwrNTucfziPlCgixXxHvHCmP3e5VvKByB8odsnR5p
VihhGhk8uXsUGs2yt68rs8L7i+W7+DeMAeMeM9eGboUlJeor1YbHIX1T1Jvj
Q1Z4d7uarN62CbCNkmCeGSf2IyvrTzGbgMYgb4m4L1ZYdszoh2r5BJyf5TLN
+G6FLKMDp6bHJkDBs9C75KcVXvH1++G0dRI6pRY+urOTsJK0M4riNwlFHobu
X1aS8NbqU/PP70/CteykhQAOEqbqn5+reDsJ2jtUtkdwk5CdciZEWYABAnbX
8tZtIGHjgdTFx8iAhTu9Kgk8JDy9KZ4rxY0BxVxBh7J5SVjnxOZR8YgB1w3f
MiX5SFjkdmm6r4UBrpf5gssFSEhJ5j7hwWIAvvRcq76ThGmPWH9siHlS8Nez
e/W7SYhfLC5m72HCT6W1kibCJLz6W0mYosGEbj/7mk4REkYNZWi7Uphwg7VE
H5IgYfTV2YTHF5ngLmp6wkOahG3aP45OxzFBxznl9xdZEvqeUiPHZxP2709F
B+4n4ZXXx1blPiHsU9UFlw+QMKGaff2+10zo2RpdFKFMwrW28HNnBxNKSX2a
69VIKL/p05EYOtFPY6TeJ2iQ0PlOUuu5cSZ4vD3vKKhNQqUtAtTxaaL/rWqb
yUYS1s+yCdK+E/0VBS9K6ZHwoMhh78NL//f/J58NTwxIqLt8IOnUXyZ8qqpN
VzcmocxDbfIONhaUf18n99qUhCGMj5/cCR66Kef4ysSChFa/NzbbEdrzRLFV
lxUJqZtXvvzxjwn6eX+HDlkT58UTbaxP2BMas/AdtiFhbpUgmwXh7/eudDZP
OxIWN3Z94f1B+Dv85fZXexLevkDdmzvDhPIk7T3njpDQNXkib9UkE2I/xJYt
HyXh41vaR1QHmOC1YUgn0pmETWZ7nYy7CX+mch/Wu5LQdODwgMZbwl9kmEui
Owl7bYpWCtQy4U99x5ygFwkXXQKWWY+Z0Pt395WHJ4h6aKf2lWcQ9gPqsp/4
kjCUrhNhdongxzIeRY2zRPyh4jckfJlgOHOs8XUAEW8030fBo0z468o+0RVC
wkcORi1HVZhAzSAH2IeScCThpvBzYSZU9GeuHgkjoUqHE8V4PRN8bHTFZq+S
sJuHMsQzzAC63hWPDbdIuNVubGR9KMHHkSZTbXEkVKvf8df1GAOU3248GZ1A
wu+BVIHVegyIM087w5lCwtqW7gvaHAwwPvg0dEUOCVeXb047ETEJle6M+IUa
Eu7etOZfis8ExEeZ1Q1OEufza+yNH8cY1LVu0rvPIuGrwRela4ZG4ct6apPD
NAlHC5sNkqpGwfSOayv1G2GvJy692HMUVqSGfvrwh4TWm9yKeFpHwLeoZLp5
MxkD/c5Fj98ZhvQvAacjeMkoFO0XYu0zDG3ymnN6fGQUjbosNmpA8MXTt4t1
O8l41vb01aW5IRh8MbLi+T4yFsf4jku/GYR1bPkRwVJkNLIsgS+hg6Cue4pT
VZaM9xbk62KVBiGx+df6pwfIOLbVeFN73gCYd2zhL9EmYyavwse+lH54w8wv
1tYh4ynulYyjTv2gu0Jbt12PjBYwk4Wi/aCi5HlixpiMIX8K1Ryf9kG55d9/
F8zIuJAirlQR1gfSnncS1lmSUVoocDrLrA+EU2tfSFHIGKsd1hfIpMP9CrL1
84Nk7Bble32mmg587ZOTpofIKLGvuUwhhg7r2TfxeDuS8XTZoIWICh2uC+Q+
XHIio9qPuBvuG+mwQlFDLcqFjPyM7KJYFsET7m4u+R5kPF5z7EJhNg3Ohv9a
UPEm42+eCEbhFRp8uXcr+o0PGQ9KhsY/cqOB5xMRIbvTZGxfprEVmdBgrK26
YtKPjKszfx6vkKPB0UlLk0B/Mup/OzP7ZjsNqP/GBlafI+PHCDW1KYI/KPzB
ZxKDyXhnm5TUri9UaFfYsEb0AhlLpXpL3PupYGKenVpxkYyr1n2LaW4j+q2b
qrz+JTIy3H274BUVtMPeN3ZfIaOx/XvPnidUqE52sT8eSax/vYaRj6igWL44
M3edjB9qovttCT553Bpz+XI0GW1WLnkbpVNBYmLP9s2xxHk81dxmn0qFh8uV
hZm3yejUc70nJoUKu/nMcX88GfuQ/dwYsZ6yf6SnLpGMtvegw/EBFbaaBXqR
kon6uqRV+OchFW65ci8PpZAR/BgH64qowHUx487p+2QssVghXFBJhat3lcT/
PSBjTfTy7arXVPhX2vI8NouMVRnmItMEb4S0OJF25ZDR21Z1g9EIFebHfowX
55Exnq3W5u13Kvj+jQrWekTGvzCr4stJg6ltuze8LyJjRe/MovZuGrjJV2Qd
KSHj4/yyDkWC/4ZNTFSmy8ioKlk3S6bQ4PDxwdbzFUQ9b/sVn+RLA1IS53xK
NRmTIwIod8to0FpyP0qyloxymx/r2HykgeE7hV01L8nYT+uTU/9NA40/R4xo
DcT9oSXUXbagQyXvXJ9nMxn3zx7Vmgymg7zcNd+fb8nIzp52yj+fDmIuZfe2
t5ORUnObb+u6Psg8byib10nG0BebasV1+kAwse+1cjcZkd1v0iuoDza9XT19
kEpGQ8nWptCZPvgjc1g7YZSo3/p4KY65fnhn4dZ0eIK4H2tEfaq0ByDppK/5
HiYZh4L3rlwTOwDyxZGHH8+Q8cHexKc3FAfBVfpJ4NufZLzqrqIemDkE+81f
/o39TdR/g31cBfswLJ94d/XgMlGPIqJ2axWHIblw6M7oSmvk/Zz+pi1tGFol
15X82WCNpBUF+yUujkCy6Xblhk3WeDjoTZdDNcEr3sIvorZa44zOUKb/PDHf
FKi2bhOwxs5V/Fdfnx4FBQk3hryoNdpp/u444TkGKeIvd7tpWGNm8LL9O6MJ
8DB6lyulbY2vQvds8A6bAEWPHpk5JOy3tr+vejoB7blTGmGG1phxg6+Ubdck
pDbPvzYwscZPya91uq0mwXOSzXSduTWmPG4eZw+fhBVi2w/dI1uj74ufH9X7
JqHDQHjIycYa66s4cySJ73Gam4y7mJ01nl4SWKEvR3y/c/T8nxyxxqTE893t
5xmwssnyd7CTNW7q3st34AEDOsftL6OLNar1rdiSU8cALxHf2+89rPFZlUf5
w7/E+/rntyd4W6OzQ2C8HD8TVrhGph8+aY23niW21ykwoeNKnOgeX2tk22We
Y2/KhLTstCLGGWv0OM1T+duJ6I8NeQceB1hjckI/e8FZYj4eK6/xD7JGi1Ae
N7cIJqxc+VJH47w1ynw1MFVKZEKn8Lu37BeJfO7jF9xJ8Mh93R6rt+HW2OVr
lbynhOiHLkOfYq9Yo7fooKxJNRNULk85Hoy0xhr5S90pxLy+Kmt+fEcUEd+6
9OCdRP/tqmfzGY22Rmv35bneNiakj3B/z48l8vVvcu8Hgl9OsG8POR1njZHW
ghe2EvO/6h5hduUEa6TfifTO62TCsnjUra9J1vjr/kxeRjsTGmVndxbcI+rn
DjmWq5XgKyW7Ipc0axQ8ELcw08QEsuZLdcEH1th2RaSa8ooJfHqi7z5mWmNT
TuMF/SomDJrE2N16aI1rg3z13hUz4SHp+4RxnjUuOe6ifM4i9md32H/FI2tM
LUv79iSJCfJH61fUFlnjzy1hktJRTFh03RcXUGKNrYMbhRxDmPDyxK3dcuXW
aDtoLUHyZsLVMwvFzAprHBw0u7/BngmmwY6aWVXWSDH/25VpyASe8MYWhxpr
FJbY0r75AJHfm3cY7a+sUcBtnFTOyQTXhKWA66+tseP5Ksnv3xggmXpslW6T
NX6JOGegTGdAZb7snqct1uifLZI1kUfUT0PL4dSP1jj7aNXMgCoDklr2s2yo
1shsFzsgvIMBR7qSz23oI/IhM+xd9GcSWIPuCZeGrXHijGDVkxdEPf9a0e7x
2RpP/bu+dFh1Et6yeR/Z84W4X6tTI3N4JyF2TdcUfZbIX7xS4Jm5CdjB+2CN
5YI1hr1mjRc8Iu6TvIaOIjsF/Q7llpgQ/O/hfraCbTsFX3GVOJwaGoO2D2Mp
93QpSDPamDl+eASGSvk1RAwoOMQ1tP6o0gjMxVr1PTai4NmFqiXGxhHgN3u+
o9GcglcG+LYqNQ2De8OdtC+2FOyxTfCU2z8MwZlvNYPtKWj0/P6j9HXDEBO2
3L/yCAUTg6xYdzuH4ImG905+Zwo+mN9ya4POELBV6KTrnaBg3+rrfXukBmHL
nXPa7ScpuEH0Re1fxgCI+RYPHvKlID/ntS8zOQNgIc2/+1QABTfPd7GsRAcg
5eHsg+QwIr5Ui5NdB/rh8WUx3HuZgrZNpye5f/dB/bEjw8VXKVhSKB3S2dAH
TMG3Qg1RFPy47Ga893AfKCU+yJyJp+Dljk+iyyl0MD77UScoiYIy0Q0+Kafp
cITMPbriHgUju1qmOQzpcHn9OWG+dAo6vg4I8PhJg6TPRa+zMiioq6Jo7dZD
g4J3oy4y2RT8pNPBMCqnQWeEZbZuPgXPjW6Uf3eW4IPjV/XeP6Lgd83H7qfs
aLCgUzNmV0xBk6HuHau1aMAlNHtltISCRwvVzG6J0GDnsqjIyXIK0s+osTZs
oIF8v0PjYgUFP5yJ+hSxRAX9mjjXy1UUjOd8ojk/SQW75Der1tdQcJttHM/R
T1TwDvz78G4tBV/Qkkzr31Ah1OaAgfArCvqoLd7Z/ZwKtxW8JorqKXjJMmJP
cCnR/3keRKg0Evl9/mlfex4Vqr70iL5upmC/SUnZrkwqtLRxNZu/o6COW/0t
7zQqDD5C995WCmZPtieV3aPCt+uBHC7tFDyRdy/lezIVVnkU5U53UvCkznF+
eYInthuMGp7rpqCiqqqS+30qSO7lY7B/IupvFd0rMYvgGXbLazFUCsLbvwde
FFCBPHRFfHsfBWfj6TP95VRwfVH9JnOAguOHNPy+v6BCUOpXD+lhChq6dI3/
a6FCdLAoZ9UoBZPtfwaz06mQbueQrzNB5C/Q3mlxiohHc43GSiYFr90Isr79
jwpeQk/eN05R8HXa5mNnt9GgfZXTscgZChYIf/V4QPCbIovru9EsBZM+PSdt
MaNByvvKiLXfKXjqpYFJuycN/pW58LXOU/BxVdaxjus0aAmp0bL8TUExFV7W
gw7ivJzcOzcuU/CRV8uhkws0SNTbfLyLzQabReRFQ3fT4dg67+s2HDaYH3O0
zyWIDs2zvDu2rbXBGuW5IBWCH6Q+1hf3ctug/MjJo+Z0Oizc5+8+vMkGtXfd
MFIy6IMjl5vcBLfa4HahKhmui0S9u/v9HNhmg7ckdc7vru6DGLl3O50FbfAM
5d80l3I/zG0JKBXebYMvljjZRs71g91PIb3xPTZYGTf+4+fzfhCuD/L0ELdB
xZB4lTnTAbieI/J7n6QNeoqM1PckDsBMVOfNKWkbVJPt2PhndACeWe97clLB
Bl96J0ruvDoIFuO9f89q2eBm26teQyNDUP72ym0ltMH4jD3ro3cPA1+x3N5F
XRsUFNv9y8pqGEYDrhmHGNtgqc5ufofyYQhaoxIfTiHiv0fZGRE5Ag8lk/bd
9LLBVzO84xz2Y8C1Ufe5pY8N7jk/wf8xYQxOf5+x4Dltg4wqr5XBnWOgXmtw
Nt7fBqtf2UKh4Th0Wsy/uBdmg4Xj3McnJCdAWSGT5HDZBnMvreO67jwBqdss
xgQjbPAb9Ub8UtIEuA895My4YYMTO8mmzL8T8MfXhpKbaINytG3f0qsn4bF0
x6Jqsg2mb687mTgyCc5Mk7TWFBu0JA09ZONkQLMTTMw+sEGef6LFPCQGBO2o
ibqSZYP+20xD8/wYINWrKLstxwbFZVasToxjwG1LyXMaj2wwxJ1uebyNAbpc
OTvai2zwYmeBmDaDAfNNu+uOldjgYwmfcRc2JuRfSnH9XmaDzoVHNLu2M+Gw
Fu/ayAobPDycrRUlw4R1S7eK+aps0Ilfii9ah+h/FVzWhdU2SMtx0adSmODr
G7GgVUvU06OpxTOuTNgrzZba+dIGV7tO+jgS/PGJEQLH623w+PWcuynhTLie
PT8232CDrnVZRbIxTFB38r1+vdkGVyi0/9tJ9N9pgc/SO97ZoHHk9gmfdIIf
Prl1FbfaoKzW/1ehecdT/X9xXGQkUqSU8aWERNpZOSeVKFm5e4mGSspIQ4WK
kEgaEhVRklFkhlKRlJW4w573JhIqI/L7/P48j/d9v99nvT+v53k87of+/1II
vb/RcRJrnFFjzbpu8zSCP+wYSxvqnPHJKnXpKkLf8+Y0lR5ocEbalG1UNcEv
7uUObuONzihlcyRuz3MRqAZ9kr7Kc8bvETN3HIj1GnOrdPVmZxycz6toTRdB
4Pgbh+etzijxI95zKlUE616a/bbscMbR3MHqHIKPeo/n3W3sckbtsUjpuQki
iF211sK9l3g/8rIdcwie2iV81jUpdEYf3WtmBVdFMJWkc+VavzN+2SyaVg8S
QRY7cZXmoDOOpJ/lWZ4UgetStbrsIWf8Y5NYsNpdBAubbvvuGHFG2auMd98I
nqiIXrCE98sZbQdS1c8RvHdmT0TJkTFnFBgt+DhoQvDN+yCp61POOEaXTY9U
FsH1wKm0ZTOEPfRbu2aWCLaZn7LPnUXCytzyFfKDQkjN8YgVSJHw4NYM96cE
f3olUfRXLCDhysaXORtYQtBmf6nJVyKhydx0x92WQmhassdn1yISFns5yT7Q
EYJptGXxcVUSZn4/MlttsA9mBxraFa0gIYn7Yv0m7z6IZUl425uScDLvzo/X
rr2wXUyg3mhOwtCXKRJx0As/k55/pAMJY19Wlqmp9cJOEUvr4HYS8nZ+XbPm
aw/88S6oO2dHQgcLezutrT1ACj1mlOZKwhnpF2lyit0gtmp7s9EBEmYXIjXx
exekVy+9knuIhNs5O6uXl3fBbKXKtjceJEyqGDSadboLXiYsi+T6kVA6TW/B
mdZOUMzhDsy+SkLP1+VneE87oJSUGRt+jYR8xbPL+Jc64Mj45e3zr5NwrTVv
cC67A8q2rItXvUVCZacENFTqgBOVEbvXPSDhaOsnVpN4O6gddRvLTyThGTCq
mVvcBpXypo+2JJOwQFrnkJlfG2juFU5aPyXhoU2tktWDrVDbujWNk0NCRO6w
5/cWOBuoQu7NJeGmwR3+qzNbQGf50KyjBSTMDYvbzPJugQvu8TS/EhIOXBJG
rp9pBv25PpJTr0l4s0HMYOhDMzRl2LwIekvCB9kZ0pY3mmH16B+Zax9IKHTz
0ale1QyCW9UvFatIOH/6v40L/wogxDjZJfYzUa9X6ZsVPgug9bxjwaN6EsGH
s9Yb+wggVFNv/8qvJIzbo3r3uI0ANrz7p5DVRMIq6aGDnloCiJBJP1TUTELj
q19l65v4EP5iXPJUGwnDJPs2s4l5N5S+I3l9J1FfZnjxgkg+hEjcsPzZTcKg
+BblHx58uJze1pHeR0L/I/zPv/bw4SJpVcDhbyRcdesyW3ctHwL/nVLXGSDh
RSpv3hVCPy88ef+q6wcJA6x8TBf+48E5hwX0B8MknD7ks6hWSMz3E6xxxi8S
Slk/qs1vIPQ7Ke22yhgJJaz1v1WX8cBv99iGxgkSyl1weTCf0HvfX9saoqdI
KDBZqxqQzAPvhOtedjMkHO81WaVC8MYJq1aFueJk5DabRgmieOA5tDLzw2wy
pkxkSZeH8sAj1s/2sjQZtaFiTtMlgoe2vutHWTJe0o05NDeIB+79CmHTcmQ8
0K9yyC2QBwdjmLpFCmT8t6TBuYVY32/+tNxPkYyPTS1NfYN54Nr72229MhlV
n9pF6l3lgUukpfjPxWQU3/LUaOwGD9ibox6mLyXj3YgB8TaCj5gdzRaH1cn4
6IJzkyCVB/QwvdYVmmSMlHpk9T2PB9R1J/27lpHR4uh5JXmCz8jNZUserCDj
d/Hr/7bweeB8eV4BQ4+Mzzsf8v0HeeBkyCCrrCJjybbB2+8l+ODQ9OTXV0My
UhZoyS1S44Ot3ta1duvJeFoh1bPKiQ+76q/Vym4i47cHt2av9OKD9VnBsQ/G
ZJysVFEKjebD9s8+aWhBxjMX1j5HHh8sT76xnkYyFv0xc7v9jw+oIS8s3EbG
4Kotar06AjA/8Xj5ehsyrn5gyTl0XgCmS0bLhnaT8ceLxd9inwnA+C24pNuR
MSzpgmFpM9GPC/nxK5zJeD+BM6dtazMYFMxdpMIhYxmFvpm+ogX091Ffft1H
Rk7N3yQ5txbQk01xit5P1LOU7f0sqQW0mRZRskeI/LbrdafrtoKamJfMtC8Z
XWN6n1dYt8HSpyWPC0+RcSAiAdputYGKk+wOv7Nk/JMXer+7pw0WJj8KGgog
/FtP6i8IbQc566bJznAy/n2f4lrn0wGUyuG049eI/K+o1/h7vwOSrOUZ01Fk
/PXxro7Ypw4wttn+SuUWGRuaa/fdW9EJ+3dl+9s/IKOkhkKgdm8nFNtGThXn
kDFzXV7SmuBukK5+mr4rj4y9Yf63rxd1g9OeciavgIyH+LEubUPdINozVTxa
QsamhV7bPtN6YKH9kfP6lWR8doZS3ajbC5zaYMOCKjJanae/C6b1Qpp9YuuO
ajKydm1/vDu8F9CBt2XfFzK20UoF70S9cNTR6t+dFjJKz08t2H2nD/Lq92Wu
aCfj7+O/udde94GY03l2TicZT84Jl2L09cFtp5elNX1kdEhNvnLYSAidX2o9
md+I/K1ru3XXUQgGe79r9H8n6tVboGPkLYS3e5cFSA4T50vXOXlnCkH+6xaj
mFEyjtyi1yhXCYHqTGvX/EPGpK4Md9keITz66huVOU7G8ekIM7spIfxwvg7m
f8m4aObhlXZFEZg0Phv6OE28J68l7cW6xDxO+vCAIkbBskWbn/3//4G1jV32
veIU9B9p/suyFcFS8r8Zb0kK6g+IhMuZIjjQtOS5mAwFpc7VHDAl5vnn5I0u
kbIUNLEGv2Q/EfxtcpivJk/BRVVHVh4g9NuK4vHmqQIFtcMqmwPCRRDNvXJi
syIFZTOoGyaiRdBCeaRZvpCC21acWt90RwS6vNI6p8UUbFUI5KvGi8CbKgjs
WELBI5rOq2sJvinh/V7jqUbBhp8b5f88EIEMbUHnXw0KBuZE6twh7L18g+gw
LQp+MdZfX0jwxn2a9dbF2hR0O8oRucaJ4BvfbThZh4LpT6e+xBH8sYEekLhu
JQV/zLD2uEeJIEAQ5/hmFQWzYy6Nf7kigip63iy71RQMDj92suuCCA517kxW
XEvBhDc2S7IJXpvtzrfirqdgyrSP09RBEST9OPLt3iYKOv2i+3yiigBOTl11
MaGgjt/1upU2RLx/r61eYU5BtVc74rSMRXD24n/13ywouDJqzXDxChG8jLJc
5LOdgu8a1tvITAvBcdHXgs07KUgamNGq7iPqGX+AMWVDQZvx/B52rRD00kIf
BttT0NKI8VoxQQgJ72v0Y+nEfp/IWv4qgj92u1QzWRS0nqntWC4vBF798HEt
FyIf1ZcfXyV4RLF9YW7aAWI9a3we/1kfhEzQoeQEBdeYZgk9/+uDE6uFe7tC
KGjR9zpubn8PyOee/vM4jIIylw8/si3rgTQz2btHIyi4JVuteG1sD/RYG7b9
iqbgvtK8t/+29wDNzcddOoGCzDYFfeq9brCMnTlnkENBQUeKxFrsgnaN6P+G
cynYnNt03GdhF5xLWfY2t4CCOzNZztmiTsjP3iENpRT8WHjO1zi6Ewyqr0Y7
fqSg0tjvSOXuDlAWV3ns106cd+DkngzddhBzOU2X66Jg7AeWjkdrG/SX8OYl
9VBwVn9JwPabbVB65u6p6m8UfJ9YN3hZsg0ODi+10f5FQY8LgUbfx1rAwd5/
uvAPBX8/6lZZVtACphnNL+wnKHjpcX9b55kWUDgcv9T/HwXbX5ht0RZvgYIO
9YF6GSrGdpzzu6fTDEkWFx4emkvFS4JCrswvQv/j25yn5QkbZppM3xHzJvVB
iZ4SFY9nKC6ZOiiAXXkzXqXKVAzYdazshtn/v9cuOs4qVFQ4oN3+d4EA5tRp
RgWoU3G1zShjz3s+/DIM2qasScX7lx7vNnnIh7arnWNpy6i4Ir+nffo8Hyq/
bU3HFVTMFKin3GPxIXtnkkuTLhVvm2toKwEf4lPElT30qWjuF2qyf9n/ecPt
4yxDKi55n8uIlOYD/fXydYbrqHiDefP0US4Ptqtf7nu7gYrRS+57qL3lwWr/
njjqZioOh00EJmXyQIW/3f6HCRWL6bdMpgi9Fd+cInHZnIpvvxrV6l7jwcBN
yYIlQMUDfIXTywN40DRywCNrKxXHuqOODHrz4I1DheaO7VRc6C+edsmdB88y
dRoFVlQc3Lk6upvDg9tyV8JO2FDR5G1TjyyNB4FHhFukbKmYESPlN7aX4InK
nSP37Ki42Ktb6okDodc6qY/XOlLRztb6xSJ7HlhclmF82EtFfz/FD9sIW6/L
XYFFpiJrwYfiVY48UMSP70aoVEw3DZP67MyDqYSVp0MZVJy/4VuPFp0HfX/D
DDTYVAzfRY/S38eDOlp/R44L4T+HRek+zIOi/F23bNyouJbsE2njy4Nk5Wc2
7QeouOv1iwg6wTORPnP/+bpT8UpIaY5SJMFb9UezZY9S8b9aEcM7geAZo88H
Hx6jYpqGWasPkc891wxUN52gYuXk6yhlgseMv0fUfvIm/CUdanRu5MEym8FL
+04S6w1WLkbfeSD3ZI/x2CkqSlBCXyWJ8+HP7MyBiLNU7Gz+6JauyocO13mJ
y84T+eM8bbTZxIeqN56kggAqZttJRJ4m+OT+OaPS7stUfDR5syooiuDLsu9n
PK5Q8elJmTtZWXw4IJW68XcYEX+nzlxKPR8MrmtmSEVRsfSQSo7sEgHMb2xx
j4qmIrWNWaEEAhhdcldb5SYVg94ejY0i+rvo0YL4lXep2IvTXrxCAdwXVVOy
71HRqWD9n8ReAQQZhiuZ3afix6SRo1zFZrDOF79q+4iKfxfaTgV5EbxeNXrm
eAYVJ7fWeBVCCxQpPN84nkXF5vPLv5X7tUCCs8dwYDYVLRxXr9+U1QL723rc
b+RTUeym9yYL7VYYGW6k5JYR/WgiZ9+k0QbzlhRs/NtIxZf6GUnj+h0wwvId
vsQj3tfbY10Bjh3QmLQmQ66ZiutSvfrzTndAvMFTbY0Oon47ve5v/NgB+hin
tLWfijq60ckXvDvB6tC54ZB/VOQdOHPRsa8L9NONMxRm0TClofhD6uJukB/+
5R4rQcOJK2Uhvjbd8PXssY6nMjS0LLMukMnsBtdIdu1nRRqGByRv2Hy6B6wa
ll4lKdPwxuzkHZS0HlipwrVqW0zDM26WiQtbeuBnon3pkBoNmQndtL9beiEg
FzMUdYnzRjQGi8d74aWYD+PLShr2RWhmF+r1Qf/ulDk3DGjICvylvp/SB+Su
OQcXrKPhLe2QYwef90GEofnC+g00rOS0D98S9EHZac+31zfT0KFyfYemBMEj
Cg0a87fQUMy65aO8vRBc6ZLVtUDDZ/qaS5wJPolN2ewfZUnD2ovqg2UxQqj5
eXil/Q4a+vTXhdjlCEHCPJ47z5qGNdkFUcN1QjC+UhNcs4uGW+p5e1IGhOD5
RWxD5B4azl+s+G+/lAiS1dd37XGgYdT6oc0GGiIQuB+4Lr+XhirB7f9NrBfB
/Jd3LKpJNGyIe/GjaifBFzMfByKoNNz57d34Q2L+P7drKs6WQUOdtzKUc4dF
8OLWahs5Ng0NjMgxnFMi6OtwGfvkQsPqikVWey6JQM0gJuWqGw2DVY8OWF8T
gdOp8r27D9Lw4NxMCoXgg9C3Y7PmHibWFb77nr8nglJ5/edVR2nof/5F3huC
N35RmexwT6Lee+fI6CWJQD85Um6XF2GrNt8qImzO0JuiOb40bGErXAtIFMFN
01H3j340fCFKc75A8ExV8IrFYWdoqNUunvz6rgjE6inl1udoyCUdfmgbI4JN
auE+MgE0POey5vjqqyLwOFSsVRlEw4h7u6Q8Cb5Kyv5Re+UyDaukKr8sJPiL
N615YecVGo5MKA8ZEPHL2+w1kA6nYf/Q/FNv6CKwvBksqIgg4ql+to+/SwSn
2/NDQ6JouG7aNCvIRAQ9J9V6JW/RcPE12fg0gheXltnFlN+hYfnf+C1I8Ii9
XNDW4Dga5rSdko4ieKQoqTdh9kOiX196MS7mCuHn4GLb90k0tMv5/NfsnhB0
THZNXkqhoePpyIO8ACFE12aSJZ7RMP2Zvkz3DiFULO2c/S6DhiWSsxUP6gph
6oBSzsXnNPzX8dz8t7QQ3KdOKYjn0bBI3yaUVdEHFiu3VoqVEfGLDvm7m/TB
wMUGk39NNNSt0a1niPXC8ZSvE5F8Ip/XJfqK+D0w8qGx8L8WGpLt/KJKs3tg
TI5nsrWThj//NG347NYD4ndaTC5/p+GCDSB89rYbFj/rNZEVo2NJs+na4VNd
EFfdNxEnTkenPsUnK+26QO2nsHCVJB3jYqZUaNpdsGxjv8keWTr66hwcfFpH
8MnrHybXF9KxV8Ab4q7sBMuGMZNFK+kYL/pmfru6Hd7/Hp94vIqO32Yve0UO
bIedKpOFm1fT8e37O1vUN7SDLWvKhLaejruLuJR/99uAIhQzjd9CR1bo9s5n
l1pBMEd80gDp2PV59LgFtgLTQKKoxJKOJ0L2Rm/71wKuXpKm7Tvp+Pq/Y1mf
LrSAx985psuc6GifOoucfaMZhtTnTmY707FNZhaWMprBG+WKtlHoeNUp6NZJ
gl9OBc8zPcAk/A0MWP77jQAmnyhM/mYT/pRXXnt3XQDnquYXheyj47P8vVq7
XAVwUUHJNPUgHR/PmZcaLCuA2esWThofpmPhy1rrLZ18uOKsXPTxKB1h+fLW
F4V8iLi72PT7CTq2uqu+rD/OB4VilUl/Hzr27Lj25twePtxoW1Ik50dHlf6E
yG4DPtxZrma62p+OKznwq/0nDzxsYwZ+n6djbPyf02YNPMCTsg9KAulYJLaT
cjefB8r3gxyDLxH5P3tWaYzQ1/6KcYk9IXSUiII+xxAevB46nrcwjI7v5+6t
eXyCBzdVhO4tV+no0M77PMLkweGtbNXkSDrePOrbtG43wQ9HGquPRtNRL22P
jJsZD5RibAPX36SjuuFMeoAhD0Sv3q37e5uOgRVjO4K1eFDcY9r79i4dmRXW
u04s5kG0fPad8Hg63siuOGquwIODm1bucnpAx/23dwX1yvDAlPNwakkSHRMf
uN8+NJsHCqGLszqT6airJJ1TOosHPc8j9z19Qsfwd5zoPjEeFPIlF3ql0VEy
iDMuINYjxc9XGGfQUdP7/fs7xH63Vb9Oiz0n+jfMukFlDsEPzkdXVWbT8WT0
NjE6cb/8+a7WqFwi/mE1PQrhX1cK7TqlgI4j12i6coT/eTV1lv+9ouOPiYsC
XwMeXB3b+buvhI61eeE210x44KL5+knmGzpOPyqOcrTmwQabTXS/d3TUKj7x
rITKgzneGXIWFXQcnvgXV32EB21x2q8lP9LRg2l69fwFHuS8u+dV/YmODY82
ilXF8CB0QFH7Vg0dGf1ompXGg3UWs8K0v9Jxk+FphY2tPJA+dNpsoImOtp/K
B2vGedASNTSYw6fj+j86z0eVCX7tbHXa1k7Hjac/qtY584EhS5Kc20VH84Ai
vSA/PqxZ/zn/Sw/RTx+yKM/v8oF/uUjNtZ+On+3lz17o4UNmxtralYN0HH2W
qqYiR/RzU2rQ8BBRn4BMWLFRAAZ6d/oCf9Nx6i3nQNRVAQR+8nn+QIyBhxb6
XqLZNAPpV7/rIQkGMsYatXaeawZ9dVdlIykGui4Rz731vBm+ejqcLZ3LQOrp
cWN79RbQVTTc3rqIgV/WLlknJd0KU6bJf5KXMFDwJWy4ensr1LmpPvVQY6Bl
dFDzN+K9n82dM29Ki4GlAbxLqlJtUEPt4y41ZKCjue1J8tJ2iHcvjG40YqBZ
+5nd9H3tcOR0xO7r6xg4cfdvVOLTdpCOXfda0piBMzYlGlMaHYDcC49/WjLQ
3tF4qKWoA7JJi09WUBlo8CF47PP8Lgg80L86iMFAXv/XEy4WXWB3skRkxmag
bVjJzVseXfD9phvzhRsDJx/MlPVWdYH216xt8Z4MbMhOUJCN6obbTtaK3pcZ
uFTh8plm3V7Y76r62eAKAzt1axId6b2wzvtHsDCMgVqztmzaGNELtdE3J5hR
RDysvpfvB3vhfuKhnMU3GPjfz7LNG9T7wOOF6bEvNxl4InJN6Z3dfSBT39Gx
M46BLUuT3GqS+6CpIydOPIGB0kfa/X1q+yD5Z4hzyQMGpjnD22fjfbB1vmHl
uhQGWoR5b7xiJYT5mmIXB58wkFWaNyh1VAhtRg1mqWkMHDCXlWi4JoSz9mey
1J8T+dhuY6BRIwRrju1hXjYDd2suYoV8F8Ki4/8tj8ll4M1ZLdbzpQm9vDDS
sqeAgSaH6+RzNUWQE1l+W+YVAxN/IdWTmO8v3o91eFfCQL/z8ixjOxE4ZB6V
vfCGgfF3JP4puIpAo9TivfE7BlaE11wZ8RHBQPWCC6PlDEyuCy1tJ/ikqLVn
c2YlAwvN9bfxogkeGcwfdv/EwA/BR+pbEkRAng5/tryGgW5+1+uGnohAW559
oK2OgbfjNo8vfC6CEbW1/91tYGC5E22uQ54I3hjM5u9tYuD2Y0VRKUUiiDTn
3pjHZ+Dqb7q7VUtEwLJNs/3YzMDLihJa+YR9er2tCqmNiGee8YekYoJflv7o
7uhg4DbW3vTpQhFkzbqe5dHNQJfRePOaXIJnRGv9x3sZ+L2c2bOUuL+3tsHq
soiBonvDiv2pBN/kn1Sc/514P+kdXywfikD1/uK2e4MMVH/SNWRwm+Cd4MKn
uj8ZuHLTSXweLgJHD8bJnBGif+9MxH09T/DP3mmE3wz0fh8el3icyIfpA7lP
YwzMDjBz+M9FBI+0tvLIkwx0Pj+5lmxP8JpM96OuKQbyT+Tl2m0heHLo8nHP
GQaOdT6FBfoET5ZWSoXMZuJus/57ymIiWJVy5MsCaSaKHmqXun8TglWE3P2E
OUycUY9cnFovhPN0h42585joG1tpIv9ACP1/uG49KkxM27D4K2e1ECTbzhid
UGXinfcmz2fNF4Jmuerfv+pMTJTdvaDhZx9QYjg3lJYz0XNTz7cVBH+/NxK+
sTRk4nib+eaDOn3QvigsosaIiVp7vy7ZL94Hk9P6VPo6JnYtr8e61l5Y+9lz
yGszYd87u29eDPFe3P+oJ25lIhtWxwyM9cCpREn/GRITGVqje2qfd4O+kvbG
4gtMNFq2zWmjdCfEipmPXghi4qAKa6SQ3wGSP/a+2HqZidKxvTmx6R3QUXnJ
8EMYE8/MK5q+tbcDbl3oXvHlJhP30u4uTrVvB3GPv9037zDRYMhiX+tUG5yg
KSVR4pgYkf34hO+zNti1YZtG6wMmpmQ0U6Tl20CsP2mRKI2Jw4fvRVt2t4An
t+hrWgYTF+Dw5nkJLdD8/suNY8+ZKNkTwLlPbYG8B+IKo7lMVLARvdZvbIbl
15ZW5xYwscOlVWz97Wa4fnbd1dOvmCj/8yRlCa0ZjpJcpf+9IfxfHuof2SMA
nuXZ8jfvmPjFYSpteYYArNbcuHSpgommEtu6k04JQHPu2xmZz0zc6sqOc1MU
QOQ4v+RTDVGvS2MPHnfx4W/vsH9kPRPDJGSSGl/yoemN1rgSl4lVi7Ke/WLz
YXumSV4Tn4kXOlU1uoh5+sU9R9+7LUykWkVuzptP8I1f0E+NLiZWUlZmz6ni
wYTb3czOHiZaX37pc+kpof+OLzyShUw8fvKCBj+cB1sNOkUrB5k4MfOeI7uX
B5lLJh4PDDFxNG5OfRuht2rSCw5kjRD9ZWsxEbiMB2G/9JZ7/2Zi3PQNxoAc
D/50YueGcSZ+pO4vUZvgwv5a6oOxSSaOPKUsmCfkQn3xCVbRNBMXEzNkcRMX
LNJCVc+LsXBnvqvXskoupN95yAcJFn770P/D7BUXlgYX3BGXYuH8lK/Gs59z
4Yp3HalchoVnYtdU+z3mwi+OSCl0LgtdPV51Rt7ngusesS+75rFQT5WUuTOW
C3WmKtflF7DQa41hcHwMF7borbGrU2KhVN6RgtDrXEhTtpaLWcTCpXvMb0tH
cUFFwqWKtISFv+rmeSwk7JCfp0JV1FgYNLQpLI34/WhrlFWzBgs72PVbyonz
XD49mX1fi9i/MU3KhbivpuD1WxdtFv69bujmR/hj9pgbuFyXhc6Pqt5IEP6m
xgxZ9K1koUrx7iiJLC4sCpKeTjVgYcBfh0ivQi5c8vzv1VEjFjLc/c7YlBP5
WS91dWYtC8+qnWqPq+fC+NgAPWYDC6tV0xma7VzILm7Q193Mwg+2hjlNg1zw
CCqaLDJh4azJNS+KprmgY5VYZWfOQlH/w6nKeTzolA2N67Jg4WDfQfN/mjwg
3ySZym4nzjOb5n0h+Gk+zVz2vhXhf+y7Vx5sHlSpLxestWGhdUSw2bKTPIAn
P8/Q7FiYX1ha2pDCA72iq4WpVBYW1Zx/NanEh64L3mHmDBbq/22sUV/Hh4Rt
NFodi4WHr4877nTkg2K1zsSYKwufjovHPrpB9Hd7mfHOYyx8w/uTa6olgLzk
VJnm4yzkunkIdu0UwInDUTxPbxa+V6Za23kKoGeEefr2KWK//Ov9Bq8FUCM5
nt8bxMJihc8a8z2aIbSq7cqZyyyMN43Jv363GbZFlVPkr7AwVbtx8M+HZihQ
iRnbEMHC1rLWLk/dFkhctXrz5dssPHd9Xdfkzxbwddyft+wZCy2zJzX2Z7TB
6kW7Q/IyWFh3Zot6iagNvgnWknc9Z+FtnajdA9rtwN4/89srl4WFehPnPj0g
5qdTcRvLXrPQvS4y7I19ByxNqHvJ+UrU/7mt9mq3TqixVoroa2LhomNxzMKQ
Trj4i+R2jM9CE90TmalpnfBtd/MC/zYWdi1ZVJgz2gkFk72et0VEPZKnl50L
7wIy9a9e9RSRj9/SM41V3SA720LMeYaF5OVRsk9+dUNpViBXMIuNm6ycFrRp
9MAKaakQkRQblRoHCr18e+BX7vxuiQVsDF1e0jW2rBduKOkkmK5g482TZQe0
/fvA6rW7b5kuG1fRzV80PSK+90ee7bbWZ6Mkbdf5l5/6YN/bNZMkIzZq6Uue
TlARwkJPn/qWtWx84ce8eGGLECqX5KW6bWCj4FbtCtN9QljjZUbxMmFjkVdh
jViKEHrULqweN2Pju0cXxQbeCyG28o1kgAUbW+/oKZ3sFoKtr0Sr5FY2ei/5
ExpF6N/Mf1YvI7ax8eVVRQcjNRFkfwq9qmRFnCdxT2r3JhEcPPXJNc6ajc0b
zzgICJ6pqXFYkLqHjWO/N4tv8Cd452yMaLUDG7tG/4SORhJ6rtP0OteJjXED
Xi4KiSLor1e5Y05io2HiuZRLL0SQcJ7h+Y7CxrOLctbYvSH4aOX9HbvobLS+
8/fzsWoRzG7sUKtnstEg6O/uTp4ICgKX/6JwiHguxseldhE8YHDwU9s+Nk4q
mm4p7xeBJi816cB+Ij+Mp1+Nh0XQcOn7mYGDbDyq12gk+UcEIUarHX0Os3Fe
Y8YNwwkRmDaf0Js8ysZuA5mR3EkR/AjJmQn0ZKN9ntz2JMJOWvenSdqLjU7n
Rob+jBO81WacGenDRiPFYErhbxHMCfcPVvZjI0uvZ/rHTxHMM99g33Caje3+
xubihD8LfwyoRPuzsbe8ZqtjpwiWPkzpsrtA+Hvp1FBPE+GvEztdLoiN76X2
61VUiUBn9mK/qktstDB9VTdN8JZBXi2EhrBxu2Mf/VaGCNa5h86xCmOjGcdC
+068CIyXbm2QiGAj7YzCfXmClyw+T8SXRbLx+u/XGyX8RLD9QvbBgGg2LjZm
zrlI8JFD1/LJydtsLG1PeGK1lojnZsu7grtsnD0wHpC0WARMq1vX/OLZWHbE
d3nOlBDc06S0RhKJ++k+bhrvhODJfN2flczGxOuhO6KSheA77/TLY0+Ifjbb
KdV5WQiB3t92fktnYwT76bSjpRDumH727MhnY7hdauXtF30QP3DZ+H4RG/1T
ta+bXO2DpPtbxJklbMzSJI8v2N8HmeJZt7hv2ah6Mm3NVaU+qKiKLq6pZqN8
u+jr0yO98PncrpCIOjYWOpWXSEEvfFkt4bCrgY23zUwnuxV7oe2Gb3c5j6jP
VvfwbYU98IdOkS3pZiNnX/7E2VnE+/yuRn02wcbxazlqdiFdoJ/QqHV4io2L
xu/x3MhdsMY+8rvODBs1T0LIOZ0uMM+ZuZA0m4NWvoHS3yo6wdm/K+WuAgfn
5J06ri7bCZfnpo5eWcFBcUW3r3ts2oF706h2kR4H177PKOuabAN9jfy0FH0O
ruyYK5ZNfN/q1lTse2fEQcVImyCDxW2gSu6p/WfCwYe5KsUxkwQftR99ds2c
gyeF152k81vgjftoiBpw0Ox1r9W4bwsc9Be3MN3OQXKu6fL9v5sh+6Fm+kk7
Dq6vPuX8QaYZJPVTr8x25ODNJ+x/4fUCoOYYucXs5WAKu43ZdU8A/8otlr6g
cnDbwuXpe4j51tG+4jcwCH+XmXP3zRZAMm9PfQ2Lg4fo20hzGvlg850ZOuDK
wZz+axvn+fMh3rfHzf8AB0mrffvcHfjwY/ooyLpzcAH5+DJHXT7cnO//R/cY
B5kBAT1lfB4I74p/yTvOwR7R+8s7cnlgujw8Y4c3kc8n4y22N3jQsfHufrdT
HDzql1ctcODB+teaOHKGg1t3Mofp63gQYp2qGnSOg/Ol4g2dlHlgwMj/cj+I
gxYR28xjCT0O6LHINLzMwcTc/p3tFVz4cqwirDiEgxezjpdEEnp/KrARBVc5
+Kz+t65KMBeq5rDUDkdyUI36qO2bFxfUYnrGxq5zsJTHUl3owoXjah4NITEc
3NSV0H3DngtvU0YzlW9zMEbtlakrckHZyD88OZaDYZtKRefXccG9QPzg+nsc
LNMWlHSu4MKrreFb3yZwUMqhLiFsKRfmfVqg7viQgxparh5e87mwz/nueHsS
B+e+kZa/Jc2Fl62aXz1TONgt/9j150wTSB9KzZp+wkFpuxsOARNNQP9pdDUi
jYiHrlu05VcTZJzJP6iawcFXVzeH6f5sAjEJsEzL4mBFl2Oj8WAT7I2oUDfJ
5mDxaHzise9N8FjZbuLDSw6mmR3rL+tvgon7jV/J+Rx0fRqYsZZYt9VjPe8t
5ODk9nf6hQNN8OBFz1XfYg7arIJE56EmGDH1OCTxmoOmVJVNYqNNsOP9qOWN
Mg7mf/CeVzDWBLF7/DW03nNQOFYXeHq6CfqbxCezKjj4zXqLhsVsgv9cwhst
PnJw5GMjSspxYSBHWrDkM9GfByaftitzIV46uO1XDZGvWrnEYU0u7GaId9fW
c7BN/MmfTYZcmMwMEKZ95eCXnTUjaaYEP4pPfw/mclDu5pev1jZcoJHP/nQR
EPVvlWiZS+NCwbTvxKIOIl9e6u0//In6OI5MD3dx0GN8oeP/eXNxynHx6l4i
3+0+nhseccHP9sjcS9+J/thrUfWqhuC3h0IF9g+ivlrKsfJ9XGgc3b/QZJiD
jumB9W7/uLDhHkd96A/Rz/d+Ry0g+rPnR4tW1QQHFRYnvtu3hwcxlnSdlCkO
fow++TD1MMH/vml3DGe54AqpZKYcwW9UtZSH3VIuaLorb6pVhw9rKrqXOcq4
YGzjC+trNnyQPrEspXSOC67qIkcsPcaHvHcPnt6Vc0FaNEOzPI8Pykfjsu0V
XTB46zlbLWcBDCzkbyhRcsHo4nSTS+cF8L50cb6+sgueKEw0zn4iAF/FW68k
VVxQ5XYzHv8ngC+FUe9fqbvgh7rv1ga5xDwlE9yku9IFb1Sf2zjPqhXcs99R
b+m7YGFteLabfysgU7xZ3MAFkzWq5x170QpDWQHtratd8PbvFIM7/7WBHeWs
KGaDC57vqHbWn90OOrMKj8za5ILxkSY3ZizaYTptbMBzswsa6Z82CjzbDun/
fIdtTF2wSdkgP2i0HS6n5vjkm7lgoyG2BKp0ANNp5Lf2Fhe0K8l+dGtzB2yY
WnP6hgXhr1/K2D9yB8x9fHxyBlzw7uK6hGK/DvgfDV/51g==
       "]]},
     Annotation[#, "Charting`Private`Tag$37576#1"]& ], 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEl3k81N8X/y2RLBWJbBWRJclOWc4h+z7GnlSySwqVlPiUREqSCpFUZE+F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       "]]},
     Annotation[#, "Charting`Private`Tag$37576#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Critical cases per 10K\"", TraditionalForm], 
     FormBox["\"Prevalence per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{Automatic, {{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 5], 0.2], 
       FormBox["\"10.\"", TraditionalForm]}, {
       NCache[
        Rational[2, 5], 0.4], 
       FormBox["\"20.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 5], 0.6], 
       FormBox["\"30.\"", TraditionalForm]}, {
       NCache[
        Rational[4, 5], 0.8], 
       FormBox["\"40.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{0.8899999999999999, {
       GrayLevel[0], 
       Opacity[1]}}, {0.7000000000000001, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.2, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7934462183922*^9, 3.793446262635705*^9}, 
   3.793446322861353*^9, {3.793446417955284*^9, 3.793446493969702*^9}, {
   3.793446528220602*^9, 3.7934466811191187`*^9}, {3.793446762960642*^9, 
   3.793446783185998*^9}, 3.7934469583619823`*^9, {3.793447077418531*^9, 
   3.7934471077778254`*^9}, {3.7934471626694593`*^9, 3.793447176249228*^9}, {
   3.793447220612138*^9, 3.793447223788662*^9}, 3.7934473045057087`*^9, {
   3.7934475125474377`*^9, 3.793447526798827*^9}, 3.793461894648978*^9, 
   3.793461954811411*^9, {3.793462025917428*^9, 3.793462051362706*^9}, {
   3.7934624165193977`*^9, 3.793462437537854*^9}, {3.793462489379582*^9, 
   3.793462572943308*^9}, 3.793462608295115*^9, 3.793468960554473*^9, 
   3.7934690632834044`*^9, 3.7935292809471073`*^9, 3.793529765163126*^9, {
   3.793529806446199*^9, 3.793529925526959*^9}, {3.793530273637145*^9, 
   3.7935302888680696`*^9}, 3.793532162151572*^9, 3.793538246353285*^9, {
   3.7935388463385468`*^9, 3.793538853743732*^9}, 3.793617485369368*^9, 
   3.7936177385418587`*^9, 3.793628687297423*^9, 3.793631367349255*^9, {
   3.7936315179470167`*^9, 3.793631524247354*^9}, 3.7936317107362137`*^9, {
   3.7936318555128393`*^9, 3.79363188690956*^9}, {3.793631936832223*^9, 
   3.7936319627131557`*^9}, {3.793632033683556*^9, 3.793632076506719*^9}, 
   3.793632435266795*^9, 3.7936326151734324`*^9, 3.7936326938437443`*^9, {
   3.793632887378137*^9, 3.793632896509204*^9}, 3.793633150297453*^9, 
   3.793633212280756*^9, 3.793634113241684*^9, 3.793634258875181*^9, {
   3.793634291668049*^9, 3.793634384224745*^9}, 3.793634839330484*^9, 
   3.793635141331812*^9, 3.793640118035039*^9, 3.793640223640168*^9, 
   3.793708821958202*^9, 3.793717681230094*^9, 3.7937179100106707`*^9, 
   3.79371818152843*^9, 3.793718273600041*^9, 3.793719545883644*^9, 
   3.793801398956727*^9, 3.793801479248869*^9, 3.7938015752891483`*^9, 
   3.793801642654684*^9, 3.793801747390401*^9, 3.794507033990834*^9, 
   3.794507502315681*^9, 3.7945075482767878`*^9, 3.794507667915263*^9, 
   3.794513117110821*^9, 3.794513184142086*^9, 3.794515037313142*^9, 
   3.794515322179332*^9, 3.794568657024329*^9, 3.7945690216934566`*^9, 
   3.794576700803309*^9, 3.7945781578308973`*^9, 3.794578443657825*^9, 
   3.794579375572747*^9, 3.794579505036727*^9, {3.7946571472105017`*^9, 
   3.794657155391067*^9}, 3.794657219836362*^9, 3.7946675298145733`*^9, 
   3.794667828426355*^9},
 CellLabel->
  "Out[920]=",ExpressionUUID->"8f7bb501-9518-4e07-94e5-ebde21050e56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"figcritprevbp", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"10000", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60bpnsprev"}], "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"10000", "*", "sf", "*", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ISq", "[", "t", "]"}], "+", 
           RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
           RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60bpnsprev"}], 
         "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "1.2"}], "}"}]}], ",", " ", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#", ",", " ", 
              RowBox[{"ToString", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "/", "sf"}], ")"}], "*", "#"}], "]"}]}], "}"}], 
            "&"}], "/@", 
           RowBox[{"FindDivisions", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", "5"}], "]"}]}], ",", 
          "All"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"dateticks", ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
     " ", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",",
      " ", 
     RowBox[{"PlotRangePadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", " ", 
        "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", " ", "Black"}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"10000", "*", ".000089"}], ",", 
            RowBox[{"{", 
             RowBox[{"Black", ",", " ", 
              RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"10000", "*", "sf", "*", "thresholdprevon"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
              RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"10000", "*", "sf", "*", "thresholdprevoff"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
              RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}]}], "}"}]}],
        "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.793708807863866*^9, 3.793708862589035*^9}, {
  3.793717820859579*^9, 3.793717820954225*^9}, {3.7946571663062553`*^9, 
  3.794657199843513*^9}},
 CellLabel->
  "In[921]:=",ExpressionUUID->"f5e77aad-2cb8-40dc-8c8b-604c35195555"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEuXk81O/3/0+LRIsWhVSSJbtk386x78wYkSSRPRWFUKKFEilZEpIlW8iS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       "]]},
     Annotation[#, "Charting`Private`Tag$37716#1"]& ], 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEl3k81N8X/y2RLBWJbBWRJclOWc4h+z7GnlSySwqVlPiUREqSCpFUZE+F
UEQhYyxj33dmCIVSKPrN7/H4/b7NP+/H83Hf73PvOefOfd2XqKu/tTsTAwOD
LQsDw/99DrPKd3rq1Gkz/L/flry+OQOf5/D/+SUjh6+gT9H/OEz2mfQGn5r/
MU3nG9uKd8f/+JHZ/eDv3hP/4yWCV+G894//8dMOgtk37w34/7li6FhAqf72
/7HLgSvxnP7/mCE85fXxxH+sK9q7yDbzj+tOWgc6xvH9jylTekGrffz/47FF
6fOaZwT/x9cOGz2IS/rH4gkeJRMf/7GHyrOft7YL/Y9nLghfGCz/xz/+bA6+
wiLyP9648cfFquRd/2Ptz5Qt+p/+8fkb+RmkmX+8eO2Nl/fO3f/j4xv8EgL8
/7EWy8hMBLfo/9jBvVn1s8Q/Dqp9/9+mQ/8473oSf6zrPxZkJR5++OYf/2St
S862Ffsf83gWTc54/+P9n5/Ky135x243wupeZ/7j9o0HF9/9+sdfPSW11jn2
/I/Z67dH4e5/rBu1KFJr9I8L2fKMm5P+caNXcsLWgn9Mq48atv74j3dGu5/r
/vKPD00TqwT+/mNbY10O523i/+Nbm3alj2j84yxvrlkxK3F0ekoukddUgE+k
36rubuJ4o0fqbkaMPwxJf/nvRbA4qp86cefkzhuwGt3TOH1LHNVOe7z9WvIA
+L7U8cumi6N118cjR288BUWTYtfTxeK46+cOjgnxXLDIeZZfSBLHewFWDiei
X4M3e/zy4qA4VrVkMwkLlgJfqnz37HdxfMC50rb9UyXUHGgppm6SQEt5cs0V
pk+w05YzsE9FAiXrdFhnt5GBTMshdJjSx10XLcJDWiA4xFi++YQEhv9Yf3il
vxXa0iLnqm9L4AmpN40P4zshTFGi8d0zCRSW3rE6p94NsrWfcorLJLDUa75J
61MPRH5h8MqelEDY/Yqt9n4/KIWmGTz7LYFjIoIRkZMDMLJFWyKVey+aqXJl
XZAagkMql8bitPZiEmuiM4fxCNA+C1TfJO5FnXeBMmFDI5DgVJoW4b0XOy3R
pOfsKHwNW3IOvr8XX6el5qndH4NHPAkaAbl7caZwLvXS3nEwylAUPFW9F8Mz
rCmypePwrMG/+9jcXhysSiuJHZoAq6ObSxyZJfHZdKo1U9AkrH/LSyAKSKJF
RjWzNwcVcq+aBpofkMSNE/ejl55SwWH7F4KhviS+EBULi5OiAUtWlLzOEUlk
mfYXFUmmwetDkls0zkqicrjBTM8KDY411c4p35BE/sXvrDXGU8B53K1RLlUS
zYL3PcmOmYKyRaZcqTeSiF4BXQLVU+BxPT1ajCSJBUxxXqEzU7BtB3oJD0ti
4Xyz9TbOaajKGTLgW5JE22npvpU90+CnFSqxlUMKC4KS3A4oT4MgRWgDu6gU
mm7d5HlfaxrqXcvHmNWksFFqhfwdp+HckkP1mpkUGlX9zGaAaRCL+pX2y1UK
mRze8FqrTwNF8MGVhWApVCBnyATvn4bQfOWjM7FS+OYNzWZ+5zTIYLvG5HMp
5Prx2EOKaxq6284KDpdLIevVDRa3l6cgwn3rSg9FCklwmu/c6BQoLBd0t1Gl
UPlpG69U/RQM3TQvafwjhcs82+2/5U1BjMhsQh2PNJa8qSOwxU2BeuHNwCop
aRRTUlPMPDsF8Z2f5YtspDFObahfWWEKDHfr5j7Kk0btZpvExgwaFBarPvFx
lsHwRvKD+hAq1DKZcc2dkcF7uxp7Deyp0Gd5IsT/ugzanHp3v1qJChu+xNgE
FcjgwrVo/prZSbDfOcp2hWEfHo+wTA89Ru9/ZMzZu8/34W0nQ5cQkwkwcxjR
LZ2VRRauCtVDOAYnMpZeHmLcj9Kh2xdERcfg/CK7SMX2/Xg0i79EnWkMntxS
+VWtvR8tf5w3/V4zCt+rbuaS4/ajbmsLT7LZKCRLq/AOK8thzcNZv1g3+v5e
jZ5kCT2AH3gef3/oOwixIZZUuHcAk2add9goD4LyKi/tYvYBvJlHCzq7NgDh
K2lTc50HMKTcNr0pbgC4/vQt+fDLY39oEO+fd/3wYnV+2fqMPMZX5AwX7emD
vl/Cf8XEFLBuk38UWbkb8t+G/YX9Cuhw/8KrNLZuCL8w9tdZXQHn7WVmPg10
geSvFwwPLRSQp/JcxOr1Lgj6qcjEcUkBXQ+ycPAMdALXkhHL93YFfL3tee3l
Bx2Ai0Ecn64r4jsDM2MatsGKuaF0Xpwi8uw/U+O/sw1eZwsY3n+kiEYPmvtV
/7TCnhOVVz1f0ccFvlqElbYCK2XjKsegIur9TLX5qtQK5PzkKRtlJQw60+k3
p0KBiE1+rNqghKXk4B/y/BTQdAdxSRMlrMahr44LLVAgPHFs5ZgS6nSssCUH
t0BczP7u1Bgl/NN3KsjgVjPYeVfVUseUUMH+YdaLz42wpTZ+vGVOCdtFV+9N
xDVC/W53xrJlJWRrf3It0qkRDvZs0orZrIyljys+/PxKBmFDYtGBQ8roedXr
1XlhMnQ+lWjboa+MMpmH80hTDRC7/usbo5UytkyWJ10uboC/xSn7OtyV8e4t
uZt/LRuglNvfuOKMMir71Cs0izTAGT8dz8xLylggP8+3OkMCadK263cilVGK
WzTuajkJxsSpT4PvKuOp6NBNUzdJ8Ci8tOpEijIePD/g8fQMCWwGbg6ZvKB/
L7OYMXuaBJzqR/8ovVZGkft+8xNXSVB774CgSIUy3o+ashLOIcGVb4zqrPXK
KF/D9F/wGAlUTTtsv7Up48maQygq0wDfMjMDewaVcVtSAzkprAGymC7erZ6i
c/O+B9GjDXDcxfRlzndltOZLNeuzIINAuUjTvXVllNj2sOhOHRlunv3I5sGr
gqPE+NW11kY43JSw13KXCqafUNUMdGuCP1KeeuoyKrghlr2hbL0J/EY4wtlR
BTeb3pCWNW4BpySBSTUTFdwZLrpQMdsCBtaSJu42KtjwvXrzRlMK7K7R5a3y
UsEIjuOKhX8o0PbiYta5uyr41VHjnXZ4G1Qev8H17JEKWp57w/aB1ga5AvcD
KBkqOMbJumWC0A4RMYWa+8rp73dl6u+T6wBVfxplZEwFgX087ujGLhCTWlLZ
PKeCnxx51LIjumDLKNMjjV/08R93Fbo2dMOU9U73BxyquFVNJJl5cw8kq9qu
mCqronWioqekfh9EfnN1uaitijZ+EQPf+vogMOvMp0wjVYyo/DnIHtQPZoK3
bjMeVcXgz/3KlwsH4O/aR9G311WRpkHR1LIZhtkSSuTEHVUshQc6eswj0OM/
NMOdrIqfh6LDnF1G4PXoSvGpAlWUr0yXuyU4Cm618iZi3aooUsifzJc3BlZX
tF9ajqpiHavQ7uXt46ClZsYbOqOKtjdeHd9zdRz4sj2Huv+qYt5RPtbrJyaA
yfXcYRZ2NfTnPqvU0TEB3wSvZSnyquFt9Yu8j00mof7W44DbUmp4KKLOtVOL
CkX6ed3limrYLevkmlBChfT1Ms0pTTX0cJSgjO+kQezbz+nbDdWw5axzYsgF
GoSc6WQ9TFDDtmsKr1aqaeAhPe575ogafh95pd37lwbEsXlKqrsayvewSfsr
TgE+Wlch+6tha1Is66TTFMjacD5avqiGIwSBzZYhU7CDS5Bhb4QaVpfY3k+5
OwUsdZLuxFg1NLLIq8hNn4LFKyoN4YlqeFaOwnY4l64vaocPFDxVw3MlQZd5
Xk4Bed4qoT9PDV9ePGxWnj8FpdkuK2xv1XDx6h7x+hdT8Nz1lItqtRq+upr7
+UPqFNwVCvl0kqyGr+tJQVx0PaqbO7Z4qksNmTf4BkaFTsGfD/qi50fVcPkc
ir7wpOtb/D6rsFk1fHuMPNNsQddvN+6wqF9q+FkuochNaQpSVH/l32VSR7no
JYeK7VPQyjY4kMyljiViFiJCP2mgmZ91KH+POv4iyJbOvKLB2bBY7xI5dUw+
+aCZdJsGmYSgxA8H1VGbymVy04sG3D/hZ6ulOr5ljTGwEaIBVbv71c9L6qj6
LCnp9kUqCHNXjPyNVMf9fD5j4lZUIIw/3bIpXh23vfpzL2wvFd7fOO0nlKWO
xyDyQGXbJNylsEhjhzoqPb80VCIzCZquyk+iZQ/iUE3Yu5DhcTirLNgSr3YQ
Zx/yvKGWjEMmK8P6I92DePDRZbFbsePAnUs+UuBwEJu53m+9qT0O1O+u/O0R
B9Hk7PXQy+ljcPf63VjhwYP4sjGneiFwFKhZXy+/vH0Is54uVEw8HALLni3f
/zw8hMIdz/XvHRmC0o0K3iZPD2GtXXn/q11DEOMRaDtZcggDQ353amYPgrz4
8n6hkUPYaLZaeKF6AC6mMQ5HKmrgZe+wF3Ms/TDWLGbboamBu7pZfC0pfWC2
fpgsaqiBReqPKvke9cHOo5Fv3x/RwB+LZtfaFfrgoyBH3GKEBr4fZdT6frIX
OB/w6rh0a6CiJ6Pmwb5uOFer8jZ3VAP5X/LszMzphqEfdvtXZjRwR1zNodOX
uuEVMUkggUETOU/xx3Pt7AY77p2LJGlNDJpLv3fBs4t+H5B8pnJZE2W5FdnO
sneC0rVDLFyiWohPrnz9cqsNrlqQE/fu00INMY8cG682oAg4y6KKFt5yYry+
Qa8NTheGEgONtfBYTm6aMl0/swar0nvPauHenKNR9f6tsFPdUDvzoxaGDW3i
tDlJAT/mntYPjVpoOHbj56QuBd43e7n3dmnhAd73F0vEKODofvMW54wWCmXt
XxKra4GE+Ka+gG3amEr4yK3f1Azsc8QL4KaNH7eRM1IWGsGxdILd8bQ2RoqW
v5IqbYSsa+ceBwRrY91D+6k9YY2gL/iwNuOWNq6szni5bW6EcMO+bZzF2piV
uNP0twIZmnl8X0h80MYKV+WVmd8NIDL0+xCQtHFv02qbfl0DlAeJuAYMamO6
TlWLgnMDbMKCpRiaNv7MabP9KNkADhwQnbGgjQcD3zeVfidBZleL8Iff2shv
stGbt4oES+nHC3tYAE9/7q8Nv00CPb+Fw4tbAINiS2Tv+JIgXv1qN4cg4KVX
z4ovuJBglHmbr4Q4IKd6Av/ESRLItzxb15YD3PJrP8fARbpeJivHO6gDLgtQ
4jMfk6DJvVYiQBcwd2TDwgcKCYQV7MpizAAty1maejY3gM8fqlmGHeDLwuPf
Ou0boOzzhZHK44DZqV1TpTkNwHaPLajHB/B3o5t1ASsZ7FySNi4GARqYOen+
8CFDhrTMI44wQOpF9dKJLjL8+FEuJxENKLRJQvGncSPoVpl+1L4HSCLf/1Xw
qRFG7Pymz74AfOOQZhZDaoJgjS4Dz9eAOzM07kmfaIYtu+G5cwUgR9mH3UJ/
m0F7eusxw3bA9unfjBf3UiDlUlGH8F/Aujtfe9but4Jg4WaBTSyI4kVK8qnL
reAh9unzNXbEAtxuM3G0DdZYZSUubkcM2C95yku+HWQpa8Mn9yFKXU/akrnU
AcG6r2OH5BHZdpz8SfHrhJoiDy1HVcSu1LwV8lQnHElqSbbQQQwqjOg5QuuC
m67ptgftEddaf+3UYeuFrg7bDUXOiH98a4e1E3tBzJD9jZwrYs9rP/bz+/qg
bF/gVnE/RKfUG1mtR/ph6oceefM1RAnBGhsRKv1+7LlyMToKcV/pW+5Pd4cg
vDdfakMsIm9wZdkBnWHgr+SLXElEfMh13LLTdgQMbkzhRAFixuYw47KeUYhf
SfnmUoS4OOv6q057DIZ8CY97yxBfZ6aXcL4Yg3NW5b+baxCPyuQY+l0Zh+cC
t0rK+hCFxp959RpPwnwMuiuPIHbKuH5Y+kg/P9d/bHs5SY/v2eyWp02FqDPZ
H6VnEG8bX8iMe0uF9rGjZ5/PI05Pbv0yLEKj+2+e3bt+Ih74pINpATTw+VzX
nPQbkdjyZbT6LQ1KDl4K5WXUwfDnKfs2fqMBU94B2TusOjimHivFIDgFFjsn
+jZx6iAHaaqC49AUJMUlRkdw6+AF9/+cPKymYILJXP0vnw4+abg+KuUyBfLn
GGkXhXUw8FXkO0u3KbhMK77/Q1QHSXn2h96fnIJ6Rx89f0kdnIyJuqZydAp4
G3d+n5bVQabgsolThCk4pt2e7qaogwOY9meDzhToHZMI+k9NB91Gwm8xyk2B
TPgFg8eaOsj50fFYO/8UbE0n7Xino4N9yo+4+tZp8LNaaKbbQAdnFnY5u43T
YGDMr+KHqQ6eCdkvVlVLg2rmqjvcBB2UtmwXUMukwS19N2XTIzrIzCLkbuJK
gwCPElav4zo4bZ8RYK5NA4cbbL0R7jrofTXpt4IADfaQ8kIr/XWQq8NuWK6R
CuVmS3UKETq4/1KZ9XEZKjzxM0yyiNZBeVrmjmEGKlyPTfL1jdVBX68ZpR3d
k2BF0dqakaiDjINScatXJ4FGjHTcka+DimOm6X29E8B7hH92vZO+oWsEha7E
jMPqJe9KoX4dPLo7yizEdRxGUt7FqY/oYMb74qmCg+OQO3RMJeCLDrLUtzqS
psZA1zXryuS6Dj6fJij+Mh4Df++D3I2SurjMW1MuLjAKDReOqCZd1MUPR1TK
l3oGwSYjaW5PmC5GJ0woxMQPwlBb9/OCCF1ciU9RqjQbhMX9Nttq7ugim9Tk
q+WPAyA4YTb/NUMX59tOMz4t6QdfK+0cvTZ6vOaW8uayXvgZevlES7cunt67
7WP55V4Izy3f4TSoi93fLDIUsRcSWNVu+E/Rx09tvlxd3wPv3x9wS17XxQa5
OnXNkW7glBbdOS9zGDXvFDoWSnbBA7tjnSHyh3GKdLSkc7ETdkek3mJRPYwe
p86HnKvsBOVhgd+COocxYEOs+G77TnC+z9Ojb38YOZ6UnWOJ7YA8xg3xj64d
Rr+/E40HuNvBvI/KYjhwGNlElb2ueVCgoXOA/Hb0MPJdCu+gAAUMWtvuStEO
49KJ4pcXBCiA9ZUi7IuH0fdEEnPqoxZQLnmg0rRRD6/lFXzlPdcMr17d+q3F
pYfcbr87BPc3g1z+1eoCHj3k6Zd2/DzZBJLPT5vHiehhOe2kxmbHJhCMN3An
KumhxJdXDrKGjfDwtua+GnU99CFdqYUNjcAbrbigrK2HugoifV+rycAVvjOU
z1gPT/3JuS0IdD90iffwDQs9fO3XeythvQFYL7BvWibqoUXNncnnlQ3AcPpn
Qq+LHv5qvGZ5DRsg1HvWycRND6k2ZSUWTA2w6ja2+523Htb7eezJrSHB+eM9
1H3+eniw/OCmN1Ek+H6kOS8lSA+jplo15I6T4Ix9TQBXiB4mO49+LrMgwax1
ufqVMD20omZLJBBI4G1RuP41Qg+DhC/r+HiQgGqcWXPsph6+2CHXohpDgpP6
KTcpd/Tw4+PkWwqVJBjBeCud+3r4x5RaSF0jgbNmFN/rZD28KZXBzGLcAL1q
VwbEnuihr/feqyGPG8BOKejpvQw9DM27OWy21gBtcj5eG3L18Mbo3o1ZbmRo
lLD7MVmsh4vUihB9k0YwFjUrt3unh0N9Hf+dpvvxOmHd8M9Veig1/vXnsEkT
VG2T48wm6+HSan2HyclmeMPIKn5qVA8NiMFtad4UkF/7PT1A1UO7tkdtRRUU
yFteeGk+q4fK27aZi/C2Qua3QY0Dv/Tw+21l/5bPrZA8WExc5NTHuyPvh0+a
tAN/b67ASR59ZNMo8Hhb2A4JHenD7fz62GrPEm8v0AG3ybd9i8X08UDcb4GE
hQ4IL3O/Fqyuj67L/ZXkyi54eHLlVIyWPlKOUPewyHdDAddtu8e6+qi+KzHy
/LNu6D9RJF1jpo9tyHxb/G4PqLIzU7ac0EeGnDc1pVF9YF70oEzMQx//C3ts
U87ZD24uMs9UfPVR1HpPju69frj7mnD+yDl9/LT6t5Y3awBmnZ4Iv4jWRzkG
r3XWxSFgZlFmLY/VxxALqyfXY4ZB8OXnb4339DE1RSN0adsIGDJ/+7iYqo8f
wr6+by4agae5Wt7ar/VxoDlCcOumMXD401fc2aePZxy3PdjKNAn+mafTpob1
MXY2oNTKexIirZiif0/o44S//OxFuj9IWb0fsPmLPhYKG3gm0P3gm+fSzqLf
9LFdyK9zOJMKDRYV+so/9JHzbkTjZwYajCxbHTBc0ceIPTFpGaY0+PV0YofT
Or1eO5kGWaJpsNk8mMmP2QCLHe8tWJTTQOIXx2wYmwGGvS3/XDdC90PpaZ3x
XAbI2zNuGrNGA2tTpQ8ZPAboFl544Tn3FHgv1WWV8htg0qfbscsiUxCe5hRP
FjZADTedBec9U/DA+OulIVED9L9guXRHbAryv//nvrDXAC9rGfpoCU9BTep2
yw2yBnj1Z/nb9a1T0G+Yrc6vYIAp/73PP8pI95MLmmIyqgZ4IW21rneOBmwp
FA4tDQP8IF5lMdxFg10GbkuWaIAjBXHhLe9poDr/a8hV3wBT2Qpw0xMamCXH
1J8zMcDjXXPjfeF0P/z19aNHNgboUpkY4KtJg7hEg+sFjgYouSWjP4+fBi90
+05XuxjgO+9L3FcXqNDxgFGX5mWANa16b1+kU+EAWE0phhrgrs8vfGd+TcKX
pZaSN1cNMNhDlse5fhIy8yyvK0cZoMfCXRvXxEkQFrQUU71ngDdc6nRvq00C
25K588FsA7zIUO0VFDQBozmmFOg0wO3Sv7Y++j4GKSfIj6v6DDDCgbgvuYa+
P3aY+umMGOCtI4m2U/fHoPm6CfvhGQPcsBbVfuXgGJQfN9YzYDTEmrwwDkrE
KNzjMyw122+I7uoxtoL7R8CiqS6ySdEQfYCVoZN5BNgjDGwt1A2x5brKynDx
MIQv6C9aHjZE/y1jtTG8w3CqUU+W6GiIlq4vB5r7BkH/qu4Tx+uGmFf49tvO
m/3wa04rymPQEN8WcktE+XSDGfFISPSYIX5bEoj/qtANT0uDT+XRDPHro11i
fStdYHbtjdXigiHuk2DbrhlD9187pAWusBphmLuCCWdRJxgd5s25f8AIlf9s
Ozkl3AGpWQoppcpG+N+By13Cs+2wyGUZ23/QCA+GpQrVvmuHlJ7oAFE9IzTp
iqSdcm6Heb+/h/IdjHD4myjn2tM2SEr8Qq75zwh9np3nMtBrha9rGytpkUZY
e6LfBAVbQe+kRCH7LSPk8a0efDxPga/7jydYPTDCP/lRt64/poDup07ngRwj
FMHY+Oq1FvgyVzX3vd0IY3zea+582gRAHBrm6zVCD2uRJApdnxJKf7ceHDLC
nPSLrAo8TaB9TbUkbMoIqWrhHUsRjRC/I+8Kxxo9n8z4KLcAMtBCSWfkmIxR
2jfK1vkAGTTHqa6EjcaIN/vTl2YbgJovaviQ2xhVGO/MsPg0gMY2OFjOZ4wt
c95XL0o3QFyw875BIWO0dHlIvjFN14/BiyIMosa4IbVj24EcEmgcfrhlz15j
fFPzgMnvLAmUi59Q3+wzRv2PJVs9TEkgJ5lToadgjH8MHQkxGiSQTHqT0Klq
jE1W30+oAQl2c1T4emga48+PTyV325BAMLRO95eOMVYE/w4zCibBtm8tAlGG
xljie3dhKZsEnCd653eYG+Pfxow372gkYG0f+5xtbYxD+avjRHm6vurPPj7k
YIyL4vzuL682wErJ0jnyUWOUD9hM6RtsgNlkNvE5L2Ms1JXcfSOXDFROnt+h
p43x1xF2g8/CjTB8Rahtc5Axfr+ZeNIooRHaXOXC5cOM8UmB4dWAhCZo7FCz
r44wxitpJSwXhJuh1kBHzvqmMb57YX/yVHYzlMrYDATeN0bVu83xLq0t8Hjx
ovrbXGNcL+lebpFphUS3a1uMXtHzGV+RvxPeCne7blF7Sozx2jP/EceeVogo
T0tYrTbGB+cdrm+KbQPvq7XzWj30fniH9f7k7gDXH82fmweNkdJ/wHdPcAc4
e/Q8PjZujFwVwvf8RjrAwmTG7L+vxnhjhJ1w/i39/sXDnV2zwQTfR+GgfHg3
yEUIhtuym2Dpsw9Gu5e7QfLnHnvqFhP8o5I74R/QA4J9qixsQiaIy9X9Dqd7
geGp8wlTBRO01ua8ciWiH1a3eagPqJrgin79u0dbB+D7df8tfpom2DT78vnZ
tAGgel+tiDU0wf1NcpKXawehUSFLoO2oCb6e1HyjLjgCD6u/tzrcNEF58/T9
ix1jEMFY/Lbljgm6l+QqKimOwxmd86kG900w+cm3Rfm742BUveyl/MQEZWZi
7/1nMwHKjOUWuRkmuFaza2a8dAJ261xSFss1wV49szXRXZOwXLX2d0uJCQrd
s7QmLEzCBMOHych3JuiTqxxhfZQKFAwnr1WZ4K14pgeHPlLhfbjOq6A6E/z2
2NdwkpcG2VVMD2fIJug4pK9vbk+DBww1l11bTTDn9sXvEEODq3jdtbfLBJ1Z
NGaOvKbB6XADI6sBE+RcuXd3WzMNnKo2yn0eNUHC4g/GgmEaGDCQtmnTTLDt
2a9zVlM0UMSbK0Wz9Horf7jDOE33f+Gmw/sWTfB0pkhV3hgNOKo4a5/+MkFj
9GoXp+vN8t+mHIE1EyQlrFqI19BgAu7ExTGZIkZ/uEXIpwElzOr8RjZTPMiz
4Zp+PA3ef+B2vsJliuPi8ZxhgTTI+tums8Rjisrl31cCCTRIgATJUztMcdY3
oeGuLA1OfeD77rjHFGtUdoUV9lPB4W93D0XKFGO/fh09UkgFPUiqNJQzxRtF
fMJnrlFB5IPQTZWDppjRQvz7XoIK7H8H/PO0TTHOxorFaWkSfmo/tt2jZ4rl
jzcJStVMQnPlblFuS1PUsvFY/3psEq5USpTOutHH2yp6nO5NwEjFAeqzOFO0
ifRsc1gdg2fvD+vyTJmiGfHE/at0/ZDJfWq6b84U+4P/27ZaNAyFSYy2eoum
KPubMS3v5DC8P//B8/wfU/RqOlZk8mkIOuQ1bvdtNUO1/VweTjGDwJKh2PP0
oBm63I/+sEm7H27duzv6TtsMIy+m20T96gOeq/NfOg6bof6Tj0olr/pg57GC
NVYLM1Q8XGMpKNUHqgIye3xdzbDr3OlXg8K94Hlb9LRSjBkmn257yyPRDV8v
hV8wizPDVIHXOkNTXRDkMxzuft8M918hZuvmd0G4Yeq9h2lmOGAVEExR64JE
RoGy32/M8HIUK0cvsRNI57ZuqBkww8HuLbmnM9thn8vfJBs5c3T4GqP7Oo8C
do4mUf1K5vgnsO+YeygFwm3un3c9aI5lV+vSUyzoUm6yj3hGzxyJex8Ii0+2
QJiaPectJ3M8M/SYPB7eDDmKT1d5jptjXcnFrSDTDB3756aS3M2RyVi/5VZH
E0iLX6t9ccYc9VsaRpf2NUH71pdXPkWaI7XV5lTZJBnWOVZPmdwyxwhaSPzJ
B2SQ2qh/pPWuOdbuagifNSRD6Fqf2nCKOZ74+0s3Lr8BspYl9no8Ncctd31i
Mk/Q/cD3M7xzL8xxY67CdDxfA/z5+o4pKN8cn8QNfiQ20vXgC+vC6mtztG7K
DNgaQQLrScLwf6Xm6LL7Sx23JQkuj6Q0sVWaY+kXdsZAeRJk9tPe3flkjsaL
q67nJUjQ2qWYw0ei51/xbjt5Hwn+tIYmpjbT49dfLzqlQ4K9TfWR4h3m+OnS
N997biSwqt92LrfXHM3xVR/pHgkufXI5qThsjmfXeBcrmujxK7MJZRPm+Ij/
7LgTdwNQyn4AfjFH331fVJ4fpfuzIpD7/M0cT39W/vTxVQNIFN4Utlgyx1P9
onbrnGSwyu1k71yl109WQ/PdaTKEZO5eOcJggbPMHi8Cu8jQklLS6c1hgYTq
t/e2lTTC6kPGmvmtFmhy71Sd+f4mEL9n9voCnwX682ys485ugovRY7HXRS1w
xGrPuaP5zbDn/GajdDULbPuur6sTQAGLs46qUloWqN/XqPSK7oeCTz0Xf6lr
gaLc+XKj7K3Q5HqIscLcArUfvbc7m9MKFyw9yntOWqDHUW2y2HobkKUqZbfG
WaAWw0/12JVOiGvL1D543wL5n/yu0nPqApvLd6xcky3Ql+Z55Pn7LhhoOR5U
9NwCW/eAwPlI+v4/z/zeocwCk878Jm490Auvd882/VdpgZU9rF/KU3vhQkPH
cM4nC2Tkty7V2dwHDDszmdeaLHBPlpX23x/0/1+tkWn6GH3+xMCTXH0D0HVa
4WgDzQLn/F8xeDoMwqMdgv7fZy0wvu5bQm/PIIifmonX/2WB/xl2EKRHhkB1
W2zfNIclVnzxCymIGAHHE+3eiiqWKKuhbTNHHYOdHO8vHTlkidFFVNqU+jiM
FT2/HQGWqHZOfUr91jj4sJ1/1WVsiU4LcZu/qE6A3GuXT38tLFE4jPeibewE
3W8bdkrZWCK7Tlm6NG0CLr/csRLiYolEFmLZ7tRJQEdGjucnLZH5ucl+i9VJ
YGH+ItzkZYmvkQlXHOj+KK9N7qefJfK85jLQfU2FWLt3uCvQEt0iWvbE/6aC
NcNza6NgSxx1djgfoEoD/pxbbmdDLXHHY7FSDzcaDBDPnU++aol78nbRGiNp
8GTtaNSnG5Y4N/SRd+IxDdxeGCTP3rJEjWAeg2q6HkgTDuRtj7dET/MNWzyL
aPB1lb9S+6ElPtGgzhe9ocHr5wwUzxRLnH4dbnspjwbnLaZH49ItUd3SfH9Q
Gg00llu/l2Va4rp6hp7+bRpd/8tZxnMtsXJ7/FDEeRrUmD7j53xliTpZm0VK
j9AgailGWqXEEutvNRcf0aKBeVqQhss7S1ws6AzuEqJB16L+scJaSyyv3Njc
RKFCcorc2d4Ger5Wr2vnX1DBxYD/GhPFErfW2FocCqUCLWkq06bPEi31G5hN
9lDhMXf055PDlijBN8jnStcXu2jpqYAJS3yxhTs8om4SaoJ9pO9+pfdDfjH8
isckUPb97PRgtMICyu7WW08mIJ892OHZditUVWlM/W/LOEQZ1E/J7LDCeZvF
2a+DY+B2dcfF14JWKFQ81pGUNwbCq6VJ1busUEuDSf2TyRjcnF7pG5a2wguC
+aTJm6PgWX/pqLC2FTKNtV9YFx4B3Q2Nc8/QCkV75Q8IjQ3DThS+su+wFToy
tJey0/1519v3jw8ZWWFW99PZY8NDoPdibdjB2gpz7/59S707CLsjw1zve1gh
q0vIWpdIP/Qdvua5+Y4Vcp6VBrn6LmCLNP7SeNcKK3jizG5c6wLV+i1+MQlW
WD18+2YOdMFds5QAtmQr7JMTUDQsp/sb2+JQpgwrtMxw2vW4tANKPGj3fpZb
4QMG331L3W0wkZXPV1xhhe35Xq+XH7cBz0xgUmCVFW6uja3J8GgDP3+GtPla
K1zdmn1t6VcriAcL5HyhWOFipl6Fqlgr3Is2rRqiWiFXgmSEi2QLVJG5D6dO
W6Hd5kK3qfpm+MrVU3tk1grdcj0kbvs2g0m8G7lngR5/jblEoKgJmB6FdrX9
scIci18PpgmNID942PHuXytsPEFlXvxNBpdd7AOWTAS0L9K5/yeTDGXPHow2
biSggkL5Vk4G+n190tkthp2A1p+vDrAXNACv1B6aMRcBlfYIPPvr3AC6PtPe
bFsJuPdqFs8UZwOcyXs5W8dDwGTjd7TqChI8/nrO//p2AhrxO6YsBZCgUV5z
8fAOAlKDG887apFgNYDpHJMQAd9g0dl4Ybo+Fdf/qhIh4HSs0Ymdm0lg8ys2
JGw3AUs6HIY6tpDg6kHbNa099Pncxk927CJB4SWh8D8SBNS75BJ4RpMEQxWj
TO+kCPjQ/fGYOV1/OBmyrl/cR8AO+2xv2QckOKR7mk1djoBlYg5ibK0k8IpQ
jvkpT8AWy7ay+W0NcL9ulatYiYALng/SBFwa4CNbdVygKgFHXt7a2U7Pf97k
xjbFgwSsanvdfYOFDGYt2wReahMwQ1o+e/YjGT5PZeVr6xCwMVOPr1+0EXSZ
tHWbDxOwS3D3sUd0v6im4uU7Z0RAf6En+5/ZNIHYo/cV+4gEvPPhsSdRsAVS
iwjW72wJ6HR+9sZ4fAvsaKZSTRwIePvd9CjPRgpwMXJv9TlKwIPJwaGHIymw
7OHumuVJwHDayMrAvVYIDF/9qeZDwKMnRMRO9NH9cdKdmM+nCGg4J2knJtYG
441lRdSzBMyLZDVxKW6DZsXNGyUuEzCx42rJ2Jd2eL5ekpseR68/m+yWywld
sGuHGSrcI6DFpdnojm9dkKww2lF1n4DIJrWUaNYNd9w41oeTCXhTkiAZzN4D
IQ3HrHZmELDo48w74cReWBr/MZH/goC/pS8VufzthTNr0Re1cgio0bQ/QsWr
D9zli546vyTgveVIvbf0+6LVA7al5DICejjdNC/4OwDkl6nRMu8JKB7buqYS
NAgGJMWd5ZUENDnwRfC/L4Og8cfZsPcTAbc8eD0RMjAEe11fJfE3E1D6gfy0
ne8I/NnvpJ0wRsAfZkIdCwljQDJ3r3WapPdHJIy2Y3IMHvidMROdIiDfN/Fv
UarjIJ8f6VQwR0BHVmEzu8FxWGu8Oxo0T693qw5XheIENMymeGl8J2D3k+xX
YdET4Cb75nz9MgEzB5P0ZTUmQcGsci32NwEj4ltYdj+YhHVfUoTtOr3/1Rx6
1xYngRzTwSHMaI2/le/wHbGiQmLucPwYszUON66OR2ZTwZ38RSCb1Rq7loli
P+epoDiz9MR/kzXe6xr9LC1Fg3V2RilVTmtcv596c8mKBmQZzpd/Nlujgs+8
0NopGiSa8Kt+4rbGZ0bX9pWH0vXKR6wimtcaNe54fD8XQQOFm/v1rPitUV5W
dIfzVXq8bHUyn6A1RvkGygcF0+ORDlsPClvjJembmvme9HjTFr3PdlljrFGB
0iB9PvdNTsd9xKyxZDr65Qdlur+SdqfJS1gjf8SuF2vbaPDX6MzpX5LWuLlo
v4r8Nyo0el1aqpCxRru68fXeOip4ZN1lNpW3xoRvqcLH/KigVJ9yk1vJGlt+
sr/doEUFhqkX3D0q1vjl7XreW3a6fklW7nLXsEYTdavOS+mT4GlIytynbY0b
lZXeM/lOgrJnx/5FtMa02Nb7iUp0/5P5RSPMgB5/8MuPxx8ngGkvv0MSwRqv
C8rv5R4YB2/xM3FNntYosjXoRyj3GKjqXeJP8LHG8doa6+jeUWByi3zs5GeN
fPnVtYxPRyHlWUoeLcAatWaWiyyUR4EiRqpnvGKN3rxJQW0uI6AuKsaommCN
qz/iGhgeDcK6ZPSdbw/o74v6jTpoDUKN3LxIdhK9ni/eGlWNDABBs/KQcJo1
mr/8dqZUZgB87J2CmHKssXTjpIkMuQ9Sb8fTmj9Y42dWbQcfzR5wS1g5F/XR
Gu3lnIznv3aDzKPjG3RrrbF33o7B82k3lGTJiRY3WOPyY/HfQpzdQPnU4PSo
0xq1fdRGnL90AtMqU7PnjDVeVtO8zkFph3oGH2fRr9Y4N3uK5hfXDrEbW7/0
zVujX162dhKhHYS2p220+GmNYhPlbTpdbaAsr6GjzEjEWhz/mTjVCp4egUUM
/EScy5u95XOAAnJ+fbrlAkRsVg28kfKzBX4E6rQGChNRy6H1+cs7LRD+35av
VFEiftRKU82qbabfR3Ilm2SJWB/MyH4Bm+D4M56SyANEVCqOZZUba4S9ORf1
UJGIeVw7xHmuN8Kbt4Yn3qgRUXfv3Jp1Mxka28aTk3SJKOO3eNDqdAMMFwpo
iOsT8c6SCWflzgZYjLXsLzAkYvn6RnUBCglY/a5fOmhCxENHOw3VrpFAwPSd
UI0ZESVT4t3q9UkgK73wzsKSiJVSo9tvC5IAN0o69xKISBN6ruz9tx6Ik85/
TtoQceysOXvCYj14fIpP+WpHRJ27aR8v0/lier3mRUci2tfbbaxeq4dbYesD
zM5EPHVh1wPRbSR4clQ5NNaFiJxazyIfKZDgjYaPiMAJIo7MyfxQcyBBncCT
imcniSh32OeAfCQJ+n51HpXzIGKi1iOPz+UkmOvkWC/1ImJLTDbBeYkEDEU6
jw/7ErGK20b4mEoDbIu/oN3sR8Sa4z6ZDiENsPdM/pDDGSIy91Ku9H9qAHNZ
gV2nzxFReq6waNtJMhxnt/ywfIGI3FnAqFhKhqCpiGPXQujzb7tpnbO1EZKf
z6clhhHxV9vI18aGRii4uhf3XKXnd5Nlg7hsE1Qfdx7JjyCie2NH4+64JpgS
rt/9KZqIvL4v3jw51gwq99PS5+4RcS1jnF2JiwJGgZ06wQ+IqFy8/YO+IQWc
CRxjTElE/HFjNsP9KgWucl0Q2/GYns+GuN4PvylAuW7xTDeLiDw0Mnfxaiv4
nF97/vA9vV9FskWV0h0QaqOkL/aBiHaLG5TtgzogTtF7Mq+aiDvz97xhruqA
t187JD7WEXGhQWHqmVMnbPDMy5ylEHF02H3NNrULHtsfydKZJKKPexXp4pFe
2KC5UYN5ioiLA4z+DVW94L37TVPNFyKWvtD6my7ZB8rT7N8N5+nrxZQjqyt9
0BBSrmXxm4iW7q9Cp18NwM9UgXYnbhv0Pty3p/PgCDhfrXUX5rXBvW9KoxlD
RqDa4+zyIJ8NEqTbzux6NwK3DpBETgjbYAjOcWriKIhVB3t5StrgD5+dywS7
MTCf6F4L1LLBjBJZ3s6iCXhdfy1OBW1wSidZ/wnLJOzIP7Dnl64NXhll9oq3
n4TQu/3Fpfo22PDx/lhBziSMnbthFGJkg2ULj0JX1ifByEmpX8PUBld42/nP
21AhX3vYb83cBp/WWN7+9pwKPHtiGD5Y2WDkcHye/gQVgjeq3Qsn2iCbjEM6
Ky8NhmbGJHTtbLCNdcZiQYUGhymxpcyONlhwkyj70JQGWUWHTGuP2OCFR16j
rnY02JxEHYx0scHLGeLRd+xpEBQaf8bohA0GP9tgq03Xj94T2szsbvT1qk2/
8tWhgbbBl/tkDxvULTseuL6PBs9lHkjd9rbBUBuF47VbacC+RfedxSl6vidf
mZ2j66H/9znzrf42uNnR6cprMhU6upNGWs/a4J9Kz7Itz6hw6L1+4L0gG6yw
YMjffIEKT54ssNhesMFU/h8/RYyowHI9NZEvxAYV5xWLsvmoQDFfqkgKs8Gr
J+5ZPMyfBFXFdKsjV23wF9vvwtTzk/CIz3xc+LoN8jMf/O+o9iR4DD9ne3LT
Bt8KxfqONEzAnzM2xMz7NsizoTBsiq4vBbItv9QTbdDqSujqp+fjcGLKOIWc
bIM1Q7xe90+NQ90xmJxPo7+/eoXf488YxFnIXNDIoefPG+SuuXMM9sgyPKJU
2uATsXunxgJGoIsWAierbfDGZpa4KzACUc+Wxpc+2eD5ps8/EjlHYFZwRlaI
ZIOHrf3a06yGoWRTV6V7uw2aX/AN6SMPggktd2yVZoOnbgved6L7/z9P9964
/cUGpbMvcHI/7oOXLun7ds/ZoE/Vcj3ZqA94ux4E6S/S8+uQuGOQ3gtDNf+x
xv2hzz94Zge/Sw+cfWovI8Ftiweng10OsHSBuEtb89ttthjF6BIjWdkJXQLm
gSZ8tvikfTn/74VOOHRX972/kC2aNslP6n/tgA3h+y3KJWwxPcRv1+REOyQe
ZQ6wPGSL2ud/eBKXW0GPoU+kU9MWC+0p3qYfWmH+aSHJCWyRKeOV8s/IVjCc
OirqoWeLF1Zd2o/saIWfAaWUyxa2GGA4t132MAWebr9zmYlgi5s97u8K30IB
i1J3qSiiLXbXgftcaQtkrvGE33OwRdKnjF+R881gG+V3IMfVFiuzv5FNTjcB
wz69/gPutih6KTHn5dYmyGsSvFHsaYsWUTFJGkWNsGFb/VDVKVu6vxnpKVsn
Q2Hx45sG/rb40Sdi8nkGGZwdzqk2nrVF64PF3VnmZChKFYvtPm+LVNlPxK9P
GuA4rhw8etEWk8jXLKXNGoBzvGVy7JIt2kvnbz+zTILS65l3va7Y4hqTwrEP
GSQ4KRWq9TXcFp2dhB81OJFgM5k4HXjNFinOYiFiYiQo95O5v3LdFsvfNirX
rND1aSujTliULXrPGwuOD9cDz5vu2Q0xthhG4blNa6uHStuCxJu36fVRaZL0
bK0Hn+UIva1xtijDK7G0s68e+B4dmb8fb4sGUpm5v2fqoVpLMUXovi1y8DKJ
crKS4NQIm1H6Q1tMkwx6fk6SBDuuDX/fm2yLl/gmFa9akqBGoiQtL8UWaw/a
7bseSoIz9bdMFdNscTb3w/MvhSQQ9j356226Lb5ZlmpRmCZBPdehZ1rPbdGn
zytpRqIBdhNpq0bZtqhyug1VcxugcakisznXFv8+NOoT/d4AwYkJ1jYFthgR
MMKoqU2GlkGdnGNvbNE17tAk7yAZQsJ32E0W2+Kot0htkDz9PrHnG6NvqS06
bA3i141shCteKY7nK2xxB1eOcpp6E8h9/8l2+7MtKpzOTyIVN8MttjzP8n76
fiqumetlaoWbr5ZZLgzZInni+MNz2ApRTvrPlUZtsUyVyLAxrBUi8oZG8qi2
+PRwwhb2v61w2YrbKW2Bvp+b2yoz2dvhVOJ5s4iNdniz+tN4CaETfHQ+fUF2
OyR4fbc+nNYJXl+2RK9x2uG04d6HY3Od4KaZXXuexw6dBN0t3WO7wHmkX9tb
xA6VuEwIvQPdYCalo2ChZIdTVpv0ol73gUnr7RZ2VTu8rN9P6ubpB6OQPr/P
6nQ2br4XENQPeo2BOahth64HDS8lawyA5pnMPUrGdlhAM6GI9g2CbCkH345j
dijVWqDWlz8CMiccijpO2CG0SRoSp0dAij3D+q4bPd5qbeQ9iVEQd9a+w+5j
h4vFmkEBT0ZBmOEs21qQHZ6bSs//kjYGnEZdq6M37TCHff8C+fME2Ncv5Pjf
tsORid47oxyT8NSI68jaHTts1FzYVWs1CerGeu923LfDfj2lresDk3CNdMw3
86EdxkwYnrYXp0Kz8SUh5WQ7TOczZwg5RQWBhgfk6hQ7LO/cfG45lwpuJq8v
WabZ4THTbhvJQSq8bGjaN5huh2b+DMVRjDRYNZnu93luh2yroomBgjTQJ2+4
tZxph98zimJ3StMgznS3ZmS2HepL1HFmytGgn6wxuy3PDnVrHiYwyNJgr5l9
SnqBHX5g1VTgE6PB2cYAswOv7FDg1vhCATcN3pvF/nn/xg7FN+4tivxNhY1N
2XkmJXbo72eRpDdCBWvzWueeUjtkjyubDquiQmrTCKfHOzu8Pm1U9CGFClPm
f95/r7DDnpFXf0PP0f1QM7/ff1X0eK7vumVMqXDFQklkyyc7LBqtnJfcSQVe
S59QmXo7fDj2vsWtYhKOtVzfX9pAr0em+Xu4OQk5lumD+k12+PtbjmCy7SSg
VY/WiTY7nKNZKNVMTYAvwWD94YAddjblfethmYCS1hMFEsN2yLF0Qpe1cRwY
rENd3ozaIdM0W+z63XF4YF1U2Uy1w8rw/ueFIuPwkSgWxrJgh5kt+/VVVcdA
0G79bwCLPb7QtU56eX4E3LsEChnY7PGvDv+RBhyBQjuV47Hs9vjD7fqKF8cI
GNifqsreYo9815UuXdIbhgCHvvARAXsM+8/Q/VfeIDQ4lTBayNljVsxJmR9v
+sBz1PA5j4I9jvXvoB6x7oMNXr0G3Ur2qHlD7dvWxV6Ac39ijh+0x09lSucc
VHqh6I4uX6CePS4f6RTjIXdDak2zTKKTPRYYRge4y9P1yPR4k/NRezwpkHXi
0FgH9LQu+Iset8fTX248lb7fATzDvMU57va4krjprtF6O0SuOEHFGXuccXxh
tGewDc7I0Yhjkfa4c536RL+BAlzFwT8zo+2xbEZru9AtCuRosCf53rJHs8Sd
TB0WFJgw2j/04649vmUoFCLlt4DjyUCvjan2mM/59qDtWBP8nN7A0Zhmj7u9
4wNiA5sg4cyD/Lin9mhyOk7oGGsTNIeWLQpk2aN/cGrgS/p5ppv497LsG3us
EE/WOfWQ7n923t21UGyPey9tT/uo3ACXM8Q+Fpfa446Ad0IR7SQQlC1yC3lH
74/36R1O50jw9rX+Rqi0x3KTC/1V0iSwOdidzVxNr/+3chl2up9Z/OBlVv/J
Hrsaz/ZWkuvhjsHq11t19ji33viqtqgeZJti7hJI9Pnq+LoMcuuBRBRR5mu0
x0dqHCpP8+n601fQ1ddsjx0BtmHB5fXAfAIvprXa44mePFICpR6e0FqF3Drs
MWDTDcrM13rQOn2yUqrbHvXP3S5K4KX7nx8/js/12uMFCn/WByRB8KVI5tcD
9ihexCzxNoAE25l2ZJ4ftsfXgpu1J7Ppfuh4sBPnmD0m5122zRolwZeKns1P
J+yRle9K4x6RBqi8mHShadoeXYi825ZTG8BjQdBY/Ic9RriKN1yuIoOV5aW1
sp/26DfgoDC0uREO5fe/slyxxx4J/Zf6xxphi3eK4KV1ej/jZ06WszRB6YjI
bCubAz5+unqIw7MZnmpfeeLJ4YCTtC5Wk090/UgZslnjcsCC4HwdZtEWOO6Q
ViG1zQFf/D1d3TjSApsou++EiTgg6cbRNw9KKeD0YY/ifkUHNCyuJZd7t4Ge
SAT1o7IDbl4YF//xtA3kLk0kO6jRedgifHigDZjUMpgjNB1Q3GUrlWLdDrkF
ezv7DBwwQD9m4LBhB/xJlQ6OOuKADePHeCnELqD+jpbd6UL/3l7UYSCxCyiO
X0beHHfAlUvdzMVDXfB8e67xsLsD2s64e7ef6gbz27JCqmccUD9QpmU9vgce
Xz5QOR7hgLyzFTKzbP1wtXrm4qkbDkjNbw0UcOoHd9YslaVoBzyQrnlGNq8f
ZON257PecUCWum/bOYkDUP6MO0U6yQEzjl1rms8dhK6G7xf98x1QwkrWdo/B
CJRvKVRZfumAl6Mi2/zo50eqzamF8NcOuHxV3VHrxQi4DU14xb91wJgFFfkz
7KOwuNBpX1ztgBNyF9kNukdhs0Cpyu9OB8yUeRZcGzMOi0eDFq71OGDnpXK1
hZpx6Hwqn8/Z74BeJZdPF6+PQ4pstvjOEQfsyDPR4wyagPCz7iOZYw64lbx6
Mv3lBJwsEU05MOmA5x4+/tM+MwEymLxN54sD9v7dlMznMQmbr9u1kGYdUGv9
3C7p55OwQOKJsf7mgLH+O3cNjU1Cx+YWg/4FB+xvOjGpKkaFUmIMk9sPB9x9
Y95b2ZUKKYmGlbM/6fVgely2lX7+hw0yh5xbcUBjckAlcz0VXMWqVNZ/O+CF
fbJRYTQqGHheXohcd0Afh0YhCl1fZPLU87cwOuJyA0FkDysNuBZ+eCUyO+LM
6oWvMRtpMK/ySlyU1REL35SF/2GgQUeI30g2myMaDRb22Hynr+eDdIoihyMa
8tSfdhqmwqMNVPt3XI5o55gx8bGWrjfGT7fpbaVz4e43Ci/o64l1aWnkccSN
/feua0bQ19MuGGO73RF/xMZYeRylgvSOboMhfkfMqwuLkFKiwny6ZeU3YUfk
07ZPE+6i14PKERK8yxHbDwRtZKHXq3RfvQqjmCNmX2kz/OU/CWHFmM8jSZ/v
NYv6/2m4zOOhat8wbs2aLIWElFJJtCAU960UolLZ5syZM6NFthRJUZGytHgJ
pYQWv4q0W7IlekvNGPs+tmwzFKkI8VZ+8+f1Oc/n3M91389zrvNdIM6HPJHj
9IZVNPRZYbJosGIAvjg8kEk0oOEkMW6TEjMArn0ynkrrafh8ftfBY9IDYDCv
UVvRUtiPvPv57RL90O516OrcfTSc49zw8p5YLyjm3bCqdqFh6sfoK1bvhfkz
yxmJdaehXm+r5ZHoHnh53dBenqLhFfaQaJqQpy7+OyUq501D039Svj6y7gZT
zcvHpcNpWJqqZNzd3A5+h18vYUfQhP9n1koN/u2QkTNaGxNJQ2SpnV0n0w5z
7fcZSF2mYfz9OdKrtvBg4IQmX/I6DfXpH2Ly3reCxttdSRU3aMgQLM4u8WqF
3fIR1lG3aGimnHRNTaEVijP46RJ3hfvlzYa+IVsgofaZq/hj4f7ouXyGTDN8
0OiVePeUht4R++bcLRDe90Mquedf0LBS561A7XATeP0+OU/slXAejCbLFE4j
WK2yZou8peHik6WBx9MaYOR8o/nfFhpe+gVz5wXXwdEHTdNxPBqOSSwfWmBR
B2Mfm4sWd9KQm9298cufWpiSbzO37qWh44asSA/VWhC70WkeOUxDk6v0vdeJ
aogs6pqeP0rDrybzy6O+VYFUZ3fRg+80tNfkNU1HVYH8kl7zjxM01LXRmXAt
4EL81r5pt180LKj3FzXZywVlz/6ioRkaLqr6XHRutBLUHvPNZUUILL/HXeK0
uhJuVQumb4kROLBo4Xc2V8gP3weLVksS+O1Uz+jVoxy4o/w55LUUgdcXa+cm
6HJgqckX852yBOpIjJvZDLHhvtvwdJc8gXG/Zu8VlLBhRehIkf88ApUqbo5j
Ghuy076GzCoRKJgjreJ9UZhvZaPmV+cT2Fi7tLU/jA3Pe79N66gReGtZW+EF
oV4v8aPo5UICfwy65ThHsyFPbyxkiyaBQ9uqKn2vs2Gj/bh5ozaBYswfDDlh
Phb7/pw+sITACv+As+Ef2LA5bqLopy6BzSN77xgMsqHsxWRIlB6BI+4Bj6Pl
ObClccpcdRWBpvkT0wtNhTw18Wv64WoCY7y/aZ8+wAFb9ZmijYYEZnyQQ6dr
HHBk/DanbSCwa09okeIsB2rD/0x/NiHQStLWKcysEvZm/C0KNSPwmYO6rFNQ
JbgNilikWRL4V3THd++xSmiXEZsxQAJDVio2eBgL+dVAvLh0C4FHWk/u0T7F
hf0BkhafbAm0X7bhU6hEFfj9J2OxdC+BY090yOOG1fBNS24mx5lA6c7qs4Zn
qiEQ5Yu3uhGowqtS0OJWw8koBYtDJIEi/fUWx/1q4Pw8FYssTwKfbNPUZLyu
hRu6mhaGpwlUf6zK0bOtBz/HpJGJswQWmkXoJYbWA56QvVN6jsAkn6yFN5/V
w5cPv8R3RhOY4ClvEazeAFY+zdW+CQRmi+xekjjeAAMv4jweZRL4X/+fhC3s
JijiSc4PyCaQ/4xhVCPZDHFiZz+YPSXQKHF0vpRNM5g5+65m5xAYVDGnOvrf
ZrgyZTshKCXwcFXhuy8fW2C9leilZU0EWqvZZRdMtIHU4VObRloIXGSgsbbD
iged8d++5vIIlPD0ZX+4yIPo3q69Wz8R6LDPfPMf7XbgRRZr7v9C4Pz2zI0L
XTrgHPf4izsidIw1TMPsz11Q4y5o1VhDx65I56BnPb2Q5lWU0GxEx0xOb8Bt
5T7wORXrcHU9HUf2vauX29YHUjfXl0ma0ZF0PcXY/7gPsDXs4fctdHyxME5d
LawfFAb3sB5voyNTcdlv2bx+6JxcpuFpR8fo+zf2XvjSDyGq3H86dtKRb83s
kaANQI6L2okP7nTckqU2fmAzH84d+mIYQafjmge/3iYF82HXidKhTRQdjSO7
5+x+yQfNqKsZkyw6JlsOliaP8GH42gHy5QE6PuGs7fddKYDi+6aqfp50vKPD
C6w9KICLeTJ1et50dNNIdk1JEYDr+85Lvb50TJp1KR59I4BlTc+3pvnTcWCq
mx/XIoCx/vN/XAPouFx89K5EnwDKx10KlILoeGs/XMgV6jjxVQFVwXSUUnd0
6+YJgKHyWz8mhI57chL60oT5aaBbO2B9ho5XZIy5Y88FMLM+4/bvMDraK5eU
l18VAHvLCfeCCDqmOyi0tfgKhHxjpxwYSceHuOPnqLWQJ/cvqjKIoePM9b9x
T1QEsD5wNGrwEh27y/eU3+/lQ23CtWkyno7rVyVH2gbxQbq+p8f2Fh2d1n07
Ghs+AKG7Q55rvaBjxgr9REPfPrBjOnq35dBxadXy/0mt7APVo4t1k/Lp6OAq
uUab3wu5cRXJ0iV01H6WV+LO6oWRaqWw8Qo6qqsNOd0je4DhmO3I6aBj7rjK
9NRQJ5za4Kju0k3H1SxHJ5uznXBNY7S/p0c4Pz/RPL5yJ1QOrTv9i09H0YgE
sdVbOsA0qujRiu90nM0/DpwXPFB8w54TLUHiB4f4vwrVLbD6gU+DkhSJ5MK/
MnuDW2B7rPztdBkS62LVuHU6LXCWcDLJVyBxdXhyeVBIM3yZbD0woE5iq4zP
+XGzJnhvNFi+ZQ2Jo3aPL2d+rYdPqpdia4xIlD9n/0HkUT3M/NF3J9aTOGkT
0Eceqod1Vf7fAjaS+Pqm8q15vXVw22tS6541iYn6+uemPtZC0e6bnw1sSJTR
qqFUdtVCk6lFfuF2Ep/OrCv+01wDspJhjnUOJK4omCpeOiz8vtyTPD3rQqK+
+I92Ef0qSLyYuf2KO4lmU6V7ukq58OyovbIancRNSzcyXPZxYcDyn0eGLBKd
bVXjRS9UwuwyoxPF+0lcH/a4Ql/ICxry9bj9kLBeuHxtayEHTMYD5RsOk/g7
S0J3hsYBp/b5bQwfEseJ11U9chzwffvqf5/9SNyNsxZu1WyIznI/euIoiUlj
HatThPmSET9jIRpIYsGRcyYap9hQGpw2558gEi3e3NM5TbGhjWHVoH6SxF4G
zyx6Fxt+2vSk3w8h0SPr+s2ltmyYZ3Dee+0ZErPXfffyFWp9lWUmr8OE/Z45
qHNBuP6myObxsAgS15Ympaky2CA5uu+ldSSJLvbuhmKBbAjs8D0qEUOiq49C
UGwsG3rYF9Z8vERix5nzDkpP2LDzVerwpVgSVScubpUW8lnx/3IfOcaTeFIn
T3Niig3Xw/qXN1wj8XrCSVGVvRwQ8/uv/9oNEpPTxS1SLnDgGE0lw+0WiZ6f
P54qKuDADuOt2l13SHw25/R4nV4liHzJUB3KJpHb9Lvw4CIu+LcWN2U/JdF0
QJPjRXKh431D4pEXJE5t5Xp/vM2FV3fE5o3nk/jRLZy7ZUUV+Lrsl/pbLqyv
KI0Z26qhpXzJL5VWEu84+tg+elELNs/MX7XwSJwXS3spIVoHL1P3BKV0kkgc
MzTT1a+D2OCI79p9JPp7M0Yena0Da4PeoVVfSXwS/Mmjc1U9PLlxlwfiDFxz
aDhm/o0GuOC/uMTXiIG9hZubTnKawWrDnCuz6xgYv9g4VeFPM/yaGiGSjBk4
YuV7RHVdC/hFFM8UmzPQMEzH/cytFnC95mIha8PAyeuUYUFgK6wsvlKU5S58
f3ShIMWcB31hgZc20xkoL+s7cCeIB+lbabQ6BgNDDjDv6wrvp3K13vTUfgby
GoruZ65sh/8+vTWzPcJAL/thi8LFHVAj+auAH8HA5jOqXS/1uuBiZXdMSCQD
xwW9eye8u2BrfIXb3BgGLni6P/7d0y4oVE+aMo5lIPOdVoL4xm64t9pwY2Qy
A4cSHHNXOH2CoD0HXy19zMBI29QQXk0PaKTX5TGbGHhvQdiaJJd+qLFTiRW0
MHADIWv/Mbwfzv90OXCEx8B1ntRV++x++OzQoXS6m4EevakD5iIDUDjD908e
YqB4ufbxBiFP+T1cuV1rmIEyqamvz3UOgM5eX637Xxl4zo18FS7Dh5hH37kv
xxgozdN+evQgHyxcNvzPbIKBbr0OOh6JfBgVCQ4tm2KgisgV3/vlfHB1/29l
9W9hPzLZ+rraApCVsBJxnhXqd3LfmDsF8Ob5udZ2UQpbE2d8aacFEEh/98xD
gkL2/Z9L3qcLYLnUnOihORSaudy6LZ4ngLYcO8ZRGQp1y3Y6MsoEEEtdMZ6U
o9AnIe3Yr3IBoGyN3FkFCm+fezjcUySAn/mK/eJKFI4+nEqVfyyALI99xZdV
KLyWL3bJ6boAyLnJCUqqFHKvpvUFhwhAsajN66Y6hRUbqyzWuAvg3cFFuHgR
hdtdB8TU1wsgWJFSe6hFYfDvyBUcKSHfvb47aqBD4f6SsxMVPD4kquilWyyn
UGX5k0vHhHmzvcwr6O0KCh1Wz60atuTDjM9jBzt9Ch31fpjtluSDx79rZ1yM
KFSU+9dtPG4A1gZscgswp3BI8U9w5jXhPGuclLJ2Unhmpjk0Jb4XzocmDRk6
UfiRtWAqcXcvmOq1lOXvpXBuwK7do/N6If0s3f+dG4UJb5I2iSb2gJ+BJ7fb
g8KfcyNvbzL/BDKXT0ctCKZwE+VSNHqvAxQ2G+9uPEXh1k6jXCODDpg/OqKe
cFq4nqt7ZGlhu3D+1BP5CAoVlCgFzWYemGlYN4rHUljCJcLsdNvAqmo67W0c
hQvlvax/F7eCTViOZ3gChTkqSzY6O7eCU5/uzEwyhUra6fk9V1rAK3vOkrF7
Qv/NT1XG5zaDP1n25fl9CpNffFXZk9MEQQqn8o5kUrhq2CvSyL0JzgV+tv38
ROjn5uB3WlYj3LCo8u8pEOpJ09EGWgN8qEx4XVMt9FPyb9Pd6VqoOrMjOrZO
WD88pTX1SC00GIo77WiksDHyUsnP/hroTgzqr2ijsNL/n103W6thwGbN0wsd
FPpfswysda4W5iU/2LqbQu/QdherpiqYJNxkS/sp/Kx38Es6jwu/5RWbQgXC
87mbqjrN5IJYGTvd7DOFYOpd7jdYCdIBEYcnhynskldD74BKUNC1WJc3KvSv
6Zl6+A8H5jePzQT8oNBp0vlZ+BUOaMQ8fm/0k0LXNiW7MT0O6JgfjPs6SeHr
/MP1os1sWD6s6f54msJxX4/QPUnCPElvXuL9W3gefD1SvjPZsHZ33LDeLIXh
/raSq8zZYCpqmz8gysRsg7UXT2kJ+SV3NixDgokHDRe9i5Bjw5ZDhXYsKSYa
ZAh0V4uxwU4tQFlbVqif2i32FmHDLs6qzg55Jo4peMbtl2SD8+m+BynzmKg6
3JXvoMgGYk3qUTdlJsbcPTMQpMMG1qd95gsWMHFD8I6j1iZs8EyQF29UY6L2
iMcDI2He+W2tqLqqwUQNh306bB9hvk2cTd6lxUT3zN5XDy+z4VSmKUteh4ky
Gzst/Z6yIVIuazxmORM37ZQNTJxhQ+s1o1rVlUxs3Kh1N2EJB/S1C7If6DOx
YRmt1nIHB+rWfvB4Z8RE3nrLUqm7HFjkOlD715yJdeIm3euISsi5q/PkxC4m
DlfnnG/4xQVJ/awYiT1MLFqx5GuZURW45xodSNrHRDT9sGL74Sr4W2Gl8dKd
ieM/i5bIt1WB/TB5cWQ/E00zt/ssLK+GHpOUgwdOMrGbNfklOqsWNpTp4FgI
EzkeRfGcwVqItstaFHFG6L882eK9Sh0Y0Asabkcw0fy/b/aWznVw8lwztl9h
4hHTAWeNtjpQ4Cpp7bnLxIyoZ0szh+vBknW52YrDxE/1ne9FbJpgJFeqfWEV
EykI/3zsWBOkSUV1/6xhor77mWGz9CaYeRY+mN3ExNAH0lENU01Q+CdoWrWH
idGS0w3mL5vBOJWp9W2SiZInUdPOpBUW+N7K2a3MwtoLSyPqo9phZD7PuFSF
hWo7zEPXvmmH92/UCvQXsLAzIyBvcrIdgpSvl0iqs/DOisSSYu8OaCiKf1+i
xUK6/4myNc6dcFU6qmXFKhbG+JX90rLsBq+cd+7X9VloeIKdvexMNyAp1iFm
wMIL3vE2KSXd8O15+KcuQxaubIv5t3rTJ9jlFjqUZMzC7By+d4FOD+iJFvmI
mrIwtPyf8inrHviTPTXiv5GFT2L6Tx870ANP/gb9sLdg4eu81eVymT0QmZV7
vGCT8Hnj4E1DTg+Qe8cmllmycJM2/8Tl4R4w/r32VKIVC8ePSYcvVugFuYdH
Z2aBhduyTDu/ru2F/wMUU9+G
       "]]},
     Annotation[#, "Charting`Private`Tag$37716#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 5], 0.2], 
       FormBox["\"10.\"", TraditionalForm]}, {
       NCache[
        Rational[2, 5], 0.4], 
       FormBox["\"20.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 5], 0.6], 
       FormBox["\"30.\"", TraditionalForm]}, {
       NCache[
        Rational[4, 5], 0.8], 
       FormBox["\"40.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.2\"", 1.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.25, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.35, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.45, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.55, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.65, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.75, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.85, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.95, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{0.8899999999999999, {
       GrayLevel[0], 
       Opacity[1]}}, {0.7000000000000001, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.2, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7937088132503643`*^9, 3.793708882176083*^9}, 
   3.793717681655506*^9, {3.793717818261732*^9, 3.793717821386374*^9}, 
   3.7937179101913652`*^9, 3.7937181818794003`*^9, 3.793718273836336*^9, 
   3.793719546027667*^9, 3.793801399085376*^9, 3.793801479407075*^9, 
   3.793801575442823*^9, 3.7938016428614264`*^9, 3.7938017475284357`*^9, 
   3.794507034222432*^9, 3.794507502463951*^9, 3.7945075485407257`*^9, 
   3.794507668058676*^9, 3.7945131175532637`*^9, 3.794513184289607*^9, 
   3.794515037461585*^9, 3.794515322333177*^9, 3.794568657157696*^9, 
   3.7945690218569613`*^9, 3.794576700966303*^9, 3.794578157991281*^9, 
   3.7945784439195967`*^9, 3.794579375673527*^9, 3.794579505190486*^9, {
   3.7946571752832403`*^9, 3.794657232061261*^9}, 3.7946675299748507`*^9, 
   3.794667828572035*^9},
 CellLabel->
  "Out[921]=",ExpressionUUID->"c0dbe2fc-6410-460f-b8ca-512e759b4a2d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fignpibp", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"10", "*", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"npi", "[", "t", "]"}]}], "/.", "sol60bpnsprev"}], "]"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "130"}], "}"}], ",", " ", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", " ", 
        RowBox[{"Opacity", "[", "0", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79344727493867*^9, 3.793447275672996*^9}, {
  3.7934625847549*^9, 3.793462585031742*^9}, {3.7936175028040037`*^9, 
  3.793617538931221*^9}},
 CellLabel->
  "In[922]:=",ExpressionUUID->"2a0b116c-0dd3-4acd-93ec-bdec144c4832"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpnpi", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"figcritprevbp", ",", " ", "fignpibp"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"PlotRange", "[", "figcritprevbp", "]"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "ar"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "imsz"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793446704447353*^9, 3.793446711536757*^9}, {
  3.793446744118206*^9, 3.793446750009528*^9}, {3.793446976069807*^9, 
  3.793446978955377*^9}, {3.793447262748226*^9, 3.7934472636613283`*^9}, {
  3.793461917634132*^9, 3.793461928547559*^9}, {3.7936314331853037`*^9, 
  3.7936314420113497`*^9}, {3.793631476571097*^9, 3.793631485116753*^9}, {
  3.793632121400091*^9, 3.7936321215815372`*^9}, {3.793633048723785*^9, 
  3.7936330803039227`*^9}, {3.7936331333339367`*^9, 3.7936331367594547`*^9}},
 CellLabel->
  "In[923]:=",ExpressionUUID->"d1eb5cbe-dd62-4b21-b443-1b9e289b0e33"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxEuXk81O/3/0+LRIsWhVSSJbtk386x78wYkSSRPRWFUKKFEilZEpIlW8iS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        "]]},
      Annotation[#, "Charting`Private`Tag$37716#1"]& ], 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxEl3k81N8X/y2RLBWJbBWRJclOWc4h+z7GnlSySwqVlPiUREqSCpFUZE+F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        "]]},
      Annotation[#, "Charting`Private`Tag$37716#2"]& ]}, {}}, {
    GraphicsComplexBox[CompressedData["
1:eJxNmXc41u3/xm2FeEJCCCmSkIzMbmRlZCejYc9IyChUqGxKRVSEx1ZWdkQi
hbJKhZSRkZCZ8f39juP7/ZyeP3qO87iu+3Zf5/t1vt/X/bn5rN0N7SjIyMh8
/u+f////AI14t4NykxLZf/9L6zLQmXaiIv1P1/Sf8SxX20FoWto/fnVJuwnt
RBe/NPtVgNBPS6UfO1sK/1ezk0ZXbg1TXxEjNGnWi74hVILQboP0wXQkKeL1
cbv8G2xaZYj1kaxflwuj5Ah9+Loc9TY+RUIPmrr9vPDvUeL1Z5Q6U20llIn1
N5cspBP9VAit2zdCrfFFldDBFXbXfY+oEa8XO6o/JnFFnVhfnFK8af9Vg9Dy
qveY9uzTIvbfq597bxZ+nNBPqlVVmMe0if0HTm8kGovqErpVqFbkn1g9Yv9o
4limcd8JYr1P9boDY4w+oXXaWTgKlQyI/asHzZXuDEEf4eMnl75jSOx/++F7
UqKKEaEfnrTIUh42wus9jI0yE4yJ9ftWlJ4n5EwIHbklz6Hyswmxn0GzZ+Vb
uCmh35iXkeuJniT276Bgz/QZOEmsP7wsVvs9xIzQQaWkfGbBU8T+yWudsus9
0Pf2cMmJBpgT+9vMRno5D1oQ2konR6flswWxX5hFQKo60JJYv35+d5WLmBWh
OVM6Ss50QW8NDwjd4XOaeH0Ifdbcjb1niHXFs+HdSi3Q9JnuKxtHzxJ63sDx
6W+nP0f/pxdompKyTfjhz1nbt6IpgsT765gNqpRPihC6b5Frg5//EKFNnepe
jQwdJvTG2ku+56HSxPspWEs+viUiS6wz3GVVPt0rT2i6KaNLR22VCD3251gr
43US8XpWi52T693gn2E/H89vYfA+opXZeCb8GLHfbLWvtLsP/N9m0yjXOQje
E++PtzZe1SS007VXvxU/gn/uF7vCpWTBu0MU3/nDETqEDmg4bSMxoEvsP3Wu
00lC6gShHZoDrLiUwPvtW9p1/SPQ6etluamx4D1JsHa3nTx4p1ihaHOYgJZK
eJQ6dRu86/7oXbuoaEzo46O5Qyuj4J+5uHeSKgK86wgpH9I7DN5dDNTX730x
JfZ7iI4aDYWBf/MXeyQOSoB3Ro5yqb/d0NJc4Re3BIF3lc5FWbb94F1CifyW
QBf0XUNNZs8Q8N4oNlqnctCS0D11fEssveC/jXrp+fBV8B7Psi9Fbi94b3oT
V932DnpQKtHW5hJ43+GSVHSCGbw/0EnwnXP6QfCuSD04EbKdj1iXkwoYilXc
R+jW/KQxY0nwLO0+2jE4hH7Oc0RDKfMl+rVIx9qAzQHwyhmvbmd0+BixPmn+
mOvfW+BRU5U1J0EM/H2wFg0WDwJ/5nW0oq+/HSfWO/8pDGwIQ79lfqWpnTqE
fltmP3p7oRJ8LdnbWWc5gK9WYYbCVUbwRFai/FDVBTwtpHB0mm8HTyY33cRy
rNE/Xe/76ITQgp9qnejV6mLwk9LYJnzfHPyUD3JPvt8CXnrezPm550PvzB2W
pSMzJ/b/eBp9Lvtf8FJkstO7yQz98p/aZpowKvBCNp7GNpYDXoQqIyqyzMCL
qdlfoXer0I45NHyzqeCl6DFvnrceeJF8cIZ7egH66ZY8rbbEPYTuD9cte7sq
RLx+SGAkzTdOklhvjnzoGSUkQ+j51LNPP1JjfqdzRJZV9IGPYnIaAddv6FeN
KTtOUIlgPo9P1U3NdYIPsjTLc9qHMI8Ha8RGnsSiP+3xYdRMlQEPj9esbjbc
wPz1yCucbGI2ILT+3S3zSRXgw0nAI/adA/hw9llLv1cNPtKF7wpFOaG/tH9V
zjlTjP4iUk7Pxn4GfHCarm94UoMHlfsbl0WKoVdT9vvetAAP6g6XZ8LWzYh1
179b5fgNwUNw68Wnj8jAg/8Jv0Lup+gnl1KpAzZMwIeXgW0Zfy7q39amvz1L
F/XfO8Fllrt8mliP3RLaI7gf/WJUeXrLslMX0S/OUrnd8XTnJdY/PAqbqo/a
C/2vX5Z3HPpDckBJF9cG6i9ZdlfqHS36gTQdZQfTOfQDms6h19mGyP9S3doG
UxnqHSRzkiHSHPn/5UNZbVaBevM/qK45YIR62ooU+zQvQds3xCf/MkU93/hX
Kur93ZR/z/KOy3rI+2X97eaPZlBf2+NFASceIe/2M5xaAn9wP6p8sj15fyLq
SXHvi2zIBOaDknP3O5c41JPUG5j5WwX1TAj8vvfDHeTZ9I6JHN0x1K98Zfj8
3THoXaY/2tdlkdfyNa9ltkHoTlrZ2apFfkJzaRiViMn9L6/sJNtX4sf5e3E/
CdboY2Eoxf1D/cYY6UcB8vp2r+mf4VLklVHXl8KNEnlVaei2/JKDvEoyb89u
pEL92pPLup3oUa/LhezL/qdxX6B4cKXnwyr6t/+bM/o8GahfR6jeE5Us1MuX
VuZ2sBHy6NEcqS3xCPVS8Mjcc1gLeTxlc9GRNgX5yy3Y192njnoJk5JYlMeh
T46SySUrol6fQiq5rMehHzoucKcqI2+pB0RlQu6iPgvmJ+lqviNvHypiGqu4
ka8nb9x7z0xh3iZJmyxrS6Ie4dapJrIn4T/Z+YU7n04jP2m5ik5KRchP9Yvt
loHb0A8Fx2lmVopwP5Nmie77SQ+/JfbbjYrvRb9LSv/96H4Q/OWv93V0EMQ8
LEnhj+71QT5YTzhfEW5GHmZnuk+W1sM/kRe/ZGNZ4ZdAV6Fq8nn0qz+l/3yn
3A5/sij84urHME9EjBkeLPnh+6Lz6ohOhin6CUWemEgMDe7D/r+KHjwwBo/x
7HmB9Gvg8e2hLI4PVuCxUfvJToZnmA/9Nd8oqoTA2z7rZ4k72zbxpztfkxgE
3rjILmxZ8wJfIu8i4gxa0A+so0+3v2VG/vX7WD9aOSPfxgFDGYlMyKveSf+x
25LgI0jkyX4q50ai/85eL3Z04kH/5TFhuNgnhf7L26jCWueI/qv0858zGp3w
6/O5kv2NOuCFl77GxV4B/VazfslR8jH8+dJ+1qskHXmVkXJ0mdKEH+L5YeYF
U9Ac2lW7GnXAj+RPujmN39Ahef2DeSPI5xGtY1XsCfCv1i/x0ruf8E8kljef
JgY8jTctUeqGgSfa+xIvqI+gfw42Xz/4+hb8db1auVIpizz+1P68PaAfukO8
6VyDGPxfKQgazemCtr0R1FSUyU9o2Y9bFSMY0T+Lvi2XuhYgr2qc915lRKJ/
7qxlC1u+j/x+kgn8wv8Y/bM4fb8l37QasV/v+ITO1V+ox96n4Vx688iv8xaf
Zz1ayG+MLf36QBL8v7btEj/7Q/g95H1D018T+a1XlEjelQD/j729mENSgv8U
MhmUIQrwO1kkW4BnEFrHalX21GH4H/btq6HqAHQ5++1FyUj42x/v9f3VR+Tb
izmhipodfP8Kmrf0TUD/GzPksbtLDz8tEtuT9JTh37ZgnitsWuh/GpTTL2dT
wPOVtT6ZgWTcDwRcJ+LVFsGvrgjH7vPe8CdSrIX7HBf8oWJp7q9zRX+z7f/h
GP8c5+eXGpfVpcN5J+7YWD6zAX97aWnCxmhw3le3xTi5a9DP/D26aVQN0M/E
25+sK4kin51DVhfSf5OIdaXr0mVBY+hfI07XaqI1kE/B0ubFOm7UX37VUuNT
A7SApVIMnTPq+7xIjfZoLfL1QzEqW/Qs5pdC8UZgGhX4ny4MGvgqinqFjZM5
Zg+j32TXUdybaMX3s/u5A/FDlJgnxfLO3Bzn4HesNq9CWDbmhR9ba9RnXfh3
I/t367NZ8LNRmnygyw55Y8t26O/dAB+VXtzWnl+RN2/9yr9tjeDFab4pq3wn
5kG0aRVp90X0e8bEka9hp9HPy40iKGz/bPq+v0fuUMkv1NNsx7iBhhqeB81Z
tOUleyHPa0aRTOFN4PF9j0QOWwvyW24oVOwmAd5shK4o/gpGHmW05mQ7ecCX
Fcuq8A0/zMsG212k3bvwefplVMUK0jbx5E0+6seFeTiSz6dxb7sWoROaVraV
HgYfrOlPrk4HgY/Ho+932XaBjxqfZJooL/TTvHWvGS058FBITu/C6VxCzCef
G/kZLRN4ftwo1l46shW8qBsKHrczxnxi4j2ablkD/gu2RZk+VIF/ooI5NccO
oR96KPukqCeAf+PLMfrWSci3CoWSSpsqznfXzUOHbwx6NvrE5wINPD914i1+
1zgOPm+aq6Uf/oZ6pGlus1iLgT/jNR8Z037AHzuaLKn5W+CF5E33qCYY9XP2
jdSOlQDf1L+MnimHwM+lxUnz25Lg/dofExu3T9DCPM9zMoSRx2Ta0P4/bdAH
X6eJiwbyE/qje//E9qRN9/lP+UJU0cjDICleXzkBvIbpU9z6+wN+W9p/fHjm
O/zuqPhzlDQOfodK0qNCjmL+JB361lWXAH8tDeiHKBLhJ3u+2J5FFfDuvBRy
7J9Y+Kvp3+f2+gj8FQ34kWQmAz+708TzGT5Da7CvVMiIwt8vMdNTxZ+gVWNe
ndx2A/411u58LrwDvN4xL38U4oR5w/SN4oH8InhsLLFXPCW96flV4evpt7fh
jxCtmsX7OMyXB+yc7nOT4G+fR36/mQfOX29/YekrG86fYuw6E1yE83D9Hq04
QI3Pr+ddMyZ/GrzUFgb39pEj78ZfwvuP/4t5krpeoTCmgPzHH7nWS8+JPCms
/2EpHMZ55kLdmdwUkJ+34gqzquyon3qLBE9lLbQQXYZhnC3qczmD/2VpOb4/
FbhrMe+0wPwQPxE9sW8DzxNIlhSfKUTgv8irhpzSCvSDDlJw61od5se6S0uI
yTr+fmTQ+hdKS/j5ZUGA014T/vAaunCnT6He0euL0+T6mBeKMjqsVyaQB+7+
v3JHWzAv+l0MHn6qgD/UlONc7xzB90wLc4Th9Kbv8y+aU478RD3Wp/PuGHEI
EusrtkO8VU64n3Rs2CrYVoOfy4PJ77bUIk9TtzqixkXAB8P39uGhANw/JKhm
Kp5xgA+F7yPWBrTo53Iq57ccEYVf7IZ0aj7+qJd9X0FPXxv6VViWmbu3O/rP
Ws7i5HkZ1IdXOUCSPxd8vJlMdpSfw/uTaAUtPxmgHm1aAbskkzDPB5f0xTSW
cZ+ds9DoFjKGn/lKA25rupi3NmV8yWLD8FczQ4LTtR75/DDnwTr1L/Im6D9Z
cZ4Jftws2dqxzwnzMfJ0hOQCPepjNPS7I8Vu0/fH101tiX9xv7oma7KmuGfT
fHjhqNPcAL84Gd6T1O3A9zVSqPWnHvAqMTH/2H0r7ju/yHz8XyyCRw83ZYfM
APA4zXk9S4IVz0fN6I/eypgBjwxSe041toPHnTmRtheu4L4S9JXS33sZzwc5
b+Q2iv1B3orkBJnkL+B+MmlYeSQwCP1eOKt4qLADPFa6CScsh6Ifx/paHvi6
C3xZGs7OCyiCD6a8vil153Ri3iu97mBSa8C8Z0sR752cw+/F5okcwzLH0V99
5XvUHYrQn+7ZLLtGKOLzSJY+Hik+gPkTQl76vD0GPMZ+yFSSTUC/fT2Wla+k
jPq16Nq9Mh+GHnjKIS+ghnlPpUArTzkGfsOfLVFf6sf5TzbP5LhHIT9kZ33N
GYbAw7X6CT/XG+DVVef25PwV8JjsWBHXLYb+dJ9MYS7wKvKmdJgmYuPQpuex
miyRIz3QvXfE2tmEMN8ni2n7ON5CMzuUDE848WO9rCPsRwz6m6TDst+tm+DH
Ri05vCMG9XfPPP9obAB+W/9pe932FX5n1mYbVPxAf+Khrw6wkEN+d7PrkA7d
hr+aF7uVfe/Cz6Lm67FSJPSzWpOC++FR8Pf4+6h2Omn4e4w7ZOSlJPyctfKa
uf4RunF+aTnzwKbv+w6+8pM9m/L/pv+GXwj8m2T9JFnDsun59WuO+nAj9BN+
oXkpxqlNPKoURfeLwy9Kakmaymj403P+kNWbUfDGEn9Jqc0N57W89sqOixXn
rWR6KrVUiM+f9G5kOYkCv+8E242LXrUAH3RUSmTGG/j8D4LL684lY76XqOX1
Vkqgfx1zm1GdZUJ+fkeQ7CQH8flXWOyPfJFGXh7+8nYP3bHp96/ClFvC1dDC
58xKus6hHgM8cbtnSjHfhVO6+ZxW0V8cixrMEoQ3PZ+S2Pu26gnm+Q+yF8Nh
Vfj7h3Rq16L/4u/5pTYr+J2Cf4yjBmdz1eCHa6aQOvcE/NAPVCo88Q18xy8n
T58uwXlJp8jp023AJ2OoaXvLJPzXt2IsO0WJ+XzFadL8uC3mc4XJe0OD56i3
4bDBwNVy8H8zQ+CvkDDqe5a0LGvlh/lc+G16mXcneGQgywr1O4DzcmbXZFZc
gr8tRtySbG/RT1zqy578dEV/2Ede4UwuDX8lySv1cjPg59rbuG9ev/H+Ivtn
qvROwM/rLWdcMu9tuk8XnW7Y0IM/muaHP8tr4zzBF+wGM4fg1wPmO/KeuchL
1tLeffZpmL/pJyeWvzLgvJXp0myu9qif8WK0fxAvPp+xbG82ZT3OuyEg5l1p
jXkqZ3L4yZH5Tb9vbHfXqvHAvKSw9lalpsO83EoqmI8Yxbyse3k+R+sNeEi+
r1E7uYD5yNo9u3JhBvx6nGz03OaPfsi6vns5uRX1Z2w1+nnxOvqVPMtR2Uo2
zMOQrOKLz+VRHxq30ADZ4/B/qlmIPiIe/ievJHgyjm96PhX3ubRcDf4/Yv7p
V00LP7lCY9MWzsJPT4uGgnNUuM9EP3+dukMD/eCmR/bL/RO4z6x4UnhT7NrE
n0iJrX8V/K8OVn7m1YT7S2tEFz0XuSGx/ibvg+iCG+4bXYzt6p9nwEfuNe2L
umK4X/ic/ThywB1+lodmxjkGIh8MVxU4E5+CX443d1vrk3FfZN4TQfZCH/fB
1V9VFF754M208cutby6430nNeTJ8cEBe0vLKDdRXwM/+FpbQmDDw86UzdttZ
HvCT2dPO9eIv+LHmr5Na/wteeGVto6cWwMvIVz9uMj7UX3JV3DdeCfX/DwMC
BzA=
     "], {{{}, 
       {RGBColor[0, 0, 1], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[{
          PolygonBox[{{340, 411, 537, 123, 185, 40, 87, 39, 249, 156, 627, 
           478, 592}, {611, 599, 370, 497, 30, 77, 29, 148, 76, 227, 114, 471,
            328}}], 
          PolygonBox[{{436, 545, 146, 204, 74, 112, 26, 73, 25, 243, 145, 477,
            338, 612}}], 
          PolygonBox[{{583, 622, 469, 586, 323, 423, 160, 215, 91, 126, 43, 
           159, 90, 349, 234, 621, 463}, {539, 593, 341, 438, 217, 297, 95, 
           130, 47, 162, 94, 350, 235, 464, 312, 605, 413}, {576, 609, 422, 
           548, 154, 210, 84, 120, 36, 153, 83, 231, 119, 330, 182, 618, 
           455}}], PolygonBox[{{578, 347, 616, 444, 566, 230, 308, 117, 180, 
           33, 80, 32, 246, 150, 339, 207, 619, 458}, {417, 615, 440, 562, 
           222, 302, 105, 170, 16, 63, 15, 62, 14, 352, 239, 466, 316, 607}}],
           PolygonBox[{{552, 225, 620, 461, 581, 304, 406, 110, 174, 23, 70, 
           22, 143, 69, 224, 109, 470, 327, 610, 427}}], 
          PolygonBox[{{439, 135, 624, 473, 588, 333, 432, 194, 278, 56, 101, 
           8, 55, 7, 54, 6, 134, 53, 480, 342, 614}}], 
          PolygonBox[{{601, 20, 629, 484, 597, 353, 446, 241, 317, 141, 200, 
           67, 107, 19, 66, 18, 240, 140, 337, 199, 456, 283}}], 
          PolygonBox[{{136, 137, 626, 475, 590, 335, 434, 196, 280, 60, 103, 
           12, 59, 11, 58, 10, 351, 237, 465, 314, 606, 415, 
           541}}]}]}, {}, {}}, {{}, {}, 
       TagBox[
        {Opacity[0], LineBox[CompressedData["
1:eJwl1nfcjmUYxvHXzB6hkp1VViF7lexRvFYyoxBllJQRsiorZZOZjJJV9lZW
RVMlimwJEZFV3/Pjj5/jOM7rvO/nea77Ou9Xvg49ErsnSUhI6JM0ISH0hH86
4yb/ATqgNCwnJENynLTeBbf4+eiIh3FLbRCyYas8HClwSn4O//ELUNjNPpRr
4Rk5s/wuXxQ1+K/oAfWS/Gq+E21OD6OM+gikRFncgXJIhWdRHnfp20aX0YZo
4Pr9tCd9Qz0nnSlXwJ9yapzmu8YGYCHphDv1jZeL4aBcAf/xg3E3PpOL61nO
Px6fxf9Ce9E3reWis+S2tCL9FmfV29E0tCLSohLSoTMq4x7rn9MV9Im4t+sP
0BfpW+q56Wy5Es7J6fEH3w1JsEjugiz6JsjF8atcJeH2g3xdzo7tYgn5E75R
fBZ/kI5Uz8PP4dvRyvQ7nFdvTzPQqsiIasiED/Fc3M/6b7SU69bEWaItaCL9
nT4SW8wP4e/FDnlUnAGckZ9HUnwkd0VWvRPlB3EozqK8ln8STfgj9NH4WfxQ
viXNQXdhp3pjOpr+Fc8T1WNf0A2PYRfGxN7ou0A30afRzH2O0ZdpVvU/+ReQ
DIvl51EjZsL6MLWc2C2PRV61uXJVXJSz4Swfg5YcVax/HjNBP7Z2P/1I7kBr
0x/js9QPoybejjONWrgbS9Adk/Q9hJqu2xN7F3scs0jXxV6gdsysPJzPhS/k
cXHGcE7ugRRYKveI76p3slwSR+Q6McNqI+Tcsdf8bvql+oP8pzHDNDHOGN5R
/xvZURf3oifq4Su8i3z639fbnlajdej39FLML7859gI55PMxt0iJZXIv1I/5
j1lWy4M98njcpzYvzhgux5zHc495xB3xPKxvp8vVH+AX8x1pHfpTzJf6UTTA
hJhfNIx5w4VYRwv9qWg1uoOusFYkniNfFy/Fs5Kn8KVwTH483lPxTpDzYq88
MWYMF+MapMYncu94xnqnyqVxXC4jr+efihmNd128ByLTfLQ6/SLmn35tvQk/
if4TZxGNYs/xKV6O82H9BC2rfwPfhbaiTelR2thaan4kfx++kSfH/sazlXvH
+wsr5T5IRBr9o9Ty41t5CvKrfRBnBlfkCvKW2PPoky/FfMUsq6eN50Z30q50
VZwZ/hV6Mn4TpqIAXkVTfIdpUdM/P+aWVo/nQH+gV61V5LfGGUVB+TLtg3RY
LfdFM6TVN1qtAL6Xp6NQ7GF8B6THGrlfzI7eaXIZnJKbI53amPgMPMZ/SX9Q
f4hfyT9Lm9JG9Ld45vQ96/+iMFrEewBr0T/mx/p0fa1oWVqL7qWnrZXjN/Kt
Y+/k9PJYvhD2yTPifOOK/CoyYJ08AC2RQf/baoXjXSPPjDOMq3JfZMR6uai+
JXx9vBazHN85PpeWi3dLnLd4V9E/rLeJM0lnxbUYiFb4CbOxIPYG9fTvo93p
NfVKdFvsEYrFntB+yIQN8iC0RnFcU+uPzNgoD47PRUb3GKd2P36W56AErssD
cCc2ycX0LeUbxO/if6Y94m+itRx0htyGlo9zjzPqbWlbOjfeeRiCdrHH6vvp
Ktos5sZ1h2I+4v2mXpAulGvgepwF3Ii9RBZsloeiPUriptpAZMUWeRieRib3
eUetCH6R58XZVFsk18QNubL8Gd8JzfnjSW7/n66Utf8BsCkelg==
          "]]},
        Annotation[#, "Charting`Private`Tag$37861#1"]& ]}}], {}}},
  AspectRatio->0.25,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 5], 0.2], 
       FormBox["\"10.\"", TraditionalForm]}, {
       NCache[
        Rational[2, 5], 0.4], 
       FormBox["\"20.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 5], 0.6], 
       FormBox["\"30.\"", TraditionalForm]}, {
       NCache[
        Rational[4, 5], 0.8], 
       FormBox["\"40.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.2\"", 1.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.25, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.35, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.45, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.55, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.65, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.75, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.85, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.95, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{0.8899999999999999, {
       GrayLevel[0], 
       Opacity[1]}}, {0.7000000000000001, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.2, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->700,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0., 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.793446723677157*^9, 3.793446785087015*^9}, 
   3.7934469801090403`*^9, 3.793447227208099*^9, {3.793447264011318*^9, 
   3.793447277456396*^9}, 3.793447311102808*^9, {3.793447516154393*^9, 
   3.793447528874736*^9}, {3.7934619226037683`*^9, 3.7934619288630877`*^9}, 
   3.793461961164349*^9, 3.7934622036035557`*^9, 3.793462451229333*^9, {
   3.793462489491652*^9, 3.793462608413128*^9}, 3.7934626961006603`*^9, 
   3.7934689623154917`*^9, 3.793469063363864*^9, 3.793529281029666*^9, 
   3.7935297652435827`*^9, {3.793529806518998*^9, 3.793529925606844*^9}, {
   3.793530273719088*^9, 3.793530288945623*^9}, 3.793532164393281*^9, 
   3.7935382465107327`*^9, 3.793538857025456*^9, {3.793617488369979*^9, 
   3.793617540148157*^9}, 3.793617738678664*^9, 3.793628687436328*^9, 
   3.793631367459117*^9, {3.79363143845481*^9, 3.793631442242111*^9}, {
   3.793631476767042*^9, 3.793631485457098*^9}, 3.793631858561059*^9, 
   3.793632121775387*^9, 3.793632435370782*^9, 3.793632615346583*^9, 
   3.7936326990393543`*^9, 3.793632896683559*^9, {3.793633051880995*^9, 
   3.793633080583713*^9}, {3.793633137138521*^9, 3.793633150393712*^9}, 
   3.793633212368238*^9, 3.793634115477564*^9, 3.793634260809019*^9, 
   3.793634384326985*^9, 3.793634839427136*^9, 3.793635141442663*^9, 
   3.7936401181586723`*^9, 3.793640223716352*^9, {3.7937088524855824`*^9, 
   3.7937088842186728`*^9}, 3.793717681970107*^9, 3.793717824835767*^9, 
   3.7937179103593197`*^9, 3.7937181821313467`*^9, 3.793718274034895*^9, 
   3.79371954616118*^9, 3.793801399207608*^9, 3.7938014796226797`*^9, 
   3.7938015756784983`*^9, 3.7938016430186653`*^9, 3.793801747714795*^9, 
   3.7945070343920383`*^9, 3.79450750269622*^9, 3.794507548699544*^9, 
   3.7945076681917458`*^9, 3.794513117786797*^9, 3.794513184607078*^9, 
   3.794515037644409*^9, 3.794515322455339*^9, 3.794568657242687*^9, 
   3.7945690220263433`*^9, 3.794576701138505*^9, 3.794578158149716*^9, 
   3.7945784441658287`*^9, 3.794579375733444*^9, 3.7945795052579117`*^9, 
   3.79465723547536*^9, 3.79466753009993*^9, 3.794667828684298*^9},
 CellLabel->
  "Out[923]=",ExpressionUUID->"519aae49-48b9-476c-82dc-a3c75c1c4121"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6A.pdf\>\"", ",", "figcritprevbpnpi"}], "]"}], ";", 
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6A.png\>\"", ",", "figcritprevbpnpi"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79466744718346*^9, 3.794667455720294*^9}, {
  3.794667819072892*^9, 3.794667821106282*^9}},
 CellLabel->
  "In[924]:=",ExpressionUUID->"f220c509-ccfb-4a3e-9af3-f72fdb0c9953"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpnpiimm", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60bpnsprev"}], "]"}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yearticks", ",", " ", "None"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "22"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Green"}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1.5"}], ",", " ", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"baseline", "+", "amplitude"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", " ", "200"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7934696625099773`*^9, 3.793469677272522*^9}, {
  3.793469808823731*^9, 3.793469971790944*^9}, {3.793470223261483*^9, 
  3.793470240817769*^9}, {3.793470311660644*^9, 3.7934703125299*^9}, {
  3.793470508123329*^9, 3.793470523377727*^9}, {3.7935388618606567`*^9, 
  3.7935388959889183`*^9}, {3.793632137623155*^9, 3.793632138501503*^9}, {
  3.7936338319734373`*^9, 3.793633964756832*^9}, {3.793634823336767*^9, 
  3.7936348291842413`*^9}, {3.7937088950579767`*^9, 3.793708897415483*^9}, {
  3.793709013641704*^9, 3.793709013847748*^9}},
 CellLabel->
  "In[925]:=",ExpressionUUID->"4c25ce42-efb4-4c47-8d82-9beb334d503a"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEt3k4le/3/i1JMmRIhVRIJQnJTNYyz/M8hhBCKsoUKomoEIXIEGXMLIS2
eWZjkyRJkpCkCFHP/T2O5/f++Gcfr2MN51rnddn7vnkdLxg5U1NRUfnSUFH9
3+cHWtGhc4qtClT//x9zweg3Nfcs+H9ctIXhPJd7+X8cIvT0GI1783/8RfE7
3Zob5T9+rJPg99Nt6j9eNnQtXnT79R9nUgx1vrvR4P/juvEzl6pUd//H27f/
8iclH/yPFdrIzKpN/+MrtwuzO+b+x0s3y1zdDvD8x/Y0nvGXLvyPT2+bmAtj
5f2PV2hbk3NN+f5jtnPln+fc/scn2jJFhYP/x063Q1pLn/2PB7fLLL36/T8u
pivQ7E069B93uybHs7z4H39pj/hg1Pg/PhDp7Ptm9n8cveNgxoQc/3+c48Y0
z2dAMIvYn4QvvNDU8UfS2Yngqc/14KcI48dmrz/3I3iCX/FIjB6sR450f40m
WNrrc8JXU9gz27pXKIPgv6kpD3NsQEyrwtGrgmBmy7TdrQ7gRh+3uvSeYFng
3v/NFfakir6Z/0kw49Vl2XUPaBbpq5jecRhDY+qPiiV4w8VGz/iJg4eRKgoV
FUiX4IAp4+VRCSLuEmAZ/88Hur7kGVK0CX6ncK9q/1XwC9AU7XUg8h9Gpoh0
XIXDTDM726/+X73aFsVIPxhIC//WcJfIDyoMELPxhxCxw92vnhLxdtngKAwA
oZamvIpqIj6X/Z1NIhDCZ6lccz8TcZX68lda1+DUtTS1p38I/lRXpeUeDBPM
CodTWY9g6Ll7caMPQ0BWInAy5jTBwa/oHtNfhy9tnA13jI8g1UhmlHDZdYi3
qkoLcyPicv1nEx1uwELIso1fwhHE7e+FnvfdhMds8XKX8ol4pL6o3P0w0MgW
4/JoOIKkLM+zoSa34GnnhTdnvhFxlVs+MovhYGC7s9Jy61EkGZw3aGq9DX+/
F8Qbcx5FfPX+leDTCMi/oX1ZV+Qohh7Io/+hGwkWu2cN1VWJfFX9hld5kbAt
J0JU0ZrIn98a47vjDpTKHmWWu0jkO2VM9bvdAUZ7p27h1KNIxZls4SocBdVL
1PkCZUS+VoCjaFwUuNzKiOTrIPpVvPpWvhIFpLxxtT3LBCdun9BviAbfZYuG
TR0BDP0b0axgeQ/G7+hWdm8QbPBobzcpBoorJNPdbQRxQvQWk37NA2ih1mH6
5k3wzpow+6kHMKrvEHDhliCmzzjGntgZDzSzUSY+LwSRZ8j33rp9PJgf+EgX
THUceVRE3c5uTYC/4VEXY7OOY/pvqtdpcg9Bx2JCqWpeCO0F838sBCaCQ/Zy
keyWE5hOzmKfS02EK0v0++t2/x/LHy54nQjp0RK/GxRO4MRJckQwdRL8JN3J
74o5gVS7g+K8biVB8jEJ9g/iwkglQDLrDk2GL+uRn7ddE8GJagbFBf0UuBeg
Pw0PRBDb9/+85pkC4uvsX/xziXjqiNzQnRQIXUub+TYkgqStIpJjzSnAtDG6
7L5XFNNzLPLMJFPh+friqpE3wc7qaML8BAJqjNcuBIqifXQYb/SxJ6AXULkW
HS6KPHrN5bHKT+DXWuB6awqR35PotP3qE8A12g3ZDoKT8rmfv3sCo7+5//Hx
ncSJknsV21LSoPBlyD84cRKpQo5sKpWlQejVyX820icx/V1aoHFnGhz9/Zzq
kd5J5OGQvPz9dxr4rIhRMwSeRIPkBqV7AunAtKyx7efgSQwd437fdi0dcMmH
oemWGMYknBS+ypkBa7rqxwpixJA8x+jtzpcBpbmc6gmPxZAkPftU53gGHHKo
v3GuRAxZVFesx+UzgJa8fZ3hvRh673B2lj2TAV2FyTMm4qdw0Vsg/nt6BoTt
8KRVgFOIDzLlJnIyQN4Z+I9qnUJ7qSdlDcUZ8IJ76szamVNYPCsaZk7KgJio
E29So4i4ulNJ/3gGmLmRWqYnT2FoAo8BB2cmMLfEfer7dgpFvUY/8fFkQjuP
85bqVULP8ubvg0czQWZkx+moneIoGsG1bUk8E7jVjctFZAleYPRd1c+EoczD
Axyq4kg6tNaSZJYJ9/7+/r7FQJw4L31bYdtM+FeRcpziLI4G0mG1J90zoYr1
gmadtzhSlV4vS/fOBG9PxXPPAsVxQl5bf+vVTDjWsevW/XBx5DFrf255LRMm
+acz/WLFMSZZIpoUngmPQ6tIDimEnnbGlMPDTDAZuzOu9Vwcvesuq69nZ0LL
AxGu/XVEfljWNfWWTMih9o9tmBFHlvPWR29tewqeEwyh9CiBoSGfnwg8eApW
SZyfpbQk0GBLc+ep7KegZnRUy9lEAqmYeIxSXz4FnmYldpKrBNp/2bYn8f1T
GHjun+MbSzDTJeUbwllQb3+b6eljCcTf7iHDylmQz5lwiZwtgTFWD00zLLMg
LKpY/niNBC4q3kp9Fp4Fkhe+kCcmCf3u89VN01nAJ7AssfMb0S/zUA0PVTYw
f6R+LPdbAkUP2xUwcmXDjNEB54cMkri4/MbhiX42JEuarmmLS2LoJwYr2sZs
+LfZyPvyliTGfBU8TNv2DOYryeFT94m49zTt8uwzGLkwPseaTNSnJZcVMj+H
0o9rFR4vJJEnbpH3rvVzcGoR1eJ7I4kssYFDNzafg0GwQpH+R6I+pnKPvEAO
nJbSYb82R9R3zRZ9Ms6BPbnnxt/8kyTuk9kp1hc5QO3oq7yNXgrR4W94xlgO
fOe6mSPGLoUsP9qqxRlzYWwwhsn+gBSKusoJkuVzoT36yaW7AgRLf5T098qF
ctWCNzViUmjv+XM8KToXMv5Wy8/IS2H6UbyimZEL9162ZexWl0KyCN2GXmUu
BHgP0SobEvUyD2hTu3JByITx8ao/kS9f86aTLw9i9wU0ne0i+hnlbKhS8qD1
25klj2EppIref0ByPg82XqvyXvkohYut0VasNPng4sQaEvFbCos3xs2uncoH
+cIc2cJD0hh6/1T315h8mFZ4U7ISKI2iovtTJ1QKgJu1buJfuDSSK+9uybcq
AMNPmcw74qRxQvX4Dh3vAqi97eW5L0caDSbd9FkfF0AsedsxpBCMD+aeLRSA
vKN4eqSQDIpuc2Xeea8QLopz9cVJySD2N+UqZxTCM1qqv4+VZNDbU1jOsLwQ
WPO7rF9YyKDBN1ml5beFMP3Tce9gmAzGqMTMnjv0AmJvxd7jfk/k79XiOFX0
AqZzFoKK7soi1X0OL82CItAfYf658YhgzdVDdDVFULX9pJtWpiymH2Gzzm8r
giiXy6afK2WRFBHPlz5ZBKL8qyf2Tcji6k5rmyyGYvBP2/IhXEwOeeqbZD6e
LobJXj5TirwcetfvfbKoXAw6f5W7eNWJuFnk0E/NYjhgG/6y1loO/Xxr9gyb
FkMjF0PMUpgcjixUuDN6FgPjQ3ZFuzdyaHAy8bFJUjH4tki8zP8ohxFZ1B/z
nxTD+C+zE2tzcjijS+Ow+rQYSoyTOOOp5NHVWNft4otiMGM9sNRxTJ74Pn5P
+dxYTPw+HX0qESSPVfq02V+/FsOpm7LbmHhPY6jVg/efREvghl5X4pHjp9H+
eVjfT/ESIHPaCKHEaTRYupX/R7oEvIqvGV/WPI1UX287/MQSyHlPynh78TSy
/Iy5HWZQAgek1RWeNZ5GgfCRNVmvEvDcOtL/uvs0Fof0NpAvlkBtr6vz2+HT
mMNi5njGtwQsne9EM86dxonecedzQSUQH9czemmXApJW3m3nv1MC9N+Mr4KT
AsYczXeyziLyq6boLb0UcCTW/MCt54T+Td8nl/wUkOzEH56TVwKqXI9asqMV
sF226sFYcQmEqo/uYqxQQJZExc312hLoZTv//PBrBRSo9b3+83UJ7B//Iwsd
CogXONinG0ugxme/46X3RD8R1QfV7SWwA18sR31RwNVd+x8ld5WABQNEZv9Q
wAjxf298e0vg2XAf9+s/RH5QnIN2fwksZ9gXj2wDjEh9YyowVAIqnj+Ul5gB
sbul/9BYCcRJ33jDwEXEQ7szOT6VgGjf078KwgQL/Y7d+qME3DemdbLNAAW+
8kuZMJXChJnn14vPAb1DVxMvapWCn9yw2rlSQDJP7ZKdcSkw80CWTR0gqch+
zN+mFBS+spxRHwRcNKnPgQulkBJYTuH+B2hRJ8En+6gUuIp3cu7Yhuh659DH
poxScOFrartJj2h/57hjREEpbNIKHfbfjaiR5zTa1lgKQuTND2ePI05QB0xp
LxH6SqX3xkUReari9r75WwrN5S6nLSURY3DuXi5DGVgn9SXrKSImXpsZFDxS
BnccM0xlzAm9uD0rPXZlMEwxpSm3QcTnp80bPcuAT52+TNgRMeJFYDPDtTKo
Pn6Zhd8T0c+QXT47pQxmfql07byJOPN35y+BiTIQP7fmHxmBWFzI3vbnRxmE
vi0UoLlH5AtxRpyiKYe99XvC1xKJ/r6JGqPHykHt9gxOvSD2606/ohJQDnFr
Kd/tyhFD737UuHa/HMbPGz55W03Et4d7ncguB1+Dmj+9zYgsUu6+m/3lQGr0
ytPsRBz5XJvK97UcGCUOWTb3Efp+PFc6qCogizO6snqUiO9l2Hx2sgIWo9BZ
fAKR1L9nzyetCpD/+2tX0Wdi/gNfJ/KdKiDCO7fx2BzhD62UxAmfChictL2Y
tUj4E0a6MxtcQbyfsPEcXEFMH+xiG4ysAPe21t6kP4Tf+huMH+IrgLpAROg+
rSK25xW4qOVXgN6BqdEdjIThI5ekHlZWQFJMYmQYqyLOZJ8WWmqoAFHfLV/8
uQkW1PhWN1IBZxQGM5zEFDFiW2qdBm0lqJw57HNdiqgvFbAcYakEwdCrak/k
FVG00yLSbl8lrDTsm3ujpogTrpJ3NEUrIVrVSVzbWhGraM24gi0roUZnufVk
GJFvztb1JqcS0j3Vk/QiFXGk7HvspdJKuHUv6fz5ewQn7x5df1UJBuTTLNmJ
irhI63JnsLcSvhiHW3IUEvuceWWR9bMS2K33zv8dIvjY7bk2mZewHuhWv++d
Inq/GOqQUXoJEymvYqQniH1SjZKTtF5C/vgZiUuzisjByH7zkPVLUHLMCf78
l9BrzIk7G/gSLrjJsHYfVcKq6SvXiqpeQudVa8kkfyVsb3F1NTtaBSbZSd8O
hSihd1B8qbZwFYwPvMl6EaaELIUd1qISVbB0wmRX830ljLgy5NyuVAVcUzqL
C9lKmFg4EiRlWwXnDRTyVAaUcCKhJ/3k/SpYuRbk0PeGyJ86LiWcUAWh+TUc
Vu+VcJH+zAXux1UQTyt1+8IMMQ/Nsk7vsyqorRVxSv5L9BP6ph9VVwWMx3gP
LAoqYwTj1eDwmSp4aHZmKEBUGdOvlFgWfKsCnrDU6G2SyqhhP9LfslQF4h84
/3ApKiMVaxI9ZaMKbBLYRlTNldHC5t4Le5ZqKNhCE/f4pjJOlPPtNpaoBt3R
6W3qY8q46vhS1OhqNXQOjXW9/KiMou+SnjMFVoNa/0CswBdlZGl9DaTgasD2
+v30S8qIT1ePMIRXg3jlQ4me7SoY6nVpl2x8NZSURP85zUTwyuPB4kfVIFx4
o+EFmwpyGN03O/i4Go5meenG7CfilNqfnzKqgStOzdn4lAqOmNo/YSqqhkd3
5Y83S6ugn8D9Oyql1cAeKfZDXEEF02vf912uqAam0APX9miq4KL+6eJXr6rh
TiC78m09FRRtOOZJqa8G2qv0O1aNifqjezo+N1QDlddK/Fs7FWxXep611FYN
19zmrbScVDBGJEd9obMa1p0meV65qeBEqAN5sqcartiPTB+/oIICXfyUfQPV
8NO6tyDFh5iv922c3dtq8DZvvsQUQOj7e75NnKiGeaMa6eAQYj8Glnnyl2qY
1nzWfOaOCpInP9zSX6mGs6opd8j3VTAn5J1C2mY1TGCcgWICUS/qxPWPpgbe
SgWP8aWroMFMx7ONXTXQfdjs1+cKQn9t7ZPcqRrQ5NWpMXulglRUS2k2cjXQ
yq0U2kZSwYjcoucZyjVA2iXMmNtF6DFZK6eZ1EDZFlp+j4+EXy6nJh741YDo
5p+vY9Mq6K36+zH1jRooWP1RpDtP5O/gupoRVQPPvr+XE/mtgjMeM8990mog
+X2F8RKjKrYfGvWK76iB0Grnm37SqsTz1teXQwKv4NHZNY+o06qYHv/y7Ib4
K3jBdNfsiZIq+nkbfrZTfAXvHMqPNesQ8ZLO1XdWr0CSfiuZ2UEVOQqTU9/E
vALd8ofVfC6quGp0YWPzyStwshN8KnFeFXlWbw+4Fb6C2FLDK9a+qlh1ourg
3q5XMG+Vzv08UhUF3uv9+LajFrZuE6etuaeKGk+00py5aoGrqO179wNVxDKP
mhPHa0F96/fGpVRVDGU1Ya7QrYXM/NNuCqWE3p8c466HtVBt2m9k+FKV+L6L
nFzMrQXyPyd5p1pVTKyPt7lcVwubxtHMd1pVsbjuSH/C51qw2BitGBpVRYuy
mwGhsnVw4ZlX2swHgnUCAusM6iDcgDryzxTR70tVlPO5OkhZT7i0c5bY98GH
iIDgOijLOmbD+52YX+FO7bG7ddCpV6cq/ksVF/O6D9Q8rIOJVQMR9TVVnBi+
d90jvQ526vpRe25VQyqbEGae8jo4/JthPoRODQWCfmzdW18H8hlpQ3FMatj+
yS1uX3sduC235lTtVcNFDqnLCmN10Jy6W59GSA0nWmpPP6Kph3fqudJ7T6oh
Hn7s9HRnPSz9kOcTlFRDsiql5DlHPRxUc1rWR0IvNIv6gVA9BCyUPn5sQnCE
VsigcT2IgMGM2DVCXzvQ0zitHmaX+yrLbqihfcnNOKncenhWoH9LPEINNZQo
OdvK6oGbS59P8oEaVh1vOnSmtR7olnVtZHLVUPoyj/u2+Xr4mKdNhiE1TKcb
ecV/6jWkOHQ9IY0S8duLJ57JvQYLDm1PxQk1XI0qPcGm8hp6b2nRK8+pYeIG
u3eeyWuosddUUduijqF95fETPq/hwR71Kp0T6jgj/e5hZMlr0OtpDe8RU8fV
3AhKW9VroA9TM9WTVseJ3wZWP1+/htAfqkv6yuqY8zBjka33NXh0qwgZW6pj
Fb3qKf+vr0H1hlK65S11pIHjvGE7SfD72+kIl/fqaHM8VuSYPAl0jK0DIifV
sXgoOixJgQSZVX4eBV/U8Vfr8PRWRSJ+s8xg6Yc6FjRGMrWpkiCd4xhnMK0G
SmcwnaXTJ4GGMntegogGtgvVsN+0J0FqzsmUKnENlD9l/jzZkQRLTPr33slo
YAyHG3ehEwlSRiIv8apooI1iz0SjKwkWPf/JFlpooMnDueNl3iRISpztar6u
gX6fGjqKQ0iwsLm9/ku4BvJ4We0Kuk4ClbOHi+mjNZDRgG9V6SYRP2Efb/BQ
A5u9/Wubwkmg1DRkM5angR63hw3i7pJg9hvp289BDVQxv37fI5kEYDz+Yc9b
DaSq6dBdeUyC+Ko//TLjGlhVba0alEoChZuSlSEzGkhz3nvbtXQSxHEUBDNs
EvPsi+00ekaCL9c6vIWpNTHL/6vR6+ckkP807Wi4XRN9xr9bC+SSIFaDxtSH
URM5VI4u3M0jwXQhr/ojVk3MyWJjW8wngdwukKnZo4kG6+JkvUISxPjZHH+/
TxPFgfVk3gsi/73/fipeTfTzFDxNXUzkKz9iPnREE+VZbaX7SkkgXpE+XXac
yH/z/P7ZShIIH82rUzmpiWMv/zD+qiYBD0PdeRd5TQxd4+tjbyAB7eBkW66R
Jlqcl5SJ7yMBler8E1kLTZxZqFDRHiTBWuWyb5etJtIl7/Tc+YYE88l0/N9c
NVFn+8+qunESDDgKh4qGaGLzMIvruwUSdFOkzBvCiLisz3XmnyRoUVMUNrqj
iRtfU5fMfpOgStBk7HKCJhbsuRHGR9UAT5b8pV/ma+LqCFtPHVsDuN1oWTw9
oom1ug3c4fIN4Pirt633vSZq4M02KaUGsHEZeXLmE7H/Gu9hWo0G0NOa07m+
oIkRVW66f4wbQJyNNbeZRgvp1oo3zT0bQDiMK9SUXgt9nlZ+/ne5AY6uHDKf
ZtZC6bYL1h0BDcA1KrmNbp8WBp18GNMU0QBUmTYO2ie1UH7rQfK5Zw2wvstF
ekxSC1eld08Kv2iAn7cuMHvKE/VZpsvclQ0w7Xaj7p66FtrsCBC72NoA3Sdz
OAdstZDyk+U489cGeNTws9/ijhZyfxXMGpZshLAtFS/77mshx0fPNDnFRvBW
vJKqlqCF9v9MmQa1G0GjYdVVPF0Lw5L2z6Q4NIL4lhq9/GwtLKe/LtDv0Qg8
ioHifPlaGLp1LEzOrxEYr8tzJRVrYYr6519jNxthlbT5j7lSC8fKP1+qvN8I
U1SvP4e/0kJRXba19seNQMbQrk2SFm5MjfToZzRCbahiiU+rFrL8tgrXe9YI
uSTqR3NdWmjSdVPcNr8RHlI1Bzn2ayHpQ9h1v+JGuIG3HN8OE36u6l9MrWgE
K9J24baPWug0efjn2utGUKPq2KXwRQsZY/V5T7Q0ghjeWSuf10L2HyOsDp2N
wEBibMn8TejHqH1qphD6r1ltgpm0MUjixwPLr42w//W+OxIy2hjzeffAdtYm
oP83dqFAQRs1Ko3nyLubYEXhiekhFW3EQ17y97maoLeeh5dVXxttfH5/mT3U
BMH1h6vmnbQxBdZ79kk2wUSdyPTTGG1c9HSxPWPRBE9rlZXYZrSRkndbuTO+
CQTzM7WPf9PGX5TIw1SJTVCctMVUZUkbqWTVKk48boLaK6/PXdnQRnajQCHv
jCagiMrdHWXRQacM0cz4wibYli02kimjgyqPglM9mpsg+kHsx1cKOii6z8Lv
SFsTsN1YnKUo62DVWKfY244mOHDmxSatHlE/pHH/WF8TSHIKHjrvqINjtI/G
r75tgnN3eb1ORekgy5lrlLfzTbAQGHpVJ0YHV9eURo59bwIf9w+hzgkEB8x3
Xv7RRLzfpz54lEb0uyrzanm5CRK3cFb/KdPBGc7ea2V/m6DDl4WmeUwH5cVk
vQ4xN8Nxu39JJsK62K5VZiwh1AxmlloR707pokWx3XVq4WYINUm44iiji6sH
OaM6RZphSOu4sbeKLkqfO31e+1QzhEiZM0Zb6aI3LeUrq2wz5IllrrPZ66LB
9Lawl3LNQDnxbSbJWRfZT0udtzjdDMf4b7Y899ZFOs0w42hshkGWouCmcF20
KZJbrFNrhr8M6x5a0bo4w/XeDDSaQWC7qnV/rC7+WjT1rtVshmubo1IfUnTR
PuHIQq5OM+SsHj7ikqmLVFZrblx6zTDw05v923NdXHyztz1cvxk2Fl5R+xTq
IkdYw67vBs1wdJb2x3qpLpp4f49ZNWoGo8+GH65XEf0sHl5wN2uGoImUHrp6
Yv/0wjvDls3QPyyWt6dDF5HtYlKOfTMENtmdFfugi7VTW6O8vZrhWX2uYfWU
LgqZ3J74ebEZyNW/AGd1UWDq45tQ32Y4XHyHW2+Z6GfdzFAb1Ax9KZVDbgx6
OFKxPkCOaob1R1uaF1n00DW6+PKr+83A/0Cn9OoePUxZPehY+aAZ/CMn793i
1cMYfnHfD4+b4dCVnRoZUnpIim26wVTYDHoXLSUFTuvhKvWXusiSZvDzyOIv
UtLDRS4HN67KZuhxlN1Sp0tw29upgNfNcFXfpWbkrB4W2HnsVx1shi6BeiGW
GKKfA52G079miBl4piCToIflXlZfftO0gEnQfQPHZD1M7BpveUrfAmN99j7l
WXroceHohOqeFli4srXWoloPfTJiFV4Lt0Apz3zP9Xo91ClovcYj0QJXOykf
8pr0MMh31jFVrgWoDjzbutmjh9ybTB/nNFqArUVDO2NSD6M9VXpmnFpg2Ouk
becXPRwb9ecV92iBxxxcF37O66F3qdLnJ5dbgN9jLk71tx6anJwoodxoAcld
90a/Muij0O/X432ZLWDpMOgmJqGPG+9vXAn52gIHGGoDrWX1sZZ26t+Wny0w
WZ51Nwz0UeDB6kTBRgu4010pGdbUR5+J82LBLK0gXGrX9E+P6HezfCGbq5V4
/1EfEjDRx0S0Sljlb4WgIo61ADt9FG+qluGVbQW03MKQdVYfPVKzI1dVWmHb
1lnuHld99LPS9trUb4XOggHhFU99tMj+x+lq2gr3zF7hwcv6aLIanrtk2QpG
VFlGGn5E/hbDg3fsWmFvXrTTxWv6GH2xoOX42VZI37SNaLqtjzZRJXxhHq3g
9FwteT5aHzUOHHotebEVjhmKFOyOI+pDeHHOtxVKs6jI51L0sf2uNJ1JSCs0
az/dy1iijxP24bRb41rhS9LMM5NRfWzmuKkmUNkKT1gj285+IOYpOG/qXdMK
ZpHHZi5N6eOvmblTRfVEvZ/7sdgFwh+X7XUsba1APr4y5LLFAPnFsxjt37RC
Ib2fxdPdBkizVaPi8EorRKi1zwhyGOCvO5InB9aIeW9w+JdyGeB8fcKqz2Yr
cK9XJTUcNMCcCw9SU2na4M7XtdEPxwyQA7tor7G1wbn2QFtuBQNkeTt+JUyo
DZRour89RQNMuZdalSrSBgeQO/i4sgFq6FV6vRBrg+GXtU9kNQywwP1adKV0
G6g83/xgYWSAEzE33pxVaQOe8BDHBBcD4v8j6KOKVRtsNPQtcbsZoEfrR6EP
Nm3wZvPgzazzBmiiPy9x6Uwb3PMlPS3zNsAY8fieG05tsOm05XN/gAFSQsfE
DbzaYFT55rmd9w0w0UmWvyC0DejCNWe7Y4l5208o0d9sA8l2Zs+oeKKfq5aI
w602iNVJuUSXTOzLvtm1FtkGGqYV16izDTBCONd1JK4NKl2+PFipMcCxbr0q
m6dtMJVTuKeizgC5O+acDLPbgG3uctJlEjHPhPlBfN4Gnheo0hZbDLBdVvQf
Q34b8Ptx5s2SDdB1vNn2TGkbPIjUJo1PG6CQJaf2VlIbkLpYlVO/EvHmD9Xp
DW2wwDTSYj1vgNHB+qdlmtpAK86pa+QHEa9wbLBubQPqx9eGBzaI89x9SNm1
uw1E3ytbxv4zwBmWrvkPPW1gd5B+TJ/aEA2ovu0z7muD6qcPP3ZvN0STWWdF
oYE2mP5s4xRFb4jy67LGcYNtwC5w6IsmE8GHtHl/UYjzdP/qRsdiiFWMO6sM
h9vAu6BovpXNEONh+lD+mzZ4suB74dZuQ+Tfm9O/a7QNukXll5Q5DNHvyfu7
9u/b4GhF+2/SfkOkudp/fe5TG4zXfaR+JWCIVB6RbTQ/2kCnbxdnkYIhir+o
Zr7N2A5tMzmFCorEfDYuC7PM7aBEraDUq2yIoUdkPKx2tYOUhOv5bxqGmGVb
wWrH1Q58j2vrjhsT8V3bFqmPtUNquaHRK1NDbD52iL1PqB04eqentSwMcUZm
6G2uaDswbWFlcbc1xPKtVVHR0u2w6uLsmHPOEBeznzEza7bD5dD1FSl3Q9R4
adxvodsOC0n3o9o8DHH18OWUMsN2+NRdXT590RBdq9ICUq3aoVds5/bDQYYo
YHL7tpZnO2T9rczPiCH27/1Ao/uwHQ5y6ODJB4YYJIDHuh63Q/LJjxRSgiGy
MzDInMloh/tODH8/JBti90TE+c6CdgjoPGNwINsQudtlX1Y2t8Pyp19Thc+J
86v89vJbZzt4b0b6n84j/LOfdD3d3w7OouWZNkWG6JFF0RQYbweDh3TLydVE
PotPnuRaO3QVpUYK1hJ+vkx6fJqqA9Q6xA7U1BviiKWClv32DpDbsFF/22SI
pNDasPXdHXDEsSRpb68hcvxhXr4r3gEbJ6wU4ieJesoJ/rirHdCh69xi9dkQ
51kyj2pd74CHnt46vDOGmJ6hcOh4VAeIFoZbvfhG+K21ftU9rQM2u2M/+iwa
IuXjp12duR3QOZ/iKvfTEBOpVU6alneAk1DZlfZVQr/N8OFiRwec1KnfvPeH
8PPML1HqoQ74e74jzPSvIRZYrSwpTnRAVxSFgXuLEdbuJ0UVz3VAYv6HuMmt
RujUOPhg6UcHOHfNcubSEnHOne45Kx0gNrecfmGHEdqkje48/4eoF2Qs2thp
hGHuEyH02zohUWuvZBOrEbq+WV//uKMTnNz56iLZjTDe5Fvmq52d8DdXumsP
lxHGTFN98+ToBLFjzl9EDxshVZoSb/bxTkg+Wn/QWc4If2nRzd816IRz6h3P
jisY4dQN7+4/Jp0gfo5yYgmN0ORwsoCdZSf0PpuVC1EzwpHKltf/HDqB+she
iyRDIwza5lBQdqkT3Pi9Y3rOGaG9auTiaGwnSKoE7o13N0KVrskndxKIfKfw
J1aeRihfolItnNQJKU9TCr5cMsJmq/BHJumdQObraN8SbIQp7clvOV90gjQv
3xbJeEJ/WMXiaRuxz9HI+98fGmHB+O6SxM5OaBZe3J+bZIQTA5MPw3o6wVC+
XpY7zQgZr77zx8FOcDe38qHOI/w9JJKtPd4JqXfjvvS+NsKczqUjbUuEX/Fr
vhGNRjhWUMQittwJgo/taZRaiH4lkycTfndCZY4wb0WnEW5wBvipbBDzNXVa
PR4ywqyz3TWa27qAep2699ycEQrsUjy2dU8XtFO52/AuGKHFyDu3jb1dcG97
/+zoohGSW5e0v3N2wb7dadv1Voh9s3YpNO7vAnFROUXxLcZI4a1hOXi4C865
XC6n2muMpBNtDC1iXSDsOapUw2mMAk9djR3Eu+DXZcX+y9zGqDLl6bwq0QWh
15kXpnmNcf7fhvBemS5ITsk/2iNkjCxs3hyc0AX2T9kqw0WMkT+LLvgudsGR
PH8VFDNGdjXmE5uKXVD2Ut2hTMoYR875Z/WqdEFA/YvvHrJEPwWXKFG1LsCW
3cFHThP52ourd9W7oHvgU3KSkjHSyYhlyWl1wYdiTjl+VWNMt0m75qvdBUv3
9N+9UDdGIZrYjHydLqD1vBUoo2WM0TdMbp7T6wJO7Vf7mnWMkXincLU17AKh
Yz9e6ekbY/EBTU5dE0Jv+1Gbt4bGKB/RnSVt3gUuTXEpC2aEnpDJIXrbLvDP
aJf3tyTm6THd+fNMF0SH/B3bamOMPImiw+8diX3k3PdzOhgjzXUJ2TrXLqAq
V3yifN4Yc24fo6v16YJdcVcVej2NcWytV7PnKuGHd+G4hbcxdjP9Ik0HdIGu
EOdBL19jbC6L1RC/TviZtZiWGGKM7VsmwlXvdYFEQlrGtwfGGLbQKhud1wUa
l4cU/R4aI7eS60/dF11gY8gwSZ1E+H087PD+0i64wXSVj+MJsa80y+xUdReQ
b+k9Vcoh4tzxzjydXeB+ZTPrUa0xLqZ9SQj41gXXTE6p8r02Jp6HB/JFlrog
Rsztc0GDMfpl+C8tr3TBywXK4cZWop+gyY6XVN1Ac67g2TyZ2DclQJ1tdzc8
MbfOUfxsjBzCrc4uikRcfrvc1hmiv3KDZ496N7jxlPU0zxrjakbXE129bhD/
Sv9TfZE4L5ePs8nW3dAZUHNa748xhtK6jF2+2g2iZ1zIzH+J80g3TH8R3A0J
ymxn+6lM0D4kK25beDfYM7pHmNCaoLd/CWlHQjespHIOWrGaYLeOTNyV8m6w
udHizM1uQvy+fbzxpLYbGlwurr7fY4ImIyTa6eZuiBbp2O/AbYJT2dEhQ0Pd
wNfg53ruqAk25x55p7TWDbpTbzYvnzbBdK6iLQ1qPVDafjNGAk2w4E9EFadh
D3AUihz6rWSCNsJzBUnWPXAt9l1FlaoJbjBMOCi69MCk722NAA0TpMkocmC9
2AMaVqfeyWmb4IjTnBR9UA8UKnzw3NQ1QfFAnqEP13uA7VAU1WsDE3Q6Elnv
EN4DftulHoQam2COoYTzwp0eGJ+bPKxkZoIeN3Inb9zvAWXyvaqtliao88s5
gzu+B3YmTb8PtzNB138jv8xSeyBL8KHAXTcT5HD4rlRZ1AP0zEqv9DwI/555
lyuW98CFn990WS4Q9UHlXK1VPSBbq3r5gQ+xjyDTo8qGHiDrLtclhZjg6lvG
7sODPbDhbWL8LMEEi2UOMnz/2QMvhPp+SycS8RF33tjfPeAwo5nSlWyCMVd1
GgT+9EDrGfi8mEbon9B4Ik3dCzF6glfl8kyQ/9OX+nfMvXBIiOoxuZ7wP0Qx
R/5YLwx/CYCzDSbosyLbLi/UCxFPlz8tN5ngYp6I1ymRXpjnmhPa12GC5Ykx
hTQSvVC5Y7jeeZA474GXBTLYC1pf8ifXv5ggfuau3WraCxuZR27fnTXBCara
mavmvVBkl3Gc5xtxH0b0BKcse4F9+KGP6hJR//mpTrZdL4w3X6eN2SD2O9qQ
132uFy5mmgseZjXF5t9WW5v9eoHfbqD35S6Cm1QuNAcQ83LqXtbaY4r2u1ut
6oN6QTZWqfbCPlOM1ruwLS20F2hCT+jVHDZFDdcvn3dH9EKi7dZL+rKmGLog
VTSb0AsqVKP7h+RNMXF0VSTsUS8sZhZ3WIEpko2KEjiSekF9xpbXRYXo985R
XyylF1YuVZGD9EwRf/QpH8/shczd94OoDU0x5aFdXurTXtCrchaIMDbFCbqE
iwzZvfBsky30gYUpxsw72b193gumEZ4ieY6mKOqprY2FvUB1XOWdiLMpjuSo
6t1/0QsFPVy3K86Zot/jv3yjRcT8u9rHSR6mWL7o7n+2tBeKK57cUbtgigI8
IXsyy3rBxsJXsvuiKXrLJNaMlfdCeSrfvTdXTHHqIauG2stesMc1GVt/U6Ta
9kDTt6oXGD/1fZ4MNEU6J4sb6dW9UHXrWaxrsCn+0rj0t62mF84KXDu9EErM
J8iYbF/XCzu7jL9evmmK8z8iesVIvVDjKZiwdovwvzLy7r/GXmArezNPE2WK
NH9PaN1v74V60xeJd+6aImO9vaBpVy+4r4apsMSYIo/Jbpd9vb3QcFosZV+C
KbI8P8pRONgL3u3R2mJppriRrLJ7c7wX+t4r5p0pM0XXh6w7KCu9EBDKYfa5
gpjnyy6xX2u9cOTQ9y3nqwiulCvav9kLwa4pllfqiPn0lUrubu0D4Z8rdHfb
TDFiQkZrhqUPoukKztW8M8Wst46OFSf64E7J6rar46Y4ZnDt2sjJPoiwUs06
9dEULTKCXOkl+yCsYHyiYJrwXzs04bFCHwQZsFql/SDmBbjvb9AHHolXdMK2
m2GQGjO7+dU+cFdsmkV6M/TW/BJ4I6gPXGeZIzcZzVD6Bq8b6XofOMnntlxh
M8OxX9U9PtF9YDPxTsFtvxlScbp8bs3sAx0BxZN6p8xw5Gd8iPZgH2j13+2j
lzRDSt5j3/q3faARMOrZJm2GJgGDchoTfaDSfTkPFcxwyv/mpYxvfSDv/ezQ
KU0zvOPF61hNQwahKoY9HGfMkOPgtkdzfGQQdLAopziYoSRL8/6FI2QQoM82
inUyQ5r6LQl/BcnAb6Nwn97dDNt5B2m0TpGBm+oi3aaPGSrVLW/eVyEDo8bw
+sc7ZshD6ju1xZ0M5u0/8i7cNUO69VNDmV5kyNRgst68b4ZO0konjC+T4Vu7
AENUnBlyhak6s/mRQVpT5RVHAjHPdMSziSAy3Ow4c/7ZI6L/OXOu+utk6NUM
3CeebIbkjIxi93AycHY+7GpIMUPZ30p/XSPI4KRVGqifZoaJj+NEPO6Qoaiz
5/j7DMKP3eSdl6PJsK719Z17lhku8PncCbpHhhhtHvnwXDNs5Ah59CCODLU6
9zZqy8zQ8d6OI3XJZNjek1ugVWmGcYblfE0pZDDSbbEZqTIjno/UPFufkGFG
d6P2Z50ZDndLBTZlkoFd3/2aYLsZphS+Sb6fR4bzhmp/H42Z4Xh/TZpmNRkq
+x1eHP5ghmZB6afpX5GByuiaXdlHM/SJeljaUkuGh0bl9b3TZshd82rPCRIZ
Go35Qrb9MEMDmaOTda1k4DL7++/SNnPUKSnqnB8gg/MwZzEVnTnG3x1NtqGQ
odhMwv4evTkKkLfmtQ2RQc3cg5TLbI5k9z8V90fIcMliNHSC0xzFPHQ+z7wn
Q6dV5RY9YXPkltm52PmFDOc+qmexnTRHryWjEKavZKBxfav25pQ5+sw9cdee
JQP4bkTZy5ijbGJxQvU8GcrvK+25rGKOiTCzZv+DDKnNvYKJVuaYYtyv+3WN
DLLa9j02tuYov8dpdGadDCP9Py7w2ptjo5lO2dQfMrB9YK/IczZH+/0Hg/s3
yRC+ZgV13ubY/ptpJnRLP3gLfzGeDDfH1qsX1xXp+oGpwm/lWaQ5TnSnyjDu
6Ic8Ofqk89Hm+KK+PXKQ4CmNE+O/YgmOPhlmydAPlmcvu25PNceVuUhalZ39
sPKVhqE7zRzHH/6Z/01wvPfDwphMcxzOYJfIZe6H3mvVS5w55tgp2MNKw9oP
52m0E8bzzHHhp1RNIcF0UWNSTwvNcSllfM6ErR+UEv8FCZWZI8+Rz4wpu/rh
w4HYgz8qzDHTR4BJnr0fgrL5GiuqzDH0HkPNW4K5hMqdAl6ZY+2v/fb9u/vh
Zanqdqg3R9zr9NJgbz+YyLzJ3dpgjn4ScbzdHP2w9NpVp72JON/15VoVrn4Q
6omKNewgzuvzNuWT+/uhw3i/+J5uc5yh2uh4dqAfXEZfDI/2muMRiR813Dz9
kP6lf58TxRyNjl3Yx3ioH3ZTczy78sGc+P34fmbbsX6gsvezYpwkzmuHzZmL
gv0wWzeyM3PKHIvZ3a5PHO+Hev+kqz1fCT7S+KtdmOj/g0uT/5c5mkmxbGsT
74eqif3z/XQWOMltm/JAsR8yFYLTzzFYoLCRbZ6Scj9Ep4ybbDJZoPtyRduK
Sj/YW6TVCewiODQl2EujH3aQee6H7LfA1eGoP6n6/WD1+pDYCTELZCvjjWM6
0w8q+8OmG8UtMM+pInCPQz8IB04lW0hZYMF2uozDZ/uBWip7a5i8Bf69FTlr
dq4f8l8cGRpVs0D2S7R3t3v3w0bqMb8Iawuk3St6ovRGP0z/iRQ6YGeBFLnK
2aO3+oFsOTtRZm+BdOzOvNm3+yFrd77mB2cLVHkloFcZ3Q+6d4X2SXpb4B2b
3UySj/rhSZBI/acwC9SJncmpL+yHGw1z/h63LXBh5aXD8+J+cKbNkViOtECz
XtNniWXEecXwFNLet8CchUmhhOp+qHnKmnIsyQIrl+W7V1v6Ybjzp/+FQgtM
trC1Dpkg4szFEqtFFjj6w4d241M/pJp4/AgttUC7bKaWG1/6wWl8yjXupQXW
nu6YfLFA3I8fQ+YVDRaII6UBYZv9sJOzSuLPkAVO9PzVOL1/AJZsfX7cHLFA
sa/O7ed4B2AoU7SQ8Z0FDoSnsz05PAApQrn8ByYskEPkbLCw8ACEXnSeeDZp
gZ0FJu8ixAbgbCVvishnC5yKm/f/LjkAgpi8S3HWAj2CJ5c+wgDsvGXW1zFv
gTMruXReKgPwo4Mtyug7kV83O0yrOQCUnX1q734Q/pQFBRboDkCVcRS10y8L
dL14bM8ZI0I/Ub1+fsUCZfWO3fcxGYCQ91sDfNcIvx65fbMzGwC1c0E/wv9a
4BE++gU5K0K/QLqQeYslDld0FQrZDADTj1+uiVstcXW37sB+O0IvwHMil84S
bxxiufvXYQAc79n1dbNZ4i9Rim2eG9G/AgvZjlqih9HappXfAJRTXbYeOGaJ
fHcPsSgHDMCsdvaOOCFLVJCjcTkcNABmkztcWMUs8Yhs3IORkAEQYh48wHLa
En0Whu7+Dh+AUVfnGCZjS5T2Vfu+J34AWMofKfSYWmJMdXNoegIx/7+O+WgL
S2R5O2fL/2gAShKENRntLLHbl0ZiX/IARDT+3sLgZola1Nxb2tIGQJL7zmW6
EEL/y+6ww3kD4HGulrf9uiXqzPuqWucPQGbpQt/tMEucqLhqEV1A7K9pLLT9
jiVx33sqJ14MwJQv8c2QYIkmRkP8JmUDwNWg96DlkSUKubOquJQPgD7jdcVb
yZZ4iXZKyqdiAGoyP6fSpFviEy+/dzdfDkBs3wuzrfmWOPB4rvbyqwFo5fpI
01Roie4H04Vcagdgw3lX2Y1iS+SSLvpqUjcArhtXmakrLTHFi/P60dcDoHBM
sZ2qwRI3/iUUZjYOwPyNQZm/w4Q/13jcN9oH4EI2Ze3eW0ssVnG1LOwg7mfb
UPXBMUt0mXchWXcOwG/GERnFj0Q/nTWukq4BoH40JhM2Z4md7gXboXcAwqrf
r7EvEPkJwxVjBG8fG6/OXrTEddedfH59A8DI+1GmbdkS9cjlZjnkAbivPLlm
vmqJ5WqCoqf7B4DN5VP1zLolBvVXfO0jOD5iyt9/0xKvUMVF2g8MwN78zzL0
VFboGji95zvByT3Ta8nUVsjWHJAcODgA3Itfqo9vs0K9i79FzlEGII3tq3/t
disUD3r9s3ZoAPgkZmV06a0wiMK8j/nNAGSZz629Z7RCyTuFwXYjA3A0YL7a
i9kKJ9K3jOa/Je7T6wWZGHYr7F4J2VQaGwClwd8ye45Z4U6fPxml0wPQvLy6
9uy4Ffqk5XPSzQyAOsd6tZSwFZZ+fUNt/3UAdGw3ZCxPWWH5ytPRvfMDYP6F
SjbltBWq3S4LzP9B3J8/O2T5jKxQp2hEJGBzAB4d4pYVDrTCSjsnQXGOQfDQ
eTC/fM0K/y7ImwlzDQL60qfVhVohnfhXXWHuQZhtXd2qG26FlNuMU8AzCAru
Qz3nY62w4MXR2/kCgzBVfM8h97kV9vp/6yuTHYTqt9vYL+ZZ4dgppy6204Nw
j/paq3ShFXEf+PP9YBCkTc4fby+1Qum+cAdLlUGI+q2+PF1nhStcBa+99QZB
TGFLJD/FCqcHgo3onAZh+zk/uflhK7QfWUofdxmEsfvfv5W9Jc5Hjp+lzm0Q
wj++N1L+YIXs6m+exl0YhLdhNdyOs1Z4afng78zAQQjtulycRmWNtXWCr88n
DILpr1nHc1ut0Ulv1aA3cRAE9zvuFqG1Rva/TK6yKYNA8TIIqGewxocJKeEi
TwfhKNsJlfd7rFE+k+1YTMkg9FpMv+E6YY1VtFtckDwIKa7VsUMi1vgr/fPE
KcoguPtFa8eIWSNGNm4XGyHmTxR7vU3aGv++9avRmyD8fRP8bFHJGgV5b51n
/DEIO78Y2uerWmNiQ/6G+TKx3wo/l4uGNdaf4t1atDYI/nu67r7TtcaaHwXD
IdQUKDXd69tqYY1P7BTPFbFTINR5Vvi6tTVOP1y4ZMlJAT3fuhk5O2vkkHJv
Yj5AAe5bMZkr9sR+pu6XB/goMBd/1qbk7P/Nn52acZQCNVmSezxcrHHKgWxz
TYgCEeU7yEfcrNFle/X528IUMGsei/x43hoXukdyr4tSgJ9SpJziRdSf++0T
LEaBpU83Ns0uWmOo5u3CIHEKkH6avmT1scYJuWzjQEkK2O7aELztb40D4us+
V2QpxPOtBtulMGtcHDpsYahEASfHfd1Ct63xjswlM1ChgNilhVtfIq2x0aCO
8ZgaBfpi49ds7luj3pYc3wVNCtD1T0yoJ1sjV/BrJTlDCgTo+xftL7bGnBc7
tzTZUUDjjI7bSKk1iu6TDbK0p8CeCwcPPaiwxhTVgb2zDhQou9fykO4V4W9H
VvuaEwXme1iDf7ZYY5B+lxTFnZhXJ0+n4x2h/3vB+bovBfxO6XCYjlsj4/1P
xnlXKBDPtfBpYsIaXxwpmu69SoHOmZOBq5+tkW048hRDAAUkb1XnHl0k/Mqw
WzEMpoChh7Vv2ZI1Zm7efGQZQgEP402EZeI+vb2tZxtKgae8iiNm60S/4Tlx
yxsUYKlvpw2nscF4LnlH/nAKHM92H2DdboN2lhEiO29TQC2a8UnqDhukF7QO
/kXwNSsDiYqdNpjjzUmpjKTA7Mqbs1McNhjc8rVu110KNIt8ISmdsEEjv6Ad
Mg8o8GFPZHSviA0KH+vJXiR4fVPQwkrMBn3GDEKz4ylwstvr+0UpG6zPZti7
/SEFnriu7M9QtEGnr1+/5yVSoFo/8auQCqFvJZmom0QBiqRsRZWaDUrS7ev9
RjD9tmAdsrYNJp8k7Tj6mAJXM7YF/jMl+p3iL7+WSoG4iOdqURY2KCjS2Mb0
hAIvLmiy7bW2wb+fDpU8JrjDbO59pq0N8tf2+x1No8DU6bu5wvY22D3ZyF9C
8D9+Ed8aRxuc939eJ51OAS7GflRztkGe36U69QRL/LzEOHDOBu+RjEbbMyhg
MMo+Yutug5MhIbZMTylwvqHy6VcPGxxzZjbQy6JAeI7FBd8LNjh1qvtCdDYF
6q6k0N71scHFuXkSdQ4FBHfxS9QGEyyVMfS5gAKJVPI/g6/boNWjGhuZFxTY
tmBcohhmg8WOW/rvFlFgov3mibZIYj7usDbZUgokBH86PBBvg5Q631/5LylA
NZu5ZybPBjWcG7VZmyjg9aaGkldogytxQhHRzRR41zwQ51lsgwccRzUZWilQ
mUbN/LPCBgPM5bN3dRDzmzpu/0uyQXYNT1/DPgoMk3hXd70h9tdgv3x3jAIq
L2Qqh98S/kbgN/VxCpQ8NvRJGrPBArmFFtoJCkRfub54YJI4D7hPiv1EAUWh
jzPHvhH9+Fs5xmcpUPAo/S1stUXSsLy61ToFbnodfHVexBYFaGVDxPYPgcIp
2qh/J21xtuXgT5eDQ7D6e97qgbgt6n0Pv57OOwQe12vWa2RskV93K+ehI0Ng
Fm8qS69iiy78GfbnRIZAoCaqOseCqJ/PXFtWGoLJ4EuR8ta2WDxnK3FddQhS
lS0tyba2aHP7w2k2jSFg6zmy9tvRFlUkD31S1R2CPx8apNU9bbF8hJ/0y3wI
eretvvx83RZb244eD/QagojO8dv+YbbIlnTjpevFIVC+32LOdNsWWYzs+2x8
hqCK48Fv8WhbHLm4PmgRMAQZx4Wlwh7a4pEEj8yM8CHwMXSq5Mu3xYdTRx2v
pw8BVyq5/AyF4ITFiqG3hJ7GrujpYaI/Jt5Ofj8EN36ZnvV8a4t7Witlz30c
gq/a71gDx4l59tEFcHwl9NY/ez2csUXG7x0971YJf54JqO2fs0Xuqyv7Pm4M
AY/R+f1Z32yxU2OtfIFqGG7nLnaVLNniGDPXH74dwyBreuqp9LItlq5WN2gy
DcMC1ZWA179tcXI2kdafdRjMLP4I9GzYouhkhcIPzmGgp1GgMvlni/WTzdqy
B4ahvij0zegWOxRYPxptyDsMl6ybXjjQ2CH5e/7MzkPDcHg7bfgMrR3xPC1p
18s/DCOlGrYXdthhs8Mh+vtHhiHaLkp8hcEOEz8r8xoIDMOvCpZPW1nt8Jc/
dJKPD0OOg3HNnV12uDM38Pj9E8Ngw/QwlnWPHVZNrN3VFhmGJqd9eHCfHdo/
ks2pFRuGuF1HUmUP2+HftYnCKzLDoPba1afhqB22H/bS2Sc3DOvu+doagnao
ZZgf+0p+GBwaRddNRexQg34pcgGGQfSinPlFGTu8N76hsU9tGHp7DVhzdO0w
yOte3C3DYbgR8GBG2MAOGTt8TcaMhkHyyPDrCiM73NN1n1/YZBhSr1l7NZnb
oZ06B0uT2TB4CLl0jTvYYfrlcaUy62HYcSfw1u4rdrjAKLby0mkYdsqL6w/6
2RHPw/ufv3MeBvaFeY7YQDvkKBm/vO4yTJyfXQHjdcJf/qS8Y27DIM2lOLg1
2g7n7dTuGXgOg0L3WkrDPTvsdTU7qO81DCrBpS4hsXY483rTVvPC/9dQ2UdT
fcdxfCjuGTPZshLlrrrjjrBukanPZ81qbCc9yT3Y7/fr4WyJ7KTrYeok8nQQ
IaQx11PjIqHGHbKDbJmHzo3vVw8z6VbMQ4cZYx72/fN9Pu/v+/v5vM7nnA+B
/UMb5+ezODQvHrVxPEPgpEpfPFXAYU3q1896FASC/Jr/qirmcOatGy2VIQQU
xuG3T//I+m/KfhQfSuBi8MjekQr2f5H+sEM4gWyXzqDBOg6D+9xc5OcItHek
NXZ3cejmOasURRHoPO8Rl/yA8SmdenWLac0Wvf0eDzmc7233OBJNYCBd8fxe
P4cyteO1a5cIaN3sKi894bDfYGvuthjC7suL0E8GOMSCDeM9TM/4eL/Z9JzD
K8nJJQuxBBaMTHojXjJ/seXm1DgCus2/5TmPcKh7g7PaEE9AdCbqm5lR9t4h
XVnBtPFGF8fbExwWli9WOyUwvn1T82cmORz6sPHfR0ybx5e32U9z+IakUCRN
ZLx3nEgZn+HwZUC0Z0gS299RC3n5HIeNgUnNjckEpHl9Yv8FDqW9XVY6KWxf
PFNGJcscLmjDNn2aSsC1dvlC4QoeY6SdYS1pBA6fGyrJeZvHdm7V7oYsAjGG
pX/Hb+bR6JC6o19JgF617zGz5tE5NG29cSHLX1+nKpHyeOvXqsOfFRF44NB+
tNWex3qV+I66hMC6I9qepR3MHygxalQRqFFaVYTs43FFcG2+4x0CK6Wl8SsO
8OijzMpP+omAvNb+eMYhHm9ez3IdriOwdG+XebWc1Y/b+Zf9TMB91C9h7BiP
M1rpni9/ITC4LefE8TAeQ43Ex9Z2EtjabIVT3/F4ysjaWtlFIO7z0nVR53nc
P+k1ZtNDwNa3TvNDFJvXtDx2j4ZA2MU+fJzEY+OaiZzifsb/91WWB5Q8Jg/d
d5p7QWCnkNi36z6rJ9wts9WjMFZr8HhtJ4+9nXqB8pUUcg1iB6a7eTQOy9Qk
GFCYvxn5StXL44XTL6pmDSnULyrmzAZ53B5olme8moLse97y9QzP7odWz8aa
gnbiqbhjjker/wrsiqQUMnb7SEoWeMxS+iW+b0dhTqHKttMRULtXruP4EQW5
RYnyub6A6zWi8cuuFFYHXK/xNBXQIqJswvMg6+/dR7Kmd5g/7mGl2ItC2933
6qSrBQw+2+I0501BYZrZsHKNgGaXmzTqryho1KltDZYCRuzrkkX7U7giiiUf
2AgYbjy21TmawsmaVnmmVEAu8YAsIJYC+uk+0bUV0EQSn1ecQOF1VeSff2wR
cPhotUaaSmGfd8Rwhoz5fbyexeZSkOioT+lsZ3mtPTieT2FRNTsW5CSglWhJ
7ltEoWJJMenuIuDVLvOnX6goxJTWnq37WEDzIl/f7koKfgen/tm0U0Dl4nSD
dzXjt+AQnr5LwBgDE9HwbQqGN76dXwaWN9rnHllP4X9h2UQw
       "]]},
     Annotation[#, "Charting`Private`Tag$38295#1"]& ]}, {}},
  AspectRatio->1.5,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 22),
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
    None, None}},
  FrameTicks->{{Automatic, {}}, {{{0, 
       FormBox[
        RotationBox["\"2020\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"2021\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"2022\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox["\"\"", TraditionalForm]}}, {}}},
  GridLines->{{}, {{0.5, {
       GrayLevel[0], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->200,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.793469805382372*^9, 3.793469814661562*^9}, {
   3.7934698453928432`*^9, 3.793469972008574*^9}, 3.793470241244164*^9, 
   3.793470314282918*^9, {3.793470508631143*^9, 3.79347052367684*^9}, 
   3.793529281349784*^9, 3.793529765439126*^9, {3.793529806711815*^9, 
   3.793529925814185*^9}, {3.793530273914832*^9, 3.793530289149942*^9}, 
   3.793532166875166*^9, 3.793538247077958*^9, {3.79353886239925*^9, 
   3.7935388963270607`*^9}, 3.793617739231846*^9, 3.7936286879447117`*^9, 
   3.793631367853709*^9, 3.7936321388044243`*^9, 3.793632435674089*^9, 
   3.793632615644248*^9, 3.793632897162451*^9, 3.793633150669476*^9, 
   3.793633212668477*^9, {3.79363383245334*^9, 3.793633838754334*^9}, {
   3.7936338809697847`*^9, 3.793633965077063*^9}, 3.7936343846799917`*^9, {
   3.793634829758572*^9, 3.793634839810528*^9}, 3.79363514176517*^9, 
   3.7936401184643097`*^9, 3.793640224229719*^9, 3.793708897727332*^9, 
   3.793709014263481*^9, 3.7937176825615053`*^9, 3.793717910848081*^9, 
   3.7937181828731213`*^9, 3.793718274495146*^9, 3.793719546555455*^9, 
   3.793801399505114*^9, 3.7938014800054903`*^9, 3.793801576092574*^9, 
   3.793801643367606*^9, 3.793801748128078*^9, 3.794507035064093*^9, 
   3.794507503086135*^9, 3.7945075493943157`*^9, 3.794507668563439*^9, 
   3.794513118312587*^9, 3.794513185342229*^9, 3.79451503881774*^9, 
   3.794515323093136*^9, 3.79456865761374*^9, 3.794569022530732*^9, 
   3.794576701556452*^9, 3.794578158571226*^9, 3.7945784447903643`*^9, 
   3.794579376025532*^9, 3.7945795055360317`*^9, 3.7946572425164633`*^9, 
   3.794667532663192*^9, 3.794667829442233*^9},
 CellLabel->
  "Out[925]=",ExpressionUUID->"00d87568-5ee7-4b24-a973-79345cf20653"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6E.pdf\>\"", ",", "figcritprevbpnpiimm"}], "]"}], ";", 
  
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6E.png\>\"", ",", "figcritprevbpnpiimm"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7946674392113*^9, 3.794667465620894*^9}, {
  3.794667814500577*^9, 3.794667816490932*^9}},
 CellLabel->
  "In[926]:=",ExpressionUUID->"c928ef1b-c4f6-42bc-bcaf-c4c84fbcfb9a"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7946674392113*^9, 3.7946674579238234`*^9}},
 CellLabel->
  "In[927]:=",ExpressionUUID->"8522c31e-3366-4b0f-b841-f69ee160884a"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot the continued rise in ICU cases after implementation of distancing, with \
prevalence, with seasonality: \
\>", "Subtitle",
 CellChangeTimes->{{3.793445775253668*^9, 3.793445791735546*^9}, {
  3.793461803106874*^9, 3.79346180437956*^9}, {3.79346302353588*^9, 
  3.79346303274085*^9}},ExpressionUUID->"e218d908-726c-46c7-bbcf-\
25694d8b4e22"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sf", " ", "=", " ", "0.02"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prmax", " ", "=", " ", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.793446122258461*^9, 3.793446135642728*^9}, {
  3.7934618271568108`*^9, 3.79346186369106*^9}, {3.793462009540318*^9, 
  3.793462018321295*^9}, {3.794657250458308*^9, 3.794657252261651*^9}},
 CellLabel->
  "In[928]:=",ExpressionUUID->"af98baf8-cda1-4cdf-bbb2-40a61d5ea2a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbps", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60bpsprev"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"10000", "*", "sf", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60bpsprev"}], "]"}]}]}],
      "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", "sf"}], ")"}], "*", "#"}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"dateticks", ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
    " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Critical cases per 10K\>\"", ",", "None", ",", " ", 
       "\"\<Prevalence per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", " ", "Black"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", ".000089"}], ",", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevon"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevoff"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7934461917708607`*^9, 3.7934462838598347`*^9}, {
   3.793446322446604*^9, 3.7934463225391617`*^9}, {3.793446417493855*^9, 
   3.793446493716259*^9}, {3.793446527768334*^9, 3.79344668076748*^9}, {
   3.793446762278329*^9, 3.7934467828855133`*^9}, {3.793446951803142*^9, 
   3.793446955141111*^9}, {3.79344707334725*^9, 3.793447099371722*^9}, {
   3.793447159075315*^9, 3.7934471754116783`*^9}, {3.7934472158450813`*^9, 
   3.793447223477141*^9}, {3.79344729650998*^9, 3.793447304161545*^9}, {
   3.793447499123787*^9, 3.7934475264506483`*^9}, {3.7934618795755053`*^9, 
   3.793461889980399*^9}, 3.793462004628837*^9, {3.7934620364212713`*^9, 
   3.79346203990898*^9}, {3.7934624225659227`*^9, 3.7934624372262497`*^9}, {
   3.79346305953295*^9, 3.793463072999475*^9}, {3.79353861265899*^9, 
   3.7935386178457613`*^9}, {3.7936321802253237`*^9, 
   3.7936321810634003`*^9}, {3.7946572590556517`*^9, 3.7946572603428297`*^9}},
 
 CellLabel->
  "In[930]:=",ExpressionUUID->"2288fb6a-69b7-4b2a-b6ee-fb8a2ee92054"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEl3k4lO8X/1EoKtJKJdl3su/n2HfGjCS0yR6lRVGJIkVSSgtKlGRNKaIk
ypJdWWbGvs4MoRKyFL/nd12/3+c7/8z1vu77Pvc57+d+nvt1drkfJ3tysLGx
HeViY/u//31cyu3ehtUGbP/vx5fbOWHmlw7/X+ez8x4V8nvznw6Tfyqz0q/y
P800/LFq3rftP51sczf4t+/wf3rGweflT9/p//STNgebH74r8f/rD70HTxab
bvpPc3NPh5Qn7fxPG9S08Jl+/p8+czXvWe33/+mpiNc+vsIi/+lDKwMSTh7/
n9bn7P8euX7Xf3qWqzopa4/of1rA+83Id9//aYWaJ8qKF/+nPa6GVRdk/E+3
cmtPvf/zP/1yVa5lU6LYf7rBJymB/8X/NPPLtT7yp/9p4WjPIOrY/3Ts6p1p
/bri/+lM37XjoiRxzNdd7m2/rW7wuXZRw9NDHNsux7luuFlg0Cszdul5sDhm
QSm55MiQwUI0rWE0VhyLDfwej+5YAZvHqrfIp4njy/Qln+FtQqBiVeh+rFAc
lRZ9Xby/yYNd9tO8l7XiWPesI98/VRd8eW7PTfWIY5Dun6jts+aw+ZEydfy3
OO5Di7j3XI5QqdRcyFgtgSu37axVoxyEE58CEvp3SuAXkqpLnJE3CO9Zc6pT
XQKTDkWnDN0KhHpmtkObtQT+80sKfdB4BoLPWSo3HZbA+jKPHWXhF0FiLWvd
l7MS+DnCOvUWIwK+PY6aqLghgVes3AqXPKMhTEWi4f1TCYSlDytcam6CfNXn
7MISCSxcP2jaefUO0Pe6R+c3S6BHnv5cYep9iBpj88kakcCzIUdbDBUfgmro
Y7OnixLY9eBMX+v9VOjnM5B4tF4S3Wjm7GkOT0FH/fzgLX1J1PH40th1NAuY
NYIVMRRJLJnSunq4NhcSXIofR/pKYrznD2kZhZcwGTbjFnxXEsNsedgqud9A
skCC7skcSfSulprftbUILJ6pCPlXSKJ1LSQ/NCiGp3XHqQcnJDE7KcvGsK4U
SPvXFe1bIYX5Uodjnit8hKUfuQkUQSkUytMM+/q1HJw3jTmYm0rhfIvupVXu
n2HNIY8GxUdSOHN0xJLe/wVKpjhypF9LYZSnVL4euQ68rqRFi9ZK4QsFZdut
dfVQnt1rtnlGCgWcHBwEGpogaMa54p+NNIbtmHtJifoGvTG2RQ1/pfHcq9/X
i3/T4PqO8YRqARl0bkjLsSijg9bLmFPl0jLoOPSNbT6qE2631yi/cZRBxZCu
gWPru8FcxCgnOVcGV2jdip/n6IPpgv7ou59k8Ka11P0bRX3wxDTM5yZNBqUU
w7W2qPbDX79SiYiVsihRG/jsVHc/vCzUSPVzk8XV/KrxghsHoYrDZu1EoCye
uviGTtk7CJ32h88dvyKL+08+avZ5MAgrx647nn4hiy/+fupatXEIBDXTKmY/
yaLA5zXd1+2GQDGySDGEKospwYXvO6KGYK/wwKqLbHI4IR3xrOznEPgfnQ1i
2ySHe0y9SK6iwxBezDt0WUYOV55VNS5zGIZsssaHq2Q5HKzm/dGXNQwfH1vL
8njLYXvf26yn34ahbfzQ/djzcuhrX7ygNT8MS1HXT8Sny2G33vaZ7zACG9pS
ezeUyGFzYNzJDYdGQHpXkfW9RjlsWp5S2HVxBPSP1RdvHZTDdZeUdbcnjQD5
fb9E8qwcLpl2lPK+GQHvVbO3d/DK47MivabZ+hG4sIeXLXWnPFYI2UcOD4zA
rSciAaJq8rilxZq/Z2YEnv1Q70y3kMdfsyWDLG4GvNOzNpfaL4+//1Qd5d/K
gKboQ2+yThDrJRMmXSUZMNQRtEs+Sh51dkVbtqkwYE7setyLJHn8cc245LI+
A9aeSF1UzpdH/+XD5wLNGCBaVujz+rM83s38/DzDlgGavPXt6jR5NM1/c0aR
wgAb536j4nF5dP6reWX9XgYcfjaTr8OugL1Bqqf27WPAmSmeHR82KWD/K9cG
PhcGXAeRGJBVQIHosX59Yjw1Vv1PhYECnnv40nHCiQGFdCsPE4oCBp8Na5ci
4tdJHvpa7a2AR59Jr/9D7N97KsjA8oICCtbRX3qYM+B3eUxO/S0FdAryng0B
Bqxal7rV7pkCdocu6qEGA7a7Fl5pKVHA15VZbBVyDNidWTdFblLAEdmoD5wi
DDCb6TvYPqiA5+PTf2zZwABXo5mGvX8U0GHL20w2TgYE3uTR6eRVRMHhiWdf
CL+TZNQ39qkpotej1fzb2kYg/4zVpcOWirih1b35bcUIVH4+ODm0XxEZnhOy
zi9GYGJ/zBdWlCKKX36m9jlyBPB234UpmiLuOjlbpyQ1Anv6pkdPTyii6VNG
bOPaEfCT59n7h10Je+waSl/8HoaEarXdf2WV8Ohl2QWXD8PAXIge4QxVwrtl
I/MylsMQd86eAXeUMKx9xYCw9DCoLWxkhmQpoUBLVVUIF3G+5x+zJtqV0H96
35vIiiFY+7dzxm+LMvL982ov3D0Ezxd+zpEDldFF/PGFfLZBOPeOMn/8vDJm
8A698KEPgN25ovnYKGX0P+oq/vvVAEzPn1+ofqiMqSb20TfdBwDnuf7q1Crj
33b97guf+qHzz/ZlUdHdePqTmKY9bx/kvQ1bBoXd6HSY8vRJWS+Enx1cdtPa
jbSkC+WdJ3tB6s9ztvt2u9Ekf3ZkT28PnJ5V4eA9vxsvbtpoWfGZ+L4U3eWQ
jtqNoyV1/NfDu0HozByHafxu1OoVGWsz6IbymQ8rwp7vxmWzOSfh8i5YO2PB
+bt1N5aUb9Wv7+iE/jc5nPx9u/FUa+uuntROeHN6HZfC2G7kvXYnudy/E1ym
W7m82VSwxSti6waeTlB4o8EdyauCGeHhEzFddGA7ncidtlkFj91x0Ge+oEPG
7wOruuRVcOhFVKSTKx1CXlesmtNUwatyNhEBanSwOSW+epOxChZkeOkH8tFB
RPXqahU7FTTQymMdGKfB76nR1fb7VPD4dMAH7XoaVBfY8Ph7qKB+TrUbWy4N
kk7m80QfV8EZ8r8Hr+JogFOneT9fUUH6Z4fupn00mLc1l8m9pYL9ThUCaUY0
KMgSNL+brIK7l4LtTRVo4Mc57nExQwXvTOYqlgjSQOxw2WXvVyr45YHv1Dw3
DbpLb6WSSlWwV6C6d+UcFRK2HinTrlFB5km6JnWUCran1btFv6ng6229pQE9
VOBq4V7g7VHBtmHejMpvVCiT69wyw1TBny5fX9BqqXD2aq5675QKHvLOuZPx
iQrKQxcpNf9UcMpCKV/2AxVYBg4nXq5Sxakbi28OlVAhLUnsZuIGVSziSuw2
eUsFl9mZ3MvCqmh4X8y9tYgKAuQvdUdlVJE6pXBwVTEV6vOSWI5qqlirfTO+
7x0VIlcHcBmAKho7u047fqSCnieIS1mp4rH7j656VFFhpny9Ef8eVRzZcdeE
p5EKL7YPH5w/qIqmerWrjDqo4BVcFDrop4pa3YPl3ANU2Nl2Lbk+SBWDn/xy
3TtBBZqSa8mbcFVsU+z+Kr9IhVvXFaiPrqviXNIv9UgeGlgyl6ej7qni4fn3
Mfu20YDD+JtAYJoqGt3m+ppJ+P8uJV15X64qRusc33XMkAanFs7YGb0l9tsf
0vDMiQbyTpb+cp+Ielxi/loH0GD41baYjY2q6Ch+m+52hQZOvuVVjEFVlOcQ
EntZQgO+qttDzROqqDwode17Ow2+iHiyl8ypYl7ZZaMI4r7Wpq3Wv75ODfvC
hMZKVOgwpdrtclpQDf+k/EkiO9Ih++aL4P3iavg0pa9G5ywdtptT3ijpqKHP
YJn9RDkd2p9IfNtqqoZfz+ZdfcWkQ9zSnx/sJDUMvnV3ppivE5YLH8q1earh
ukiW0pUjnTAozngSHK+G1V5GVV8EuyA5vLj88EM1jPpnEepi1QWO3TG9Vs/V
8FPgAYVtF7qg6o6S0I4PanjEpd9JZKgLMjlC4itYavjZwCb7X1k3BPTzhvOg
OpJlI39l5vaCS6LgiKaVOmZQi3iaxnrBjCxl5emojg1Z9/4My/SBSKXRxnIf
deQYmyoeye6Db89DMoPi1TGPV9CX360fNI4zW/oH1XHyaXbVpbABEJWeUV83
oY5Xr9fJcGQMAN8AR7LuH2L9WSv+uYYBYJGFPe/xauC2nHBJk+2DkKSxZ95a
TQMN8mjfD5UPwvK/T7veXtHA3T2OS2nCwzBe1BI1fFMDj1/jf2dhMwy0473f
1ydpoIWx3jqVc8NQMDBf6P9CAxVjzF2DOobBo0rZSpSqgSedUgQ44kaAdNEg
335AA62S279sfU/wgKbNxtDvGvhrqUEoizkCm7O8e6nLGsgU1z7w1YABX2JT
Tt6Q1sTExKby3EEGvDHNpb5T0cQ6Ljbq3CompC2V6LH0NDHN6zOJT5EJ5wLb
uYwdiHEecNt7mgleMkNHA1018fqtc5+O3mUCZfBnyyNPTWw9AnbrCpkg77gm
eS5EE/+8Xdnf/IMJW9cKsUlGauIva9nlLh4WcFZLeVLiNDEjV8zFTpwFUxfV
68IfaOJFnTsTInos6NU0VnrxRBP7Jt267MgsqP9JSujK1cT2F5NmrV4sKM46
ML/qrSaqLR81zA5hQbq7/wGNCk3sntxT9DWGBfHbzn0+Uk/sV7Kq2jyJBdUT
B6f8OzTR4b2XqUgWC/5+NN11ZkAT19/M3LxQyILdt+VIYeOaOMZQfNxRzgIv
j/Vh1/5oorXbDr+3tSx4qPEnL55DC8cZPU2PW1jwdVVPd9JaLUzWpDgktLOA
q+sTb/pWLby5uCk8kcYCvbxMnTwxLVSPf9Hwhs6CE2FxvkWKWqj3YEXDODGe
4XD6wUdtLdR0dJS06GBBt5hLzRcTLbQ+ZLC66SsL1s/C7Fd7LSzfM8yKqmeB
2RcJiS4XLSxNUPE7/5kFF5J4HYc9tdA/dJPKmxIWvPL/dXkiUAvdXDk36bxg
AcOA+mr2vBZel0zn3pLGgu3rP/QvR2nh3E//g3tus8Bh6Anf6tuEbu08sXyJ
BVGF1wwEHmmhs4Lc4Z2BLCi9eixgW6YWlpwxjf/oxoJf+xwfir/WQs5Q+VXf
zVkgKa9Tr1CmhQyRVU25uwm/WzhlsE0L23cPFQqzE34/+b7Xsk8Lj00ZNw4z
mPD39Nco8pgWpnsnWwXUE+dH8NGwB5s2jlWHlv66xQQ9d7XUaHlt5DFp/7Cw
jgkn1ISab2tqo6CEfQTXOAMyuNiWko20UXm4wE/uCwPW59S7vnDWxi3fJJ2/
hzKA8dt9S2ukNnrKT5xy7h+B+Cvxcdt7tNEhuPaaevQwMDInL+Tf0MFDzTFf
I54OgD2N7/ff+zpoZBb2b/LsABRz7/a1eqKDpzz2Hb9mMwDXvU7tGSnSwTvO
m/NPzPaDsvicwrZ+HUx24ThoZtcPiRTBdJ8xHTwzlkW0nf3AEaEjVDStgwIm
qa/T5vugbeACl8NqXaRtjgz749IHIY/Z+6JUdPHhOo1nDvK9MNgkuqdNTxdv
7tLl5BzuAZsl4/pd5rq4t2EoSepRDwjvj3pb6qqL30XzLQY29MAnId5bU5G6
6DBIIq/d2A1yVvJceFMX153c+1iC1gUJIbYXbiTqYoLW+lTmoy7wpt30kX6h
i23lIo+DFbtgzb2NhgeounhjU/uRnR6dEFSl/jZnQBd7fuWXd6p3Qu+0k8L8
d110S/1eSF7dCa8oiYIJbHooPp18N7iQDkIR724O8OjhUz+RC5JxdIgs6OJU
2qSHFT6+jrd86OC0XniqVkaP4KWB/DuidPiI4LNFTQ+pOYx5WQ46SAce6vUw
0MN07FcKGaLB7ceXHAss9DDIev/FC9U0WGx6UrdM1sOfHBrLKjk08Fj6jLb7
9TC2cTYqKZ4GTQojRUneepj99F7/yxAawfdST9Uv6OH5h1I7BuxosLrUQjAi
Sg+Lfz3/PKNLg5PffW+23NLDBEMH6XxZgk+ErnMKJ+vh2nGBjzzE/WpqlXv+
6DM9/ChrsMC5lgYvQhp/Fefr4Se+X22P2GiwNWvSm+udHmY0bDFqnqHCJRpf
L6VSD+MkvvreH6fCGPdux7QmPbzdq3v69zAVKJrkukmaHnY3iF7o76VCqdcp
1BvSQ+Ow5cuunVSQuJdQFD2hh199dqccplIhrqpQnvpHD7XmFod+tFPhz3TH
E3EOfXQ+mHFyBcETh8Tntp5co4+LDoo5icT8OorgzY+b9VFZKaI+n4inGqHD
uXaXPv7zv7zSuI8Kl+3qH0jK6aPVHSs/xREqtAi6yaO6Pp71cnt7mch358j4
x32gj4kq2mb6RD3HXoZSTlnq436d4FHXZSLf8+uYsRR99PTUftBN8Aiv+eNz
Gfv10U2RfbJ0Cw1cBJTXlXvr4yifY9SCBA0ye8rT6Cf0sSiy6O9tdRr8yXRQ
/31eH/2588YjzGhgdnrwy5oofZQ5/UK63pkGCXDKTfKWPgoWXkjw9qfBEM/K
n5Ckj1cTjxzce4kGKh0JEfvS9TE2c23Cg/s0CE+T2HLqhT4a+Uroy+TTQFjL
3CDjkz4WG/Jv3T1Ig4AVtK8fG/RxWd7lxLN/NCht8vGkd+jjuiMNhUeE6LDP
MyZ2zXd9lO5da1e8lw6ZyttEJGf08bpO8xfrYDrMLua8hmV93Mf/6IJYEh0S
bjd2ntxggKI9i2uSB+gwtP/AsdgdBki7o/VPm7sTVGR+sGdIGeCRqN2XhBQ7
ofkjvwxd1wCt1vhlpYR1As8E5Sx4GCD5foda5u4u2Fc8zLPvmAHW1U2EWhwm
+CQiKOVksAFWn+f5LnW7C0yF7lc9izXAOzdMeTL+dEG4eeeGNYUGyDHtYp37
tRuaBI4+l/hogJ6h/k/IvD2wo3dRB2oNMGiPD7eeWQ+8O73D/WSPAebcu7ip
52MPzKQdeknjBDzmYRob+qkXTAJ+GU/xAe4x+L35MFcf3Na6TOUVAvyWZWN8
27oPlJufLhkoAt5quTcxRO8Dv78Mm2dOgK08eQUQ0Q/9TgGjJ54DwnqvqsqW
AQjW7TDzLgA8zbUuP5R9EPhEIN3tA+Dk102H16sOgsEo/0HzVsCooRDp2geD
8PD8m7bty4BHDq0+zB0wBEIv1wmu5kTc9H3Y8uDTIfAS/VwTwYOo/1qD5y99
CP5xyUuEbCJ0jflAiPkwyLf86zsih7gqeK/xm50jEGxUENerjHhbvMzOx5Ho
h9946e/TIPQjuwcO10bANbE5yc4QUTze77DVxAhk8EZa1pohXnq8il1CmAFT
oVpzxjaIWZWsiRqi349xT9ujvRdRTdiycXUWAzra9qx844bIk6nYF9bGAFFz
nteK7ogOlQez/JYYUCJ3il88AHEuXTbrsC0TVqZIfUw5iZj5JtvZ4SQTSPzd
AYLBiEaKdgLhBA+xpk3q10UQWn3E/EwHE9S850OiryHueFDzRHGaCeH0POmV
cYgNRs1nV/GzoMHanXrxDmJwl2/HkgwLtpRtjpp/gPg+dbUlnxEL3JXr1U6n
IC4oyIdqObPgxZOwocmniK9lmrVD/FmwsFHttm8WYqP1i39fLxK8cJWFwy8I
PydcykxusuD2/MMfB94gjnMuhbc+IvjqqEMKvQQxXf2T3KVsFsj2cto6fkSU
feg170DwUBDp3WJTJeK5n5sNrcpYUP7pWLZlHeLP6yH9x6pYsEZdbF9lM6J6
41u56joWOD+nckM7oqRM5lunJoLHBGOLSjoR973dIihF8NLP6+ip1k88nxEh
aQNC6y1Nb8gfQfzrU82XTsy/Fpj1SeY7ooTbM7fDBO+0Du4/kf4TsY9qlHyx
mgXCewREds4iJvFvk1pJ8JlfTXVT4iLiu6drpxfesqBI+3zoRnZD7D6ret2f
4B+OXCX5m1yGeLX9W5D7UxbYCQ93rl5jiGBgvp5xjwWJtx5ER643xCxOBxZb
NAuGOWy1ljcbYszQt3+lBE8qB7EzQ7YbosWBX3vEfQneYhbend5liCun1b/i
XhZ82ednclyKGF9dpLLdhAUHDVrTPFQMsWRRdqWWEAtMDkqcvqRpiHSB8yWC
nIS/4WfNUvQMsWddZTsnwcOzFdu+U80M0a5TLGJHORNiTT3UrF0NsfiBhJyM
MxNOehVx+RwyxJn5mR5dPSY4X11Fj/Q0xHfn7569v5MJYrW5oWXHDVEu3XPR
bJgB72xmqndHGuJew2vrbLwYkBpgnmgXbYhq0f1mx0wZcCUu8ejROEOMVZdp
4RdnAKlFn//ZA0NsOTZ+5lffCDApUfu25hliPvnkWCN5BDa6bhlfajfEANbi
2QGZYVg471u2rcsQ9widt6pdMQz9D9/f0uo3xPD9wtIxPUOQ03tQ/eSYIZJ+
vCrIuDUERu6ZF0eWDFFZ4faB1zODcNxXe32DlBFWqAt89CobAMeY60MseSOU
dmi9nnx/AHRyego5VYwweKYtuD9wALgmLrmAnhFyjQylPhUbgIeBdU8LSEZo
zD1j4hPTD3VnXTUSQ4zQk15R9bi6FxyfJU6IhRnh61sVaSnneqH3GzX9RaQR
2u0dkO5X6oUpBccNlTeNcD0/r2lsSg9ccL1dZ3fXCJW2Vc+LO/cAV3TLJXqS
EaoIFwe4EbwlNGzzc/KZEXLXbLs9H9cN6euvPw/JMcKiye0hkfbdoAi1B1a+
MsJ6uDYxv74bjJJMGwVLjfCJpnPj4MMuaKiJiEyvIOL1bas+5dkFTjMVuko1
RsQLvcdeRrkLjpIMsk2+GeGwpXmPSkMnzIZeONxMNcJt2fUGDx91QnjOu60u
PUY4v2lcxukEcb/Q55qHB43wgVHnRl/zTkjg0rx6nGWE8SVKM907O0FYLchg
YcIImSTx5yULxH13+PVM5G8jHLKWqOGk0aG0VMkjackI9yv0aK0k7juzsYBt
EiuNMdA1JKfiIh1atuR+y19tjP53eIRWetHBxXQsWofPGH+pas8129Nh+KS0
YdVGY1z51cleRo8Ox1K95uyFjDFmMvLMBjk6zDWm53fuNEaZ4OCy+O10uLw4
6OUpYYxdf27YPuenwxqZXcI/ZY0xKkvvjRM3He45HWw/p2yMrqsaAp+w0UEk
8lEsp4YxZjUGsmL/0iD7VZfxLV1jtLPYarF1kQZqfYKLQobGKCJoVmhGjJet
cS54ZmaMfTeZNkLEegude77KNsYYiSl1CVx0+ObdJvLegcj3lRx3MR8d3O4K
0Ez3GqPe0xuTV7bRgfGJdLPFzRjJni5ebLJ0CPwZZ+bqTuSfrCcjo0uHhR2N
/0a8iXzObFrJQdQfac1bGBhgjJvzkmpjPemwLsTSf/GkMfY0GLvXE/49yLgq
FhVsjCFO8+vLCX9F26o6+S8a48TDT9/9S+iQy77ydnKEMcpXRS+0dtJBQ8nI
UjLaGL+JdAb+WaJDuVs426s4Y1Tk3ybdKdEJVjFlb3UTjFFI+fXvi/ad0Pb2
77HqRGO0bNR/yjrfCQdGdCQdHhujt5oTl1BOJ7AEQnq60o1RouD++KaeTvgb
MGP9K98YNzZ0mZ2z7IKoZNUVFwqNEf/s+jIW0QX8tSfecb03xtHEtjG1ii4Q
F5+U3l5NPO8eexsvk26w7WRwmncb4w/77LvlAT1Q195d/3bAGBVGndsWPvSA
2ddv8dJMY9R8mEretr4X8EvZDp4pY6SW5clJlveCWtE99UZuE/wqyRvNt6sf
Xr2KXdRfa4IP5zMChff0g2Le5YoXAiaomy23tYB4n6XSj9ne2mGCu+JzGuQW
+kHotpknRdUEz6m5xl9mDsD9G3pylVom+M3GbMd6iUHYGK3yS83ABBMdNHw1
jwzC2nDh0M2WJpgk2OuT1z8IbMdmE+gHiPjxl3aydw9BqO+4i5WHCQq+kVsW
ECK+Zx6DIu99TfA57x7DO3uH4bdrU+7D0yaoeqmG16OF6BctMyoPxpggL2/J
gFbRCBwxfRjTctMEeVrf3swZH4F+vE0yvGuC6SdYox93MYCuebFbNNUEJQyP
CNy4ygAn1dNP7jwzQTPXTqZUMQO+Kfr5rMwxwWt8VpdlmAxokHCaHik0wbTO
5WJ1ZILlLpt3Tu9N0O3Jg2QFPyZUbzcKryk3wfO9out9bjOhfIPimqx6E6yZ
7i2N7WGCPp/4N8GvJriXh3HxOBsL3vEIPYjpMMHgxmPCkbtY8JqdS9x/wASZ
b4yG9Q8Q99m/xdFuhgnxvLX7B4n7LXfuV77tuAlm/NIuLL7DAplpZlDZLxP0
/FTFqMhhQcaPHl2lPyaow0FSYv/EArHvreypf02wZ1+GZUgHC1IZtTX8HKZY
9Sw7W2GUBTsGP964xG2Kpxu4D4ktsCCpp5AytcYU3/atzjm4ehS20HMEjwiY
YoK8cxVz8ygktKX1tW4xRWsuK7YK0VHgb7n/zGSHKb7Too7/kh+FG/U3jhaK
muLm9CXnS+qjwFMTsVtS2hSn5B/znNEbhahPIX/uKZjiZ7GLNR2Go7Ci7PgH
blVTtD3ho5FjOgrhJZ4RwVqm2FtbIbVoPgr3j8z7X9c3xdmgydl6i1F4sfaG
U4qRKVb4unbvJXTlWxF8ZW6KC19vX3tmNgpdh9/IVNqY4u6N5TXvjUdhitdi
A9XBFEstnnimwSisKur6O+pkiva5/jz7dUZh56HjjL+upnjUMu3yjOooaPCs
aOE7bIpJmx+/P0HUY/vmXomolyl68VQ9oYmNgscB2afqR03RbdtJid1Co3Bu
VVmsRaApcl94LnaZbxTiCxzOuAaZokLVzlPfVoxCptvIwWPnTLHRImNW+g8L
yrhCLC+FmeL5QxvjYwn/x11Stz+PNsUj243O3SP4aQWnGte7OFMMGnkrYvWe
BUL5NT8a7pgir0kKVYLgPfMVPz5NPTLFuSqOC4FXWPAkR9/XoMAU8w27FLhV
WVCy5yvZ4a0pXryc2fhqOwtalj30PEpNMZPMPfiW4Jl/lFi+mGpT/DnU8vF7
O8EnfzsL2ztNkVkxsvn+cSYczzj2mNVnih1pm+PfOzIhisQRvThM+FcWHu+t
zYTX6TJuu36Y4qOr+1KOsjNhnW0wR8AKMwwdYRN+HcuAykeb7FfKm2GKxw5T
+YQRUAISSyXUDJkOdS8vXhqCsZnmoteXzVDgITWK7jYEGbn2V9SumSFPfHmy
stYQbBeyF9W4Y4YVDov0nslBWDVj66adZYYHdzSphboNwkC2dQu0E/udCyV3
6RB8cbg+pbzTDAumHdI2bRkA563WAYb9ZmhcbqNz7Hc/NF2x4jH+boZHQXby
Um4/vDtkaWLGbo76Hy+1OYr0w53N5sU2CuZoej17xHJnL9g1Vkc1qphjzs2w
0/XdPcATabbHTsscaUIBevVJPRD+y3TK3tgcfb9rH0vY2gP+DSbylH3myFW3
x793RzdIRVQutB4wR4lr0a21A10wqG1S6+hhjn4uadO/MroI3jb2cjpujj+f
PJF3Uyf6yctGqfuumOOLDUccZDw7gU3707HOGHMc+r7yyE31Tij9Yajvessc
j+Qqrhn5v/3sfsNOt2RzjODfDBkFdJjYUJHZk2qOx3b3NateJ/ihDs8eyDDH
nbfERKaJ+05YCzceekXks+ZBurkoHeiTHwf7i8zxFT3hzMwKon9+Bq8OlxK6
cM5qDYsG9m4fwwYrzPGBZr/r/SYa8GwAuyM15hgTpH8y7S0NqmrLtg83mOOH
nFw19adEvx9u8N3jmznKfwze6BZPAz3NspIRqjm+e5DKsfMyDf5M6F/z6jHH
zg8yzKggGthQXM9FD5pj0qc/V5X8afCkONg/l2mO9U+3rVH1JObvuHegedwc
b3qsu33/EDE/4jVp6pc5Fi0dGHc/QIM0VovRpj/myOMZdCSJ0LO2k2paf80x
XmC/lvFhGli/5pVyZbfA5eCCNHcvGqRulRG8yGWBbtmpB/8F0GAm1Iw3jdcC
RSSebN4aTAOroSP/PvNboEDQPa+3kTR4bHHpB2OTBZY5/ajqu0OD6byUgdXb
LHB84+YHd5/RwHJDaau8iAVmvPDBnhIapATTq+wlLFC+OY/zfQsNfvfMvj0p
a4F+g4wFlTEaWBhvzL6rZIF16cKulgTfPMrc/bBYjcjn2bQ7hwQdptbax3Vp
W+Aus3kLdzM6mJ/yD18ysMDKa2tUAvzo8JAWfXKXiQVyNZ22k4qnwy/95x4m
lhZ4+cKN5oR3BA8+rXTytiPWB5svlDDo8DNgWSfP2QIVvd8n6hO8adq6XaFl
vwVmlbwcSif4I0lLZ+dvdwvUkBL42F7QCSYrglZoB1ggO8d640yZLkj0uT3j
etICqaErBB19u2CyMZ958awFmvoyynpyiPEHY/WVlyywqdznU4p2N0z+4y5j
Rlmg6xfp9P7IbjA5IvGSJ9YCre9nbdzcSowrHEog3SPqfSIhejq4B4w+t7t1
Z1sg+crL51nMXrgv/dtuOd8CU1TcpNWt+2D8Br+haKEFHjZnctJe9cE9Z2sJ
n48WGBLsRGUz6YexifKJ360W2LHKNiBSZgCA0tu3mW6BY59MOI57DkBC8eJX
7V6ifvlnnNufDIBBhEZRGMsCH6xdcFfdMQi3t+Ze5P1H+Oe9Qzd+8xDoGt/n
E5O0RPYUw6KjC8OgVpjKeC1nie4zHxtltEZAUSr7g8luS8xdeNX8/PQIiPB+
OOqlZ4n6YcnkqNEREAqtNvpjaIkHyuK2lxM8seFHs+A1c0t0tXt3x8eZAVyt
gzVZZEuczeX3qi1nAJvpeIqOsyUGpWXc8ppiwHzRTFD9fmL+j6aj+qJMGE9a
JT7hY4liX+2Pn77ABMYagcXQY5ZYdzWtoCqDCX0Xt31bd9oSI3DfmGozE765
K4Yrh1nixXHdcCeif21o09xbEWmJMcFLR7n0WVBlZqhIjrHEeg2JF1/2E/dP
sRXn0E1LxCfrgh9dYEGxrGP3qbuWWOE+YxmVyIKCh/tfr0y2xCV/1dzINyzI
WecdczfVEq8M3NiT1MiC9PDAw5IZlpizQ7eqbpgFKVMhWm9zLHFl6twJIYIf
HnhE8Fm8ssQNp2Labqwl7sOOWAatyBL3G6U6yuwchRiLex98Sy3xkviruCnF
UYh89zhhocISv8Rf7f1B8EGofNbR6zWWmCYymCJlOQpnUgqMtjdaoued/C2p
lFEI5C8VzPtmiU6zZ28cchsF38tVP/VplvhEzfV54JFRcJ9uqmnqsUSrwTpu
ms8ouHnRUg4OWaLpc3X9FP9R2EMbCPrJssQ1Wfmx9cdGwc7qu82lSWL+DyU/
n+OjYFE6LSYwbYnlg3MmocS4oeLSwpN5SyTrdF8VINbrpHJ/U122xP4XF5jK
RHw1gfVZlSut8Ouzd2ID7qOgGCkUvofHCqMjz/yVI/KTmhXby+CzQrGpJRRy
HAURHwXFs5usMNVGePKN1SgIdWpwrtpmhYJizf0rcRQ22mD3AxEr9Nb8PiWg
Ngpryyxfy0haoZe1zRJTchTYnrgdtt5thW2X3jrzEHy2sMFLq1vDCs9yepN9
51jw+8pxvgA9K2zMK3tUwGABw/fyhzhzK9Tdc3BMspwF/V3XE3baWmGaGM3H
neBFuu3doy/JVviDfRtv9l3i/OzOFPy23wpZz++kh3mzoPrpq5/uR6ywPaM0
YIc9Cz5uel/z28cKNbj7TzLVifMy3xi06bQV3m9YtVuEnQX3K35/dY6xQu7V
udp/4pgQyV74tvmmFdKM+Xa4nGBCoOGZR2Z3rVCzJGabLIUJFhVzPmqpVri9
z2aN9CYmzJX/W+YrssK1eeFGVncY4FLOrVgzQIw/2r28NnQEdnzcFqOubY1b
i/keCEoNAc9y9/FcA2vcnBty7DfbEMwapOwRM7HGyHtbwmo7B6GpTGTXentr
rE527jgVNwgXyySKxz2scT58vdHSzAD0f1BiPL1ljYu2veuba/qh4d/PeqF7
1qhtepfnxJN+KNYveBWfbI33nbkoSqH9EP9BLTQswxrXGVbWcan2g9EH7Y2u
pdaoKyAi0YJ98LTU2EiAZY1l/0ZFg9b3gGzOE2u5CWu0TmUICrd1w8tE9j0m
U9YYTfp3nna/G0rPfPQ+89caU0LX1laLdoORp/CJm+w26Byal7ltrAu+UELP
ZXLZoHasAF9lQRe0Keve6OS3wcmLBxotLbrAZWfSvd+bbDBhlRu70aYu6F87
/3jNNhvsKtmgWDnUCeNjRQUGEjZIu3mJfOdKJ5ykbyrdK2uDnAndn2ecO2Gu
5nRVoJINDhcIb1ij2Amcz1RoT7RtMCTy892zPXSIvRM/8N7ABj8Pc8h1v6WD
wOWfY23GNpg+d0x0YwLRPwfaT09Y2GARb02fxEmCNw6++MdlZ4M6OJ6/mUyH
dNu13CIUG+R5ntr0XZUOsnr+/NrONig4J2mSvYXopwVlxY6622DJ9N0jU8M0
KOWOlo/0tsFFp/vSEQR/GM0y1R/52+Bz9rXKvO9o8GXYDIpO2GAar/jr2Oc0
sGt9ZtF8xgadnK4Pr75Pg7aKlWTWeaL+MCla5DUauLw84sp+yQbXP/zWt3Se
Bv0pnzyEooj6qkSFQ07QwPvGrmOq122wgDFbNO1Dg8nz4Wdtbtmg385LXifd
aXDary/c8y6x/l5M6NR+Giw4G8RcTLJBm+mtFkGuBP+YP7pz/7EN3jPO+brg
QgMujb8PX6bb4Ip6yuxlNxrEirtm1GbZ4JxO6L21BM8IbHiXP/jCBrO6Dt5O
InjnAbtgyeJrGzwTslpbhuAT4Z9nP20sIfxqMXhafIYG6b0d9QplNig+uNbE
guAp2Ub1drPPNnipIDKOepMGL98n9B78YoM/jqSkez6mgUb2b2Zwow0+TvLc
+esl4ecD8q/4bzYYJxjLFVJJ+Hn11UI21QbVOu95/qXToDaIf2Vltw1eGH2k
du4XDUgex9f2DNhgi7Luxl88dOggN22eZRDPN3pd+0FJOgwqxcpI/7LBQGnu
AyJH6OAj/F3FcNYG734O+3A8kg6Ta6z0XBaJ83uDolnwnA4Lo9z2sZy2eMky
tIB3mg7hNC/nZzy22LounCSyoxO4aqoOl/HZYs3Ka85iFp0gkB5x+qegLQqf
T5b9+bQT5A4sJzoq2qLvg3O1V052gdM+q2tdqrboMydZXZXfBeGOd8+4a9ti
My1Vy/BHF7RbyVECTWzxxu33iyOnuyFMc++aWBdbPK57PrmF4PdslScLAods
8e6HFP9voz3QpjDBSvS0xcUL23C1bi/IiEdUPQ+0RTbJ+cqNw73Qyp9/8XOU
LWqIbL1jK90PS7wL/laxtvh2RDAoxbkfpLlNXb/G22LWJufKVTH9EPqvU7Pv
oS0+3resKvuzH6TGuH4tFNjiik0uicdqB+D85wNHVPpscdh5DRVTiP6nLMuh
ZNgW8fhzjVP0IWgpmQYcs0X9OF5z843DIPEyZrvdjC1KjlvIGV4bhuaHRe2+
vHZ441Tow8+eI7Bwn73yJ78dLkYqu5kljYD4HZuCs5vtcOpRwPuAxhEIiR6M
u7LLDqW9ctVslRiQHqkQukbKDsMbBLs79zOgKSz46B15OzxL784siWGA2Jl1
Fmmadqh5rvetdB8D7E7s05DWt0NRo5GYx1xMCPZPF883ssOMqUcmu+WZ8MT7
h4CGhR2qjWtAmz0TGt112D/Y2iF16rrYJeJ7P7f/yg9jCqFLXGqV45kguq+l
p87ZDrPPS3/recGEs/Ze72hH7DAnUGyj+DARz+pV5kFfO2w3eZ9UvMiEBtO/
9xjH7NA5NsPSeD0LZtH8SsBpO0z4NDNZKc6CXXq3T02H2GH8jbCvBhossNHs
OXw+zA77Oy/9fW3KgjMq0iSOK3b4WK9nWIrCglSFUwbRMXb405BPP+UAC+ql
y+T5b9mhj8q1/dt9WHDrW4aB9l07fC0dGKR5nAWOF26S3JPsULjxkNKz0yzY
Khnsfv2xHRrfaA73C2ZBd/Oh02/S7bB7/sqeG+eI+CGWUT1ZduiSrnVi43kW
eIqpPODKt8OkwHUpXMS4bKNQttIbOwz0jUrxO8uCyTMrSp1L7ND7rK6o+Sni
PhUZb7xUZofzWpNVTwNYcLaurS/7M6HPcLte82KB3ukPv1q/2OHm7h8Ffwme
YxPOWPGv0Q5DhEVOrHJkQWVN3CbJVju8n2L58LUFC6JPnJWyp9lh7OV7iVx6
LLDbdkg7uIeY/1O5abUiCwSqLKzTBu3w4fc/V6uEWdBxbPf+OqYdnnl585/h
OhYkbxU6/nvcDh222FVd/csEcf/vt03/2GHleO+b+HYmsDa1pR/7a4dRy1ez
vcqZkPextOg+uz3qynS2SWYzQWNDXOcorz3K7s0XuH6OCQulZ8YF1ttjdkCu
NR5mwkevg0u6m+3xlc/6eA5zggfeKYvGidjj8ZdSkU18TNh3uNVXRd0eg763
uPrdZ4Awb+l5Vx17TFvx+o3fWQYMvkm/EQn2yPsvf/mtEwP8Vp151WFpjzI5
nj3OGxhwIX/r/LkD9ijsuPJ6yJURSP23/9rnq/ZosuftrDRlGJiJrAzHTnv8
Yq8fy/thAFLWR9cc6bPHAFvSw+I7A+AULcM6OWyPm33LP5/yG4DKYD+Z+El7
fHfYUUZ76wC0yM22e7GTkHPinDLfmX7I9TbzmlxBQuGxu2Kadv1w9em92SAu
Eq4o3jFZLNkPBts0t1zhJeG9l5mv6UR/k8cT7Px0EwkVisW/jF3phWtmX1iy
W0m4n71SKFm/Fzwubw0pECKhWo+gyZnZHti+UJxYsZOEtx4kOtCO9kDM6Hxn
nwwJd8bwqzl4dYOXhNVRb3kS7qrkXeMu3Q2Gh5MWJxVJSGX8ien/3gVzNJ3t
S6ok3PP1mIvO2S7w/nJ+/3YDEj56zetZ/bgTjFY2TDxFEl7My6rMD+gEYdx+
Uc6YhN5XmkeF9Tuh421pio4FCX+xD8fd7KdDwe81Sp+sSLh68/vT8W/ocENp
/0dLWxJaFCgpCMbQweT5vz5nMglNtpuHF2rTQWTINrDfkYQJnj1FNRvosCic
wuazl4SNbafUXH7QoOCewa6zbiR0aAjEP9k0iPsW92rpAAnvCrWo/ouhge+6
PsOowyS8wb0/N8SfBiJRYe53vUg4sL9oU50qDf5WNE9t9yWhT7vptfuCNKD+
2xmRfpSE+1TvJDaxEfG1AzfIHyP8cDgxcHSUCnFB5U9fB5JwnbbD6NFWKvi9
4lfTPUXC3wf8z9eVUcFs4lDlpyASqpy8+Sgihwr/PNhHvp4j4c1SH5fZa1Sg
pToE7Qsl/PhasCIzhApvutM4B8JIeKdBo+/pUSrc2jp11+cyCbdmWpeOHKCC
v6OR5M9IEm76tCLAl0IFi1u3i85eJWH3QPMHWUsqiDUMmi1Hk3D350RZCaTC
ErcqNSqWyI+1ZOaoRYVO4wjvdTdJGKK87t3r3VRYFWU51hBPwiKxl3s65Kig
8YUv4HoCCUvjT3k7SlHBg6fjh+V9EjYINFhKi1Mh3ubhyVVJJIwXtjhiI0qF
sjj3meqHJLSbuC70fhcVxlukg688Js4Pj8/QMWJcaMOPBeMnJMzm1rR1J9Zb
7CkM5XhGQsYUd+tNIv6Z++fZKp6T0HKyY/IXsX863TAiLJuE/zzi5COI/L5t
W8VlkEfCmJ/HDhoQ+S/vb7r2N584bxtYu4WJ+uRTE3jfF5DwoKK8xQ6ifpdB
l7iQQhIaF+cd0iD8uSa+a71WMQlXiptPeRD+FXkx78y+I/y5/pM93Y8Kw5l5
mws/kNBtKfTk5FkqCHw/lXiqnIQb4z5LQhQVAo6zPf5ZRUIv05qR3mdUSHpV
vSv/Cwl3xCkUib2lwpffsekB9SRce3m5zaWWCuLBgtljLSR0Uutm3vpJBfK7
PvmsVuJ9EI95HsVJ8N7fZ/neHSQMXjXrun8bDbrDVQqHu4j6933amGxJgzvR
1uW9DBL+UOaKGMinQXn9euNHoyR0SWu/611P8OVaWpXrOAkly46W5zFpYHXb
o572i4Qvu/bM+4rSgSM5tOPbXxI+3WnyTD+VDoG5+ePVAg6YL/7jsc+7TkiZ
DDp+ZZMDXrUo5Lfu74QGZb0p460OqDV3TKKEqwukCr/8Kd/hgKfJkdMKe7qg
98MAx3tpB5RwytZXmesCm+YNgvkGDijmu3T7kGMP1LAy8wwMifVi7/3LLvaA
EYeBUZOxA/af+GhzOqsHNNV9jk5YOOBcvO36weUeEE0u/SBHccA9huYWyS97
Yc7L0z3T2wFb2iR3bOXvh/Slopy0W8T+b0VYCfcHYOdWG9x9xwFnlbrv/3g5
AEm7B9rK7zqgw/jkKve6AbjpwbvUl+SAw+4Lq278G4BzdQdJws8c8GBmy8iY
xyCQ7q2aSSpxQKXUc9cOag7BXwUXg4RBB7z+XujKWdYw1Np6VrmMOKAzeAhZ
co3AvYBAm10sB7zZzvdISnwElPOiXF5MOOCu+k8lPIdGwEP+9Zkvcw7owZBa
cKeNQL3smvy/68j4W++k2Np6Bjyw2qLxeT0ZAwyz4mJHGeDhJ/oheiMZx6JJ
thtXMWEpS6t+sxAZW0/wmOuaMkFFxpOpLEHG194j77o/MiFJqmynpy4ZC6zT
ZCWLWOBtXpshZ0DGBp7J5eE2Fqh5tylMIRnL2PUlw36zoCljTDfMjIwcBTZ5
35VGIbl65pOpJRl53kslxtiOgg+DzWqNDRmXz7NvT/UbBQ7JLc6JDmSMVKtz
+fBkFJpNRfsOOpJRI1Yg5MaHUXjoqeAluZeM5v6kCA/qKPhe0ZoY30fGxLNr
1kr/HAWNZ8anX7uR8Qnbq8Qy7jFYUWW3GHKQjNTV73fwC49By/C+y+hOxgmv
+kEu1TF4uNJzNbcnGQ3zWpxvmI2Br3jgrUZvwp9LDTNxzmOgYXJ+S4IfGStf
xjYt+owBh0dUiksAGfs/n/9TeXYMmiPiJXYFEuPMnXu7Iol4Tx/mMk+SMUzm
qpfKLSLe5+eqL4LIGLKtoOZjIhFvqODd6WAyOl+b1wtJI/JbUWaoe56MNiGK
y07PifxEa7+wXyRj50FKJiVnDB4Ztdl/CSfjW0f+Sd+8MfBz7+uIiyBjDpu9
6D1Ca14e278nioyNE5zvqcT8lU9mhrdFk1H+yXSMYuYYfK1g8x+8TkbyrrJX
SU/GIGWA93dmHBknM6+6CyePwVH2LeeOxxP71Wqll8aPgdYuUXaNBDKeX9uX
Exw1BktS0Td/3CMjv0aQbGLIGFQq/tyRlUhG7mVS4m+/MYhR35vr/pCMUf5P
62+4jIGDXpnO9sdkNDhr5HPMYgy2GkvUtqeRkZUdefqR2hj0WsbuvZlORr2h
2o1iO4l69rqc5sgm/P79UsfxxygoH6jgKM0l49nVR8ME2kfhj4d0fFA+GfdB
zh/rklGIPDmbx3pDRtnwZua+0FGwCtmv9+QtkV8Ko9p4/yjwh1fWub4j/OKM
VWrVHYVHN24zmz6SUTArJ3vdDAs8EuaDrn0io2q8Rs3XZoJXkw+tNKoi4wO9
NyzvLBYUZSruKqwjo5bCew+dfSxo+VznktxO7KcfoV6SywSOBY4m7+9kFFut
8fC7PAO+sPm57Zoko92OqV87F0YgjvvrWOdPMuofa8porx6BbZsec9vNkvFW
k4HvxIERUFPWNVRjp6Ao6VJGQ8wweHudesO2hYJSGnY+0p2DoBjQafROkIKb
mucu6KcPwvQpw6+ntlNQ58po9bVjgxB+iW+SsYuCd/w1KNMrBiHpYY5UozwF
pR8aRHqpDkDDt6GkRCMKhkUWXNrl0gd9LwV1xU0p6OOR/KpmZR9Mxdl3vTCn
YKOWcMB74vsmaP1+W6UNBe1aWmSerukFr8+3H046UbB5Wl1pvq0bQtK+6IXs
o6DAq9c3EmK6ITZsqXuFGwVvXv4u88iwG17r+u0QPEzk326Ru/C6C9jeGKYY
H6UgnOTkm87qhA23zxo0BVAwMcM3lvtoJ0gG5vU6B1JQuyPh1FWFTrCVF9x5
LIiCgo6bLlYV0SEp/efjB2EU5Nvs1rZI9O8vLkui2GUKsj1oTlXPoEHFIbf+
vEgKxtpz3a45RQPW9i8in6MpuE5KWIEhQAP1u4/TJu5QMGX5bcLzQ8R9fqrd
MPgeBe9fq5zS06SCmwPvIEciBU2DP29Zw0eFy2vPim5NoWD4he+Z5p864N73
3E9PUin4lvGjKedRB2TVDrorPKXgAaHcAa1zHdByxe6pUSYFhY7ElpRqdMDQ
kUjjxmwKduYuz2Rv7oBZw3dDe/MoeCHLa/rln3bYsSQhHlBAQbG4eNpUaTv4
nfmXfr+Ugr+w7noFpR1CHVVNRT9ScOikZPR33Xa4peI7kltBQeswhyB+iXZ4
O9km8amagiIdNv5SC21Q18BTbVNLPA+VHYvrGG3Qm41e1HoKFtzQTej91gYr
vXMzxlso6Ow5cE4yvw22mA6anW2lYCHJqepGShvIim1lsndQsMRjUKM+rg0M
2O2uxtIouD/tSnNvWBs49EVIbemiIO+m/piaE23g8aGkJq2HgkmUJrFwjzYI
Tv7hLd9PwaWx8fEVzm2Qstc103CEgn3VgxMuhsT+ety6K1gUZDyz7iNptIGv
yOvGyjHCb+0zyzvl26Bp5cFDURMUTG06HPVJtA3URnl+m/+k4MPXa3NVhNog
qbHoyurfFOSWb3nvJ9AGy6/ct9bPUDBOIrLVj5fI5966nNg5CtKrjA1UOAk/
zr3Tt1ukoN4HJdEPy62gfNCrhW+JgmtKfZ5xL7bCXWOBI1/ZHDHtJN/k2j+t
sCBVNnN7hSOS4k1EG363wqE1ftccuRzR74u0j8GvVqj+uWnb5tWOaPGle+TQ
j1aQa6/Io/I6ooHhpQqlyVa4VRKAiescsXjj3geZE60w+0iw1WW9IzqIHP5a
S2i3y1We2zc6YoKWKd4i5ld4nZjr2eyIYZuc384R8SStd1x/LOiIG45PrmKb
aoVYpdodh7c7ov0/N+6n060wtSHopehOR1QNnovsJfLdOydiPLzLEd/f3+SY
T9RT2t3Q/kzcEUc3rDYXYGsD0YpgH28pR1xrNmnNSfhx7Zn4orSsI5rQ/lle
42mDieiWG2Pyjihdt/ffA/42IB+7IJKrRMyv2c6lvqUNisnSrwNUHNHmXMBK
F+E22KHZZqqk7ojKN/0ecEq2weVt4bSfmo7I90rNXV2xDWyHqf9O6Tvi+tqC
LVuxDQq+RNxSR0fM9X3mVG3ZBlvzlMT+GDnia/VklZ+UNhgMumpxzsIRWcML
S69828DCRbVL19oR/4U+vm4e1AZ5Bn0B/2wd8ef7Iz8ol4jzxa15J5ziiHC7
/HRDEnG+vw9KGDk5Ykj/HRWNzDYwbokrXrHPEW3h7/L6ojZYl8joiTrgiHeT
2Dm2tbZBuuw96Ru+jjj5+lymhUA78PAZvbfzd8S41qnDO8Ta4fjvCVv+447o
emix0UWtHXRKTU/dOe2IVdeEp9c4t0OL7cyHxDBH3HmVPKOT3g5/Ax0pGXeJ
+NoX8uTsO+CFfPMfrQeOaMf9V/KNRwccZlk+rE9yxJcm7zpuEd+H6oMw8vOx
I0ZYzm8we94Bt+xkz+pmO+JegxyZpJVE/yPPltxS5ojnWTs/tzVRoYN5Dv5P
BVceDuXbhSV7IpSiUIkkUfQTinOUhCSV2cdYQoqkQouyJSkKkVBKokUqRVmK
aBGlJBozljEMZkjKkhD53u/P+3qf9zznuc85z7nP9V4ze6tcUDfJPyCFmNdi
b/8W/H7jgn8OL9S6J8GBAfXvBotrXfBvyC+Puo0ceC7LrvBuJOxDXua8R4S+
Fj7omhQS50symPU1mwtT2brnLva74GppRZc/r7nwmHVr9dIfLmjR6x0QIuDC
fHZq0NZhF3zOW74qWqcFeG8jpRKnXHDUK+3mj4ctcDiboq+jREI9jYCL0V9a
Ic119pGdFiR0/fmPK+HJAxuxFo1vm0goHTdA5l7kwa/sglo6kLCoeCt1SRkP
tolcl/nYkBDxXN2QSgeMHSn5csqJhM/Lcxp+13UAKfagUZ4nCd+VhNPz8/gg
ttqm1cibhAHHTC0d3vIh/5P6uWf7SNj5UBv0eHyQUKnhVfqT8LGc5b87yp1Q
lLn8UnMICY9Kh1dXhXWCcmHzgEQcCT+2b4mSIPR0BelR2oWLJNxxJCBqJLIL
DoxH28xLJGFQWkzymqwuqLI0vr74CgmzVh+Ti2nvgsCa+O3GN0kY76dpzmMI
oL7dOs+tkIQZUde+tO/rhniZ/H1lrSRceEXkkfayFy48GZc8xiOhzy92lain
F2LpW3NMOkkom7FWr1ZBCNH5PH5+LwlN19Yef8USQhRpdfj+PhKeOOtxM/2s
ECL+HdPQHfj/84DE+AdCOOWsRL85RMIfqgvEXUaFcHLCdZwxSsJ/l16u+K0q
guPZeamL/pAwhyfI2m4mgqDRLY1JUyTMK1QWfggRwZHMxMNOMyQcDP/W9ClZ
BIG27YpzxMnIKlvy1PKxCPzTQhyjpckIs2ap63eK4ID1m36UI+PbkRDdhD8i
8O1XPD8tT0Ytt48ta+X7wCeZubJMkYwzlU50Ka0+8Np0/12IMhmPmnx2llvb
B549v/eaLCDj61uq/5lBH7hf2iz+ayEZTXTF78U59gFrQ0JWvjoZvyoNOotT
+4DJb7Xar0FG8fIlS6959AH9vF67zlIytpwa0Cbt7wOqcXBo13IyTj4w2bju
UB+QW6vUbuqQUfXx8XfrjvaBS7RCCUOPjOfUy9fQgvtg9xoGedFqMs6h3a3O
I7Az++5o0xoyrn/Umrk6qA+cwkcvJ60l49q70UP8wD5w1LNe52RCxmjjdJsv
foRebLhYL2dKRq/dH8li3n1gd7Ll4HszMh5wXrD5OLMPbLVXykdvJGNw9F4z
2N0HNnVH89CKjHZZ9w+62vbB5uBKu2kko5Pci4JWsz5AzbnC0i1kvI20r69X
9YHVe9rZEFsyNikY5yxW64NNgXe0TezJOLfUNPSnVB9YqI1U/dxORhuPiig7
Yj4yew3u+U5k5N+RGV/LI+an+dzrOi5kXBbxo4JDxM+4XGdjF5mMcSGuR/NT
RbDW5wj3Bo2MZ3SWD5idEoFByRzVRW5k7Ej/+fnOFkLPelCLmjzIqC0vZZCp
IwI9udzdSV5kXHTlSWWIlAhWMK0S5A4QfK4KO/XvrRCWiB2WmQ4i+P5iGRxt
KgT1++V3So+R0YV17UrZPCEs2i23NeQkGUcCtS7o9vfC/JzbkT/DyRh7/zG1
JqMX5O3Yk50XyJg36T64abQHKDVDeYcukrHGprRiQV0PZNvNZUwnkFHu97eI
8Ns9YGZv82LRFTI2jr8a1NxFzKsOT0N33iRj2J6h4h33uuGl46Wpl4VEfBIS
X+RvF4D0p/v5Ds/JeM1E41KolgB273jH5JSQUfHhDg/zkS4Q7Zh6OVJOxg8b
BbbJGV0wf+eB0/o1ZDyrvdN5X18n+O2y/Xe1jYwNO/WelCbw4XmDxyOdDiI+
DmnGS3yI+2f3aVZhJxlll9G0JzfxIXV3UcXnXoLf5dTGVE4HvN6zPFxyiIh3
JuO2TQ4P5jZZGiWPkJEjyxqKovOA6kLrWDpGxqmGnwmGyjwYdEmETX/JePx6
Xt6fs+2gTv43c0SSgot+Bvc5RbSBN1utQEyGgnPqU/9MbG6DAvJ/7pfkKKht
e01jj3Qb2FL8K+8rUpCHESLtK62Q1HwucIMyBYNzLS7fZrVCG+X20nfzKWgx
bVjauaoVjlBbIvhqFBTrCtbNfdcC5ZzfawOWUDC9RFbTMLUFZGhKnX81Kfju
/rufp31b4AbNznrhCgr+veZED1FugT7u3qEcXQomRQUHafVzYT09/JbxKgo6
qGzcm/SGCx/oz2c5GRLrdT6pfA7lwr7ObTnK6yjIDq7Q6KRwQcKXa9tsQmA5
9wuyplzIHjzQd82UgrO8DY9vVeUCBE/FuZtTcN6WJ82XxznQ9veioc4mCn7t
dQ772caBk1FaDX1WFLSaKzVAfcOBhbJPjj6ypmBpkP3VugccKErYrHrUhoI1
O5+MbUvlwC7VppIN2yhYFP1LoyaKA4PXvRlT9hTk6F+4Z3+YA3Haf6YrHSko
6aiZWevBAb282KyzOyl4MeDb7K0uHHi3Vn2Lw24KbjjRdbnEjgOexQ96FEgU
rO4bT1gKHBCzsoxtpFBQ3HVX1okNHMh8+1k/jU5B1hYVv8p1HLDY7v6J6UrB
kP11UUNrOMBpGDq0zJ2CXsEOdFkDDgRTzyj3elKwR2NpmASBlTvmP8vzpuDv
VcmhHcT6x953KId8KSgXYfc3lbDnOLBh0sSPglWXR+tXEvv1Ham9Pn6QgsOO
R25fsuJAzAQdygMpqCq3VbNmGwe0IwY6I49S8JbOL9GX3RyolAqLtg2h4AcH
uye5bhxgXVRcOecEBSe+9FZuCeDAX5VbtfWhFLx84ODme2EcSMsw9k8Jo2DX
mrV6XxI5YLrsrQItkuBj3RmvkhwOBBoK93TFUNC8gjZe3sCBuc+Oj905T8GR
7dQmdj8H8jbKpfvFUzD5hoLUHUkudNut4Y0mUTAus9TYFbkQWV8RUZpCwft+
LsrozgVNsrN22FUKljx4rPklkgu0vUd9pTMpOPgrQmy4lgtjfRJz6m5SsG9T
znD4Ly6kBKY+TMym4Imw4vHCRS3w+XTpsNo9Cr5W7AmUDmiBzWkzpwwKKZgR
Px5vY9AKHZpJWkPPCP7vPNrQ7dYKp3KXv35WQsEGpYzU5UT9FD/dKg0VFDT4
ZXP+uEQbGHyKS9pVS9h3Mmw9PdYGtXs01qvWUbAz4XSFzIZ28Gl5xG75TEHa
74uD6060Q5awYbFXE+Gf1off7uI8WCC+6E5IB1EvT7I+ol4HiLkfp8t3UfDG
711xNwM7oL+co5DdTazfmDdysKwDKk6kH/vUR0Ef9Ux/o1V88BlSt18xSvBx
bDO1pZYPJXyNgQYZKhbfvvq0xrALsq3CsvbNoWLLLnLNJ1YXxF/nuUzPpWJ4
4KI9iQld4E69Wa6nQsWRgi1MdeL+k/2yNCFcg4pLt9vHjr8SAP2VtvEaYypG
bRwLSaf2gI1GdO/r9VTcILzKcD/fA4ah3RnUDVT8N3FmjkNpD4hvyJ0dvYmK
FXp+sgaqvTCQIlmiBlS8KHYgYXJzL7CHvf0fW1PRx7c6PzWgFx480v3WYktF
w0j9yOGqXkiVP3c+0J6KOdGN/Yl9vRBxQGgp5UhF5rT0zEtFIbjo3ruzbhcV
D/ntPRdPEYJVtAzj/R4qPme9slQ/IQS9Ll9FVzJhfz7l1Zx0IUxlrjoey6Ci
Kic3ZKpRCL1/zxtosqiYPBhr+2tQCF9o/fxCdyranZw6u1ZGBGXFDlfs91Jx
X6snpVRLBDkLHth3eFNxpfbtBef/E8Glo3P+BflScfOSjlc37Ak91eD3VM6P
ipnkz14TDBF4GtX5ZB2k4u7QzYfT/UWw46LBYtNAKm7rG70dEUr05+/x9R+P
UNFKa05tQawIltv/OOMRTEVrqSo1gxQRyN/dYfbnGHG+GqvFY5kiGJN4NBB/
koqpRs5JyndEwPdUuLX8NBUXf62inM0XwYfKAFJJOBU3Xc9z3/NEBEWa9bJO
UVRcZeK4K6pIBDdOGVUIogn+pfkNC5+LIKrq+wn/c8R+K3toGgT2lrr33+/z
VJQyWXQ+h1hvt91r6HQ8FYVdB7WLCHsGiUsfSiVQMW+4S2HPQxHM+9bmm5BE
8KkZtC72rghG1NJXLEqhotvDUw70LBGwWSR+VioVTXx2HfpyleDzttL1VelU
PJhBdxy+SPgj+kR5eo2KpwqGEt5HiSByzQWVjTeomNZTz6MQ+tPriG39mywq
Xlhh+TjPl/CnWDzO8TZxflen3+9phD9TFbbfcqnoqzn0qpjgX9E6VJx1j8iX
UWXNKELPsj+MnDj0kIq65buXVCsT+ysW/Df+mIr7JSzKd/4TQqaL/1DEUyp2
K2oON4qE4MXr9r1cTMVrKuNt38uEMDz0jfKsiop3xoeUTV2EwDa9rGL1loqk
TfudDpsJoTTUqb66morq4W7UnsWE/pZ8b8v5SLw/9XJ/Kr8XFNRK/vv7jYrj
0V2s7x69MOwaNHSGQ/i/X1fnJfbCt+y1D+VbiXzZRfk2o9kL1w3ur9DkU7Gu
c1hhktsD+pihYt1PxV3PC176OvSA7b5TQzH/qFg91RvDUO+G8Gf4UHklDU/f
myk4kU7ML2JHGV9X0TDxZON00cFO6N+eK3vZgIa9xdeeSG7uBHKXrI+SMQ3n
8d1slL7zwUCxUXOeJQ2vzBeNayAfPOmSn+qBhm6VVjJ2qnxIy90QmrCZhv6d
1jqfuR0we9P1ZgU7GpJXXmn02dABLb7eiXP30PD8fFmrQ7N4MK/oqtUnEg1x
5UDIqeJ2sJ2pHYin0lBhQ+j+hYfa4ckVQ3t5Fg3bT78IMxG0QS/f/c9Hdxo2
6VzY9uVmGywxSM6N20tDcdNQSWNWG8S+/jNrzn4CW++4H8hvhYq5+gUf/Gi4
7nx1mntOK4xSmawLATTcmzEYvOlAK7j9rCyTDaJh//QRz8a/LZBiMeJbG0LD
fbVPRjLet8CHszoLz5+g4Qe1zyY+V1rAdMmFozLhNMz/FBayaEML+O97uawm
krAnl5srOacFsp8O1p+LJs4vKNWa3cmFufZ7DKQv0DA4c1nff8lc2JxytqU6
nobLkv6G+x/iwvGO4tiYBBrKy+1RL95B9K/gJT2SV2j4U86jMmYeF9SrnJLf
XaVhpe39SdnfHNgpH2l9NoPgJ0pG7EYrB6IphT9tMmn4onzBEL7lQFl2T6ZE
Fg1TY0u4v4h5/NePhY5vs2mY/uH+hQfXOKBr7jB5JpeGIxrRsQEXOMCMPnVv
yz0aRtGV6BtCOZBU/4g8+wFxfrUT0bOJfl2t3inx5iENLw3ENNV7cmDKW6Uw
qoCGvFSpP2k0Dhg/2eqxuZCGn324vxhE//edOqYo/px4v+L7uwU7OHBjW155
VQkNw9T5X1/bc6Dxcptf5AsaQuRaRzdC78jwFNStK2go+iN8KSSw1SrrGrEq
gl8++zF1OweCgo6GVL6h4eEWb99HO4l+/yp3RUQ1DV8Ppav0kDjAl+N8hVoa
aionSU24cmABWS5y5iMNPRq9Unv3ccDh1iajV59puM1mak7eUQ5EDAS0hzXQ
8KZa5QOI5MDzDbfirJqIfDn+pOo2oT8GohrN/7GJfI9uSP96iwOHcpsmLnFp
OL3wYkVIIQeG338r1WqjYVb2ohM51YR//ewTBTwaFp1ybaES8fgjzzG37qRh
S7fScOIQoSeNuBMNAgLHXWywl+XC1K6WUs9eGr7VWd0Q8f/vj1fbzKO/03Bl
k4Ivi8aF6NL2ifmDNNxlRD88E8IF6TZeae4vGpbbSRappHJBflmn+fvfNMzT
rw2P53Bh4YMeczkxOl6bnH3hOKFHMj71TmSI03HGxjD60NUWWPJLWLpako7T
PpUa76taYPl//eY75OhIKvo5lqDeCgavBs0T59ORMntLiVNbKzzu/DmxdCEd
R9JxjdK8NjCWGCp9okZHRbyxecXWNthgP2LeqEnHGJpfrGlhG2xu/GOuuoqO
pfqNSwQ32uHt7/GJO6vpqLpd1ki8vR22LZos3WBIx4B9ehSfJTxwdJ0yp5nQ
cZvBusvjN3hAEYpZXLekY4/Sc+/VhR3g/1fWYvluOmq+aVeLndMJPzXmTD51
oeMhG4nS2PWdcATly7ZQ6MgV6lB1WJ1w7KyChTeTjpv33spYV9gJUYoqFvd8
6DivTX57glcXXNVeYmEYSsePnYMnI7oE4O+YPPD7NB1Fl5O+LFrUDRgsd7M8
go63Z5pa3u/ohv7q8dk7Yuh4RPm2cUtJN1gd+PbJL4nwp6BxVjehV1SSHSNM
Ugi+ZGZN2r/sAdGLN8Z/U+lYOcj1LvjRA0lzn169cJ2Op9kjw7N39EJ3wSWP
+3fpaNEwmzI+2QulXMn5h/PomOtrZH98uRAuiZ+uNntIx3CxuSvN7YSwd/Xo
cbECYv3RCRsDfyGYufitrnlK8Fu4+8eWS0KYe7qrPeEZHQs6baSPPhJCVy4t
kVJCR2eZKy4FdUKI+7Ptd285HW/NmptnOlsE7ktf3X1USUdtckDykcXEPG9v
Sg95Q8cVF1kqOetEIHvkobxVNR1NxZ2S3m8VAS9jxSvJWjqe+DUa3koRQeGb
a4c/faSjro1Ih79PBLEDyiuufKajUUVB27dgEbguuMBmNtDxgFqccUWkCIyt
Zp1f0URHRozjo+txIpDed3zjAJuId95ZieBkEbQl/PxRyKWj9OEXftvTRfCk
xCcrtI2O5KCl2TqEXonpbN+9pYOOBsulHsveFAFDjiQ5p4uOUgY5LdM3RLDW
pK74azcd/32S6pAl1kswtxzIENJxynds/D/CHje6bIlnPx3rNnt4XyD2e/Rw
Xf2qH3R8Sd4QohhP6Bf2vcihn0Q8y1Sufib0A2VGa33pMB0Dpce+Nxwj9IHe
1d6I33QcVwy8pu0nglm7FNLtxun4rmdx/icmoQ9OnN0+7y8dB9o/b2xxFMGD
7Knp5mk6zlJ7sdllowgiPh4tuCnGwCRhX7WtnghIo/2e+2YzMP9sQelLFRHo
a3guMJJioHzJW07ltBCaApxPVsxh4HTKQ17WJyHcv/reIEaBgTf9lh5LLhRC
WKVVxw4lBl6MtFhvnSaElcprbNpVGbhN3139ryuhTy1yxnLUGGi3KJitAYQe
3bv4vv8SBobd0DHU0xLCyWeyClPLGGhdN+qj1dYLn6m9zeprGPgj7LRKjQOh
H3xLk74ZMTC3SyJBTqcXDhyP355ozMAHyjtYif96QDrN+JWkGQOl39SGxj3u
AWwOu/NrMwPVomrXbJDrgaekhcHVVAZmLx/ILbovgAjvfsNIBgMz/8oGrD4l
AKfgctFGFgMLnVIKfZwE8D1lL/PJXgZ6jcUWbR3ughVNj7dcD2Dgvk5IZph1
QepuO+Uj0Qzk3TDOrKrmg5fn4jqDcwx0v/by+ZN0PhgfGTwrPM/AI7EpxnIH
+VCflDLBTGCg/xUPhtYCPsg08PnbMhi4/KCj7qdmHrD5hRnimQxMXGFp7RLD
g5xfMS7lNxnYX9m9x9yUB9bz1tQY5zLw68Cw3s6Mdji588RjjQIGjgTKbiwP
agM7N8f9nKcMTNOdsSAZtYHqIS3t5GcM5Dj470r63gqFl96lyrxgYFbqHU/p
/a0QdSPN+U05A2umPmrZ6beC8yM/ubBKBhqWx6+w+NECA5+UwkbeMbDc+Vi/
2fEWKGvv3vCohoGWmhsv2GILxP4oHvL9yMCHXLFlMnItsGIuy5v3hYElboKj
OdlccHXMc6xtZaDnQG3m/38/dtzEcRGJx0BSfMhLWiUHUtQHBXw+Ax3eOv9V
zuDAB9G60PEeBn6b/PD25S4O9NQ32kaLGJhS/yL+jhEHxIqDled9Z2Dy1aK3
gwrE/H229P7KXwx8eV48IK6hGXb5M4ILhxm4d10umVPUDP57phF+M7D1yVWl
oPRmuL3MmkOeZOD4tS+kGJ9mqJAR3O6aYhB65XriqFMztPyMPhQww8A/Fi8v
ZJk1w7yKGqkYCSZarmzcekOxGVbnHviqJM3EzN+1vb1TbLCNl7+RKctE1fzt
j+nf2eB59NH+VfJMlNt85vtoCxtO053/e6bAxMOpwpqCj2xIsx4Ws1Zi4qmV
XtfPl7OhSC+lrk6FiROdA2UnC9hQr2iaRlVlYgRZ/XRYDhv6x5r3di8i9rMY
sryQzgZJ3gmjwMVM3DhJXnk9gQ1L3y3++1eDibQr282LYtiwKb+8+txSJo7O
qT/6NYwNlGS3yyraTMzwGtn68xgbjpycxbqpw0SR4fTe6cNsuORxe9VqPSb+
svO8NOXPhvt2W38/12fi86fL3w34suGtkbBy8xrC/pIZ90/ebOhQPR//2YiJ
xidW70rcy4bJaX0q3ZiJ1oHHBEaebFDtqdPuXc/E87MEC/M92LCuLuDn4Q1M
lFkTMChBPHcsnPdi2pyJJWBvYk6875vxNOb8JiamTJge2EzYPxPpsnsBMLF6
27wxdWL/G75jGresCX5uLT9c7seG0p1pfQY2TPwW/iJ4RSAbmkwtnpXYEvZp
ejccgtlE/22LsLFnomnu82j9UDbISYY5ftnOJPpr4ZuKSDboDGgtYjoxcVPw
wd+zzrMBG6sEQmcm2pJkPv1MZMOxW5KhMyQmKs4M/vqQzYbLsXdt46hMnF88
yniSz4ZHh+yVFzKYuPhFUppZMRu6LS/eN3RnYtNbY3v1z2yYWWEUXObJRG/a
Oc2DRPzV5RvQ1puJDynzY3cJ2eDcMp/jeoCJH+yChVXizeBX9fx2nz8TlRY8
OG2n1Awx96iHgg8x8faH5ZtcljZDech1qYtBTFxj1p70A5pBX2XFfy/DCPur
ZFxropshTWzTSFgkE8OPb/F4kNYMkoN7nlhHM/H+qqxNCg+bgV9zZs378wSf
ZrOrbZqb4UqYQOdrChOzi8mosI6op/5sVVEeE4cib83o/eFAQHNZU95DJkbZ
RF05osSF1rdfLx8sYCK1bM0/WQMuPL8prjjyjInc/BcZCz254EfylP5XSfCz
bsUfVgMX2JXLxlWambh1lU/13rIWsHlk/pzNZWLs0ksOJE4LPLm2Kyi9jeB3
G0UjYKwF4kMif2l2MbGBpVUrb9IK1gadolU/mHg0cdL39cNWyL+axYXZrjg/
6M7Z83fb4EyA1gs/I1dsVuGZxGXxwMpEKm5mnSv6TIX7csp5MP5ngJ683hXH
tF70qLXywD+ybLLM3BVPwXBo8IIOIKeQLORsXPFuxLYHR853gF5ZXOk9qit+
U6oabDLlw2fJ8eKeSFd8nJ/lfnBeJ8R+4J07Ee2KTQ2xEkc0OmFLwjvK3HOu
eHnXMpGnfieULEr+sz7eFc/9itOSsemEW6sNN0SnuuKVmp3/yCGdELTL6/ny
B65YvGXlidfsTlDP/FLk1uSKxt0P7lRHd8FnO5X4XrYrovGzVxcvdUHUKGnv
Qa4rBq9bE2ee1gV921uVQnmuuNr1Ta7Vgy4omewJSBW5InnehdSJ+i7wv6Nn
q/HdFdMs21w7OV2wdLefRs4PV4xYzPfI7+yCc/d/fXwy7IpGDrau34n+Rab+
1fs05Yp/N5569P//w5aTsBJzmXFFpaUfV0otEUDF44jmllksXNc2m9+jLQAd
aakYkRQLPabVo7abCGD02TzBbCUWBtaavXrgLIDLKrqZFjosPCNZWHLnrABs
X/kGVa1kYe+2h8FlcQKYPPBgu50+C/XNVv16lCQAj9drJ0lGLFzpmVJrnimA
tYc3Ug6bs5Cd8aKq6akAupeEGY5vZKGz14TuQLEA0moqJcOtWPjwlNuw4KUA
ZrRsi+K3sHBK7cC7oGoBfP7srHRvBwupdjNn1DkCiDqZLDJ0ZiFl/d+s9W0C
MNVlv3q2m4XySewRQ74AMk8zAt5QWHj2g9WSt0IBOK+6sdWBzkIrK1IX67sA
JL7xlzQwWVj/TfCKO0jobwOfjzwPFoapyvoH/hbAUs69bG8vFu5tdtsbPy6A
xjPfTwz4sFDM7Fxd7F8BWLQG6k36sTA8ZJ209qxuGIwpnIkIYOE+7VVdlbO7
Idt4jC19mIWLFVqtQaobZC+Enl0QwsJpC0p2u1w3KGxav7PxOAtNVAYC9ed2
w/zBgUVJoSx8rXt1227FblDPyu1yCmOh/VFvA5JSNxFvVr58JAsVrw6bmKh0
g67EwpAPZ1goGjM6MzC/Gwye10NsDAu9fuZYRKp2g7FvrKzteRYqt3NODi3s
BjN168bZ8SyMXLLHy1KNmB/qJq5XXWKhpdy1hd7q3WAT9tQnPImFzeJmz3wX
d4PDWr+1liksbPd84mq3pBucu7QnJ1MJHHNpnYRGN1FfbW9K0lno85G86zqB
mbZXLoZcZ6HUxaT2eZrd4Dm+g7L+Jgt36FWPeRDYN09q2fAtFtZOhJYnEDiA
+ar/cQ4LpVkWuzMIHKRwvOjgXRZebrvQFEngk5Vrw1bnEfGkLt9hS+CII33b
+vJZ6JAd2yYk9otZka109zELrT0GCnwIHM+mt3o9ZWGHxanx14S/l2NVcpc/
Y6H6N5/OKeI8Vy3qAvjFLOR/a0mfT+DrA9FmN8pYuFwg5SxHnD/7hqU4s5yF
37LVjHnE/HXPeeyjWiULhWXWAYkEf4/EH19pfs1Cx4aHxssIfouK9rldecfC
33HxDxMJ/st8lq7aU8PCxkT5uR3K3VD9Ienl508sHJn3wFiNiGfdKYeY+C8s
PJhVtkeSiPdXw9nODo0E//6V0g1EPvAuBwnecYj6UyuUkCHypdtmzcMzrSyk
R26sOkrkU/9YT4g1j4Wzc/4bfSXWDWN0ily5gIVPdZ/nTE4KYEp+XtPJXhYy
53Ku9P0RgPirmkyzPhbOvMjuLh0VgIK2xbqiQRaeCNsfNfODqPfvS6gPJljo
n3JdSadDAPqZ35btnyLy29oWdVqJet156bvuDAtVZJQuyTQLYFPhTFi2hBuO
vm90PPFZAC6hXbnpim64fObcAzmiXulrrh2iKLuhJ3f2WX2int079pgvWOCG
XS9ehBsR9e6/5V1dorobigZEHX13BRA9597IOR03FFzsndC9LIDmFKN6VT03
/Do7QIwbT/ijWZyXq++G3xcG7A8+J4Ava6s93hi5IT/nFAYQ+n0xubv+n7kb
XiVVG/p4C+Bp1tL8YCc37FgbeSCLuL8k9e+dk9jlhi9tJGRV1giAWmi0N3mP
G7ZWS2Qc1RXAv3dW6k+oblgZpnZ6ZpEA7L8zYwc83fA1GDx2mO4C/n/pXnuP
uWG6wPgH93UXmLxaisMnCHtxTY3bXnRBjN29xZGn3NDvUGfY3cIuMGAUf70R
6Yb7+zYt35TTBccivmFLHOFPyj3DV8T9r/BRSWNXlhsmZUU8O7ilCyzdL3yz
qnXDDw37KfKlnTBQKN2iVueGx9VVA1Qed8J16bO80c9uuEyMdVkptxMmH4UL
85rcMNBUxXI0kehH00ETqnzCP5/YYbpvJ6y/5qbxc8wNtfqNTQcXdMICv4yn
O5XdcRJabi4K4MPAfO76chV3ZL7xFYvfy4e3FQuL9Re4Y9L8B0ozVD4EKV95
IbnIHW9Zvd7Ys4UPX0sT3r7QcEf76FNeJWp8SJQ5y165yh09lQvPMOI6wPfp
G+oVfXfE2z5KgSEdgEzxVnEDd5zLQqM4jw74+Ti8o93QHdOTf35gb+gAJ8pJ
UfJ6dxxL2W1Z380D3VmlB2aZumPWRGC/9hceTOf9GQjY4I4KM4bUqBc8yP8X
NGRv4Y6Guq+7XS/zIPpe4dHije447WXyovU0D5i7h3+vsHTHkrBTVV77ebB+
au3xy1buOBjpt2fChQdz7hyanAF3ND/9uS4defA/F6ty6A==
       "]]},
     Annotation[#, "Charting`Private`Tag$38651#1"]& ], 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEmnc41W/4x+2MJFSiaVN29rpve89jh5ARpVRCStKQldFQolIhksoMSRo4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       "]]},
     Annotation[#, "Charting`Private`Tag$38651#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Critical cases per 10K\"", TraditionalForm], 
     FormBox["\"Prevalence per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{Automatic, {{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 5], 0.2], 
       FormBox["\"10.\"", TraditionalForm]}, {
       NCache[
        Rational[2, 5], 0.4], 
       FormBox["\"20.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 5], 0.6], 
       FormBox["\"30.\"", TraditionalForm]}, {
       NCache[
        Rational[4, 5], 0.8], 
       FormBox["\"40.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{0.8899999999999999, {
       GrayLevel[0], 
       Opacity[1]}}, {0.7000000000000001, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.2, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7934462183922*^9, 3.793446262635705*^9}, 
   3.793446322861353*^9, {3.793446417955284*^9, 3.793446493969702*^9}, {
   3.793446528220602*^9, 3.7934466811191187`*^9}, {3.793446762960642*^9, 
   3.793446783185998*^9}, 3.7934469583619823`*^9, {3.793447077418531*^9, 
   3.7934471077778254`*^9}, {3.7934471626694593`*^9, 3.793447176249228*^9}, {
   3.793447220612138*^9, 3.793447223788662*^9}, 3.7934473045057087`*^9, {
   3.7934475125474377`*^9, 3.793447526798827*^9}, 3.793461894648978*^9, 
   3.793461954811411*^9, {3.793462025917428*^9, 3.793462051362706*^9}, {
   3.7934624165193977`*^9, 3.793462437537854*^9}, {3.793462489379582*^9, 
   3.793462572943308*^9}, 3.793462608295115*^9, 3.793463073451934*^9, 
   3.793469063710894*^9, 3.793529281741108*^9, 3.7935297656727667`*^9, {
   3.7935298070245333`*^9, 3.793529926132883*^9}, {3.793530274168375*^9, 
   3.793530289438217*^9}, 3.793532174176157*^9, 3.793538247473281*^9, {
   3.793538609925652*^9, 3.7935386184566174`*^9}, 3.7936176643324738`*^9, 
   3.793617739913664*^9, 3.793628688422764*^9, 3.793631368379669*^9, 
   3.793632181435913*^9, 3.793632436100501*^9, 3.79363261614002*^9, 
   3.79363289767867*^9, 3.793633151168467*^9, 3.793633213136217*^9, 
   3.79363438528654*^9, 3.793634840298051*^9, 3.793635142169423*^9, 
   3.793640118873715*^9, 3.79364022459678*^9, 3.793709172791792*^9, 
   3.793717683096919*^9, 3.793717911461453*^9, 3.7937181834540567`*^9, 
   3.793718274942525*^9, 3.793719546969058*^9, 3.79380139985353*^9, 
   3.793801480456283*^9, 3.793801576534741*^9, 3.7938016438461027`*^9, 
   3.793801748581594*^9, 3.794507035686893*^9, 3.794507503528822*^9, 
   3.794507549871644*^9, 3.794507669309033*^9, 3.794513118950705*^9, 
   3.794513185807193*^9, 3.7945150393193398`*^9, 3.794515323661188*^9, 
   3.7945686581239157`*^9, 3.794569023047379*^9, 3.7945767020032387`*^9, 
   3.794578159030787*^9, 3.794578445404962*^9, 3.7945793763943243`*^9, 
   3.7945795058447943`*^9, 3.794657260812409*^9, 3.7946675332544394`*^9, 
   3.794667830134185*^9},
 CellLabel->
  "Out[930]=",ExpressionUUID->"ae81f538-53dc-433b-960e-415ea0a47e30"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbps", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60bpsprev"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"10000", "*", "sf", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60bpsprev"}], "]"}]}]}],
      "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1.2"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", "sf"}], ")"}], "*", "#"}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}], 
         ",", " ", "All"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"dateticks", ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
    " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", " ", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", " ", "Black"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", ".000089"}], ",", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevon"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevoff"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793709147296422*^9, 3.793709164089078*^9}, {
  3.793717851683216*^9, 3.793717851773666*^9}, {3.7946572649048986`*^9, 
  3.7946572663324013`*^9}},
 CellLabel->
  "In[931]:=",ExpressionUUID->"53b83aca-4b87-4dee-8cc9-5b7f76a2fb67"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEl3k4lO8X/1EoKtJKJdl3su/n2HfGjCS0yR6lRVGJIkVSSgtKlGRNKaIk
ypJdWWbGvs4MoRKyFL/nd12/3+c7/8z1vu77Pvc57+d+nvt1drkfJ3tysLGx
HeViY/u//31cyu3ehtUGbP/vx5fbOWHmlw7/X+ez8x4V8nvznw6Tfyqz0q/y
P800/LFq3rftP51sczf4t+/wf3rGweflT9/p//STNgebH74r8f/rD70HTxab
bvpPc3NPh5Qn7fxPG9S08Jl+/p8+czXvWe33/+mpiNc+vsIi/+lDKwMSTh7/
n9bn7P8euX7Xf3qWqzopa4/of1rA+83Id9//aYWaJ8qKF/+nPa6GVRdk/E+3
cmtPvf/zP/1yVa5lU6LYf7rBJymB/8X/NPPLtT7yp/9p4WjPIOrY/3Ts6p1p
/bri/+lM37XjoiRxzNdd7m2/rW7wuXZRw9NDHNsux7luuFlg0Cszdul5sDhm
QSm55MiQwUI0rWE0VhyLDfwej+5YAZvHqrfIp4njy/Qln+FtQqBiVeh+rFAc
lRZ9Xby/yYNd9tO8l7XiWPesI98/VRd8eW7PTfWIY5Dun6jts+aw+ZEydfy3
OO5Di7j3XI5QqdRcyFgtgSu37axVoxyEE58CEvp3SuAXkqpLnJE3CO9Zc6pT
XQKTDkWnDN0KhHpmtkObtQT+80sKfdB4BoLPWSo3HZbA+jKPHWXhF0FiLWvd
l7MS+DnCOvUWIwK+PY6aqLghgVes3AqXPKMhTEWi4f1TCYSlDytcam6CfNXn
7MISCSxcP2jaefUO0Pe6R+c3S6BHnv5cYep9iBpj88kakcCzIUdbDBUfgmro
Y7OnixLY9eBMX+v9VOjnM5B4tF4S3Wjm7GkOT0FH/fzgLX1J1PH40th1NAuY
NYIVMRRJLJnSunq4NhcSXIofR/pKYrznD2kZhZcwGTbjFnxXEsNsedgqud9A
skCC7skcSfSulprftbUILJ6pCPlXSKJ1LSQ/NCiGp3XHqQcnJDE7KcvGsK4U
SPvXFe1bIYX5Uodjnit8hKUfuQkUQSkUytMM+/q1HJw3jTmYm0rhfIvupVXu
n2HNIY8GxUdSOHN0xJLe/wVKpjhypF9LYZSnVL4euQ68rqRFi9ZK4QsFZdut
dfVQnt1rtnlGCgWcHBwEGpogaMa54p+NNIbtmHtJifoGvTG2RQ1/pfHcq9/X
i3/T4PqO8YRqARl0bkjLsSijg9bLmFPl0jLoOPSNbT6qE2631yi/cZRBxZCu
gWPru8FcxCgnOVcGV2jdip/n6IPpgv7ou59k8Ka11P0bRX3wxDTM5yZNBqUU
w7W2qPbDX79SiYiVsihRG/jsVHc/vCzUSPVzk8XV/KrxghsHoYrDZu1EoCye
uviGTtk7CJ32h88dvyKL+08+avZ5MAgrx647nn4hiy/+fupatXEIBDXTKmY/
yaLA5zXd1+2GQDGySDGEKospwYXvO6KGYK/wwKqLbHI4IR3xrOznEPgfnQ1i
2ySHe0y9SK6iwxBezDt0WUYOV55VNS5zGIZsssaHq2Q5HKzm/dGXNQwfH1vL
8njLYXvf26yn34ahbfzQ/djzcuhrX7ygNT8MS1HXT8Sny2G33vaZ7zACG9pS
ezeUyGFzYNzJDYdGQHpXkfW9RjlsWp5S2HVxBPSP1RdvHZTDdZeUdbcnjQD5
fb9E8qwcLpl2lPK+GQHvVbO3d/DK47MivabZ+hG4sIeXLXWnPFYI2UcOD4zA
rSciAaJq8rilxZq/Z2YEnv1Q70y3kMdfsyWDLG4GvNOzNpfaL4+//1Qd5d/K
gKboQ2+yThDrJRMmXSUZMNQRtEs+Sh51dkVbtqkwYE7setyLJHn8cc245LI+
A9aeSF1UzpdH/+XD5wLNGCBaVujz+rM83s38/DzDlgGavPXt6jR5NM1/c0aR
wgAb536j4nF5dP6reWX9XgYcfjaTr8OugL1Bqqf27WPAmSmeHR82KWD/K9cG
PhcGXAeRGJBVQIHosX59Yjw1Vv1PhYECnnv40nHCiQGFdCsPE4oCBp8Na5ci
4tdJHvpa7a2AR59Jr/9D7N97KsjA8oICCtbRX3qYM+B3eUxO/S0FdAryng0B
Bqxal7rV7pkCdocu6qEGA7a7Fl5pKVHA15VZbBVyDNidWTdFblLAEdmoD5wi
DDCb6TvYPqiA5+PTf2zZwABXo5mGvX8U0GHL20w2TgYE3uTR6eRVRMHhiWdf
CL+TZNQ39qkpotej1fzb2kYg/4zVpcOWirih1b35bcUIVH4+ODm0XxEZnhOy
zi9GYGJ/zBdWlCKKX36m9jlyBPB234UpmiLuOjlbpyQ1Anv6pkdPTyii6VNG
bOPaEfCT59n7h10Je+waSl/8HoaEarXdf2WV8Ohl2QWXD8PAXIge4QxVwrtl
I/MylsMQd86eAXeUMKx9xYCw9DCoLWxkhmQpoUBLVVUIF3G+5x+zJtqV0H96
35vIiiFY+7dzxm+LMvL982ov3D0Ezxd+zpEDldFF/PGFfLZBOPeOMn/8vDJm
8A698KEPgN25ovnYKGX0P+oq/vvVAEzPn1+ofqiMqSb20TfdBwDnuf7q1Crj
33b97guf+qHzz/ZlUdHdePqTmKY9bx/kvQ1bBoXd6HSY8vRJWS+Enx1cdtPa
jbSkC+WdJ3tB6s9ztvt2u9Ekf3ZkT28PnJ5V4eA9vxsvbtpoWfGZ+L4U3eWQ
jtqNoyV1/NfDu0HozByHafxu1OoVGWsz6IbymQ8rwp7vxmWzOSfh8i5YO2PB
+bt1N5aUb9Wv7+iE/jc5nPx9u/FUa+uuntROeHN6HZfC2G7kvXYnudy/E1ym
W7m82VSwxSti6waeTlB4o8EdyauCGeHhEzFddGA7ncidtlkFj91x0Ge+oEPG
7wOruuRVcOhFVKSTKx1CXlesmtNUwatyNhEBanSwOSW+epOxChZkeOkH8tFB
RPXqahU7FTTQymMdGKfB76nR1fb7VPD4dMAH7XoaVBfY8Ph7qKB+TrUbWy4N
kk7m80QfV8EZ8r8Hr+JogFOneT9fUUH6Z4fupn00mLc1l8m9pYL9ThUCaUY0
KMgSNL+brIK7l4LtTRVo4Mc57nExQwXvTOYqlgjSQOxw2WXvVyr45YHv1Dw3
DbpLb6WSSlWwV6C6d+UcFRK2HinTrlFB5km6JnWUCran1btFv6ng6229pQE9
VOBq4V7g7VHBtmHejMpvVCiT69wyw1TBny5fX9BqqXD2aq5675QKHvLOuZPx
iQrKQxcpNf9UcMpCKV/2AxVYBg4nXq5Sxakbi28OlVAhLUnsZuIGVSziSuw2
eUsFl9mZ3MvCqmh4X8y9tYgKAuQvdUdlVJE6pXBwVTEV6vOSWI5qqlirfTO+
7x0VIlcHcBmAKho7u047fqSCnieIS1mp4rH7j656VFFhpny9Ef8eVRzZcdeE
p5EKL7YPH5w/qIqmerWrjDqo4BVcFDrop4pa3YPl3ANU2Nl2Lbk+SBWDn/xy
3TtBBZqSa8mbcFVsU+z+Kr9IhVvXFaiPrqviXNIv9UgeGlgyl6ej7qni4fn3
Mfu20YDD+JtAYJoqGt3m+ppJ+P8uJV15X64qRusc33XMkAanFs7YGb0l9tsf
0vDMiQbyTpb+cp+Ielxi/loH0GD41baYjY2q6Ch+m+52hQZOvuVVjEFVlOcQ
EntZQgO+qttDzROqqDwode17Ow2+iHiyl8ypYl7ZZaMI4r7Wpq3Wv75ODfvC
hMZKVOgwpdrtclpQDf+k/EkiO9Ih++aL4P3iavg0pa9G5ywdtptT3ijpqKHP
YJn9RDkd2p9IfNtqqoZfz+ZdfcWkQ9zSnx/sJDUMvnV3ppivE5YLH8q1earh
ukiW0pUjnTAozngSHK+G1V5GVV8EuyA5vLj88EM1jPpnEepi1QWO3TG9Vs/V
8FPgAYVtF7qg6o6S0I4PanjEpd9JZKgLMjlC4itYavjZwCb7X1k3BPTzhvOg
OpJlI39l5vaCS6LgiKaVOmZQi3iaxnrBjCxl5emojg1Z9/4My/SBSKXRxnIf
deQYmyoeye6Db89DMoPi1TGPV9CX360fNI4zW/oH1XHyaXbVpbABEJWeUV83
oY5Xr9fJcGQMAN8AR7LuH2L9WSv+uYYBYJGFPe/xauC2nHBJk+2DkKSxZ95a
TQMN8mjfD5UPwvK/T7veXtHA3T2OS2nCwzBe1BI1fFMDj1/jf2dhMwy0473f
1ydpoIWx3jqVc8NQMDBf6P9CAxVjzF2DOobBo0rZSpSqgSedUgQ44kaAdNEg
335AA62S279sfU/wgKbNxtDvGvhrqUEoizkCm7O8e6nLGsgU1z7w1YABX2JT
Tt6Q1sTExKby3EEGvDHNpb5T0cQ6Ljbq3CompC2V6LH0NDHN6zOJT5EJ5wLb
uYwdiHEecNt7mgleMkNHA1018fqtc5+O3mUCZfBnyyNPTWw9AnbrCpkg77gm
eS5EE/+8Xdnf/IMJW9cKsUlGauIva9nlLh4WcFZLeVLiNDEjV8zFTpwFUxfV
68IfaOJFnTsTInos6NU0VnrxRBP7Jt267MgsqP9JSujK1cT2F5NmrV4sKM46
ML/qrSaqLR81zA5hQbq7/wGNCk3sntxT9DWGBfHbzn0+Uk/sV7Kq2jyJBdUT
B6f8OzTR4b2XqUgWC/5+NN11ZkAT19/M3LxQyILdt+VIYeOaOMZQfNxRzgIv
j/Vh1/5oorXbDr+3tSx4qPEnL55DC8cZPU2PW1jwdVVPd9JaLUzWpDgktLOA
q+sTb/pWLby5uCk8kcYCvbxMnTwxLVSPf9Hwhs6CE2FxvkWKWqj3YEXDODGe
4XD6wUdtLdR0dJS06GBBt5hLzRcTLbQ+ZLC66SsL1s/C7Fd7LSzfM8yKqmeB
2RcJiS4XLSxNUPE7/5kFF5J4HYc9tdA/dJPKmxIWvPL/dXkiUAvdXDk36bxg
AcOA+mr2vBZel0zn3pLGgu3rP/QvR2nh3E//g3tus8Bh6Anf6tuEbu08sXyJ
BVGF1wwEHmmhs4Lc4Z2BLCi9eixgW6YWlpwxjf/oxoJf+xwfir/WQs5Q+VXf
zVkgKa9Tr1CmhQyRVU25uwm/WzhlsE0L23cPFQqzE34/+b7Xsk8Lj00ZNw4z
mPD39Nco8pgWpnsnWwXUE+dH8NGwB5s2jlWHlv66xQQ9d7XUaHlt5DFp/7Cw
jgkn1ISab2tqo6CEfQTXOAMyuNiWko20UXm4wE/uCwPW59S7vnDWxi3fJJ2/
hzKA8dt9S2ukNnrKT5xy7h+B+Cvxcdt7tNEhuPaaevQwMDInL+Tf0MFDzTFf
I54OgD2N7/ff+zpoZBb2b/LsABRz7/a1eqKDpzz2Hb9mMwDXvU7tGSnSwTvO
m/NPzPaDsvicwrZ+HUx24ThoZtcPiRTBdJ8xHTwzlkW0nf3AEaEjVDStgwIm
qa/T5vugbeACl8NqXaRtjgz749IHIY/Z+6JUdPHhOo1nDvK9MNgkuqdNTxdv
7tLl5BzuAZsl4/pd5rq4t2EoSepRDwjvj3pb6qqL30XzLQY29MAnId5bU5G6
6DBIIq/d2A1yVvJceFMX153c+1iC1gUJIbYXbiTqYoLW+lTmoy7wpt30kX6h
i23lIo+DFbtgzb2NhgeounhjU/uRnR6dEFSl/jZnQBd7fuWXd6p3Qu+0k8L8
d110S/1eSF7dCa8oiYIJbHooPp18N7iQDkIR724O8OjhUz+RC5JxdIgs6OJU
2qSHFT6+jrd86OC0XniqVkaP4KWB/DuidPiI4LNFTQ+pOYx5WQ46SAce6vUw
0MN07FcKGaLB7ceXHAss9DDIev/FC9U0WGx6UrdM1sOfHBrLKjk08Fj6jLb7
9TC2cTYqKZ4GTQojRUneepj99F7/yxAawfdST9Uv6OH5h1I7BuxosLrUQjAi
Sg+Lfz3/PKNLg5PffW+23NLDBEMH6XxZgk+ErnMKJ+vh2nGBjzzE/WpqlXv+
6DM9/ChrsMC5lgYvQhp/Fefr4Se+X22P2GiwNWvSm+udHmY0bDFqnqHCJRpf
L6VSD+MkvvreH6fCGPdux7QmPbzdq3v69zAVKJrkukmaHnY3iF7o76VCqdcp
1BvSQ+Ow5cuunVSQuJdQFD2hh199dqccplIhrqpQnvpHD7XmFod+tFPhz3TH
E3EOfXQ+mHFyBcETh8Tntp5co4+LDoo5icT8OorgzY+b9VFZKaI+n4inGqHD
uXaXPv7zv7zSuI8Kl+3qH0jK6aPVHSs/xREqtAi6yaO6Pp71cnt7mch358j4
x32gj4kq2mb6RD3HXoZSTlnq436d4FHXZSLf8+uYsRR99PTUftBN8Aiv+eNz
Gfv10U2RfbJ0Cw1cBJTXlXvr4yifY9SCBA0ye8rT6Cf0sSiy6O9tdRr8yXRQ
/31eH/2588YjzGhgdnrwy5oofZQ5/UK63pkGCXDKTfKWPgoWXkjw9qfBEM/K
n5Ckj1cTjxzce4kGKh0JEfvS9TE2c23Cg/s0CE+T2HLqhT4a+Uroy+TTQFjL
3CDjkz4WG/Jv3T1Ig4AVtK8fG/RxWd7lxLN/NCht8vGkd+jjuiMNhUeE6LDP
MyZ2zXd9lO5da1e8lw6ZyttEJGf08bpO8xfrYDrMLua8hmV93Mf/6IJYEh0S
bjd2ntxggKI9i2uSB+gwtP/AsdgdBki7o/VPm7sTVGR+sGdIGeCRqN2XhBQ7
ofkjvwxd1wCt1vhlpYR1As8E5Sx4GCD5foda5u4u2Fc8zLPvmAHW1U2EWhwm
+CQiKOVksAFWn+f5LnW7C0yF7lc9izXAOzdMeTL+dEG4eeeGNYUGyDHtYp37
tRuaBI4+l/hogJ6h/k/IvD2wo3dRB2oNMGiPD7eeWQ+8O73D/WSPAebcu7ip
52MPzKQdeknjBDzmYRob+qkXTAJ+GU/xAe4x+L35MFcf3Na6TOUVAvyWZWN8
27oPlJufLhkoAt5quTcxRO8Dv78Mm2dOgK08eQUQ0Q/9TgGjJ54DwnqvqsqW
AQjW7TDzLgA8zbUuP5R9EPhEIN3tA+Dk102H16sOgsEo/0HzVsCooRDp2geD
8PD8m7bty4BHDq0+zB0wBEIv1wmu5kTc9H3Y8uDTIfAS/VwTwYOo/1qD5y99
CP5xyUuEbCJ0jflAiPkwyLf86zsih7gqeK/xm50jEGxUENerjHhbvMzOx5Ho
h9946e/TIPQjuwcO10bANbE5yc4QUTze77DVxAhk8EZa1pohXnq8il1CmAFT
oVpzxjaIWZWsiRqi349xT9ujvRdRTdiycXUWAzra9qx844bIk6nYF9bGAFFz
nteK7ogOlQez/JYYUCJ3il88AHEuXTbrsC0TVqZIfUw5iZj5JtvZ4SQTSPzd
AYLBiEaKdgLhBA+xpk3q10UQWn3E/EwHE9S850OiryHueFDzRHGaCeH0POmV
cYgNRs1nV/GzoMHanXrxDmJwl2/HkgwLtpRtjpp/gPg+dbUlnxEL3JXr1U6n
IC4oyIdqObPgxZOwocmniK9lmrVD/FmwsFHttm8WYqP1i39fLxK8cJWFwy8I
PydcykxusuD2/MMfB94gjnMuhbc+IvjqqEMKvQQxXf2T3KVsFsj2cto6fkSU
feg170DwUBDp3WJTJeK5n5sNrcpYUP7pWLZlHeLP6yH9x6pYsEZdbF9lM6J6
41u56joWOD+nckM7oqRM5lunJoLHBGOLSjoR973dIihF8NLP6+ip1k88nxEh
aQNC6y1Nb8gfQfzrU82XTsy/Fpj1SeY7ooTbM7fDBO+0Du4/kf4TsY9qlHyx
mgXCewREds4iJvFvk1pJ8JlfTXVT4iLiu6drpxfesqBI+3zoRnZD7D6ret2f
4B+OXCX5m1yGeLX9W5D7UxbYCQ93rl5jiGBgvp5xjwWJtx5ER643xCxOBxZb
NAuGOWy1ljcbYszQt3+lBE8qB7EzQ7YbosWBX3vEfQneYhbend5liCun1b/i
XhZ82ednclyKGF9dpLLdhAUHDVrTPFQMsWRRdqWWEAtMDkqcvqRpiHSB8yWC
nIS/4WfNUvQMsWddZTsnwcOzFdu+U80M0a5TLGJHORNiTT3UrF0NsfiBhJyM
MxNOehVx+RwyxJn5mR5dPSY4X11Fj/Q0xHfn7569v5MJYrW5oWXHDVEu3XPR
bJgB72xmqndHGuJew2vrbLwYkBpgnmgXbYhq0f1mx0wZcCUu8ejROEOMVZdp
4RdnAKlFn//ZA0NsOTZ+5lffCDApUfu25hliPvnkWCN5BDa6bhlfajfEANbi
2QGZYVg471u2rcsQ9widt6pdMQz9D9/f0uo3xPD9wtIxPUOQ03tQ/eSYIZJ+
vCrIuDUERu6ZF0eWDFFZ4faB1zODcNxXe32DlBFWqAt89CobAMeY60MseSOU
dmi9nnx/AHRyego5VYwweKYtuD9wALgmLrmAnhFyjQylPhUbgIeBdU8LSEZo
zD1j4hPTD3VnXTUSQ4zQk15R9bi6FxyfJU6IhRnh61sVaSnneqH3GzX9RaQR
2u0dkO5X6oUpBccNlTeNcD0/r2lsSg9ccL1dZ3fXCJW2Vc+LO/cAV3TLJXqS
EaoIFwe4EbwlNGzzc/KZEXLXbLs9H9cN6euvPw/JMcKiye0hkfbdoAi1B1a+
MsJ6uDYxv74bjJJMGwVLjfCJpnPj4MMuaKiJiEyvIOL1bas+5dkFTjMVuko1
RsQLvcdeRrkLjpIMsk2+GeGwpXmPSkMnzIZeONxMNcJt2fUGDx91QnjOu60u
PUY4v2lcxukEcb/Q55qHB43wgVHnRl/zTkjg0rx6nGWE8SVKM907O0FYLchg
YcIImSTx5yULxH13+PVM5G8jHLKWqOGk0aG0VMkjackI9yv0aK0k7juzsYBt
EiuNMdA1JKfiIh1atuR+y19tjP53eIRWetHBxXQsWofPGH+pas8129Nh+KS0
YdVGY1z51cleRo8Ox1K95uyFjDFmMvLMBjk6zDWm53fuNEaZ4OCy+O10uLw4
6OUpYYxdf27YPuenwxqZXcI/ZY0xKkvvjRM3He45HWw/p2yMrqsaAp+w0UEk
8lEsp4YxZjUGsmL/0iD7VZfxLV1jtLPYarF1kQZqfYKLQobGKCJoVmhGjJet
cS54ZmaMfTeZNkLEegude77KNsYYiSl1CVx0+ObdJvLegcj3lRx3MR8d3O4K
0Ez3GqPe0xuTV7bRgfGJdLPFzRjJni5ebLJ0CPwZZ+bqTuSfrCcjo0uHhR2N
/0a8iXzObFrJQdQfac1bGBhgjJvzkmpjPemwLsTSf/GkMfY0GLvXE/49yLgq
FhVsjCFO8+vLCX9F26o6+S8a48TDT9/9S+iQy77ydnKEMcpXRS+0dtJBQ8nI
UjLaGL+JdAb+WaJDuVs426s4Y1Tk3ybdKdEJVjFlb3UTjFFI+fXvi/ad0Pb2
77HqRGO0bNR/yjrfCQdGdCQdHhujt5oTl1BOJ7AEQnq60o1RouD++KaeTvgb
MGP9K98YNzZ0mZ2z7IKoZNUVFwqNEf/s+jIW0QX8tSfecb03xtHEtjG1ii4Q
F5+U3l5NPO8eexsvk26w7WRwmncb4w/77LvlAT1Q195d/3bAGBVGndsWPvSA
2ddv8dJMY9R8mEretr4X8EvZDp4pY6SW5clJlveCWtE99UZuE/wqyRvNt6sf
Xr2KXdRfa4IP5zMChff0g2Le5YoXAiaomy23tYB4n6XSj9ne2mGCu+JzGuQW
+kHotpknRdUEz6m5xl9mDsD9G3pylVom+M3GbMd6iUHYGK3yS83ABBMdNHw1
jwzC2nDh0M2WJpgk2OuT1z8IbMdmE+gHiPjxl3aydw9BqO+4i5WHCQq+kVsW
ECK+Zx6DIu99TfA57x7DO3uH4bdrU+7D0yaoeqmG16OF6BctMyoPxpggL2/J
gFbRCBwxfRjTctMEeVrf3swZH4F+vE0yvGuC6SdYox93MYCuebFbNNUEJQyP
CNy4ygAn1dNP7jwzQTPXTqZUMQO+Kfr5rMwxwWt8VpdlmAxokHCaHik0wbTO
5WJ1ZILlLpt3Tu9N0O3Jg2QFPyZUbzcKryk3wfO9out9bjOhfIPimqx6E6yZ
7i2N7WGCPp/4N8GvJriXh3HxOBsL3vEIPYjpMMHgxmPCkbtY8JqdS9x/wASZ
b4yG9Q8Q99m/xdFuhgnxvLX7B4n7LXfuV77tuAlm/NIuLL7DAplpZlDZLxP0
/FTFqMhhQcaPHl2lPyaow0FSYv/EArHvreypf02wZ1+GZUgHC1IZtTX8HKZY
9Sw7W2GUBTsGP964xG2Kpxu4D4ktsCCpp5AytcYU3/atzjm4ehS20HMEjwiY
YoK8cxVz8ygktKX1tW4xRWsuK7YK0VHgb7n/zGSHKb7Too7/kh+FG/U3jhaK
muLm9CXnS+qjwFMTsVtS2hSn5B/znNEbhahPIX/uKZjiZ7GLNR2Go7Ci7PgH
blVTtD3ho5FjOgrhJZ4RwVqm2FtbIbVoPgr3j8z7X9c3xdmgydl6i1F4sfaG
U4qRKVb4unbvJXTlWxF8ZW6KC19vX3tmNgpdh9/IVNqY4u6N5TXvjUdhitdi
A9XBFEstnnimwSisKur6O+pkiva5/jz7dUZh56HjjL+upnjUMu3yjOooaPCs
aOE7bIpJmx+/P0HUY/vmXomolyl68VQ9oYmNgscB2afqR03RbdtJid1Co3Bu
VVmsRaApcl94LnaZbxTiCxzOuAaZokLVzlPfVoxCptvIwWPnTLHRImNW+g8L
yrhCLC+FmeL5QxvjYwn/x11Stz+PNsUj243O3SP4aQWnGte7OFMMGnkrYvWe
BUL5NT8a7pgir0kKVYLgPfMVPz5NPTLFuSqOC4FXWPAkR9/XoMAU8w27FLhV
WVCy5yvZ4a0pXryc2fhqOwtalj30PEpNMZPMPfiW4Jl/lFi+mGpT/DnU8vF7
O8EnfzsL2ztNkVkxsvn+cSYczzj2mNVnih1pm+PfOzIhisQRvThM+FcWHu+t
zYTX6TJuu36Y4qOr+1KOsjNhnW0wR8AKMwwdYRN+HcuAykeb7FfKm2GKxw5T
+YQRUAISSyXUDJkOdS8vXhqCsZnmoteXzVDgITWK7jYEGbn2V9SumSFPfHmy
stYQbBeyF9W4Y4YVDov0nslBWDVj66adZYYHdzSphboNwkC2dQu0E/udCyV3
6RB8cbg+pbzTDAumHdI2bRkA563WAYb9ZmhcbqNz7Hc/NF2x4jH+boZHQXby
Um4/vDtkaWLGbo76Hy+1OYr0w53N5sU2CuZoej17xHJnL9g1Vkc1qphjzs2w
0/XdPcATabbHTsscaUIBevVJPRD+y3TK3tgcfb9rH0vY2gP+DSbylH3myFW3
x793RzdIRVQutB4wR4lr0a21A10wqG1S6+hhjn4uadO/MroI3jb2cjpujj+f
PJF3Uyf6yctGqfuumOOLDUccZDw7gU3707HOGHMc+r7yyE31Tij9Yajvessc
j+Qqrhn5v/3sfsNOt2RzjODfDBkFdJjYUJHZk2qOx3b3NateJ/ihDs8eyDDH
nbfERKaJ+05YCzceekXks+ZBurkoHeiTHwf7i8zxFT3hzMwKon9+Bq8OlxK6
cM5qDYsG9m4fwwYrzPGBZr/r/SYa8GwAuyM15hgTpH8y7S0NqmrLtg83mOOH
nFw19adEvx9u8N3jmznKfwze6BZPAz3NspIRqjm+e5DKsfMyDf5M6F/z6jHH
zg8yzKggGthQXM9FD5pj0qc/V5X8afCkONg/l2mO9U+3rVH1JObvuHegedwc
b3qsu33/EDE/4jVp6pc5Fi0dGHc/QIM0VovRpj/myOMZdCSJ0LO2k2paf80x
XmC/lvFhGli/5pVyZbfA5eCCNHcvGqRulRG8yGWBbtmpB/8F0GAm1Iw3jdcC
RSSebN4aTAOroSP/PvNboEDQPa+3kTR4bHHpB2OTBZY5/ajqu0OD6byUgdXb
LHB84+YHd5/RwHJDaau8iAVmvPDBnhIapATTq+wlLFC+OY/zfQsNfvfMvj0p
a4F+g4wFlTEaWBhvzL6rZIF16cKulgTfPMrc/bBYjcjn2bQ7hwQdptbax3Vp
W+Aus3kLdzM6mJ/yD18ysMDKa2tUAvzo8JAWfXKXiQVyNZ22k4qnwy/95x4m
lhZ4+cKN5oR3BA8+rXTytiPWB5svlDDo8DNgWSfP2QIVvd8n6hO8adq6XaFl
vwVmlbwcSif4I0lLZ+dvdwvUkBL42F7QCSYrglZoB1ggO8d640yZLkj0uT3j
etICqaErBB19u2CyMZ958awFmvoyynpyiPEHY/WVlyywqdznU4p2N0z+4y5j
Rlmg6xfp9P7IbjA5IvGSJ9YCre9nbdzcSowrHEog3SPqfSIhejq4B4w+t7t1
Z1sg+crL51nMXrgv/dtuOd8CU1TcpNWt+2D8Br+haKEFHjZnctJe9cE9Z2sJ
n48WGBLsRGUz6YexifKJ360W2LHKNiBSZgCA0tu3mW6BY59MOI57DkBC8eJX
7V6ifvlnnNufDIBBhEZRGMsCH6xdcFfdMQi3t+Ze5P1H+Oe9Qzd+8xDoGt/n
E5O0RPYUw6KjC8OgVpjKeC1nie4zHxtltEZAUSr7g8luS8xdeNX8/PQIiPB+
OOqlZ4n6YcnkqNEREAqtNvpjaIkHyuK2lxM8seFHs+A1c0t0tXt3x8eZAVyt
gzVZZEuczeX3qi1nAJvpeIqOsyUGpWXc8ppiwHzRTFD9fmL+j6aj+qJMGE9a
JT7hY4liX+2Pn77ABMYagcXQY5ZYdzWtoCqDCX0Xt31bd9oSI3DfmGozE765
K4Yrh1nixXHdcCeif21o09xbEWmJMcFLR7n0WVBlZqhIjrHEeg2JF1/2E/dP
sRXn0E1LxCfrgh9dYEGxrGP3qbuWWOE+YxmVyIKCh/tfr0y2xCV/1dzINyzI
WecdczfVEq8M3NiT1MiC9PDAw5IZlpizQ7eqbpgFKVMhWm9zLHFl6twJIYIf
HnhE8Fm8ssQNp2Labqwl7sOOWAatyBL3G6U6yuwchRiLex98Sy3xkviruCnF
UYh89zhhocISv8Rf7f1B8EGofNbR6zWWmCYymCJlOQpnUgqMtjdaoued/C2p
lFEI5C8VzPtmiU6zZ28cchsF38tVP/VplvhEzfV54JFRcJ9uqmnqsUSrwTpu
ms8ouHnRUg4OWaLpc3X9FP9R2EMbCPrJssQ1Wfmx9cdGwc7qu82lSWL+DyU/
n+OjYFE6LSYwbYnlg3MmocS4oeLSwpN5SyTrdF8VINbrpHJ/U122xP4XF5jK
RHw1gfVZlSut8Ouzd2ID7qOgGCkUvofHCqMjz/yVI/KTmhXby+CzQrGpJRRy
HAURHwXFs5usMNVGePKN1SgIdWpwrtpmhYJizf0rcRQ22mD3AxEr9Nb8PiWg
Ngpryyxfy0haoZe1zRJTchTYnrgdtt5thW2X3jrzEHy2sMFLq1vDCs9yepN9
51jw+8pxvgA9K2zMK3tUwGABw/fyhzhzK9Tdc3BMspwF/V3XE3baWmGaGM3H
neBFuu3doy/JVviDfRtv9l3i/OzOFPy23wpZz++kh3mzoPrpq5/uR6ywPaM0
YIc9Cz5uel/z28cKNbj7TzLVifMy3xi06bQV3m9YtVuEnQX3K35/dY6xQu7V
udp/4pgQyV74tvmmFdKM+Xa4nGBCoOGZR2Z3rVCzJGabLIUJFhVzPmqpVri9
z2aN9CYmzJX/W+YrssK1eeFGVncY4FLOrVgzQIw/2r28NnQEdnzcFqOubY1b
i/keCEoNAc9y9/FcA2vcnBty7DfbEMwapOwRM7HGyHtbwmo7B6GpTGTXentr
rE527jgVNwgXyySKxz2scT58vdHSzAD0f1BiPL1ljYu2veuba/qh4d/PeqF7
1qhtepfnxJN+KNYveBWfbI33nbkoSqH9EP9BLTQswxrXGVbWcan2g9EH7Y2u
pdaoKyAi0YJ98LTU2EiAZY1l/0ZFg9b3gGzOE2u5CWu0TmUICrd1w8tE9j0m
U9YYTfp3nna/G0rPfPQ+89caU0LX1laLdoORp/CJm+w26Byal7ltrAu+UELP
ZXLZoHasAF9lQRe0Keve6OS3wcmLBxotLbrAZWfSvd+bbDBhlRu70aYu6F87
/3jNNhvsKtmgWDnUCeNjRQUGEjZIu3mJfOdKJ5ykbyrdK2uDnAndn2ecO2Gu
5nRVoJINDhcIb1ij2Amcz1RoT7RtMCTy892zPXSIvRM/8N7ABj8Pc8h1v6WD
wOWfY23GNpg+d0x0YwLRPwfaT09Y2GARb02fxEmCNw6++MdlZ4M6OJ6/mUyH
dNu13CIUG+R5ntr0XZUOsnr+/NrONig4J2mSvYXopwVlxY6622DJ9N0jU8M0
KOWOlo/0tsFFp/vSEQR/GM0y1R/52+Bz9rXKvO9o8GXYDIpO2GAar/jr2Oc0
sGt9ZtF8xgadnK4Pr75Pg7aKlWTWeaL+MCla5DUauLw84sp+yQbXP/zWt3Se
Bv0pnzyEooj6qkSFQ07QwPvGrmOq122wgDFbNO1Dg8nz4Wdtbtmg385LXifd
aXDary/c8y6x/l5M6NR+Giw4G8RcTLJBm+mtFkGuBP+YP7pz/7EN3jPO+brg
QgMujb8PX6bb4Ip6yuxlNxrEirtm1GbZ4JxO6L21BM8IbHiXP/jCBrO6Dt5O
InjnAbtgyeJrGzwTslpbhuAT4Z9nP20sIfxqMXhafIYG6b0d9QplNig+uNbE
guAp2Ub1drPPNnipIDKOepMGL98n9B78YoM/jqSkez6mgUb2b2Zwow0+TvLc
+esl4ecD8q/4bzYYJxjLFVJJ+Hn11UI21QbVOu95/qXToDaIf2Vltw1eGH2k
du4XDUgex9f2DNhgi7Luxl88dOggN22eZRDPN3pd+0FJOgwqxcpI/7LBQGnu
AyJH6OAj/F3FcNYG734O+3A8kg6Ta6z0XBaJ83uDolnwnA4Lo9z2sZy2eMky
tIB3mg7hNC/nZzy22LounCSyoxO4aqoOl/HZYs3Ka85iFp0gkB5x+qegLQqf
T5b9+bQT5A4sJzoq2qLvg3O1V052gdM+q2tdqrboMydZXZXfBeGOd8+4a9ti
My1Vy/BHF7RbyVECTWzxxu33iyOnuyFMc++aWBdbPK57PrmF4PdslScLAods
8e6HFP9voz3QpjDBSvS0xcUL23C1bi/IiEdUPQ+0RTbJ+cqNw73Qyp9/8XOU
LWqIbL1jK90PS7wL/laxtvh2RDAoxbkfpLlNXb/G22LWJufKVTH9EPqvU7Pv
oS0+3resKvuzH6TGuH4tFNjiik0uicdqB+D85wNHVPpscdh5DRVTiP6nLMuh
ZNgW8fhzjVP0IWgpmQYcs0X9OF5z843DIPEyZrvdjC1KjlvIGV4bhuaHRe2+
vHZ441Tow8+eI7Bwn73yJ78dLkYqu5kljYD4HZuCs5vtcOpRwPuAxhEIiR6M
u7LLDqW9ctVslRiQHqkQukbKDsMbBLs79zOgKSz46B15OzxL784siWGA2Jl1
Fmmadqh5rvetdB8D7E7s05DWt0NRo5GYx1xMCPZPF883ssOMqUcmu+WZ8MT7
h4CGhR2qjWtAmz0TGt112D/Y2iF16rrYJeJ7P7f/yg9jCqFLXGqV45kguq+l
p87ZDrPPS3/recGEs/Ze72hH7DAnUGyj+DARz+pV5kFfO2w3eZ9UvMiEBtO/
9xjH7NA5NsPSeD0LZtH8SsBpO0z4NDNZKc6CXXq3T02H2GH8jbCvBhossNHs
OXw+zA77Oy/9fW3KgjMq0iSOK3b4WK9nWIrCglSFUwbRMXb405BPP+UAC+ql
y+T5b9mhj8q1/dt9WHDrW4aB9l07fC0dGKR5nAWOF26S3JPsULjxkNKz0yzY
Khnsfv2xHRrfaA73C2ZBd/Oh02/S7bB7/sqeG+eI+CGWUT1ZduiSrnVi43kW
eIqpPODKt8OkwHUpXMS4bKNQttIbOwz0jUrxO8uCyTMrSp1L7ND7rK6o+Sni
PhUZb7xUZofzWpNVTwNYcLaurS/7M6HPcLte82KB3ukPv1q/2OHm7h8Ffwme
YxPOWPGv0Q5DhEVOrHJkQWVN3CbJVju8n2L58LUFC6JPnJWyp9lh7OV7iVx6
LLDbdkg7uIeY/1O5abUiCwSqLKzTBu3w4fc/V6uEWdBxbPf+OqYdnnl585/h
OhYkbxU6/nvcDh222FVd/csEcf/vt03/2GHleO+b+HYmsDa1pR/7a4dRy1ez
vcqZkPextOg+uz3qynS2SWYzQWNDXOcorz3K7s0XuH6OCQulZ8YF1ttjdkCu
NR5mwkevg0u6m+3xlc/6eA5zggfeKYvGidjj8ZdSkU18TNh3uNVXRd0eg763
uPrdZ4Awb+l5Vx17TFvx+o3fWQYMvkm/EQn2yPsvf/mtEwP8Vp151WFpjzI5
nj3OGxhwIX/r/LkD9ijsuPJ6yJURSP23/9rnq/ZosuftrDRlGJiJrAzHTnv8
Yq8fy/thAFLWR9cc6bPHAFvSw+I7A+AULcM6OWyPm33LP5/yG4DKYD+Z+El7
fHfYUUZ76wC0yM22e7GTkHPinDLfmX7I9TbzmlxBQuGxu2Kadv1w9em92SAu
Eq4o3jFZLNkPBts0t1zhJeG9l5mv6UR/k8cT7Px0EwkVisW/jF3phWtmX1iy
W0m4n71SKFm/Fzwubw0pECKhWo+gyZnZHti+UJxYsZOEtx4kOtCO9kDM6Hxn
nwwJd8bwqzl4dYOXhNVRb3kS7qrkXeMu3Q2Gh5MWJxVJSGX8ien/3gVzNJ3t
S6ok3PP1mIvO2S7w/nJ+/3YDEj56zetZ/bgTjFY2TDxFEl7My6rMD+gEYdx+
Uc6YhN5XmkeF9Tuh421pio4FCX+xD8fd7KdDwe81Sp+sSLh68/vT8W/ocENp
/0dLWxJaFCgpCMbQweT5vz5nMglNtpuHF2rTQWTINrDfkYQJnj1FNRvosCic
wuazl4SNbafUXH7QoOCewa6zbiR0aAjEP9k0iPsW92rpAAnvCrWo/ouhge+6
PsOowyS8wb0/N8SfBiJRYe53vUg4sL9oU50qDf5WNE9t9yWhT7vptfuCNKD+
2xmRfpSE+1TvJDaxEfG1AzfIHyP8cDgxcHSUCnFB5U9fB5JwnbbD6NFWKvi9
4lfTPUXC3wf8z9eVUcFs4lDlpyASqpy8+Sgihwr/PNhHvp4j4c1SH5fZa1Sg
pToE7Qsl/PhasCIzhApvutM4B8JIeKdBo+/pUSrc2jp11+cyCbdmWpeOHKCC
v6OR5M9IEm76tCLAl0IFi1u3i85eJWH3QPMHWUsqiDUMmi1Hk3D350RZCaTC
ErcqNSqWyI+1ZOaoRYVO4wjvdTdJGKK87t3r3VRYFWU51hBPwiKxl3s65Kig
8YUv4HoCCUvjT3k7SlHBg6fjh+V9EjYINFhKi1Mh3ubhyVVJJIwXtjhiI0qF
sjj3meqHJLSbuC70fhcVxlukg688Js4Pj8/QMWJcaMOPBeMnJMzm1rR1J9Zb
7CkM5XhGQsYUd+tNIv6Z++fZKp6T0HKyY/IXsX863TAiLJuE/zzi5COI/L5t
W8VlkEfCmJ/HDhoQ+S/vb7r2N584bxtYu4WJ+uRTE3jfF5DwoKK8xQ6ifpdB
l7iQQhIaF+cd0iD8uSa+a71WMQlXiptPeRD+FXkx78y+I/y5/pM93Y8Kw5l5
mws/kNBtKfTk5FkqCHw/lXiqnIQb4z5LQhQVAo6zPf5ZRUIv05qR3mdUSHpV
vSv/Cwl3xCkUib2lwpffsekB9SRce3m5zaWWCuLBgtljLSR0Uutm3vpJBfK7
PvmsVuJ9EI95HsVJ8N7fZ/neHSQMXjXrun8bDbrDVQqHu4j6933amGxJgzvR
1uW9DBL+UOaKGMinQXn9euNHoyR0SWu/611P8OVaWpXrOAkly46W5zFpYHXb
o572i4Qvu/bM+4rSgSM5tOPbXxI+3WnyTD+VDoG5+ePVAg6YL/7jsc+7TkiZ
DDp+ZZMDXrUo5Lfu74QGZb0p460OqDV3TKKEqwukCr/8Kd/hgKfJkdMKe7qg
98MAx3tpB5RwytZXmesCm+YNgvkGDijmu3T7kGMP1LAy8wwMifVi7/3LLvaA
EYeBUZOxA/af+GhzOqsHNNV9jk5YOOBcvO36weUeEE0u/SBHccA9huYWyS97
Yc7L0z3T2wFb2iR3bOXvh/Slopy0W8T+b0VYCfcHYOdWG9x9xwFnlbrv/3g5
AEm7B9rK7zqgw/jkKve6AbjpwbvUl+SAw+4Lq278G4BzdQdJws8c8GBmy8iY
xyCQ7q2aSSpxQKXUc9cOag7BXwUXg4RBB7z+XujKWdYw1Np6VrmMOKAzeAhZ
co3AvYBAm10sB7zZzvdISnwElPOiXF5MOOCu+k8lPIdGwEP+9Zkvcw7owZBa
cKeNQL3smvy/68j4W++k2Np6Bjyw2qLxeT0ZAwyz4mJHGeDhJ/oheiMZx6JJ
thtXMWEpS6t+sxAZW0/wmOuaMkFFxpOpLEHG194j77o/MiFJqmynpy4ZC6zT
ZCWLWOBtXpshZ0DGBp7J5eE2Fqh5tylMIRnL2PUlw36zoCljTDfMjIwcBTZ5
35VGIbl65pOpJRl53kslxtiOgg+DzWqNDRmXz7NvT/UbBQ7JLc6JDmSMVKtz
+fBkFJpNRfsOOpJRI1Yg5MaHUXjoqeAluZeM5v6kCA/qKPhe0ZoY30fGxLNr
1kr/HAWNZ8anX7uR8Qnbq8Qy7jFYUWW3GHKQjNTV73fwC49By/C+y+hOxgmv
+kEu1TF4uNJzNbcnGQ3zWpxvmI2Br3jgrUZvwp9LDTNxzmOgYXJ+S4IfGStf
xjYt+owBh0dUiksAGfs/n/9TeXYMmiPiJXYFEuPMnXu7Iol4Tx/mMk+SMUzm
qpfKLSLe5+eqL4LIGLKtoOZjIhFvqODd6WAyOl+b1wtJI/JbUWaoe56MNiGK
y07PifxEa7+wXyRj50FKJiVnDB4Ztdl/CSfjW0f+Sd+8MfBz7+uIiyBjDpu9
6D1Ca14e278nioyNE5zvqcT8lU9mhrdFk1H+yXSMYuYYfK1g8x+8TkbyrrJX
SU/GIGWA93dmHBknM6+6CyePwVH2LeeOxxP71Wqll8aPgdYuUXaNBDKeX9uX
Exw1BktS0Td/3CMjv0aQbGLIGFQq/tyRlUhG7mVS4m+/MYhR35vr/pCMUf5P
62+4jIGDXpnO9sdkNDhr5HPMYgy2GkvUtqeRkZUdefqR2hj0WsbuvZlORr2h
2o1iO4l69rqc5sgm/P79UsfxxygoH6jgKM0l49nVR8ME2kfhj4d0fFA+GfdB
zh/rklGIPDmbx3pDRtnwZua+0FGwCtmv9+QtkV8Ko9p4/yjwh1fWub4j/OKM
VWrVHYVHN24zmz6SUTArJ3vdDAs8EuaDrn0io2q8Rs3XZoJXkw+tNKoi4wO9
NyzvLBYUZSruKqwjo5bCew+dfSxo+VznktxO7KcfoV6SywSOBY4m7+9kFFut
8fC7PAO+sPm57Zoko92OqV87F0YgjvvrWOdPMuofa8porx6BbZsec9vNkvFW
k4HvxIERUFPWNVRjp6Ao6VJGQ8wweHudesO2hYJSGnY+0p2DoBjQafROkIKb
mucu6KcPwvQpw6+ntlNQ58po9bVjgxB+iW+SsYuCd/w1KNMrBiHpYY5UozwF
pR8aRHqpDkDDt6GkRCMKhkUWXNrl0gd9LwV1xU0p6OOR/KpmZR9Mxdl3vTCn
YKOWcMB74vsmaP1+W6UNBe1aWmSerukFr8+3H046UbB5Wl1pvq0bQtK+6IXs
o6DAq9c3EmK6ITZsqXuFGwVvXv4u88iwG17r+u0QPEzk326Ru/C6C9jeGKYY
H6UgnOTkm87qhA23zxo0BVAwMcM3lvtoJ0gG5vU6B1JQuyPh1FWFTrCVF9x5
LIiCgo6bLlYV0SEp/efjB2EU5Nvs1rZI9O8vLkui2GUKsj1oTlXPoEHFIbf+
vEgKxtpz3a45RQPW9i8in6MpuE5KWIEhQAP1u4/TJu5QMGX5bcLzQ8R9fqrd
MPgeBe9fq5zS06SCmwPvIEciBU2DP29Zw0eFy2vPim5NoWD4he+Z5p864N73
3E9PUin4lvGjKedRB2TVDrorPKXgAaHcAa1zHdByxe6pUSYFhY7ElpRqdMDQ
kUjjxmwKduYuz2Rv7oBZw3dDe/MoeCHLa/rln3bYsSQhHlBAQbG4eNpUaTv4
nfmXfr+Ugr+w7noFpR1CHVVNRT9ScOikZPR33Xa4peI7kltBQeswhyB+iXZ4
O9km8amagiIdNv5SC21Q18BTbVNLPA+VHYvrGG3Qm41e1HoKFtzQTej91gYr
vXMzxlso6Ow5cE4yvw22mA6anW2lYCHJqepGShvIim1lsndQsMRjUKM+rg0M
2O2uxtIouD/tSnNvWBs49EVIbemiIO+m/piaE23g8aGkJq2HgkmUJrFwjzYI
Tv7hLd9PwaWx8fEVzm2Qstc103CEgn3VgxMuhsT+ety6K1gUZDyz7iNptIGv
yOvGyjHCb+0zyzvl26Bp5cFDURMUTG06HPVJtA3URnl+m/+k4MPXa3NVhNog
qbHoyurfFOSWb3nvJ9AGy6/ct9bPUDBOIrLVj5fI5966nNg5CtKrjA1UOAk/
zr3Tt1ukoN4HJdEPy62gfNCrhW+JgmtKfZ5xL7bCXWOBI1/ZHDHtJN/k2j+t
sCBVNnN7hSOS4k1EG363wqE1ftccuRzR74u0j8GvVqj+uWnb5tWOaPGle+TQ
j1aQa6/Io/I6ooHhpQqlyVa4VRKAiescsXjj3geZE60w+0iw1WW9IzqIHP5a
S2i3y1We2zc6YoKWKd4i5ld4nZjr2eyIYZuc384R8SStd1x/LOiIG45PrmKb
aoVYpdodh7c7ov0/N+6n060wtSHopehOR1QNnovsJfLdOydiPLzLEd/f3+SY
T9RT2t3Q/kzcEUc3rDYXYGsD0YpgH28pR1xrNmnNSfhx7Zn4orSsI5rQ/lle
42mDieiWG2Pyjihdt/ffA/42IB+7IJKrRMyv2c6lvqUNisnSrwNUHNHmXMBK
F+E22KHZZqqk7ojKN/0ecEq2weVt4bSfmo7I90rNXV2xDWyHqf9O6Tvi+tqC
LVuxDQq+RNxSR0fM9X3mVG3ZBlvzlMT+GDnia/VklZ+UNhgMumpxzsIRWcML
S69828DCRbVL19oR/4U+vm4e1AZ5Bn0B/2wd8ef7Iz8ol4jzxa15J5ziiHC7
/HRDEnG+vw9KGDk5Ykj/HRWNzDYwbokrXrHPEW3h7/L6ojZYl8joiTrgiHeT
2Dm2tbZBuuw96Ru+jjj5+lymhUA78PAZvbfzd8S41qnDO8Ta4fjvCVv+447o
emix0UWtHXRKTU/dOe2IVdeEp9c4t0OL7cyHxDBH3HmVPKOT3g5/Ax0pGXeJ
+NoX8uTsO+CFfPMfrQeOaMf9V/KNRwccZlk+rE9yxJcm7zpuEd+H6oMw8vOx
I0ZYzm8we94Bt+xkz+pmO+JegxyZpJVE/yPPltxS5ojnWTs/tzVRoYN5Dv5P
BVceDuXbhSV7IpSiUIkkUfQTinOUhCSV2cdYQoqkQouyJSkKkVBKokUqRVmK
aBGlJBozljEMZkjKkhD53u/P+3qf9zznuc85z7nP9V4ze6tcUDfJPyCFmNdi
b/8W/H7jgn8OL9S6J8GBAfXvBotrXfBvyC+Puo0ceC7LrvBuJOxDXua8R4S+
Fj7omhQS50symPU1mwtT2brnLva74GppRZc/r7nwmHVr9dIfLmjR6x0QIuDC
fHZq0NZhF3zOW74qWqcFeG8jpRKnXHDUK+3mj4ctcDiboq+jREI9jYCL0V9a
Ic119pGdFiR0/fmPK+HJAxuxFo1vm0goHTdA5l7kwa/sglo6kLCoeCt1SRkP
tolcl/nYkBDxXN2QSgeMHSn5csqJhM/Lcxp+13UAKfagUZ4nCd+VhNPz8/gg
ttqm1cibhAHHTC0d3vIh/5P6uWf7SNj5UBv0eHyQUKnhVfqT8LGc5b87yp1Q
lLn8UnMICY9Kh1dXhXWCcmHzgEQcCT+2b4mSIPR0BelR2oWLJNxxJCBqJLIL
DoxH28xLJGFQWkzymqwuqLI0vr74CgmzVh+Ti2nvgsCa+O3GN0kY76dpzmMI
oL7dOs+tkIQZUde+tO/rhniZ/H1lrSRceEXkkfayFy48GZc8xiOhzy92lain
F2LpW3NMOkkom7FWr1ZBCNH5PH5+LwlN19Yef8USQhRpdfj+PhKeOOtxM/2s
ECL+HdPQHfj/84DE+AdCOOWsRL85RMIfqgvEXUaFcHLCdZwxSsJ/l16u+K0q
guPZeamL/pAwhyfI2m4mgqDRLY1JUyTMK1QWfggRwZHMxMNOMyQcDP/W9ClZ
BIG27YpzxMnIKlvy1PKxCPzTQhyjpckIs2ap63eK4ID1m36UI+PbkRDdhD8i
8O1XPD8tT0Ytt48ta+X7wCeZubJMkYwzlU50Ka0+8Np0/12IMhmPmnx2llvb
B549v/eaLCDj61uq/5lBH7hf2iz+ayEZTXTF78U59gFrQ0JWvjoZvyoNOotT
+4DJb7Xar0FG8fIlS6959AH9vF67zlIytpwa0Cbt7wOqcXBo13IyTj4w2bju
UB+QW6vUbuqQUfXx8XfrjvaBS7RCCUOPjOfUy9fQgvtg9xoGedFqMs6h3a3O
I7Az++5o0xoyrn/Umrk6qA+cwkcvJ60l49q70UP8wD5w1LNe52RCxmjjdJsv
foRebLhYL2dKRq/dH8li3n1gd7Ll4HszMh5wXrD5OLMPbLVXykdvJGNw9F4z
2N0HNnVH89CKjHZZ9w+62vbB5uBKu2kko5Pci4JWsz5AzbnC0i1kvI20r69X
9YHVe9rZEFsyNikY5yxW64NNgXe0TezJOLfUNPSnVB9YqI1U/dxORhuPiig7
Yj4yew3u+U5k5N+RGV/LI+an+dzrOi5kXBbxo4JDxM+4XGdjF5mMcSGuR/NT
RbDW5wj3Bo2MZ3SWD5idEoFByRzVRW5k7Ej/+fnOFkLPelCLmjzIqC0vZZCp
IwI9udzdSV5kXHTlSWWIlAhWMK0S5A4QfK4KO/XvrRCWiB2WmQ4i+P5iGRxt
KgT1++V3So+R0YV17UrZPCEs2i23NeQkGUcCtS7o9vfC/JzbkT/DyRh7/zG1
JqMX5O3Yk50XyJg36T64abQHKDVDeYcukrHGprRiQV0PZNvNZUwnkFHu97eI
8Ns9YGZv82LRFTI2jr8a1NxFzKsOT0N33iRj2J6h4h33uuGl46Wpl4VEfBIS
X+RvF4D0p/v5Ds/JeM1E41KolgB273jH5JSQUfHhDg/zkS4Q7Zh6OVJOxg8b
BbbJGV0wf+eB0/o1ZDyrvdN5X18n+O2y/Xe1jYwNO/WelCbw4XmDxyOdDiI+
DmnGS3yI+2f3aVZhJxlll9G0JzfxIXV3UcXnXoLf5dTGVE4HvN6zPFxyiIh3
JuO2TQ4P5jZZGiWPkJEjyxqKovOA6kLrWDpGxqmGnwmGyjwYdEmETX/JePx6
Xt6fs+2gTv43c0SSgot+Bvc5RbSBN1utQEyGgnPqU/9MbG6DAvJ/7pfkKKht
e01jj3Qb2FL8K+8rUpCHESLtK62Q1HwucIMyBYNzLS7fZrVCG+X20nfzKWgx
bVjauaoVjlBbIvhqFBTrCtbNfdcC5ZzfawOWUDC9RFbTMLUFZGhKnX81Kfju
/rufp31b4AbNznrhCgr+veZED1FugT7u3qEcXQomRQUHafVzYT09/JbxKgo6
qGzcm/SGCx/oz2c5GRLrdT6pfA7lwr7ObTnK6yjIDq7Q6KRwQcKXa9tsQmA5
9wuyplzIHjzQd82UgrO8DY9vVeUCBE/FuZtTcN6WJ82XxznQ9veioc4mCn7t
dQ772caBk1FaDX1WFLSaKzVAfcOBhbJPjj6ypmBpkP3VugccKErYrHrUhoI1
O5+MbUvlwC7VppIN2yhYFP1LoyaKA4PXvRlT9hTk6F+4Z3+YA3Haf6YrHSko
6aiZWevBAb282KyzOyl4MeDb7K0uHHi3Vn2Lw24KbjjRdbnEjgOexQ96FEgU
rO4bT1gKHBCzsoxtpFBQ3HVX1okNHMh8+1k/jU5B1hYVv8p1HLDY7v6J6UrB
kP11UUNrOMBpGDq0zJ2CXsEOdFkDDgRTzyj3elKwR2NpmASBlTvmP8vzpuDv
VcmhHcT6x953KId8KSgXYfc3lbDnOLBh0sSPglWXR+tXEvv1Ham9Pn6QgsOO
R25fsuJAzAQdygMpqCq3VbNmGwe0IwY6I49S8JbOL9GX3RyolAqLtg2h4AcH
uye5bhxgXVRcOecEBSe+9FZuCeDAX5VbtfWhFLx84ODme2EcSMsw9k8Jo2DX
mrV6XxI5YLrsrQItkuBj3RmvkhwOBBoK93TFUNC8gjZe3sCBuc+Oj905T8GR
7dQmdj8H8jbKpfvFUzD5hoLUHUkudNut4Y0mUTAus9TYFbkQWV8RUZpCwft+
LsrozgVNsrN22FUKljx4rPklkgu0vUd9pTMpOPgrQmy4lgtjfRJz6m5SsG9T
znD4Ly6kBKY+TMym4Imw4vHCRS3w+XTpsNo9Cr5W7AmUDmiBzWkzpwwKKZgR
Px5vY9AKHZpJWkPPCP7vPNrQ7dYKp3KXv35WQsEGpYzU5UT9FD/dKg0VFDT4
ZXP+uEQbGHyKS9pVS9h3Mmw9PdYGtXs01qvWUbAz4XSFzIZ28Gl5xG75TEHa
74uD6060Q5awYbFXE+Gf1off7uI8WCC+6E5IB1EvT7I+ol4HiLkfp8t3UfDG
711xNwM7oL+co5DdTazfmDdysKwDKk6kH/vUR0Ef9Ux/o1V88BlSt18xSvBx
bDO1pZYPJXyNgQYZKhbfvvq0xrALsq3CsvbNoWLLLnLNJ1YXxF/nuUzPpWJ4
4KI9iQld4E69Wa6nQsWRgi1MdeL+k/2yNCFcg4pLt9vHjr8SAP2VtvEaYypG
bRwLSaf2gI1GdO/r9VTcILzKcD/fA4ah3RnUDVT8N3FmjkNpD4hvyJ0dvYmK
FXp+sgaqvTCQIlmiBlS8KHYgYXJzL7CHvf0fW1PRx7c6PzWgFx480v3WYktF
w0j9yOGqXkiVP3c+0J6KOdGN/Yl9vRBxQGgp5UhF5rT0zEtFIbjo3ruzbhcV
D/ntPRdPEYJVtAzj/R4qPme9slQ/IQS9Ll9FVzJhfz7l1Zx0IUxlrjoey6Ci
Kic3ZKpRCL1/zxtosqiYPBhr+2tQCF9o/fxCdyranZw6u1ZGBGXFDlfs91Jx
X6snpVRLBDkLHth3eFNxpfbtBef/E8Glo3P+BflScfOSjlc37Ak91eD3VM6P
ipnkz14TDBF4GtX5ZB2k4u7QzYfT/UWw46LBYtNAKm7rG70dEUr05+/x9R+P
UNFKa05tQawIltv/OOMRTEVrqSo1gxQRyN/dYfbnGHG+GqvFY5kiGJN4NBB/
koqpRs5JyndEwPdUuLX8NBUXf62inM0XwYfKAFJJOBU3Xc9z3/NEBEWa9bJO
UVRcZeK4K6pIBDdOGVUIogn+pfkNC5+LIKrq+wn/c8R+K3toGgT2lrr33+/z
VJQyWXQ+h1hvt91r6HQ8FYVdB7WLCHsGiUsfSiVQMW+4S2HPQxHM+9bmm5BE
8KkZtC72rghG1NJXLEqhotvDUw70LBGwWSR+VioVTXx2HfpyleDzttL1VelU
PJhBdxy+SPgj+kR5eo2KpwqGEt5HiSByzQWVjTeomNZTz6MQ+tPriG39mywq
Xlhh+TjPl/CnWDzO8TZxflen3+9phD9TFbbfcqnoqzn0qpjgX9E6VJx1j8iX
UWXNKELPsj+MnDj0kIq65buXVCsT+ysW/Df+mIr7JSzKd/4TQqaL/1DEUyp2
K2oON4qE4MXr9r1cTMVrKuNt38uEMDz0jfKsiop3xoeUTV2EwDa9rGL1loqk
TfudDpsJoTTUqb66morq4W7UnsWE/pZ8b8v5SLw/9XJ/Kr8XFNRK/vv7jYrj
0V2s7x69MOwaNHSGQ/i/X1fnJfbCt+y1D+VbiXzZRfk2o9kL1w3ur9DkU7Gu
c1hhktsD+pihYt1PxV3PC176OvSA7b5TQzH/qFg91RvDUO+G8Gf4UHklDU/f
myk4kU7ML2JHGV9X0TDxZON00cFO6N+eK3vZgIa9xdeeSG7uBHKXrI+SMQ3n
8d1slL7zwUCxUXOeJQ2vzBeNayAfPOmSn+qBhm6VVjJ2qnxIy90QmrCZhv6d
1jqfuR0we9P1ZgU7GpJXXmn02dABLb7eiXP30PD8fFmrQ7N4MK/oqtUnEg1x
5UDIqeJ2sJ2pHYin0lBhQ+j+hYfa4ckVQ3t5Fg3bT78IMxG0QS/f/c9Hdxo2
6VzY9uVmGywxSM6N20tDcdNQSWNWG8S+/jNrzn4CW++4H8hvhYq5+gUf/Gi4
7nx1mntOK4xSmawLATTcmzEYvOlAK7j9rCyTDaJh//QRz8a/LZBiMeJbG0LD
fbVPRjLet8CHszoLz5+g4Qe1zyY+V1rAdMmFozLhNMz/FBayaEML+O97uawm
krAnl5srOacFsp8O1p+LJs4vKNWa3cmFufZ7DKQv0DA4c1nff8lc2JxytqU6
nobLkv6G+x/iwvGO4tiYBBrKy+1RL95B9K/gJT2SV2j4U86jMmYeF9SrnJLf
XaVhpe39SdnfHNgpH2l9NoPgJ0pG7EYrB6IphT9tMmn4onzBEL7lQFl2T6ZE
Fg1TY0u4v4h5/NePhY5vs2mY/uH+hQfXOKBr7jB5JpeGIxrRsQEXOMCMPnVv
yz0aRtGV6BtCOZBU/4g8+wFxfrUT0bOJfl2t3inx5iENLw3ENNV7cmDKW6Uw
qoCGvFSpP2k0Dhg/2eqxuZCGn324vxhE//edOqYo/px4v+L7uwU7OHBjW155
VQkNw9T5X1/bc6Dxcptf5AsaQuRaRzdC78jwFNStK2go+iN8KSSw1SrrGrEq
gl8++zF1OweCgo6GVL6h4eEWb99HO4l+/yp3RUQ1DV8Ppav0kDjAl+N8hVoa
aionSU24cmABWS5y5iMNPRq9Unv3ccDh1iajV59puM1mak7eUQ5EDAS0hzXQ
8KZa5QOI5MDzDbfirJqIfDn+pOo2oT8GohrN/7GJfI9uSP96iwOHcpsmLnFp
OL3wYkVIIQeG338r1WqjYVb2ohM51YR//ewTBTwaFp1ybaES8fgjzzG37qRh
S7fScOIQoSeNuBMNAgLHXWywl+XC1K6WUs9eGr7VWd0Q8f/vj1fbzKO/03Bl
k4Ivi8aF6NL2ifmDNNxlRD88E8IF6TZeae4vGpbbSRappHJBflmn+fvfNMzT
rw2P53Bh4YMeczkxOl6bnH3hOKFHMj71TmSI03HGxjD60NUWWPJLWLpako7T
PpUa76taYPl//eY75OhIKvo5lqDeCgavBs0T59ORMntLiVNbKzzu/DmxdCEd
R9JxjdK8NjCWGCp9okZHRbyxecXWNthgP2LeqEnHGJpfrGlhG2xu/GOuuoqO
pfqNSwQ32uHt7/GJO6vpqLpd1ki8vR22LZos3WBIx4B9ehSfJTxwdJ0yp5nQ
cZvBusvjN3hAEYpZXLekY4/Sc+/VhR3g/1fWYvluOmq+aVeLndMJPzXmTD51
oeMhG4nS2PWdcATly7ZQ6MgV6lB1WJ1w7KyChTeTjpv33spYV9gJUYoqFvd8
6DivTX57glcXXNVeYmEYSsePnYMnI7oE4O+YPPD7NB1Fl5O+LFrUDRgsd7M8
go63Z5pa3u/ohv7q8dk7Yuh4RPm2cUtJN1gd+PbJL4nwp6BxVjehV1SSHSNM
Ugi+ZGZN2r/sAdGLN8Z/U+lYOcj1LvjRA0lzn169cJ2Op9kjw7N39EJ3wSWP
+3fpaNEwmzI+2QulXMn5h/PomOtrZH98uRAuiZ+uNntIx3CxuSvN7YSwd/Xo
cbECYv3RCRsDfyGYufitrnlK8Fu4+8eWS0KYe7qrPeEZHQs6baSPPhJCVy4t
kVJCR2eZKy4FdUKI+7Ptd285HW/NmptnOlsE7ktf3X1USUdtckDykcXEPG9v
Sg95Q8cVF1kqOetEIHvkobxVNR1NxZ2S3m8VAS9jxSvJWjqe+DUa3koRQeGb
a4c/faSjro1Ih79PBLEDyiuufKajUUVB27dgEbguuMBmNtDxgFqccUWkCIyt
Zp1f0URHRozjo+txIpDed3zjAJuId95ZieBkEbQl/PxRyKWj9OEXftvTRfCk
xCcrtI2O5KCl2TqEXonpbN+9pYOOBsulHsveFAFDjiQ5p4uOUgY5LdM3RLDW
pK74azcd/32S6pAl1kswtxzIENJxynds/D/CHje6bIlnPx3rNnt4XyD2e/Rw
Xf2qH3R8Sd4QohhP6Bf2vcihn0Q8y1Sufib0A2VGa33pMB0Dpce+Nxwj9IHe
1d6I33QcVwy8pu0nglm7FNLtxun4rmdx/icmoQ9OnN0+7y8dB9o/b2xxFMGD
7Knp5mk6zlJ7sdllowgiPh4tuCnGwCRhX7WtnghIo/2e+2YzMP9sQelLFRHo
a3guMJJioHzJW07ltBCaApxPVsxh4HTKQ17WJyHcv/reIEaBgTf9lh5LLhRC
WKVVxw4lBl6MtFhvnSaElcprbNpVGbhN3139ryuhTy1yxnLUGGi3KJitAYQe
3bv4vv8SBobd0DHU0xLCyWeyClPLGGhdN+qj1dYLn6m9zeprGPgj7LRKjQOh
H3xLk74ZMTC3SyJBTqcXDhyP355ozMAHyjtYif96QDrN+JWkGQOl39SGxj3u
AWwOu/NrMwPVomrXbJDrgaekhcHVVAZmLx/ILbovgAjvfsNIBgMz/8oGrD4l
AKfgctFGFgMLnVIKfZwE8D1lL/PJXgZ6jcUWbR3ughVNj7dcD2Dgvk5IZph1
QepuO+Uj0Qzk3TDOrKrmg5fn4jqDcwx0v/by+ZN0PhgfGTwrPM/AI7EpxnIH
+VCflDLBTGCg/xUPhtYCPsg08PnbMhi4/KCj7qdmHrD5hRnimQxMXGFp7RLD
g5xfMS7lNxnYX9m9x9yUB9bz1tQY5zLw68Cw3s6Mdji588RjjQIGjgTKbiwP
agM7N8f9nKcMTNOdsSAZtYHqIS3t5GcM5Dj470r63gqFl96lyrxgYFbqHU/p
/a0QdSPN+U05A2umPmrZ6beC8yM/ubBKBhqWx6+w+NECA5+UwkbeMbDc+Vi/
2fEWKGvv3vCohoGWmhsv2GILxP4oHvL9yMCHXLFlMnItsGIuy5v3hYElboKj
OdlccHXMc6xtZaDnQG3m/38/dtzEcRGJx0BSfMhLWiUHUtQHBXw+Ax3eOv9V
zuDAB9G60PEeBn6b/PD25S4O9NQ32kaLGJhS/yL+jhEHxIqDled9Z2Dy1aK3
gwrE/H229P7KXwx8eV48IK6hGXb5M4ILhxm4d10umVPUDP57phF+M7D1yVWl
oPRmuL3MmkOeZOD4tS+kGJ9mqJAR3O6aYhB65XriqFMztPyMPhQww8A/Fi8v
ZJk1w7yKGqkYCSZarmzcekOxGVbnHviqJM3EzN+1vb1TbLCNl7+RKctE1fzt
j+nf2eB59NH+VfJMlNt85vtoCxtO053/e6bAxMOpwpqCj2xIsx4Ws1Zi4qmV
XtfPl7OhSC+lrk6FiROdA2UnC9hQr2iaRlVlYgRZ/XRYDhv6x5r3di8i9rMY
sryQzgZJ3gmjwMVM3DhJXnk9gQ1L3y3++1eDibQr282LYtiwKb+8+txSJo7O
qT/6NYwNlGS3yyraTMzwGtn68xgbjpycxbqpw0SR4fTe6cNsuORxe9VqPSb+
svO8NOXPhvt2W38/12fi86fL3w34suGtkbBy8xrC/pIZ90/ebOhQPR//2YiJ
xidW70rcy4bJaX0q3ZiJ1oHHBEaebFDtqdPuXc/E87MEC/M92LCuLuDn4Q1M
lFkTMChBPHcsnPdi2pyJJWBvYk6875vxNOb8JiamTJge2EzYPxPpsnsBMLF6
27wxdWL/G75jGresCX5uLT9c7seG0p1pfQY2TPwW/iJ4RSAbmkwtnpXYEvZp
ejccgtlE/22LsLFnomnu82j9UDbISYY5ftnOJPpr4ZuKSDboDGgtYjoxcVPw
wd+zzrMBG6sEQmcm2pJkPv1MZMOxW5KhMyQmKs4M/vqQzYbLsXdt46hMnF88
yniSz4ZHh+yVFzKYuPhFUppZMRu6LS/eN3RnYtNbY3v1z2yYWWEUXObJRG/a
Oc2DRPzV5RvQ1puJDynzY3cJ2eDcMp/jeoCJH+yChVXizeBX9fx2nz8TlRY8
OG2n1Awx96iHgg8x8faH5ZtcljZDech1qYtBTFxj1p70A5pBX2XFfy/DCPur
ZFxropshTWzTSFgkE8OPb/F4kNYMkoN7nlhHM/H+qqxNCg+bgV9zZs378wSf
ZrOrbZqb4UqYQOdrChOzi8mosI6op/5sVVEeE4cib83o/eFAQHNZU95DJkbZ
RF05osSF1rdfLx8sYCK1bM0/WQMuPL8prjjyjInc/BcZCz254EfylP5XSfCz
bsUfVgMX2JXLxlWambh1lU/13rIWsHlk/pzNZWLs0ksOJE4LPLm2Kyi9jeB3
G0UjYKwF4kMif2l2MbGBpVUrb9IK1gadolU/mHg0cdL39cNWyL+axYXZrjg/
6M7Z83fb4EyA1gs/I1dsVuGZxGXxwMpEKm5mnSv6TIX7csp5MP5ngJ683hXH
tF70qLXywD+ybLLM3BVPwXBo8IIOIKeQLORsXPFuxLYHR853gF5ZXOk9qit+
U6oabDLlw2fJ8eKeSFd8nJ/lfnBeJ8R+4J07Ee2KTQ2xEkc0OmFLwjvK3HOu
eHnXMpGnfieULEr+sz7eFc/9itOSsemEW6sNN0SnuuKVmp3/yCGdELTL6/ny
B65YvGXlidfsTlDP/FLk1uSKxt0P7lRHd8FnO5X4XrYrovGzVxcvdUHUKGnv
Qa4rBq9bE2ee1gV921uVQnmuuNr1Ta7Vgy4omewJSBW5InnehdSJ+i7wv6Nn
q/HdFdMs21w7OV2wdLefRs4PV4xYzPfI7+yCc/d/fXwy7IpGDrau34n+Rab+
1fs05Yp/N5569P//w5aTsBJzmXFFpaUfV0otEUDF44jmllksXNc2m9+jLQAd
aakYkRQLPabVo7abCGD02TzBbCUWBtaavXrgLIDLKrqZFjosPCNZWHLnrABs
X/kGVa1kYe+2h8FlcQKYPPBgu50+C/XNVv16lCQAj9drJ0lGLFzpmVJrnimA
tYc3Ug6bs5Cd8aKq6akAupeEGY5vZKGz14TuQLEA0moqJcOtWPjwlNuw4KUA
ZrRsi+K3sHBK7cC7oGoBfP7srHRvBwupdjNn1DkCiDqZLDJ0ZiFl/d+s9W0C
MNVlv3q2m4XySewRQ74AMk8zAt5QWHj2g9WSt0IBOK+6sdWBzkIrK1IX67sA
JL7xlzQwWVj/TfCKO0jobwOfjzwPFoapyvoH/hbAUs69bG8vFu5tdtsbPy6A
xjPfTwz4sFDM7Fxd7F8BWLQG6k36sTA8ZJ209qxuGIwpnIkIYOE+7VVdlbO7
Idt4jC19mIWLFVqtQaobZC+Enl0QwsJpC0p2u1w3KGxav7PxOAtNVAYC9ed2
w/zBgUVJoSx8rXt1227FblDPyu1yCmOh/VFvA5JSNxFvVr58JAsVrw6bmKh0
g67EwpAPZ1goGjM6MzC/Gwye10NsDAu9fuZYRKp2g7FvrKzteRYqt3NODi3s
BjN168bZ8SyMXLLHy1KNmB/qJq5XXWKhpdy1hd7q3WAT9tQnPImFzeJmz3wX
d4PDWr+1liksbPd84mq3pBucu7QnJ1MJHHNpnYRGN1FfbW9K0lno85G86zqB
mbZXLoZcZ6HUxaT2eZrd4Dm+g7L+Jgt36FWPeRDYN09q2fAtFtZOhJYnEDiA
+ar/cQ4LpVkWuzMIHKRwvOjgXRZebrvQFEngk5Vrw1bnEfGkLt9hS+CII33b
+vJZ6JAd2yYk9otZka109zELrT0GCnwIHM+mt3o9ZWGHxanx14S/l2NVcpc/
Y6H6N5/OKeI8Vy3qAvjFLOR/a0mfT+DrA9FmN8pYuFwg5SxHnD/7hqU4s5yF
37LVjHnE/HXPeeyjWiULhWXWAYkEf4/EH19pfs1Cx4aHxssIfouK9rldecfC
33HxDxMJ/st8lq7aU8PCxkT5uR3K3VD9Ienl508sHJn3wFiNiGfdKYeY+C8s
PJhVtkeSiPdXw9nODo0E//6V0g1EPvAuBwnecYj6UyuUkCHypdtmzcMzrSyk
R26sOkrkU/9YT4g1j4Wzc/4bfSXWDWN0ily5gIVPdZ/nTE4KYEp+XtPJXhYy
53Ku9P0RgPirmkyzPhbOvMjuLh0VgIK2xbqiQRaeCNsfNfODqPfvS6gPJljo
n3JdSadDAPqZ35btnyLy29oWdVqJet156bvuDAtVZJQuyTQLYFPhTFi2hBuO
vm90PPFZAC6hXbnpim64fObcAzmiXulrrh2iKLuhJ3f2WX2int079pgvWOCG
XS9ehBsR9e6/5V1dorobigZEHX13BRA9597IOR03FFzsndC9LIDmFKN6VT03
/Do7QIwbT/ijWZyXq++G3xcG7A8+J4Ava6s93hi5IT/nFAYQ+n0xubv+n7kb
XiVVG/p4C+Bp1tL8YCc37FgbeSCLuL8k9e+dk9jlhi9tJGRV1giAWmi0N3mP
G7ZWS2Qc1RXAv3dW6k+oblgZpnZ6ZpEA7L8zYwc83fA1GDx2mO4C/n/pXnuP
uWG6wPgH93UXmLxaisMnCHtxTY3bXnRBjN29xZGn3NDvUGfY3cIuMGAUf70R
6Yb7+zYt35TTBccivmFLHOFPyj3DV8T9r/BRSWNXlhsmZUU8O7ilCyzdL3yz
qnXDDw37KfKlnTBQKN2iVueGx9VVA1Qed8J16bO80c9uuEyMdVkptxMmH4UL
85rcMNBUxXI0kehH00ETqnzCP5/YYbpvJ6y/5qbxc8wNtfqNTQcXdMICv4yn
O5XdcRJabi4K4MPAfO76chV3ZL7xFYvfy4e3FQuL9Re4Y9L8B0ozVD4EKV95
IbnIHW9Zvd7Ys4UPX0sT3r7QcEf76FNeJWp8SJQ5y165yh09lQvPMOI6wPfp
G+oVfXfE2z5KgSEdgEzxVnEDd5zLQqM4jw74+Ti8o93QHdOTf35gb+gAJ8pJ
UfJ6dxxL2W1Z380D3VmlB2aZumPWRGC/9hceTOf9GQjY4I4KM4bUqBc8yP8X
NGRv4Y6Guq+7XS/zIPpe4dHije447WXyovU0D5i7h3+vsHTHkrBTVV77ebB+
au3xy1buOBjpt2fChQdz7hyanAF3ND/9uS4defA/F6ty6A==
       "]]},
     Annotation[#, "Charting`Private`Tag$38791#1"]& ], 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEmnc41W/4x+2MJFSiaVN29rpve89jh5ARpVRCStKQldFQolIhksoMSRo4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       "]]},
     Annotation[#, "Charting`Private`Tag$38791#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 5], 0.2], 
       FormBox["\"10.\"", TraditionalForm]}, {
       NCache[
        Rational[2, 5], 0.4], 
       FormBox["\"20.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 5], 0.6], 
       FormBox["\"30.\"", TraditionalForm]}, {
       NCache[
        Rational[4, 5], 0.8], 
       FormBox["\"40.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.2\"", 1.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.25, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.35, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.45, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.55, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.65, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.75, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.85, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.95, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{0.8899999999999999, {
       GrayLevel[0], 
       Opacity[1]}}, {0.7000000000000001, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.2, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.793709151185916*^9, 3.793709174491349*^9}, 
   3.7937176832629633`*^9, 3.793717852255567*^9, 3.793717911686911*^9, 
   3.793718183631056*^9, 3.7937182751019506`*^9, 3.793719547101345*^9, 
   3.793801399984601*^9, 3.793801480612418*^9, 3.793801576746934*^9, 
   3.793801644000451*^9, 3.793801748737666*^9, 3.794507035928727*^9, 
   3.794507503687416*^9, 3.7945075500395937`*^9, 3.7945076695763893`*^9, 
   3.794513119171998*^9, 3.7945131859645767`*^9, 3.794515039455679*^9, 
   3.794515323794306*^9, 3.794568658289297*^9, 3.794569023186124*^9, 
   3.794576702305551*^9, 3.794578159179213*^9, 3.7945784456306562`*^9, 
   3.794579376513176*^9, 3.7945795059605923`*^9, 3.79465726671902*^9, 
   3.794667533461643*^9, 3.794667830260696*^9},
 CellLabel->
  "Out[931]=",ExpressionUUID->"e4814613-5857-440e-847d-e2b11becf783"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fignpibps", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"10", "*", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"npi", "[", "t", "]"}]}], "/.", "sol60bpsprev"}], "]"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "130"}], "}"}], ",", " ", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", " ", 
        RowBox[{"Opacity", "[", "0", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79344727493867*^9, 3.793447275672996*^9}, {
   3.7934625847549*^9, 3.793462585031742*^9}, {3.793463088769895*^9, 
   3.793463091558565*^9}, 3.793617656897922*^9},
 CellLabel->
  "In[932]:=",ExpressionUUID->"f770bff2-1227-4854-a4cd-5a6ad65ab904"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpsnpi", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"figcritprevbps", ",", " ", "fignpibps"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"PlotRange", "[", "figcritprevbps", "]"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "ar"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "imsz"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793446704447353*^9, 3.793446711536757*^9}, {
  3.793446744118206*^9, 3.793446750009528*^9}, {3.793446976069807*^9, 
  3.793446978955377*^9}, {3.793447262748226*^9, 3.7934472636613283`*^9}, {
  3.793461917634132*^9, 3.793461928547559*^9}, {3.793463093975984*^9, 
  3.793463097176322*^9}, {3.793463150716834*^9, 3.793463154325522*^9}, {
  3.79363216851443*^9, 3.793632172538486*^9}, {3.7936331945653276`*^9, 
  3.7936331977712507`*^9}},
 CellLabel->
  "In[933]:=",ExpressionUUID->"2778d970-612b-4019-b123-cc3ed9fa412a"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxEl3k4lO8X/1EoKtJKJdl3su/n2HfGjCS0yR6lRVGJIkVSSgtKlGRNKaIk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        "]]},
      Annotation[#, "Charting`Private`Tag$38791#1"]& ], 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxEmnc41W/4x+2MJFSiaVN29rpve89jh5ARpVRCStKQldFQolIhksoMSRo4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        "]]},
      Annotation[#, "Charting`Private`Tag$38791#2"]& ]}, {}}, {
    GraphicsComplexBox[CompressedData["
1:eJxNWXk4VW37RaZQSsqQBiLhGDJlyHTMs8iYKWWOhEoUDShSochYUSRDyVAI
6UXmmUhlKkOFRAod/H7fd33vXvzBta7nOWc/91rrXvfeG6/TSVNnGioqKs3/
//Wfv4P0Ej2uam+Vqf73k959yOCHO63qv7hiwMG3RHMrgRkYfp2rStpFYHem
2IXZT/wEzi+WfeBhK/w/zKk6vhQxSndBnMCqs/7M1WGSxH6vIeaLTKoyBI7Z
Hlh9rOkAsX8sa/r8sxsKxLrUFQW6DbxKBB6y8Pp66rEKgR2Uu9KOS6oRn288
e0Q28RyZWDfsH6PT/qhO4IulzlcC5DSJ/eIqJhOSF7QI/GdK6ZrLJ21iv6L6
XdY9e3WJ9btv5jqsIvUI/LBcncw2oU/sF7FfTTwsZkjgpn2VpE3RRuAncSLz
cL8xsd6vfsV14y0TAhu0beF6pnyIwBRRG+U7I8ByvHzUsndMie9r7vyclEg2
I9bvWR7JUhsFpvgcNsuMO0zgBLt1vsYK5gSOYsx1LfvwL+ZUZdF5tzQcaUHg
RpsX1EZilsT+rTScmWcGge+dF6/8HGpF7A8pVs1jE7Qm1icvd8mvvAO+u4dH
QSzIhtjfajXWyy16hMB2BtkGDR+OEPuFt/DLlAfbEviK965XnuJ2BOZObS9y
6AZeHxkUtvWMPYFDmbPmrgo4EFjJMbJHuQGYOfPk0qqKI4HnD7nlz7j/UvkX
/6Z/m/TEnI9YZ3E83iyWKkhgA6shcskkiTh//x+eVT6+/cS6hXtV7diIFIFX
l//hfRkmS+w/6CT9IIIkT2CWeHY1+15FYj/TlNlZlePKBJ74pdG08YoqsZ/9
CMfkSg/8zyLEu3NGGH4f082scYjUINatKP3FPf3w/+1t2iUGovB7YsK3pppL
OgR2v1w7o9QH/+94vT1SRl6fwK43eL2lrhsQ+4Oq7Y9JDhoS69ZHu9wlZYyx
vz7IjkcZfn+08iInLRr+ThKs3OWsCH/TLNG0un4Hlom7nzZ1G/7WG88ZWRqH
v9kKeydpr8PfBvvU9htJwc+eh7RW7n60INZ9xMbNRsLhZ5vXeyRFJeHnjVwl
Mn97gGV5Iv0YQ+Bnctcf+W1CNgSWVKaO4O+Gv+NNddh8Q+HnGvHxKrIo/LzV
M6nAmA3+SzaIC5hz/0L4T4lu6HvoZl5iXUEmaCRaaS+BHy/NLJj6SBDXa8pL
mjgsDb/JnhxvHxpB3o4p9z7/HSRH7D93n3owXBJ+2ymnrZz5D/KW1L48eEwE
fiszmH+7PxR+8zRRztboJBP7uWO1nM2k4LfhbP12lR7kq446e3acOPxlU8Ug
VjeMPKXLkOxLl4efujY9C64OR56y1erop40gT/OYAqweboWfFlycnbJc4acm
YZZnlI2mBE69ETve+hp+oipSu6fuCT/tIVElt1fCT+bXvMSzneCncoOblPJC
+Cm1plU4wQb+KRnaMdnBCL+8a5w7dzIPuN/NOXqDGfzDkTMqz0QF/xSYc5x+
a4U83FRZTx9OC79IJzvs+PEb+ZXPmKvbmriHwAORhi+aKfuIz2+Y16Gb60Ie
jfCPpQfESBO4Puqe7419mL8xYTE3eT4hj+bTHPP76DBvH3FFvSjthx9Oustv
bhYkEziXmjY2+Qryp5Canv/EMPygeZn8wDoMefNtqmpqrkuHWB+qEB97GI18
aTi9ibbmI/yw58xGnbQD0P/Bst216qvIF5N4xvmkUujvzu8T3eIKvV1d/Iqo
OKD3qXRLYYHN0Lftk1q2QyEwt8XKqi8d9CUnrJ4nFQJTUoUCrh2Bvlqu53+G
rwDHtD21WJcDvU/8Xa/AZwq9A43PPduRj3yIZgx7JyiEPBhX+8G46N5N5IEj
rdcd35O7ifXO++FTb24IEHgDpX/egwN5QN/OsMT8CfdfnY/PZZ2OQR5I8C+I
bh/C/VbWp6q096fQ/ylBRd08q//qz6nK/cVgZjqDTKxLv4iXaWGAvozzhrby
T9DvDziFuILp0e/dEoo3+jdBz5ADlixRNujvdpHfPS7U6Ge+5PIKETPoeZxU
eKZ+AdilOjZl2gJ6RhsJn1XMRv/+9i1pP28EPY/rFQQZ30f/Ft0ib/PTgJ4u
P7l1+X8Bk1i7dm5Sgn40dz/Kh34HVu0Nzpwho19lw0qfCM5Az5Jl/8VtQ+jX
Lgb52Vd/+Ah8et7qzbIB+tX/tyQNcxD6lUfbrEhcAf06NufE0RWK/ryo3b+F
pRj3B2SnrODRFeSzbRxbn6Yl+vFEswbJzBr9R67usf2Yjf4LrhQomTyO/kug
5ir9Wwi9zj/jXAy0R78FNjqY7MyAHtISimrS1NBjoOYSfTQFevjUR+lL3oce
/5jxhdD9xDy2PubnxpAK/oVVk7aofUM/fTnNM0oXB/4tx6kUUpTQT4wdQ0Pa
SeC/s/RWzasd6KeHjSd7HaYwP1UX6SkKDRIETpI1X9SXliVwpFOaubwl8o7K
+/ed9/bwe5mjroYWtTaBZ7xWFfKs4HfBb/Q/lwpwPyQp5DwuIYB5VJTKd7P3
DPhgN/a4IFwPPta3774VsgP1k15Py0ezo17+7mfqKd6oV3s3OSc5V4jYf5Cj
is5FRoHAHpQxgwwL5HmKT+PDAhMygSle8/o/n8EvsZy5wczL8Ae5Qp79SDme
d2r0H3KwPIcfklJyBFtI0F9s7jfjjTo8X5BarsccaoC+Tjft25rZrIn1y6xb
FLJcUJ+RZeDEbWnoF0J6KETrUUPk4eyVQjf3ncjDneYsfv0yyMM9Rysvuz5H
/u2uIbNXuSH/rrv4mY++QP55518w89NF/il/3eSg3YX8mxU9vKXmFvhSra/c
wTQLvgyuFJrM/kR/lZ957XqGAr569ETMfDSQdzUBHkIx03gePCDj5jmlg36S
yAu3eToFzKX/anuNAfh966AyOnMf/aU9YcfrogE/qZymXHeUB9+V5xLPtnwF
thhZ77JZEv30h6VPXm0YuHFif9DCKPy19DRkPLsbeXb8asjbgkw+AldlD2ht
m//3+YhTVfDPY6q7Rsgz+b71Stc3Is80ue/WZkQhv6QHuf5yq615Xv+pOWus
Dj6nRR3vmMSjvy5qp96+ex/5dOs488pgEvjavvU+g9FvzH/2d/H+mrPg642S
ZMr2OPAVb1pU2TqG/vuiIzrwKwZ8bdA1IzFEgh8DO4q8tRT82hZzZ9H2Fvjy
Z4t7RccJ/06HzNsGxCF/fi0GLb1NwbyeMN3pHM+M/GkN02NS/455mtIX4cur
gfovLPcfGEyBn1aeyDVt40a+0G6pH6g6gfomDCnlcxWoj0/mm7whE87//c4x
2+fHMM9cWvfpqa1Hfki0PVxRFkN+0E9dslE5SCZw90uK99tE6BdTIX0hJBPz
pOARVbtrCvLi4iXW6TFe+DnYLcX6TAXO+7JAk0GlEvx3B3oNPWFEXpwN26jg
bIvz/3gWMvhJDHyHXs8/KFKGfl+mJwmc24o8F3zkbRi9A3kuxH+l9rEP+EzI
GYwdWQc+Wd1TuINW1s6nLsXRR5jf8Vb6Am6vkZdG+r2B3Cyob7fZ+JLOE9Tn
dIpOYVAb57fa+u2QtibeL9xYiFl+Oo/5ZMAddYPaDv7IVNQJ1uXA/NFYd3qd
vBf80fFOMntbA+aPS1bMOn0J1KNq0qd0tBN+sNtCEb56Dv7d7Gj5JvIo8jFD
SDiZOQT6S/1imxJwJhOYn396H89b6D9brpwj24n8ezer6ZBfC/0/XThU8rAD
82EmzbjyBw/0jUrkUPjug+fp3BX/n7oK0PcZNbMnt0cRMQ/OXM3LaPiO95U1
4m3FY+sxDwqecGnHJWMeaJkK6jkfhj9KGPa766Wj3nYuW5KqDOYB626VR7YV
mAcDnb2Pnoaifq2Ozph946g/vSTgRO448is/kdpcYxZ8XDwcd8ZJHn6ziBCa
8P2CeUCmUSa3qiPP4r18DHgngGdvGn94qg1/HZ3QTWlKQr7NpOc32KjAb7Ru
77V6peDfbxV9G9O/rMH6GetjSci32bqe0l0fge9wT38eGoI/UhjCBn61Yh6I
1qVLiAXzEdglLC2CrwF+vnh2ZNVWDvOgfrczdekC3ldkXTl9zzcA82B3aGoU
nSz4ZArVMjeSA58axwTymaLgd3+PwYvOcZgHSfuHu6viwNdNho5v/TOYB8/s
00R2T4Evj4VQjU3R4IvK9IJ94TD6I1uRKdEzCnylF0y3XQ0FP9qcS6UHxNa8
D/KdDhuPWPP+p5LjpfBW+PeOTcn9UHfMA6PAF4tR4ZgHrMM0yYp/4M/ZDcY3
P8ij3n0Mmkc6YuCf4x58FRHs6O/cFu6rxa6ox9Sw1ravBM8/PDPjpSJ0a+63
TldMKNoj/2PlLvcyc6PfFXI+FdNJkon1KtuLVM9vQp8SpYLnMcnI+19+ah1+
PPDn3j0/qD1LcJ7zGXz/FJeAT19VljJ1S5xH1ZbmAw0JfOVwxfm2Z4CPbtGp
iUTnNfPPsyHUfAV6K+R9eG68iO9/o7Te/jE9zlO/QeGh0iOcx5a0rqyCjOuv
/Mi9Y8YF/44FNFP8B5HHflk+1Zk6yGOJVp1hbRbkcZKcwq45J+jV7BY0XyEM
fbKN0z5ptsBfVXPmLzf7wy+Zr64fC9BHHjHeZvTv84AebgXeOpM2ZAJvajhV
Rv8KenArlQ/q1CFvDO/7K9q/Qv4KcfZqDXAgb68e3lrW4Im8Xc7+M+l9APx7
FYxwSX5F/im8zn7ynbLmeUHGZmhhGnxzt2+nZeLFfExYSAqIfwA+svi8+N/8
RT8mnVP7S1UIft/UyIv/3AV+O+d82KceY54lfDV6/3AX+Aw2ktrBWg0+rxWt
b9/rDj47xPauBmiBLw+llzpez9fMpzzd55f+WePPxk1l4Ufhhy/8dlcy11kR
uEBBkFXxFPyxN+qxpe0pvN/neaK9XZ8PeUU18XhznwzqPU+7Z1fqWehLrtL/
R/k29LXX4rhC0455UCJSL0PNB71iB7jKWM5AL1vT2Xl+JejFmts/peXxiJiP
ynXtrJrVmI/bUiV6J+fw/7xFQ22h3GjMR5tErtEDeug34z7WOcpdnPeyUVPC
XhHMxwDFd1quBTj/4YzEqT0hZAI39nxsejm85nnJ7EhgxAj4Ec5J1xeZgh4W
1nrXPkihv+9tjqg7Ngg+6iay8pTV0O8Nhs61NqPAg/lcivya6PenpLY/cgnI
ew2q/h09B6G367D2I7b98C+VY4ANywhwEZXfkU4h5P3JjO7Fm++BA6QMOM0H
4LfJQoZ+rmbMRzbXotHv7nwELp2lydlXCP/kvQxZVRHFfGStjf3cNoX5aF3y
hcnaG/Mx3sKhJ1ACfBq1vA1vkVzzvLTMUDkejn6bDrp41iAa83EXp4Hq/ttr
/t+YvvfqjW/gp9L8aULkDfDzouPoU4FB9NeG4oDfmRHg54RrOW/9JfBRM7+w
mCmC/jnutL2ZdHUNP+zvpSu2rHnfWcf1JtIM85Bv37zMxin4LzVrf0qJNOpZ
YV46oRe15n5dj0O2ejPygEpE44O4M87P0PIkV+8F5l9Sy9hiEg3Op+H1U32W
dY1/I69/niCRif2y4mTdvRHgW8yrn1zGBX8FXuS0GC3G9QZ3xuz6WQx+fuxg
Xio4jOu5FVRbxQmj/krHqxseJqPebMn0JTZH1LffoHL55l/oZWIctFz6G9+/
JJveNrUO5+HxPPbnZRrO07+eZomkiuub2G18Yb0O/ttS6k6x7Eb+hv9wsj+n
jPzV7OIRbbcD/6s6Pt5/BMG3Q1uYaEkj/DH7+fKyxSnofeprhvRJVQVV6v8i
TtXSurNDlY7g+3IMz5k2czKunyy17nzxGr6XlxY73iAfaCXZl+TcUc9e6lIP
alnwWVFd9DnwDz6f1bsocmwSfKnfvhDul4x6RrbTxzMsIp/rSgeWPj8GH93M
pMbqreAja0Fgr0s65lFTg7rpJx7wIdXK4XWpCnyUPZLddsJljf83dJNs1VBv
8PK80+8c1CfM7EdHeQ39lh6zLs3bo96lt5TWTdSYR3RZ1yTUjkBP+a7EWTFX
zKOjs3UGjTy4P5GqT4ncLIXzakkqzdw+gXz/9atMTCAC+iSliJ1634j87R5j
DgzYhXkUmlXo91IR/GfSZlGb1uN+obq53jJxEnps4VR14xnE+6LEenK6aAz0
MKWJ1rW6C/+ntgyxuLwCn7ubxa/xHSATn++src2bKQNf/MwHXUb/Qm/Ho8H7
uk2hX+K18POhoqj/441TsZcsUD/T2W2BNt6Yry/LHpy0pdEg1qfsSjxKM3Be
b6HugsAV+MdL/tHfHZXwD2X6FY1/HvxiUfMxYtgTfrC4ECD25QX0v2yy246h
Fs/Hq5ObAzmOQ//WyxUHDtJDfzbN4vKIIOjd51D3tUkQ86CFoTDhnhzOF3P9
o7lVKvTlm1m9I9IDfVN8Qn9G8CPPpSkSAbHK0Pf/ACwyLms=
     "], {{{}, 
       {RGBColor[0, 0, 1], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[{
          PolygonBox[{{435, 557, 385, 497, 117, 177, 35, 80, 34, 330, 232, 
           572}}], PolygonBox[{{526, 537, 291, 387, 123, 182, 42, 87, 41, 446,
            332, 564, 419}}], 
          PolygonBox[{{546, 199, 567, 426, 531, 272, 369, 76, 113, 29, 144, 
           75, 577, 441}}], 
          PolygonBox[{{317, 412, 521, 224, 292, 131, 189, 58, 97, 10, 130, 57,
            575, 439, 544}, {566, 539, 296, 391, 139, 195, 69, 106, 21, 68, 
           20, 228, 138, 311, 194}}], 
          PolygonBox[{{360, 532, 282, 379, 94, 159, 7, 54, 6, 223, 127, 310, 
           186, 424, 263, 554}}], 
          PolygonBox[{{574, 580, 445, 550, 331, 418, 234, 301, 151, 204, 84, 
           120, 38, 150, 83, 220, 119}}], 
          PolygonBox[{{286, 549, 329, 417, 230, 297, 142, 197, 72, 109, 24, 
           141, 71, 320, 216, 569, 429, 534}, {565, 440, 545, 318, 407, 214, 
           284, 104, 167, 18, 65, 17, 136, 64, 213, 103, 306, 166}}], 
          PolygonBox[{{455, 294, 558, 389, 500, 134, 191, 62, 101, 14, 133, 
           61, 212, 100, 305, 164, 421, 244, 552, 341}}]}]}, {}, {}}, {{}, {}, 
       TagBox[
        {Opacity[0], LineBox[CompressedData["
1:eJwl1nfcjmUYBuDPlhVF9orIyCozO6REIStlRqRS9i4zomhQtkohW8nMSkZC
ZY/KyIpkb+q4fv1xOK/zvp/3fT/Pez8fedt0bvBaooSEhJqJExIi1/ijHn+b
J9Gch7GdkISkrLX/NGfNk3meR9hn7SWSs0wfQDLW6c/wj3kKL3Ba70NWfon3
9wEfmR8lt/lbWdr6ftmBwtZSyJkst15Gvin/IHl0UjCVFvS1n42MXjdblpO/
xt9BjtUrUlY/IDuSkhX6W6Tke70+58zTaEk5Dlp7mbtYqQ/kLtbrDThv/pSb
5ncpQSv9jOxHdjL5GebIHXE/zePMJWUlmUcukVVkefuDSEVrKvAdg8nvmkPx
2a6bZH5Y1pD55HKZ2t4PsiEXzJ/RhkdJwwbrz3LR/Dltqchv1jqRilX6EC6a
h/AAh+Pn8RmTzTXJb14hq8u09jaaG/Ggfkn/wjxdlpQvyp1UYijpaEdlVjOM
S64bSjGvLxDfoVwoj9hLbZ5irsXd+ibZmMvxObSnCr9beyXuAWv0t7lsHkZB
jsY98F5TzY+TXt8sm1DI+hU9vfwyzmCkXirOttxFVYaTgWrcwww6kMN1u+XH
sjJ5vX6prCqrx3k1v0oa1uojuJcf9aZcNc+kI3/r/cnJnniWvMcncTZ4TD8k
4+EtEvde3iNnyTJynf2y5nfkn2SkBpl4OZ73OOOMjPsT31ecTa9bFM+gPGY9
rZym1+Y+fYtsxjXzLDpRi8PWOpOO9fooMvOT/hzXzV9xy/xenNX4fvSzcgBF
fU6u+Aw5V5aXe+M+x/cj3yULr1I7zjXvUcj+8Xje5BNxPr1uZdwbmdX6VnNz
bphn8xpPkI3sbLP3PDfNc+jMkxyx9nqcMTboo+N7Zbv+ArfMc7ltHs0jcb3+
T/xOIjeZ/Qzz5D7ryc3jzaVkNXm/XCaryTr2x5CTN3gqMs4k99r/SpaVG63/
a36fcpH6FTmcwpzQc/GzuQW3zfPoQl1yk4df7LXkjnk+XanHUWtdyMAm/QPy
8qvein/NC+jGOf0t8rBffzrOmLlrnEE26/EPxgfxXfKhelWOoLj1IjKH/FpW
lCfjvsd9kc+Qj4V057z1gTzkurwyi5wvD9hLYZ4Qv3uorx+T3eK+8aP+EfnZ
obcm/oFbJHrQgON6dzKyRR/LtXhm4kxySn+AneY2JIr74zNnyK+t35FjKGGt
tMwlF8dzL3vaP0hDxlGAXjwbz0X8fuAh1/4lP5N1KOB138kasqD1Xea2JOYb
vTeNOKH3IBNb9U94kN36iyRhsd6HC+ZBcW/5TW/MSXPPeN7YFrfF531orsB4
/bocSTFy2vtGVpKn7aWTn8eZl0/JVRSy3oTCfEtfBlvPR1bXLYj3lr9bTykn
xjNKU/2U7BXPC9v1CRRhj96OpCzR+9GMonHfKEZxSlCSva5rTzKW6v15jr/0
3nFu+FmfyA3zqDiLnNHv9jNNN9eloHl1ov//P1TK3n9dbAwF
          "]]},
        Annotation[#, "Charting`Private`Tag$38937#1"]& ]}}], {}}},
  AspectRatio->0.25,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 5], 0.2], 
       FormBox["\"10.\"", TraditionalForm]}, {
       NCache[
        Rational[2, 5], 0.4], 
       FormBox["\"20.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 5], 0.6], 
       FormBox["\"30.\"", TraditionalForm]}, {
       NCache[
        Rational[4, 5], 0.8], 
       FormBox["\"40.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.2\"", 0.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.4\"", 0.4`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.6\"", 0.6`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.8\"", 0.8`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.2\"", 1.2`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.25, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.35, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.45, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.55, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.65, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.75, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.85, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.95, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.05, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.15, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{0.8899999999999999, {
       GrayLevel[0], 
       Opacity[1]}}, {0.7000000000000001, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.2, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->700,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0., 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.793446723677157*^9, 3.793446785087015*^9}, 
   3.7934469801090403`*^9, 3.793447227208099*^9, {3.793447264011318*^9, 
   3.793447277456396*^9}, 3.793447311102808*^9, {3.793447516154393*^9, 
   3.793447528874736*^9}, {3.7934619226037683`*^9, 3.7934619288630877`*^9}, 
   3.793461961164349*^9, 3.7934622036035557`*^9, 3.793462451229333*^9, {
   3.793462489491652*^9, 3.793462608413128*^9}, 3.7934626961006603`*^9, 
   3.793463101949006*^9, 3.793463162163579*^9, 3.793469063784091*^9, 
   3.79352928181706*^9, 3.793529765743968*^9, {3.793529807095574*^9, 
   3.793529926214718*^9}, {3.793530274258504*^9, 3.7935302895109863`*^9}, 
   3.793532176390874*^9, 3.793538247675445*^9, 3.793538621743272*^9, 
   3.7936176670134687`*^9, 3.793617740073183*^9, 3.7936286885906897`*^9, 
   3.793631368536269*^9, 3.7936321728943987`*^9, 3.793632436201429*^9, 
   3.793632616516098*^9, 3.793632897848282*^9, 3.793633151320738*^9, {
   3.79363319811522*^9, 3.793633213245633*^9}, 3.793634385413712*^9, 
   3.79363484039583*^9, 3.793635142278419*^9, 3.793640118982139*^9, 
   3.793640224661243*^9, 3.7937091795920973`*^9, 3.7937176834133244`*^9, 
   3.79371785385695*^9, 3.7937179119530373`*^9, 3.793718183805469*^9, 
   3.793718275270541*^9, 3.79371954723167*^9, 3.793801400086944*^9, 
   3.793801480757762*^9, 3.793801576909615*^9, 3.7938016441479063`*^9, 
   3.7938017488942947`*^9, 3.794507036141409*^9, 3.7945075038858843`*^9, 
   3.794507550173286*^9, 3.794507669740239*^9, 3.7945131193645687`*^9, 
   3.794513186110403*^9, 3.794515039594195*^9, 3.794515323921063*^9, 
   3.794568658387549*^9, 3.794569023357252*^9, 3.794576702515628*^9, 
   3.794578159351513*^9, 3.79457844600253*^9, 3.794579376600594*^9, 
   3.7945795060590763`*^9, 3.794657270807013*^9, 3.794667533792252*^9, 
   3.794667830427065*^9},
 CellLabel->
  "Out[933]=",ExpressionUUID->"5a2d64c3-8d62-48cb-87fb-1cfc930787c9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6B.pdf\>\"", ",", "figcritprevbpsnpi"}], "]"}], ";", 
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6B.png\>\"", ",", "figcritprevbpsnpi"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79466742313615*^9, 3.794667426144238*^9}, {
  3.794667472698448*^9, 3.794667476521557*^9}, {3.794667808362321*^9, 
  3.794667810267651*^9}},
 CellLabel->
  "In[934]:=",ExpressionUUID->"0d24b8f0-0e98-4125-b20d-871ec2f33dfd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpsnpiimm", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60bpsprev"}], "]"}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yearticks", ",", " ", "None"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "22"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "200"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", "Green"}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1.5"}], ",", " ", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"baseline", "+", "amplitude"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.793469988806632*^9, {3.793470075413954*^9, 3.793470081093424*^9}, {
   3.793470211112308*^9, 3.7934702152043467`*^9}, {3.793470333200201*^9, 
   3.793470334099934*^9}, {3.793470537368553*^9, 3.793470539306753*^9}, {
   3.793538635282527*^9, 3.7935386648543167`*^9}, {3.793538718000548*^9, 
   3.793538728081834*^9}, {3.793633190196765*^9, 3.793633190971692*^9}, {
   3.7936348114620523`*^9, 3.793634816964944*^9}, {3.79370907905031*^9, 
   3.7937090831893*^9}},
 CellLabel->
  "In[935]:=",ExpressionUUID->"4317bb8e-9358-43bc-bc1d-191d5b8ffc1e"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxFuXk0lf/3/o+EqIwVUiEyhCTztLd5nudZQhQlVKgkSUgZyqySkEyZM3dw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       "]]},
     Annotation[#, "Charting`Private`Tag$39370#1"]& ]}, {}},
  AspectRatio->1.5,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 22),
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
    None, None}},
  FrameTicks->{{Automatic, {}}, {{{0, 
       FormBox[
        RotationBox["\"2020\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"2021\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"2022\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox["\"\"", TraditionalForm]}}, {}}},
  GridLines->{{}, {{0.5, {
       GrayLevel[0], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->200,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7934699894726562`*^9, {3.793470075830908*^9, 3.793470081965844*^9}, 
   3.793470216425116*^9, 3.793470334682704*^9, 3.793470539599276*^9, 
   3.7935292820531263`*^9, 3.7935297659296017`*^9, {3.7935298072783747`*^9, 
   3.7935299264119387`*^9}, {3.793530274436921*^9, 3.793530289692074*^9}, 
   3.793532178261346*^9, 3.793538248176729*^9, {3.793538635776616*^9, 
   3.793538665169251*^9}, {3.793538718266941*^9, 3.793538728341588*^9}, 
   3.7936176722288923`*^9, 3.793617740484042*^9, 3.79362868895872*^9, 
   3.793631369181305*^9, 3.793632436452693*^9, 3.7936326170747547`*^9, 
   3.793632898155519*^9, 3.79363315158302*^9, {3.793633191290484*^9, 
   3.793633213479291*^9}, 3.793634385668785*^9, {3.793634817238412*^9, 
   3.7936348406421328`*^9}, 3.793635142583169*^9, 3.793640119259891*^9, 
   3.793640224892289*^9, 3.7937091822357492`*^9, 3.7937176837078543`*^9, 
   3.79371791231691*^9, 3.793718184254736*^9, 3.793718275663245*^9, 
   3.793719547591016*^9, 3.793801400401219*^9, 3.793801481111108*^9, 
   3.793801577284792*^9, 3.793801644505484*^9, 3.7938017492594423`*^9, 
   3.794507036708665*^9, 3.794507504357739*^9, 3.794507550542511*^9, 
   3.7945076701024313`*^9, 3.794513119743074*^9, 3.794513186485004*^9, 
   3.794515039975915*^9, 3.7945153243038692`*^9, 3.794568658659904*^9, 
   3.794569023759548*^9, 3.794576702938386*^9, 3.7945781597119513`*^9, 
   3.794578446523521*^9, 3.7945793769726353`*^9, 3.794579506403648*^9, 
   3.794657277789727*^9, 3.7946675348917503`*^9, 3.7946678311076393`*^9},
 CellLabel->
  "Out[935]=",ExpressionUUID->"db16f247-e126-4935-b0fa-b229e978cb75"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6F.pdf\>\"", ",", "figcritprevbpsnpiimm"}], "]"}], ";", 
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6F.png\>\"", ",", "figcritprevbpsnpiimm"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7946674127993717`*^9, 3.794667415743104*^9}, {
  3.7946674879628887`*^9, 3.794667491628037*^9}, {3.794667803930437*^9, 
  3.7946678058700857`*^9}},
 CellLabel->
  "In[936]:=",ExpressionUUID->"5d802398-f020-4389-88b0-f2563cca9f9c"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot the continued rise in ICU cases after implementation of distancing, with \
prevalence, without seasonality, and double the ICU capacity: \
\>", "Subtitle",
 CellChangeTimes->{{3.793445775253668*^9, 3.793445791735546*^9}, {
  3.793461803106874*^9, 3.79346180437956*^9}, {3.79346302353588*^9, 
  3.79346303274085*^9}, {3.7934635851245403`*^9, 3.7934635913014708`*^9}, {
  3.793468488723399*^9, 
  3.79346848882721*^9}},ExpressionUUID->"a14510e7-0df2-4c28-91b2-\
b0bd559d373a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sf", " ", "=", " ", "0.02"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prmax", " ", "=", " ", "2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.793446122258461*^9, 3.793446135642728*^9}, {
  3.7934618271568108`*^9, 3.79346186369106*^9}, {3.793462009540318*^9, 
  3.793462018321295*^9}, {3.794657368540917*^9, 3.794657369673212*^9}},
 CellLabel->
  "In[937]:=",ExpressionUUID->"b7ba0189-608a-4cc9-a7fd-cc60feb0b608"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpnsmoreICU", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60bpnsprevmoreICU"}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", "sf", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60bpnsprevmoreICU"}], 
        "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "2.4"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", "sf"}], ")"}], "*", "#"}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}], 
         ",", " ", "All"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"dateticks", ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
    " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", " ", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", " ", "Black"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", ".000089", "*", "2"}], ",", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", "  ", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevonmoreICU"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevoffmoreICU"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7934461917708607`*^9, 3.7934462838598347`*^9}, {
   3.793446322446604*^9, 3.7934463225391617`*^9}, {3.793446417493855*^9, 
   3.793446493716259*^9}, {3.793446527768334*^9, 3.79344668076748*^9}, {
   3.793446762278329*^9, 3.7934467828855133`*^9}, {3.793446951803142*^9, 
   3.793446955141111*^9}, {3.79344707334725*^9, 3.793447099371722*^9}, {
   3.793447159075315*^9, 3.7934471754116783`*^9}, {3.7934472158450813`*^9, 
   3.793447223477141*^9}, {3.79344729650998*^9, 3.793447304161545*^9}, {
   3.793447499123787*^9, 3.7934475264506483`*^9}, {3.7934618795755053`*^9, 
   3.793461889980399*^9}, 3.793462004628837*^9, {3.7934620364212713`*^9, 
   3.79346203990898*^9}, {3.7934624225659227`*^9, 3.7934624372262497`*^9}, {
   3.79346305953295*^9, 3.793463072999475*^9}, {3.793463614556497*^9, 
   3.793463639026314*^9}, {3.793463688190838*^9, 3.793463699529416*^9}, {
   3.793468506492344*^9, 3.793468512241255*^9}, {3.7934690521791267`*^9, 
   3.7934690528079863`*^9}, {3.793529951989105*^9, 3.79352995227308*^9}, {
   3.793538296607723*^9, 3.793538349702276*^9}, {3.793632211990872*^9, 
   3.793632213131914*^9}, 3.793706396683765*^9, {3.793709344977947*^9, 
   3.793709358141308*^9}, {3.793717875513443*^9, 3.7937178862232656`*^9}, {
   3.7946573796682167`*^9, 3.794657380971161*^9}},
 CellLabel->
  "In[939]:=",ExpressionUUID->"91195b8f-f0f8-4ad9-99ea-ac3922c7f56e"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEuXk41P/3/48kWSpUthZky57s2zm2sS/DSKGUCkmRKEtKCy0qS0qoRLaS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       "]]},
     Annotation[#, "Charting`Private`Tag$39727#1"]& ], 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxFl3c81v/3/6lQVkqLECKr7Jlxjr33uOyVkRWJooFKVlLKjghJMoqUpBKa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       "]]},
     Annotation[#, "Charting`Private`Tag$39727#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 2], 0.5], 
       FormBox["\"25.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 2], 1.5], 
       FormBox["\"75.\"", TraditionalForm]}, {2, 
       FormBox["\"100.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.5\"", 0.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.5\"", 1.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.0\"", 2.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{1.7799999999999998`, {
       GrayLevel[0], 
       Opacity[1]}}, {1.4000000000000001`, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.4, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 2.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7934462183922*^9, 3.793446262635705*^9}, 
   3.793446322861353*^9, {3.793446417955284*^9, 3.793446493969702*^9}, {
   3.793446528220602*^9, 3.7934466811191187`*^9}, {3.793446762960642*^9, 
   3.793446783185998*^9}, 3.7934469583619823`*^9, {3.793447077418531*^9, 
   3.7934471077778254`*^9}, {3.7934471626694593`*^9, 3.793447176249228*^9}, {
   3.793447220612138*^9, 3.793447223788662*^9}, 3.7934473045057087`*^9, {
   3.7934475125474377`*^9, 3.793447526798827*^9}, 3.793461894648978*^9, 
   3.793461954811411*^9, {3.793462025917428*^9, 3.793462051362706*^9}, {
   3.7934624165193977`*^9, 3.793462437537854*^9}, {3.793462489379582*^9, 
   3.793462572943308*^9}, 3.793462608295115*^9, 3.793463073451934*^9, {
   3.7934636214960127`*^9, 3.793463699918407*^9}, {3.79346376440827*^9, 
   3.79346376988308*^9}, 3.793463805573547*^9, 3.79346851319989*^9, {
   3.79346862065024*^9, 3.793468649807746*^9}, 3.793468764258175*^9, 
   3.793468826592022*^9, 3.793469064588636*^9, 3.7935292834068537`*^9, 
   3.79352976668906*^9, {3.7935298081718893`*^9, 3.7935299525646677`*^9}, {
   3.793530275214665*^9, 3.793530290660701*^9}, 3.7935321998961363`*^9, {
   3.7935382500095463`*^9, 3.793538270776973*^9}, {3.7935383186980743`*^9, 
   3.793538350088092*^9}, 3.793617741944303*^9, 3.793628690509836*^9, 
   3.793631370955662*^9, 3.793632213465222*^9, 3.793632437655604*^9, 
   3.793632619354067*^9, 3.793632899566637*^9, 3.793633152650743*^9, 
   3.793633214507358*^9, 3.793634386804269*^9, 3.793634841640366*^9, 
   3.79363514371541*^9, 3.793640120294117*^9, 3.7936402259345703`*^9, {
   3.7937063915804853`*^9, 3.793706397254778*^9}, 3.793709358562379*^9, 
   3.793717685077854*^9, {3.793717876127532*^9, 3.7937179134764*^9}, 
   3.7937181857979097`*^9, 3.7937182772014914`*^9, 3.793719548895088*^9, 
   3.793801401508336*^9, 3.793801482507049*^9, 3.7938015787801037`*^9, 
   3.793801645890503*^9, 3.793801750964737*^9, 3.7945070381585903`*^9, 
   3.794507505414393*^9, 3.79450755165725*^9, 3.794507671079335*^9, 
   3.794513121533935*^9, 3.794513188179587*^9, 3.7945150418469143`*^9, 
   3.7945153255093317`*^9, 3.7945686595558577`*^9, 3.794569025303363*^9, 
   3.7945767046424017`*^9, 3.79457816110443*^9, 3.7945784485594473`*^9, 
   3.7945793783490953`*^9, 3.7945795074729767`*^9, {3.794657373826873*^9, 
   3.794657381332364*^9}, 3.7946675357312803`*^9, 3.794667624269565*^9, 
   3.794667831659314*^9},
 CellLabel->
  "Out[939]=",ExpressionUUID->"10970ed1-9028-4ce6-b90c-d24ae52a9ad2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fignpibpnsmoreICU", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"10", "*", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"npi", "[", "t", "]"}]}], "/.", "sol60bpnsprevmoreICU"}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", " ", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", " ", 
        RowBox[{"Opacity", "[", "0", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79344727493867*^9, 3.793447275672996*^9}, {
  3.7934625847549*^9, 3.793462585031742*^9}, {3.793463088769895*^9, 
  3.793463091558565*^9}, {3.793463731240335*^9, 3.7934637317780437`*^9}, {
  3.793463834924958*^9, 3.793463837569601*^9}, {3.793468518598464*^9, 
  3.793468521174193*^9}},
 CellLabel->
  "In[940]:=",ExpressionUUID->"746fac6e-02c9-4c4f-a2cc-e6b8db1828bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpnsnpimoreICU", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"figcritprevbpnsmoreICU", ",", " ", "fignpibpnsmoreICU"}], "}"}],
     ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"PlotRange", "[", "figcritprevbpnsmoreICU", "]"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "ar"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "imsz"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793446704447353*^9, 3.793446711536757*^9}, {
  3.793446744118206*^9, 3.793446750009528*^9}, {3.793446976069807*^9, 
  3.793446978955377*^9}, {3.793447262748226*^9, 3.7934472636613283`*^9}, {
  3.793461917634132*^9, 3.793461928547559*^9}, {3.793463093975984*^9, 
  3.793463097176322*^9}, {3.793463150716834*^9, 3.793463154325522*^9}, {
  3.793463735931305*^9, 3.793463762176955*^9}, {3.7934685250249233`*^9, 
  3.793468532220965*^9}, {3.793632220984662*^9, 3.793632224737013*^9}, {
  3.793633166344995*^9, 3.7936331685680523`*^9}},
 CellLabel->
  "In[941]:=",ExpressionUUID->"de8575c4-5107-45b8-9419-38ca0d4bf8c7"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxEuXk41P/3/48kWSpUthZky57s2zm2sS/DSKGUCkmRKEtKCy0qS0qoRLaS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        "]]},
      Annotation[#, "Charting`Private`Tag$39727#1"]& ], 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxFl3c81v/3/6lQVkqLECKr7Jlxjr33uOyVkRWJooFKVlLKjghJMoqUpBKa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        "]]},
      Annotation[#, "Charting`Private`Tag$39727#2"]& ]}, {}}, {
    GraphicsComplexBox[CompressedData["
1:eJxNWHc4Vo0bfhWFaFjJSshKQioZec2MUES2Ml8jsxKRGRmfkFTIyAj1yeqV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     "], {{{}, 
       {RGBColor[0, 0, 1], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[{
          PolygonBox[{{427, 360, 39, 82, 38, 127, 81, 254, 178, 332, 231}}], 
          PolygonBox[{{252, 331, 413, 230, 299, 103, 145, 33, 77, 32, 124, 76,
            440, 342, 421}, {256, 329, 411, 227, 296, 96, 139, 24, 68, 23, 67,
            22, 441, 343, 422}}], 
          PolygonBox[{{316, 428, 309, 392, 137, 193, 20, 64, 19, 63, 18, 116, 
           62, 341, 249, 431}}], 
          PolygonBox[{{426, 417, 238, 307, 133, 189, 11, 55, 10, 9, 54, 8, 
           111, 53, 248, 168, 327, 221}, {409, 247, 430, 315, 398, 162, 215, 
           73, 99, 28, 72, 27, 183, 121, 246, 161, 435, 326}}], 
          PolygonBox[{{154, 333, 414, 233, 302, 114, 155, 60, 91, 15, 59, 14, 
           58, 13, 180, 113, 339, 244, 429, 313, 396}}]}]}, {}, {}}, {{}, {}, 
       
       TagBox[
        {Opacity[0], LineBox[CompressedData["
1:eJwl1WWYFmUUBuBduhvpWFKQlg5ppGNpAxWbFBswEewWDEwMShAFlLC7u7u7
u+N+Ln/ce55z5pvve2fmnWuLZs4vnldYUFCw05/U6f6UYKe8hCnsTglKUorS
lGEvnyvJnfJpTKUrs81q8Yx8OfMoy95mpbhLXsrpche+lq9TxzFNXqg2Yz1v
6/dU16q/0Y35lKM75alADypyN8uyZud8o65Sx7ON6fpFanPekdfRkzn62jwr
X8ERVGIfs9Lck7Xmelmsb8G78np6MVe/C8/letWhbGal/ly1Fxv5ST9RXaBu
pTK9qUIfquYe0ZcrOZIOPv+5eo06hju4Xb9cHci/cjX2lctwr3xG1k6/3Huz
OjwvX8VRVGeGWVnuk8/MOXJXvs13cYLckvfklepwbpYvUPuyid/1k9U91KOp
QX9qMoBa3M9Z+Q2f68YGvtNfr05ghnyi2or35Q0MzDPW1+UF+WqOoTb7mZXj
Afns9Jykb80H8kYG5Rnq6/Fi7h3nyb35WT42+1XuyBfyterY3Ft5hTqI2/Iy
sJqp7MgzNhpMHYZQl3PYn10d/zDPTR3BVm7RX6j24w95KAvk+ryU3+U46uU7
zMrzYPYMBzAse8CsAS/nHeF46ue4WQUeyrUxk5P1bfhI3sRFeTb8mXcoz15u
yDpeyV5Xh7GFVfpfWMg2GjCchhzICF7Nc+N8n++T6+NX/Y3qJBbJS9VOfClv
p1HWpq/IwzmXgxhJ43y3eSUeyd7iYEZlP5k14jX5BhbTJOeaVebR3NvsLbk7
38uHcIrclo+z39WR3CpfrPZP5i/9TeoUtjM6+52mjKEo945D2c3xT7IH1VF5
97I39JeoA/hbHpv9KTfm9dyP7Gma5XrMqvBY1sBhjKM5LbJmx6ryeL6Twxmf
PWrWhDey1uxxWmZNZtV4Ql6ed0DuwQ+5T2oxs+RT1XZ5Z/lUP1rdrP7DhOwV
WlFM66zL8eqs5Un9ZeoQVmSPqz35UZ7NErk9n8lbmJh9rG/Km/LqPIe8E7ke
sxo8JV/KHCbRhra5v7SjPR3oSCc6M8t5NXk662Euk/MOmBXxlrwm18oyfWe+
knfkt+TBFLKGaYX//4/r4th/CWHGmQ==
          "]]},
        Annotation[#, "Charting`Private`Tag$39868#1"]& ]}}], {}}},
  AspectRatio->0.25,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 2], 0.5], 
       FormBox["\"25.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 2], 1.5], 
       FormBox["\"75.\"", TraditionalForm]}, {2, 
       FormBox["\"100.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.5\"", 0.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.5\"", 1.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.0\"", 2.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{1.7799999999999998`, {
       GrayLevel[0], 
       Opacity[1]}}, {1.4000000000000001`, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.4, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->700,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0., 2.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.793446723677157*^9, 3.793446785087015*^9}, 
   3.7934469801090403`*^9, 3.793447227208099*^9, {3.793447264011318*^9, 
   3.793447277456396*^9}, 3.793447311102808*^9, {3.793447516154393*^9, 
   3.793447528874736*^9}, {3.7934619226037683`*^9, 3.7934619288630877`*^9}, 
   3.793461961164349*^9, 3.7934622036035557`*^9, 3.793462451229333*^9, {
   3.793462489491652*^9, 3.793462608413128*^9}, 3.7934626961006603`*^9, 
   3.793463101949006*^9, 3.793463162163579*^9, 3.793463772110477*^9, 
   3.79346380569412*^9, 3.793463838724552*^9, {3.793468532925724*^9, 
   3.793468536657257*^9}, {3.7934686207695312`*^9, 3.7934686499304*^9}, 
   3.7934687644040728`*^9, 3.7934688300004253`*^9, 3.793469064699635*^9, 
   3.793529283558605*^9, 3.7935297668038816`*^9, {3.793529808291574*^9, 
   3.793529927462143*^9}, 3.7935299681095943`*^9, {3.79353027535737*^9, 
   3.793530290780676*^9}, 3.793532202960617*^9, {3.793538250157241*^9, 
   3.7935382709019947`*^9}, 3.7935383645120783`*^9, 3.793617742161929*^9, 
   3.793628690649108*^9, 3.793631371132779*^9, 3.7936322250533257`*^9, 
   3.79363243775622*^9, 3.79363261969636*^9, 3.793632899709095*^9, {
   3.793633152752654*^9, 3.793633168896945*^9}, 3.7936332145956163`*^9, 
   3.793634386902039*^9, 3.79363484173254*^9, 3.793635143854876*^9, 
   3.7936401203591623`*^9, 3.793640225990679*^9, 3.79370639960987*^9, 
   3.793709362996584*^9, 3.793717685299515*^9, {3.7937178783831863`*^9, 
   3.793717913593142*^9}, 3.793718185952609*^9, 3.7937182773569517`*^9, 
   3.7937195490203867`*^9, 3.793801401636013*^9, 3.79380148268859*^9, 
   3.7938015789407997`*^9, 3.793801646044918*^9, 3.793801751141594*^9, 
   3.794507038319764*^9, 3.7945075054674797`*^9, 3.794507551717298*^9, 
   3.794507671133346*^9, 3.7945131216944647`*^9, 3.7945131883299303`*^9, 
   3.7945150421018553`*^9, 3.7945153256390543`*^9, 3.794568659613101*^9, 
   3.794569025467752*^9, 3.794576704840392*^9, 3.794578161248749*^9, 
   3.794578448772991*^9, 3.7945793785216084`*^9, 3.794579507544088*^9, 
   3.794657383575921*^9, 3.794667536160228*^9, 3.794667624427738*^9, 
   3.7946678318022957`*^9},
 CellLabel->
  "Out[941]=",ExpressionUUID->"c3755d38-4c25-4612-9ac7-3eb1d0d6e88b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6C.pdf\>\"", ",", "figcritprevbpnsnpimoreICU"}], "]"}],
   ";", 
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6C.png\>\"", ",", "figcritprevbpnsnpimoreICU"}], "]"}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7946627090172157`*^9, 3.794662749556136*^9}, 
   3.7946627889370117`*^9, {3.794667494831417*^9, 3.7946674981889343`*^9}, {
   3.7946676181606607`*^9, 3.794667618926928*^9}, {3.7946677974896383`*^9, 
   3.794667799604192*^9}},
 CellLabel->
  "In[942]:=",ExpressionUUID->"c7a2ba89-41ba-458d-af51-e3d93dd89c57"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpnsnpimoreICUimm", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60bpnsprevmoreICU"}], 
      "]"}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yearticks", ",", " ", "None"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "22"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "200"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", "Green"}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1.5"}], ",", " ", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"baseline", "+", "amplitude"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793469988806632*^9, 3.7934700082683477`*^9}, {
   3.793470038526507*^9, 3.793470056914083*^9}, {3.793470274444605*^9, 
   3.7934702829037123`*^9}, {3.79347036974651*^9, 3.7934703704895077`*^9}, {
   3.793470556186792*^9, 3.7934705581514893`*^9}, {3.793529386153145*^9, 
   3.7935293878629503`*^9}, 3.7935322327817307`*^9, 3.793538393765749*^9, 
   3.793538571167437*^9, {3.793633159180678*^9, 3.7936331599583187`*^9}, {
   3.793633265520977*^9, 3.793633286211862*^9}, {3.7936344923070993`*^9, 
   3.7936345144074707`*^9}, {3.79363460462407*^9, 3.7936346233944397`*^9}, {
   3.7936346932563057`*^9, 3.793634705953627*^9}, 3.793634927183379*^9, {
   3.79363535310824*^9, 3.793635428876202*^9}, {3.793709108374894*^9, 
   3.7937091233922853`*^9}},
 CellLabel->
  "In[943]:=",ExpressionUUID->"b839f804-aa42-4413-bb77-6e6d141970ab"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxF13c41f8bMHArKSppkZSkjOxNuG97c6zIXkmKVEQqUVJGQpKsrCTJTsg4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       "]]},
     Annotation[#, "Charting`Private`Tag$40290#1"]& ]}, {}},
  AspectRatio->1.5,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 22),
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
    None, None}},
  FrameTicks->{{Automatic, {}}, {{{0, 
       FormBox[
        RotationBox["\"2020\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"2021\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"2022\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox["\"\"", TraditionalForm]}}, {}}},
  GridLines->{{}, {{0.5, {
       GrayLevel[0], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->200,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.793470009367878*^9, {3.7934700400693808`*^9, 3.793470057179406*^9}, 
   3.7934702833255377`*^9, 3.793470370726521*^9, 3.7934705585448427`*^9, 
   3.79352928379874*^9, 3.793529388383419*^9, 3.793529767026054*^9, {
   3.793529808539554*^9, 3.793529927720668*^9}, 3.793530244969163*^9, {
   3.793530275586074*^9, 3.793530291027587*^9}, {3.793532205628861*^9, 
   3.793532233091138*^9}, {3.793538250434671*^9, 3.793538271178636*^9}, 
   3.793538394509164*^9, 3.7935385714961557`*^9, 3.793617742565181*^9, 
   3.7936286909945917`*^9, 3.793631371582651*^9, 3.7936324380237703`*^9, 
   3.793632620281435*^9, 3.7936329000387*^9, {3.793633153015909*^9, 
   3.793633160274107*^9}, 3.7936332148388767`*^9, {3.793633269750188*^9, 
   3.7936332865265903`*^9}, 3.793634387169797*^9, {3.7936344926945744`*^9, 
   3.7936345146909037`*^9}, {3.793634605648184*^9, 3.793634623693284*^9}, {
   3.793634693595882*^9, 3.7936347062551727`*^9}, 3.793634841984968*^9, 
   3.793634927521706*^9, 3.7936351441781187`*^9, {3.7936353617426643`*^9, 
   3.793635429448123*^9}, 3.793640120735701*^9, 3.793640226212624*^9, 
   3.793709365139903*^9, 3.793717685780158*^9, 3.7937179139231873`*^9, 
   3.7937181863315573`*^9, 3.793718277744611*^9, 3.7937195493837557`*^9, 
   3.793801401949926*^9, 3.793801483046771*^9, 3.7938015793183317`*^9, 
   3.7938016463965673`*^9, 3.793801751513597*^9, 3.7945070386473017`*^9, 
   3.7945075057444553`*^9, 3.794507551981391*^9, 3.794507671442021*^9, 
   3.794513122068602*^9, 3.794513188770434*^9, 3.7945150428050127`*^9, 
   3.794515325984376*^9, 3.7945686598679237`*^9, 3.7945690260337353`*^9, 
   3.794576705260112*^9, 3.794578161613551*^9, 3.794578449223859*^9, 
   3.794579378855773*^9, 3.794579507806683*^9, 3.794657386941924*^9, 
   3.7946675367838383`*^9, 3.794667625618957*^9, 3.7946678326783123`*^9},
 CellLabel->
  "Out[943]=",ExpressionUUID->"293e1d30-26b4-4b33-badf-72fc19648b9f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6G.pdf\>\"", ",", "figcritprevbpnsnpimoreICUimm"}], 
   "]"}], ";", 
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6G.png\>\"", ",", "figcritprevbpnsnpimoreICUimm"}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{
  3.794662755326527*^9, 3.7946627854393377`*^9, {3.794667500947113*^9, 
   3.794667504315342*^9}, 3.79466772279642*^9, {3.794667762167326*^9, 
   3.794667794985015*^9}},
 CellLabel->
  "In[944]:=",ExpressionUUID->"6ea84ae9-20b3-4b99-96d7-3117d9c32deb"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot the continued rise in ICU cases after implementation of distancing, with \
prevalence, with seasonality, and double the ICU capacity: \
\>", "Subtitle",
 CellChangeTimes->{{3.793445775253668*^9, 3.793445791735546*^9}, {
  3.793461803106874*^9, 3.79346180437956*^9}, {3.79346302353588*^9, 
  3.79346303274085*^9}, {3.7934635851245403`*^9, 
  3.7934635913014708`*^9}},ExpressionUUID->"44bb905e-0d19-408f-8202-\
a0f142d47781"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sf", " ", "=", " ", "0.02"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prmax", " ", "=", " ", "2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.793446122258461*^9, 3.793446135642728*^9}, {
  3.7934618271568108`*^9, 3.79346186369106*^9}, {3.793462009540318*^9, 
  3.793462018321295*^9}, {3.794657287592448*^9, 3.794657288672876*^9}, {
  3.794657332834889*^9, 3.7946573341345177`*^9}},
 CellLabel->
  "In[945]:=",ExpressionUUID->"53bc77f2-db51-42db-ad35-70bbabc3148c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpsmoreICU", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"10000", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"CCq", "[", "t", "]"}], "/.", "sol60bpsprevmoreICU"}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"10000", "*", "sf", "*", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ISq", "[", "t", "]"}], "+", 
          RowBox[{"IHq", "[", "t", "]"}], " ", "+", " ", 
          RowBox[{"ICq", "[", "t", "]"}]}], "/.", "sol60bpsprevmoreICU"}], 
        "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "2.4"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", " ", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "/", "sf"}], ")"}], "*", "#"}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"FindDivisions", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "prmax"}], "}"}], ",", "5"}], "]"}]}], 
         ",", " ", "All"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"dateticks", ",", " ", "Automatic"}], "}"}]}], "}"}]}], ",", 
    " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "True"}], "}"}]}], ",", 
    " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "fs"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "None", ",", "\"\<Prevalence per 10K\>\"", ",", "None", ",", " ", 
       "\"\<Critical cases per 10K\>\""}], "}"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", " ", "Black"}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", ".000089", "*", "2"}], ",", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", "  ", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevonmoreICU"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"10000", "*", "sf", "*", "thresholdprevoffmoreICU"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"Black", ",", " ", "Dashed", ",", " ", 
             RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7934461917708607`*^9, 3.7934462838598347`*^9}, {
   3.793446322446604*^9, 3.7934463225391617`*^9}, {3.793446417493855*^9, 
   3.793446493716259*^9}, {3.793446527768334*^9, 3.79344668076748*^9}, {
   3.793446762278329*^9, 3.7934467828855133`*^9}, {3.793446951803142*^9, 
   3.793446955141111*^9}, {3.79344707334725*^9, 3.793447099371722*^9}, {
   3.793447159075315*^9, 3.7934471754116783`*^9}, {3.7934472158450813`*^9, 
   3.793447223477141*^9}, {3.79344729650998*^9, 3.793447304161545*^9}, {
   3.793447499123787*^9, 3.7934475264506483`*^9}, {3.7934618795755053`*^9, 
   3.793461889980399*^9}, 3.793462004628837*^9, {3.7934620364212713`*^9, 
   3.79346203990898*^9}, {3.7934624225659227`*^9, 3.7934624372262497`*^9}, {
   3.79346305953295*^9, 3.793463072999475*^9}, {3.793463614556497*^9, 
   3.793463639026314*^9}, {3.793463688190838*^9, 3.793463699529416*^9}, {
   3.793469043599822*^9, 3.7934690446542673`*^9}, {3.7935384674227543`*^9, 
   3.7935384923379917`*^9}, {3.7936321932785273`*^9, 3.793632194119083*^9}, {
   3.7937063246374207`*^9, 3.793706337665127*^9}, {3.7937092488406467`*^9, 
   3.793709262902858*^9}, {3.793717894896758*^9, 3.793717894962476*^9}, {
   3.794657292380962*^9, 3.794657300128281*^9}, {3.7946573442841387`*^9, 
   3.794657346799968*^9}},
 CellLabel->
  "In[947]:=",ExpressionUUID->"4ebe5f1b-558e-43b0-9388-9fb45a9f7bb2"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEl3k4lO8X/1FRStIitKrsJdn3cwzGvoxlrKUUUYnKnlKRQmRLZWm1la2N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       "]]},
     Annotation[#, "Charting`Private`Tag$40646#1"]& ], 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEl3c81W/YxyVUpCJlpIwoWdnZ12VvjnGMY5WEZJQUTSoRySgpUpJRqMhK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       "]]},
     Annotation[#, "Charting`Private`Tag$40646#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 2], 0.5], 
       FormBox["\"25.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 2], 1.5], 
       FormBox["\"75.\"", TraditionalForm]}, {2, 
       FormBox["\"100.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.5\"", 0.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.5\"", 1.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.0\"", 2.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{1.7799999999999998`, {
       GrayLevel[0], 
       Opacity[1]}}, {1.4000000000000001`, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.4, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 2.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7934462183922*^9, 3.793446262635705*^9}, 
   3.793446322861353*^9, {3.793446417955284*^9, 3.793446493969702*^9}, {
   3.793446528220602*^9, 3.7934466811191187`*^9}, {3.793446762960642*^9, 
   3.793446783185998*^9}, 3.7934469583619823`*^9, {3.793447077418531*^9, 
   3.7934471077778254`*^9}, {3.7934471626694593`*^9, 3.793447176249228*^9}, {
   3.793447220612138*^9, 3.793447223788662*^9}, 3.7934473045057087`*^9, {
   3.7934475125474377`*^9, 3.793447526798827*^9}, 3.793461894648978*^9, 
   3.793461954811411*^9, {3.793462025917428*^9, 3.793462051362706*^9}, {
   3.7934624165193977`*^9, 3.793462437537854*^9}, {3.793462489379582*^9, 
   3.793462572943308*^9}, 3.793462608295115*^9, 3.793463073451934*^9, {
   3.7934636214960127`*^9, 3.793463699918407*^9}, {3.79346376440827*^9, 
   3.79346376988308*^9}, 3.793463805573547*^9, 3.793468776167488*^9, 
   3.793469064134989*^9, 3.7935292824597*^9, 3.793529766160926*^9, {
   3.793529807574965*^9, 3.793529926719837*^9}, {3.793530274687523*^9, 
   3.793530290049543*^9}, 3.7935321877990627`*^9, 3.793538248783348*^9, {
   3.793538468238106*^9, 3.793538492643279*^9}, 3.793617740986946*^9, 
   3.793628689537457*^9, 3.793631369930167*^9, 3.793632194756431*^9, 
   3.7936324368787403`*^9, 3.7936326178996077`*^9, 3.793632898644896*^9, 
   3.79363315193443*^9, 3.793633213827849*^9, 3.793634386041009*^9, 
   3.793634840987155*^9, 3.793635142962036*^9, 3.793640119639208*^9, 
   3.793640225245536*^9, {3.793706325887813*^9, 3.793706351722612*^9}, {
   3.7937092535948*^9, 3.793709263558992*^9}, 3.7937176840903788`*^9, {
   3.793717895726021*^9, 3.793717912666235*^9}, 3.793718184737295*^9, 
   3.793718276136427*^9, 3.793719547998176*^9, 3.7938014007323217`*^9, 
   3.793801481542742*^9, 3.793801577763555*^9, 3.793801644958044*^9, 
   3.7938017497031813`*^9, 3.7945070372581387`*^9, 3.7945075048658257`*^9, 
   3.794507550952498*^9, 3.7945076704242897`*^9, 3.794513120371544*^9, 
   3.794513186950197*^9, 3.794515040529749*^9, 3.794515324684389*^9, 
   3.7945686589362183`*^9, 3.79456902426402*^9, 3.794576703541501*^9, 
   3.794578160154456*^9, 3.794578447211854*^9, 3.794579377346352*^9, 
   3.7945795067006207`*^9, {3.79465731860327*^9, 3.79465735690277*^9}, 
   3.794667537867008*^9, 3.7946676290392723`*^9, 3.794667833242858*^9},
 CellLabel->
  "Out[947]=",ExpressionUUID->"596cd867-e70b-4bb8-ab42-43ac655cf6a0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fignpibpsmoreICU", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"10", "*", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"npi", "[", "t", "]"}]}], "/.", "sol60bpsprevmoreICU"}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", " ", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", " ", 
        RowBox[{"Opacity", "[", "0", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79344727493867*^9, 3.793447275672996*^9}, {
  3.7934625847549*^9, 3.793462585031742*^9}, {3.793463088769895*^9, 
  3.793463091558565*^9}, {3.793463731240335*^9, 3.7934637317780437`*^9}, {
  3.793463834924958*^9, 3.793463837569601*^9}},
 CellLabel->
  "In[948]:=",ExpressionUUID->"dbd07b5a-1c61-4498-8365-d267b50242e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpsnpimoreICU", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"figcritprevbpsmoreICU", ",", " ", "fignpibpsmoreICU"}], "}"}], 
    ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"PlotRange", "[", "figcritprevbpsmoreICU", "]"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "ar"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "imsz"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793446704447353*^9, 3.793446711536757*^9}, {
  3.793446744118206*^9, 3.793446750009528*^9}, {3.793446976069807*^9, 
  3.793446978955377*^9}, {3.793447262748226*^9, 3.7934472636613283`*^9}, {
  3.793461917634132*^9, 3.793461928547559*^9}, {3.793463093975984*^9, 
  3.793463097176322*^9}, {3.793463150716834*^9, 3.793463154325522*^9}, {
  3.793463735931305*^9, 3.793463762176955*^9}, {3.793632199378549*^9, 
  3.7936322023504744`*^9}, {3.793633179748782*^9, 3.793633182218555*^9}},
 CellLabel->
  "In[949]:=",ExpressionUUID->"b274bde1-9c49-4f25-8276-ab59abe75b95"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxEl3k4lO8X/1FRStIitKrsJdn3cwzGvoxlrKUUUYnKnlKRQmRLZWm1la2N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        "]]},
      Annotation[#, "Charting`Private`Tag$40646#1"]& ], 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxEl3c81W/YxyVUpCJlpIwoWdnZ12VvjnGMY5WEZJQUTSoRySgpUpJRqMhK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        "]]},
      Annotation[#, "Charting`Private`Tag$40646#2"]& ]}, {}}, {
    GraphicsComplexBox[CompressedData["
1:eJxNV3k41fkbvYSytJC1VEK2JFuSJVeIbCFkSQviWrIv2YUoGS6pEWUJJS1C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     "], {{{}, 
       {RGBColor[0, 0, 1], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[{
          PolygonBox[{{325, 252, 314, 118, 163, 15, 59, 14, 100, 58, 206, 143,
            343, 265}}], 
          PolygonBox[{{340, 264, 324, 181, 235, 69, 90, 24, 68, 23, 106, 67, 
           147, 89, 271, 202}}], 
          PolygonBox[{{190, 341, 258, 319, 150, 191, 98, 131, 55, 79, 9, 54, 
           8, 207, 149, 344, 266, 326}, {221, 329, 201, 253, 122, 167, 20, 64,
            19, 103, 63, 145, 86, 200, 121, 262, 166, 334}, {310, 196, 338, 
           249, 311, 110, 140, 73, 93, 28, 72, 27, 210, 154, 267, 195, 337, 
           248}}]}]}, {}, {}}, {{}, {}, 
       TagBox[
        {Opacity[0], LineBox[CompressedData["
1:eJwl1Hecz3UcwPFzxt1xZ5OGFXchI+vuWnYn45KTI2SFSN2Vhra9FTIKldFA
RmmYUZTKbim0lwaFlnY93w9/PO/1/bx/37vf776fz13NgYV5BUUSEhJ6+xKt
6MsBfZSb6ExTEilKMYpTgkrufV8f42ZyaUYt8690DWPoTxKVzT/QRYzgChqY
HdeNPEBzapt9rc8wlkus/9PdDKCJ9S96pW7VHC1JT+Za7yeZTFLoQhbjGMjL
zKOl+xPpzlvWnbRc/CzXZ+hBXcwt8V5kU4pUqnj9kC7hVrpyIenmR/RZxnMt
aZxpfliXclvca/2Xvk4eDa1PxGfVTXqZptCDGdb7uIhBlOZiyvA4t8dr7vtb
u+kbermm0c11Iz2pm5kZz5MMs290LRMYTFnOMv9Qn2AkV3Ep5Tjbax/pk9xB
d1pwnvm3+hwTGRJnxuxXfYWHaGVdlLfjTGn54Poc/TjOgj4V50rv1DfJZ1bs
E9dRIX4OFVnGXfzDTjr4vtJcHc/M+gL9SV/iQVpTx+w7fZ5JDKUSVc0/0eXc
TU/aUNf8e32ByQyjmdlvuo2HqUw1s091BW1dJ3FP7JH+G89Qd8V+xefT2XEf
18c5o12cJ3rFvnOUF2Pu/mTymRL7EH+g7JHhNHd9SrczP84Y1c0+06e5l97k
UM/8mK5jKjfEXlPD/HNdyX30obHZz7qFObTnfLMfdD3TYt/j/wV7XXfUsvTi
RutM/V276qtaShfoO3GG4mzGvnNN7BvTKSDLfX9onr4W76upLIz902K8G/tF
Tddf6CpG0Tc+R+xFPIP4veIezqUWtUknI85rnIXY33gu8btRnwY0pFGcn3gO
8f3e50tdzWj60SnuN/9RN3A/hWSb/ak7eCTOkHVx3nOdqxWKnP4/28T6f4GW
kkY=
          "]]},
        Annotation[#, "Charting`Private`Tag$40787#1"]& ]}}], {}}},
  AspectRatio->0.25,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, False}},
  FrameLabel->{{
     FormBox["\"Prevalence per 10K\"", TraditionalForm], 
     FormBox["\"Critical cases per 10K\"", TraditionalForm]}, {None, None}},
  FrameTicks->{{{{0, 
       FormBox["\"0.\"", TraditionalForm]}, {
       NCache[
        Rational[1, 2], 0.5], 
       FormBox["\"25.\"", TraditionalForm]}, {1, 
       FormBox["\"50.\"", TraditionalForm]}, {
       NCache[
        Rational[3, 2], 1.5], 
       FormBox["\"75.\"", TraditionalForm]}, {2, 
       FormBox["\"100.\"", TraditionalForm]}}, {{0., 
       FormBox["0", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"0.5\"", 0.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.0\"", 1.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.5, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"1.5\"", 1.5`15.954589770191003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2., 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"2.0\"", 2.`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.7, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.8, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.2, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.5, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}, {{{0, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {0, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2020\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2020", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {52, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2021\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2021", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"Jan\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104, 
       FormBox[
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"\\n\\n2022\"", FontSize -> 14, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["\n\n2022", FontSize -> 14]]], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        RotationBox["\"Apr\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        RotationBox["\"July\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox[
        RotationBox["\"Oct\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}, {{0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {0, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {39, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {52, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {91, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {104, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}, {143, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm]}}}},
  GridLines->{{}, {{1.7799999999999998`, {
       GrayLevel[0], 
       Opacity[1]}}, {1.4000000000000001`, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}, {0.4, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->700,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0., 2.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.793446723677157*^9, 3.793446785087015*^9}, 
   3.7934469801090403`*^9, 3.793447227208099*^9, {3.793447264011318*^9, 
   3.793447277456396*^9}, 3.793447311102808*^9, {3.793447516154393*^9, 
   3.793447528874736*^9}, {3.7934619226037683`*^9, 3.7934619288630877`*^9}, 
   3.793461961164349*^9, 3.7934622036035557`*^9, 3.793462451229333*^9, {
   3.793462489491652*^9, 3.793462608413128*^9}, 3.7934626961006603`*^9, 
   3.793463101949006*^9, 3.793463162163579*^9, 3.793463772110477*^9, 
   3.79346380569412*^9, 3.793463838724552*^9, 3.79346877873803*^9, 
   3.7934690642088823`*^9, 3.7935292825425787`*^9, 3.793529766232078*^9, {
   3.793529807644423*^9, 3.793529926797653*^9}, {3.793530274772929*^9, 
   3.793530290118945*^9}, 3.793532190475625*^9, 3.793538248937784*^9, 
   3.7935384964154997`*^9, 3.793617741130563*^9, 3.793628689680678*^9, 
   3.793631370071877*^9, 3.793632202645069*^9, 3.7936324369778*^9, 
   3.7936326180329*^9, 3.793632898809112*^9, 3.793633152046958*^9, 
   3.7936331825457897`*^9, 3.793633213913981*^9, 3.793634386173511*^9, 
   3.793634841074868*^9, 3.793635143070656*^9, 3.793640119693592*^9, 
   3.793640225319536*^9, {3.793706340549452*^9, 3.7937063536703987`*^9}, 
   3.7937092665764837`*^9, 3.793717684229246*^9, {3.7937178980447607`*^9, 
   3.793717912785774*^9}, 3.793718184939293*^9, 3.793718276303259*^9, 
   3.793719548121491*^9, 3.7938014008285*^9, 3.7938014816923018`*^9, 
   3.793801577927144*^9, 3.7938016451029663`*^9, 3.793801749868079*^9, 
   3.794507037378613*^9, 3.794507504918057*^9, 3.7945075510037117`*^9, 
   3.794507670477558*^9, 3.794513120541926*^9, 3.794513187168954*^9, 
   3.794515040690503*^9, 3.794515324813582*^9, 3.7945686590006323`*^9, 
   3.794569024417222*^9, 3.79457670375518*^9, 3.7945781603354397`*^9, 
   3.79457844739612*^9, 3.794579377446313*^9, 3.794579506760495*^9, 
   3.794657359310774*^9, 3.794667538092993*^9, 3.794667629243408*^9, 
   3.794667833395755*^9},
 CellLabel->
  "Out[949]=",ExpressionUUID->"0b810125-c78b-4600-9442-139fdfbee60a"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6D.pdf\>\"", ",", "figcritprevbpsnpimoreICU"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6D.png\>\"", ",", "figcritprevbpsnpimoreICU"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794662764144621*^9, 3.794662781620789*^9}, {
  3.794667508539109*^9, 3.79466751189289*^9}, {3.7946677228011227`*^9, 
  3.7946677228020363`*^9}, {3.7946677621689987`*^9, 3.794667781650879*^9}},
 CellLabel->
  "In[950]:=",ExpressionUUID->"0bfe79e0-59b7-469d-9038-9c19a905c47d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figcritprevbpsnpimoreICUimm", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"Sq", "[", "t", "]"}]}], "/.", "sol60bpsprevmoreICU"}], "]"}],
      "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "plotwindowlong"}], "]"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yearticks", ",", " ", "None"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",",
     " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "None"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"FontSize", "\[Rule]", "22"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", "\"\<Cumulative infections\>\""}], "}"}]}], ",", 
    " ", 
    RowBox[{"ImageSize", "\[Rule]", "200"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", "Green"}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "1.5"}], ",", " ", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"baseline", "+", "amplitude"}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], "}"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.793469988806632*^9, 3.7934700082683477`*^9}, {
   3.793470070376527*^9, 3.7934700910573807`*^9}, {3.793470165412545*^9, 
   3.7934701921635637`*^9}, {3.793470350690662*^9, 3.793470351572834*^9}, {
   3.793470547872568*^9, 3.793470549769924*^9}, {3.79353851898458*^9, 
   3.79353854157791*^9}, 3.793538580993394*^9, {3.793633175269741*^9, 
   3.793633176040575*^9}, {3.793634776414893*^9, 3.7936347926643343`*^9}, {
   3.793709091581172*^9, 3.793709096409807*^9}},
 CellLabel->
  "In[952]:=",ExpressionUUID->"be4eda7c-fa41-44e1-ad47-aa6d47befe25"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJxF13c41f8bP3ApI1RGA0lGIpvsdd/23jM7KRpKkhQVJQmVrOyQZJa9996d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       "]]},
     Annotation[#, "Charting`Private`Tag$41209#1"]& ]}, {}},
  AspectRatio->1.5,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 22),
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Cumulative infections\"", TraditionalForm], None}, {
    None, None}},
  FrameTicks->{{Automatic, {}}, {{{0, 
       FormBox[
        RotationBox["\"2020\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[31, 7], 4.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[59, 7], 8.428571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[90, 7], 12.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[120, 7], 17.142857142857142`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[151, 7], 21.571428571428573`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[181, 7], 25.857142857142858`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[212, 7], 30.285714285714285`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[243, 7], 34.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[304, 7], 43.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[334, 7], 47.714285714285715`], 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox[
        RotationBox["\"2021\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[395, 7], 56.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[423, 7], 60.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[454, 7], 64.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[484, 7], 69.14285714285714], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[515, 7], 73.57142857142857], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[545, 7], 77.85714285714286], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[576, 7], 82.28571428571429], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[607, 7], 86.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[668, 7], 95.42857142857143], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[698, 7], 99.71428571428571], 
       FormBox["\"\"", TraditionalForm]}, {104, 
       FormBox[
        RotationBox["\"2022\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {
       NCache[
        Rational[759, 7], 108.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[787, 7], 112.42857142857143`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[818, 7], 116.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[848, 7], 121.14285714285714`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[879, 7], 125.57142857142857`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[909, 7], 129.85714285714286`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[940, 7], 134.28571428571428`], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[
        Rational[971, 7], 138.71428571428572`], 
       FormBox["\"\"", TraditionalForm]}, {143, 
       FormBox["\"\"", TraditionalForm]}}, {}}},
  GridLines->{{}, {{0.5, {
       GrayLevel[0], 
       Opacity[1]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->200,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 129.99999734693878`}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.793470009367878*^9, {3.7934700711592827`*^9, 3.79347009137438*^9}, {
   3.7934701769400053`*^9, 3.79347019249289*^9}, 3.793470351817913*^9, 
   3.7934705500653753`*^9, 3.793529282773035*^9, 3.7935297664115343`*^9, {
   3.793529807826633*^9, 3.793529927005988*^9}, {3.793530274953706*^9, 
   3.79353029030054*^9}, 3.793532192517605*^9, 3.793538249239847*^9, {
   3.793538525988431*^9, 3.793538541851001*^9}, 3.79353858152817*^9, 
   3.793617741415947*^9, 3.793628690048635*^9, 3.793631370541898*^9, 
   3.793632437225952*^9, 3.793632618513098*^9, 3.793632899134734*^9, {
   3.793633152301569*^9, 3.7936331767562304`*^9}, 3.7936332141557302`*^9, 
   3.793634386427669*^9, {3.7936347790261183`*^9, 3.7936347929702597`*^9}, 
   3.7936348413333063`*^9, 3.793635143354506*^9, 3.793640119993409*^9, 
   3.793640225647064*^9, 3.793709275555098*^9, 3.793717684605297*^9, 
   3.793717913129421*^9, 3.793718185327454*^9, 3.7937182767078667`*^9, 
   3.7937195484620533`*^9, 3.793801401114151*^9, 3.7938014820449343`*^9, 
   3.7938015782987757`*^9, 3.7938016454567223`*^9, 3.793801750321369*^9, 
   3.7945070377107477`*^9, 3.7945075051737337`*^9, 3.794507551266214*^9, 
   3.794507670778119*^9, 3.794513121074642*^9, 3.7945131876139917`*^9, 
   3.7945150412367697`*^9, 3.794515325140779*^9, 3.794568659264061*^9, 
   3.794569024805434*^9, 3.7945767041579742`*^9, 3.794578160686804*^9, 
   3.794578447811783*^9, 3.7945793778475924`*^9, 3.794579507074839*^9, 
   3.794657363003417*^9, 3.794667539234098*^9, 3.7946676306875973`*^9, 
   3.794667834642953*^9},
 CellLabel->
  "Out[952]=",ExpressionUUID->"a888f91a-2e69-49ea-bea2-8c37489e7f5a"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6H.pdf\>\"", ",", "figcritprevbpsnpimoreICUimm"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/sk792/DropboxHarvard/Projects/Wuhan/writeup/Science/\
Submission2/figures/fig6H.png\>\"", ",", "figcritprevbpsnpimoreICUimm"}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7946627744083347`*^9, 3.794662777775992*^9}, {
  3.794667515938088*^9, 3.794667519026795*^9}, {3.7946677228057756`*^9, 
  3.794667722806601*^9}, {3.79466776217102*^9, 3.794667787590426*^9}},
 CellLabel->
  "In[953]:=",ExpressionUUID->"09c0a962-9783-48f8-b4e9-78a2bbbff11a"]
}, Closed]]
}, Open  ]]
},
WindowSize->{1280, 1035},
WindowMargins->{{0, Automatic}, {Automatic, -180}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 200, 3, 80, "Subtitle",ExpressionUUID->"2ff7685d-4431-4733-a6dc-eb03aac664d6"],
Cell[783, 27, 1168, 25, 449, "Text",ExpressionUUID->"b60253c1-3dc2-4619-afc5-5c60a11ee2de"]
}, Closed]],
Cell[CellGroupData[{
Cell[1988, 57, 163, 3, 72, "Title",ExpressionUUID->"fe9183ad-39dc-4baf-afff-e7d104581afe"],
Cell[2154, 62, 173, 3, 53, "Subtitle",ExpressionUUID->"04b0bacc-6ba0-4a28-8587-c64867cea39d"],
Cell[2330, 67, 2985, 83, 241, "Input",ExpressionUUID->"141cf336-bfaa-438f-9303-4191553821ed"],
Cell[CellGroupData[{
Cell[5340, 154, 169, 3, 53, "Subtitle",ExpressionUUID->"25b7a628-1f53-4321-a8c8-c9a691798dde"],
Cell[5512, 159, 100319, 2658, 11665, "Input",ExpressionUUID->"378d2fa8-8139-4363-8401-833ea9e62283"]
}, Closed]],
Cell[CellGroupData[{
Cell[105868, 2822, 168, 3, 53, "Subtitle",ExpressionUUID->"bae8e1ce-7076-471c-8e09-82f688cb58b0"],
Cell[106039, 2827, 44453, 1046, 1795, "Input",ExpressionUUID->"714225f8-68cb-4304-94db-e5b60663193e"]
}, Closed]],
Cell[CellGroupData[{
Cell[150529, 3878, 178, 3, 53, "Subtitle",ExpressionUUID->"53125f91-a9fe-44a5-b45c-bb5e343cd1b9"],
Cell[150710, 3883, 8926, 200, 472, "Input",ExpressionUUID->"888a48f1-5d01-4f63-9e78-19be0ed94d9d"],
Cell[159639, 4085, 545, 12, 30, "Input",ExpressionUUID->"eb3d0e3b-d028-4079-ba6d-a325e738cd6a"],
Cell[160187, 4099, 2667, 42, 30, "Input",ExpressionUUID->"c80e3ba9-d763-4994-92f1-51cc546a7d7f"],
Cell[162857, 4143, 4039, 111, 262, "Input",ExpressionUUID->"7b51fd4b-e75f-474b-a781-4d9a463c0929"]
}, Closed]],
Cell[CellGroupData[{
Cell[166933, 4259, 225, 4, 53, "Subtitle",ExpressionUUID->"206007e1-e0d0-4f63-81a3-e3ea91d8bfdf"],
Cell[CellGroupData[{
Cell[167183, 4267, 215, 4, 54, "Subsection",ExpressionUUID->"0b9aab27-8667-40c4-9959-f6181b069508"],
Cell[CellGroupData[{
Cell[167423, 4275, 177, 3, 45, "Subsubsection",ExpressionUUID->"bed0f23c-5785-46c2-9ac1-ebc6ce020d70"],
Cell[167603, 4280, 846, 20, 136, "Input",ExpressionUUID->"65ee156e-f7eb-41a2-8633-db174b829f1b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168486, 4305, 166, 3, 45, "Subsubsection",ExpressionUUID->"c1237918-da52-42fd-a582-66e3b68e8cee"],
Cell[168655, 4310, 256, 6, 30, "Input",ExpressionUUID->"98347448-fc9c-43b8-8e30-5d013a95309b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168948, 4321, 216, 4, 45, "Subsubsection",ExpressionUUID->"a20696c8-180b-4a3c-9d0a-587612829b18"],
Cell[169167, 4327, 9078, 181, 325, "Input",ExpressionUUID->"f1b05c94-8542-4b64-9433-61731956abe6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178282, 4513, 216, 4, 45, "Subsubsection",ExpressionUUID->"dfc40dac-1285-488a-9bc5-e74b12e325cc"],
Cell[CellGroupData[{
Cell[178523, 4521, 237, 4, 30, "Input",ExpressionUUID->"1e5cadb8-3212-478d-a8b6-83a76ae2a7b2"],
Cell[178763, 4527, 134134, 2375, 300, "Output",ExpressionUUID->"c7f1edf9-a37f-427c-a364-0996e80352b8"]
}, Open  ]],
Cell[312912, 6905, 585, 15, 52, "Input",ExpressionUUID->"aae97602-f56b-4040-bd1d-ca8c0ac53634"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[313546, 6926, 188, 3, 54, "Subsection",ExpressionUUID->"f080211a-528f-4b6d-8ed8-24abfda161b8"],
Cell[CellGroupData[{
Cell[313759, 6933, 177, 3, 45, "Subsubsection",ExpressionUUID->"a6b44300-d510-42e9-a59a-8d5adc429882"],
Cell[313939, 6938, 798, 19, 136, "Input",ExpressionUUID->"324a6c07-d025-4eb3-b7be-a7d9cc326c53"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314774, 6962, 215, 4, 45, "Subsubsection",ExpressionUUID->"9d54a903-7aaa-46ce-aec0-e86751f6aeb6"],
Cell[314992, 6968, 191, 5, 30, "Input",ExpressionUUID->"506bbd7a-ac28-40eb-ba9f-682b1acc81ae"]
}, Open  ]],
Cell[CellGroupData[{
Cell[315220, 6978, 216, 4, 45, "Subsubsection",ExpressionUUID->"0685a7e7-2350-4d3c-84e3-f85d6ad559e8"],
Cell[315439, 6984, 9078, 181, 325, "Input",ExpressionUUID->"cb03dde3-40dc-424f-87c5-785506102ec3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[324554, 7170, 165, 3, 45, "Subsubsection",ExpressionUUID->"aa04129a-1173-4480-89e1-9aef4bc8f225"],
Cell[CellGroupData[{
Cell[324744, 7177, 237, 4, 30, "Input",ExpressionUUID->"d152d2f1-5e0e-4818-bd8a-b8191bc3cede"],
Cell[324984, 7183, 126913, 2257, 300, "Output",ExpressionUUID->"d3a0da68-5073-480b-aadf-bbcf186e398d"]
}, Open  ]],
Cell[451912, 9443, 587, 15, 52, "Input",ExpressionUUID->"9f03c8cd-381c-4723-baaf-e9e8ac0fe567"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[452548, 9464, 295, 5, 54, "Subsection",ExpressionUUID->"9b4127bf-4e95-447a-bffb-0aecdaec48a0"],
Cell[CellGroupData[{
Cell[452868, 9473, 177, 3, 45, "Subsubsection",ExpressionUUID->"deb0762c-78a9-4c83-b511-a8ec53166dd3"],
Cell[453048, 9478, 852, 20, 136, "Input",ExpressionUUID->"c2e4f71f-b111-457a-b1d5-15fddab351c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[453937, 9503, 166, 3, 45, "Subsubsection",ExpressionUUID->"7f17ed78-19c5-43cb-aab4-aebf01b6c520"],
Cell[454106, 9508, 191, 5, 30, "Input",ExpressionUUID->"6d5c02d0-3c4d-45db-bcae-f9700b08cdbf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[454334, 9518, 216, 4, 45, "Subsubsection",ExpressionUUID->"49630a9b-99cc-4ab6-b92a-a57ff141c6c2"],
Cell[454553, 9524, 9078, 181, 325, "Input",ExpressionUUID->"9549ceea-cd30-44df-b002-ed6ba6d2f6bc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[463668, 9710, 165, 3, 45, "Subsubsection",ExpressionUUID->"98ec3e25-58e2-4978-aba7-72121cfec259"],
Cell[CellGroupData[{
Cell[463858, 9717, 237, 4, 30, "Input",ExpressionUUID->"44095c16-072a-411b-bf29-c849a2e7739f"],
Cell[464098, 9723, 107132, 1958, 300, "Output",ExpressionUUID->"26eb3f8f-b08b-48ce-aa39-3d86f9692348"]
}, Open  ]],
Cell[571245, 11684, 583, 15, 52, "Input",ExpressionUUID->"5a5bd183-29eb-4791-9690-6c29a02d70e0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[571877, 11705, 332, 5, 54, "Subsection",ExpressionUUID->"51a78905-2a31-4f38-b551-2a7d344cd3cf"],
Cell[CellGroupData[{
Cell[572234, 11714, 177, 3, 45, "Subsubsection",ExpressionUUID->"0d8963c9-9028-4435-9d07-25448f133c77"],
Cell[572414, 11719, 892, 20, 136, "Input",ExpressionUUID->"053c03c5-464e-4617-90c2-ef43d6c54fc8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[573343, 11744, 166, 3, 45, "Subsubsection",ExpressionUUID->"cd46fbb5-29e5-424f-90cc-2d9b213eb78e"],
Cell[573512, 11749, 191, 5, 30, "Input",ExpressionUUID->"a0a92c39-3ef8-42fd-845c-c657e5b63e77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[573740, 11759, 216, 4, 45, "Subsubsection",ExpressionUUID->"80b761df-a1a1-4d2c-a0e7-814ade46f995"],
Cell[573959, 11765, 9078, 181, 325, "Input",ExpressionUUID->"7e2965c3-403b-484f-86fb-03e0a10478a5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583074, 11951, 165, 3, 45, "Subsubsection",ExpressionUUID->"2202baba-50c5-4b4f-9b22-372bd322c038"],
Cell[CellGroupData[{
Cell[583264, 11958, 237, 4, 30, "Input",ExpressionUUID->"4224cc08-ce97-4a37-b24b-9011202cb9a4"],
Cell[583504, 11964, 135793, 2402, 300, "Output",ExpressionUUID->"98405843-3da6-4fdb-848d-373ee6fd862c"]
}, Open  ]],
Cell[719312, 14369, 583, 15, 52, "Input",ExpressionUUID->"9743288f-4533-404f-8882-d360a203f6d7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[719944, 14390, 434, 7, 54, "Subsection",ExpressionUUID->"4a29be5f-0ba2-4b94-a4ca-99fc0a53a19c"],
Cell[CellGroupData[{
Cell[720403, 14401, 177, 3, 45, "Subsubsection",ExpressionUUID->"0bd78647-b111-4aeb-8a6e-b778ef126e9a"],
Cell[720583, 14406, 941, 21, 136, "Input",ExpressionUUID->"f2c27d3d-0649-4c00-b9d4-651a789fc131"]
}, Open  ]],
Cell[CellGroupData[{
Cell[721561, 14432, 166, 3, 45, "Subsubsection",ExpressionUUID->"fb07e9bb-10be-41b0-ab98-fc28d0e1e034"],
Cell[721730, 14437, 191, 5, 30, "Input",ExpressionUUID->"435ec262-e662-4883-abc1-b2f23931c62b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[721958, 14447, 216, 4, 45, "Subsubsection",ExpressionUUID->"888ded4c-697d-4575-a43b-b097d6639de4"],
Cell[722177, 14453, 9078, 181, 325, "Input",ExpressionUUID->"1527a34c-be74-46dc-b1b2-2dfc84aa9837"]
}, Open  ]],
Cell[CellGroupData[{
Cell[731292, 14639, 165, 3, 45, "Subsubsection",ExpressionUUID->"d2c7f15a-651e-49ad-a675-ad0e70cc940e"],
Cell[CellGroupData[{
Cell[731482, 14646, 237, 4, 30, "Input",ExpressionUUID->"3368ac59-2d8a-455e-9acf-3c4d7c4c787c"],
Cell[731722, 14652, 133166, 2359, 300, "Output",ExpressionUUID->"0ab41845-67cd-476d-abcd-7b473cd421b1"]
}, Open  ]],
Cell[864903, 17014, 585, 15, 52, "Input",ExpressionUUID->"1f2374d6-b7e6-4fb9-876e-15950adede43"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[865537, 17035, 434, 7, 54, "Subsection",ExpressionUUID->"d379f03b-7da0-495a-b753-526f123bcfbb"],
Cell[CellGroupData[{
Cell[865996, 17046, 177, 3, 45, "Subsubsection",ExpressionUUID->"27b9806e-9784-4adf-9a12-39cbf74da847"],
Cell[866176, 17051, 945, 21, 136, "Input",ExpressionUUID->"a5da8fb9-8fbe-4693-a044-ac2998c166a4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[867158, 17077, 166, 3, 45, "Subsubsection",ExpressionUUID->"64e557ef-7bd5-48f9-9bc4-dc7ae47498a8"],
Cell[867327, 17082, 191, 5, 30, "Input",ExpressionUUID->"f3d22003-55e6-45c1-91c6-aed9119f97e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[867555, 17092, 216, 4, 45, "Subsubsection",ExpressionUUID->"51a9455f-92da-44be-bf44-a8b55e176b98"],
Cell[867774, 17098, 6026, 140, 325, "Input",ExpressionUUID->"6174542c-aa72-44c5-bb6f-802892929ca3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[873837, 17243, 165, 3, 45, "Subsubsection",ExpressionUUID->"48b03727-9a33-447a-b146-91d904faaecc"],
Cell[CellGroupData[{
Cell[874027, 17250, 189, 3, 30, "Input",ExpressionUUID->"70a1a684-bc5a-4b1a-8ab0-92eb28340453"],
Cell[874219, 17255, 130985, 2325, 300, "Output",ExpressionUUID->"5129e16c-55c7-4510-b85f-ef0ceb993aba"]
}, Open  ]],
Cell[1005219, 19583, 585, 15, 52, "Input",ExpressionUUID->"4d7cff73-b1ce-4e11-a987-fdec47aa3c16"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1005877, 19606, 183, 3, 98, "Title",ExpressionUUID->"c59c641f-2437-49ec-8027-880b99f4a54e"],
Cell[1006063, 19611, 191, 3, 53, "Subtitle",ExpressionUUID->"4b1cccbc-24f4-48ad-a586-578804dfe71d"],
Cell[1006257, 19616, 8411, 187, 808, "Input",ExpressionUUID->"c499504f-1ceb-4881-b311-7e11e2002f34"],
Cell[CellGroupData[{
Cell[1014693, 19807, 173, 3, 53, "Subtitle",ExpressionUUID->"fa81f003-75c5-4ae2-b047-62716c9d6491"],
Cell[1014869, 19812, 8010, 196, 493, "Input",ExpressionUUID->"a5a54cc0-489a-4805-a9b5-2689653bac7b"]
}, Closed]],
Cell[CellGroupData[{
Cell[1022916, 20013, 225, 4, 53, "Subtitle",ExpressionUUID->"a2881e2e-df61-49d0-8b5f-f54342137197"],
Cell[CellGroupData[{
Cell[1023166, 20021, 289, 6, 54, "Subsection",ExpressionUUID->"40b28e49-d460-48ec-8746-eb8c66c42df7"],
Cell[1023458, 20029, 712, 17, 115, "Input",ExpressionUUID->"fdf2592f-4492-4541-85ca-cc9f9a0363f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1024207, 20051, 303, 6, 54, "Subsection",ExpressionUUID->"8c249c33-6546-4d9f-b35e-8d9e3556249c"],
Cell[1024513, 20059, 733, 17, 115, "Input",ExpressionUUID->"7594814e-de43-4145-9be5-dcdbb9670a35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1025283, 20081, 330, 6, 54, "Subsection",ExpressionUUID->"f79e9a77-8013-456c-a541-f5c51663e4de"],
Cell[1025616, 20089, 787, 18, 115, "Input",ExpressionUUID->"d1cf0c26-6111-466f-92e3-1dd17ff28f6f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1026440, 20112, 329, 6, 54, "Subsection",ExpressionUUID->"bce3105c-9f99-43b7-89ed-fcc834a9d51e"],
Cell[1026772, 20120, 809, 18, 115, "Input",ExpressionUUID->"59dd2c9d-bfb9-4313-8c9d-8e893c97f274"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1027618, 20143, 301, 5, 54, "Subsection",ExpressionUUID->"dfd6c851-51e1-4bd8-bfad-38e2aeefaf00"],
Cell[1027922, 20150, 785, 18, 115, "Input",ExpressionUUID->"7d2d8250-b4bf-490c-8fcb-47ca837c8e2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1028744, 20173, 306, 5, 54, "Subsection",ExpressionUUID->"89ad829b-a6d8-4adc-ae1b-ea1537596cdf"],
Cell[1029053, 20180, 788, 18, 115, "Input",ExpressionUUID->"c808532e-47dd-4960-952e-3d49f7293db0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1029878, 20203, 302, 5, 54, "Subsection",ExpressionUUID->"8a3ce68b-7f6a-479f-89c8-3ecc566c14f5"],
Cell[1030183, 20210, 782, 18, 115, "Input",ExpressionUUID->"4e06ffa5-7827-4111-904d-e96d2d6a9f19"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1031002, 20233, 330, 6, 54, "Subsection",ExpressionUUID->"26a39f6f-6bbe-4b59-aeb3-0a8ed357c3ae"],
Cell[1031335, 20241, 792, 19, 115, "Input",ExpressionUUID->"68aad3ef-63e5-4be4-b1fb-aa842406a107"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1032164, 20265, 305, 5, 54, "Subsection",ExpressionUUID->"1d4b5775-4bf8-48fe-acfb-74e41fbc3e20"],
Cell[1032472, 20272, 788, 19, 115, "Input",ExpressionUUID->"8f2adf23-2df5-435d-821c-20dcbd4b086d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1033297, 20296, 331, 6, 54, "Subsection",ExpressionUUID->"dec29f79-d42e-4073-a216-a1b76c51ccc5"],
Cell[1033631, 20304, 789, 19, 115, "Input",ExpressionUUID->"017aa20e-7c73-4eae-90f7-991f1a8cdbca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1034457, 20328, 330, 6, 54, "Subsection",ExpressionUUID->"597c11eb-87e2-44d0-8b3d-0d85cf07af50"],
Cell[1034790, 20336, 792, 19, 115, "Input",ExpressionUUID->"3809af86-6ad0-4974-8778-46741ef171de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1035619, 20360, 328, 6, 54, "Subsection",ExpressionUUID->"77a445f3-7b22-4e2a-b665-6e75a26d1c2d"],
Cell[1035950, 20368, 792, 19, 115, "Input",ExpressionUUID->"51f9ac7b-a648-4c3c-8f37-ed97aee0a083"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1036779, 20392, 328, 6, 54, "Subsection",ExpressionUUID->"3eb22a45-bba7-4b35-a6b7-bcc9fcbeacac"],
Cell[1037110, 20400, 790, 19, 115, "Input",ExpressionUUID->"1a62a7db-c2db-4fd9-8774-cf80bc6e3b38"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1037937, 20424, 374, 6, 54, "Subsection",ExpressionUUID->"c5f228d2-6a26-4bcb-bd82-f27460b3e6c0"],
Cell[1038314, 20432, 846, 19, 115, "Input",ExpressionUUID->"5e265148-91c8-456f-8c50-6e7e72330ce1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1039197, 20456, 348, 6, 54, "Subsection",ExpressionUUID->"000f1f57-ca75-4f46-b8c5-515d278a685a"],
Cell[1039548, 20464, 843, 19, 115, "Input",ExpressionUUID->"9c18eeb2-280b-42ad-8d92-fa297a4593de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1040428, 20488, 349, 6, 54, "Subsection",ExpressionUUID->"0f2490b0-44ba-4793-94b3-c573d2b4724e"],
Cell[1040780, 20496, 842, 19, 115, "Input",ExpressionUUID->"0f07bd29-f918-4643-8ded-d7a2dbd71b31"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1041671, 20521, 224, 4, 53, "Subtitle",ExpressionUUID->"a9ef91f3-6f4e-4c97-9ae2-440a2a7904dd"],
Cell[CellGroupData[{
Cell[1041920, 20529, 243, 5, 54, "Subsection",ExpressionUUID->"7a1a0bb4-fbbb-44e8-b70a-ee160d597d4a"],
Cell[1042166, 20536, 715, 17, 115, "Input",ExpressionUUID->"f8b026c0-50cd-4a3d-887b-4bf492116aa5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1042918, 20558, 249, 4, 54, "Subsection",ExpressionUUID->"0c3c0d85-a444-4ab8-b0c0-a9370c7322ec"],
Cell[1043170, 20564, 737, 17, 115, "Input",ExpressionUUID->"9a697622-55af-4e43-b433-45cd2fd2487b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1043944, 20586, 275, 4, 54, "Subsection",ExpressionUUID->"5a962afd-9818-4ec8-9542-cb32541ee009"],
Cell[1044222, 20592, 736, 17, 115, "Input",ExpressionUUID->"5cf35696-07fd-446f-babc-9ba2cce9aa4d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1044995, 20614, 272, 4, 54, "Subsection",ExpressionUUID->"f5f3155e-1f2a-4e8a-9b75-955c997d75cc"],
Cell[1045270, 20620, 734, 17, 115, "Input",ExpressionUUID->"d14a76b9-4d81-469a-9395-5d97063af91d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1046041, 20642, 273, 4, 54, "Subsection",ExpressionUUID->"6f3ba592-7fe4-471a-abf5-52d43c18ceaf"],
Cell[1046317, 20648, 734, 17, 115, "Input",ExpressionUUID->"5d96bee7-826b-4630-9fcd-07fc5fe63c44"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1047088, 20670, 275, 4, 54, "Subsection",ExpressionUUID->"0544be84-3918-496b-9cc8-346494d60794"],
Cell[1047366, 20676, 735, 17, 115, "Input",ExpressionUUID->"e24fbf00-200a-4870-b18d-b0cd30bf3b57"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1048138, 20698, 273, 4, 54, "Subsection",ExpressionUUID->"d0f8c2d5-2e2b-4fa9-a962-f128d78e765e"],
Cell[1048414, 20704, 730, 17, 115, "Input",ExpressionUUID->"f91ebda5-8516-4c68-bf92-c257477f8caf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1049181, 20726, 302, 5, 54, "Subsection",ExpressionUUID->"6093d10e-d633-416a-ba8e-597483920057"],
Cell[1049486, 20733, 737, 18, 115, "Input",ExpressionUUID->"9687dde1-520f-48d4-b3a5-b4b1afcda18b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1050260, 20756, 276, 4, 54, "Subsection",ExpressionUUID->"f99b2e33-3ed0-4e46-ba04-edee1d98b485"],
Cell[1050539, 20762, 738, 18, 115, "Input",ExpressionUUID->"b102d5e3-4a83-46ad-9fdd-836089dcb77b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1051314, 20785, 301, 5, 54, "Subsection",ExpressionUUID->"ff1df3b7-b09a-4d74-b412-ddf6f9c77646"],
Cell[1051618, 20792, 738, 18, 115, "Input",ExpressionUUID->"0dcda806-b4fb-42df-ba8f-55d0ae78c6e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1052393, 20815, 302, 5, 54, "Subsection",ExpressionUUID->"fc4e06dc-c073-430a-9baf-611f6205a34d"],
Cell[1052698, 20822, 795, 19, 115, "Input",ExpressionUUID->"24d6ba3e-1cc1-4206-8e6e-7afd169629ed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1053530, 20846, 300, 5, 54, "Subsection",ExpressionUUID->"703b0ba1-ec34-4b4f-9ce7-37d8f1a3db7d"],
Cell[1053833, 20853, 789, 19, 115, "Input",ExpressionUUID->"dce6e139-4bf1-48fc-8109-ad3e92fa98f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1054659, 20877, 300, 5, 54, "Subsection",ExpressionUUID->"1f90269f-2a19-4711-a94e-80cd1431c32f"],
Cell[1054962, 20884, 790, 19, 115, "Input",ExpressionUUID->"97940b84-69df-44fb-91da-d861770a1899"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1055789, 20908, 351, 6, 54, "Subsection",ExpressionUUID->"998ca9e1-1f15-4b11-a933-a0af0a9f3ba0"],
Cell[1056143, 20916, 898, 20, 115, "Input",ExpressionUUID->"092742d7-fd6f-401f-a3c2-7824fe1083ab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1057078, 20941, 319, 5, 54, "Subsection",ExpressionUUID->"6d43e062-6a0e-4f09-82a6-f263d0871ade"],
Cell[1057400, 20948, 842, 19, 115, "Input",ExpressionUUID->"2ab26060-be7d-4e65-8a57-ece189ab671e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1058279, 20972, 321, 5, 54, "Subsection",ExpressionUUID->"ca09e891-9ec4-4b1a-8b94-e34aad01dd79"],
Cell[1058603, 20979, 842, 19, 115, "Input",ExpressionUUID->"56c2f6fc-fbc8-4b7d-b5e3-05c5336fba65"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1059494, 21004, 284, 7, 53, "Subtitle",ExpressionUUID->"0e4fa598-d9a7-48da-9f7a-7754df60b798"],
Cell[CellGroupData[{
Cell[1059803, 21015, 292, 6, 54, "Subsection",ExpressionUUID->"c3e4d880-40dc-4cf9-9a9e-b6e0452a3b15"],
Cell[1060098, 21023, 9113, 217, 535, "Input",ExpressionUUID->"dc7d79e7-d1ba-4403-af03-71eef77810ac"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1069260, 21246, 327, 6, 53, "Subtitle",ExpressionUUID->"5130feeb-a0d8-4a29-ad06-2d43f388a1a0"],
Cell[CellGroupData[{
Cell[1069612, 21256, 292, 6, 54, "Subsection",ExpressionUUID->"a6b60215-b711-4640-be1a-c042919c64b6"],
Cell[1069907, 21264, 9161, 218, 535, "Input",ExpressionUUID->"4155d2c0-dcdf-4104-b009-14333fb31f08"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1079117, 21488, 526, 9, 85, "Subtitle",ExpressionUUID->"08aa2ad6-736e-40e1-a40f-75c55daeba1f"],
Cell[CellGroupData[{
Cell[1079668, 21501, 292, 6, 54, "Subsection",ExpressionUUID->"17788797-649d-430f-a733-10ee5d3775e2"],
Cell[1079963, 21509, 9305, 220, 535, "Input",ExpressionUUID->"e69c1d47-b091-454c-bc08-a90db52932b5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1089317, 21735, 480, 9, 85, "Subtitle",ExpressionUUID->"5c1298b0-c1b1-47e6-9ad8-be0f63d2231a"],
Cell[CellGroupData[{
Cell[1089822, 21748, 292, 6, 54, "Subsection",ExpressionUUID->"023af686-0753-48c0-afb7-efa5d8abe745"],
Cell[1090117, 21756, 9252, 219, 535, "Input",ExpressionUUID->"e9dc0a1c-52b1-4510-8018-8899b77c1414"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1099418, 21981, 375, 7, 53, "Subtitle",ExpressionUUID->"160c2d5f-faaf-47bd-a49b-70c0233dfd59"],
Cell[1099796, 21990, 1822, 46, 241, "Input",ExpressionUUID->"35976152-c853-43c9-af7b-d6fbec4053c3"],
Cell[CellGroupData[{
Cell[1101643, 22040, 159, 3, 54, "Subsection",ExpressionUUID->"4aa234e1-ee7a-4d63-a6db-41cae3a750e9"],
Cell[1101805, 22045, 284, 6, 30, "Input",ExpressionUUID->"fcc0e3aa-4e5f-49f7-b1e6-87a602c15158"],
Cell[CellGroupData[{
Cell[1102114, 22055, 7327, 180, 430, "Input",ExpressionUUID->"9d8a20ba-d60c-4912-9a5b-6a9d62e5c7f2"],
Cell[1109444, 22237, 163885, 2835, 320, "Output",ExpressionUUID->"89020fb7-2b6a-494c-87c3-053f93033af5"]
}, Open  ]],
Cell[1273344, 25075, 595, 15, 52, "Input",ExpressionUUID->"47efdc16-3059-4e27-9e9c-86695073e7ca"],
Cell[CellGroupData[{
Cell[1273964, 25094, 4673, 118, 325, "Input",ExpressionUUID->"a3b37dd1-1f56-4eb6-aa47-fdfd1dc4a04d"],
Cell[1278640, 25214, 67409, 1210, 325, "Output",ExpressionUUID->"d0f106eb-0f39-4f12-a9bb-eead8a651454"]
}, Open  ]],
Cell[1346064, 26427, 603, 15, 52, "Input",ExpressionUUID->"f5576089-d139-4463-9350-8b56db5109cc"],
Cell[CellGroupData[{
Cell[1346692, 26446, 7297, 177, 472, "Input",ExpressionUUID->"801aded2-b276-409f-be4c-4eb3df0d3198"],
Cell[1353992, 26625, 159790, 2769, 322, "Output",ExpressionUUID->"42d6fc4a-91d1-4521-a386-5a938589b1bf"]
}, Open  ]],
Cell[1513797, 29397, 597, 15, 52, "Input",ExpressionUUID->"c2596c68-80ea-4180-a39f-29573db1482e"],
Cell[CellGroupData[{
Cell[1514419, 29416, 4716, 118, 325, "Input",ExpressionUUID->"a740ee4c-0017-4501-811f-2f21ce8f1e27"],
Cell[1519138, 29536, 68689, 1230, 325, "Output",ExpressionUUID->"5ad16666-359c-4dc1-bb87-b78bbbbea81f"]
}, Open  ]],
Cell[1587842, 30769, 605, 15, 52, "Input",ExpressionUUID->"f7270eb1-83fd-4fab-ba37-6e0019979859"],
Cell[CellGroupData[{
Cell[1588472, 30788, 8362, 192, 430, "Input",ExpressionUUID->"6604a171-3630-4f80-adce-38bf4554cd3a"],
Cell[1596837, 30982, 147985, 2574, 322, "Output",ExpressionUUID->"cc7f82dd-63e4-405c-af2f-c329f1ba0841"]
}, Open  ]],
Cell[1744837, 33559, 597, 15, 52, "Input",ExpressionUUID->"bc230842-7d08-4db8-9a16-29c777d8d30d"],
Cell[CellGroupData[{
Cell[1745459, 33578, 4726, 118, 325, "Input",ExpressionUUID->"961aa4a2-9d99-47e0-baa3-9b9135ac7b2a"],
Cell[1750188, 33698, 68805, 1232, 325, "Output",ExpressionUUID->"a73d3afc-bca7-469d-8310-8e9bdfc7fe5e"]
}, Open  ]],
Cell[1819008, 34933, 607, 15, 52, "Input",ExpressionUUID->"889b6c4e-f135-4438-a018-39faa55266e6"],
Cell[CellGroupData[{
Cell[1819640, 34952, 7261, 181, 430, "Input",ExpressionUUID->"0a8690b1-c110-4a98-a10d-aaadff8adf61"],
Cell[1826904, 35135, 144398, 2515, 322, "Output",ExpressionUUID->"fc676658-96c2-49f6-9ac5-5f93735ca9bc"]
}, Open  ]],
Cell[1971317, 37653, 599, 15, 52, "Input",ExpressionUUID->"bdf37a25-b21f-4f63-96f3-6412f424ae82"],
Cell[CellGroupData[{
Cell[1971941, 37672, 4724, 118, 325, "Input",ExpressionUUID->"52ba00a2-a15f-4d95-b184-6889d8184c50"],
Cell[1976668, 37792, 64998, 1170, 325, "Output",ExpressionUUID->"2bec0feb-2bf7-4de4-a5a2-baa59eec897e"]
}, Open  ]],
Cell[2041681, 38965, 607, 15, 52, "Input",ExpressionUUID->"8a488acd-9675-4724-aa86-4106afaf60a3"],
Cell[CellGroupData[{
Cell[2042313, 38984, 7295, 181, 430, "Input",ExpressionUUID->"18951ee6-0c58-4876-8b38-cfbfa77dd756"],
Cell[2049611, 39167, 129601, 2273, 322, "Output",ExpressionUUID->"55e0f99d-bd21-416c-8b77-773d98f86655"]
}, Open  ]],
Cell[2179227, 41443, 599, 15, 52, "Input",ExpressionUUID->"d3da8008-af84-4d6e-8532-4b0d49d480eb"],
Cell[CellGroupData[{
Cell[2179851, 41462, 4780, 119, 325, "Input",ExpressionUUID->"c727e3e4-5383-4f11-b205-0fc8d5bb74a8"],
Cell[2184634, 41583, 61273, 1108, 325, "Output",ExpressionUUID->"2ca82935-0ea3-433e-a1a3-2bba5415651d"]
}, Open  ]],
Cell[2245922, 42694, 606, 15, 52, "Input",ExpressionUUID->"a04b8ff4-cd6e-4e14-9041-e75f9ed3d46f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2246577, 42715, 303, 6, 53, "Subtitle",ExpressionUUID->"75328225-bc12-41b7-9f26-18aad7055651"],
Cell[CellGroupData[{
Cell[2246905, 42725, 169, 3, 54, "Subsection",ExpressionUUID->"92848e1f-1917-4ed7-b7af-63a21d27e186"],
Cell[2247077, 42730, 1358, 41, 262, "Input",ExpressionUUID->"4061a4f1-0e33-4531-8b79-2376bea03048"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2248472, 42776, 159, 3, 54, "Subsection",ExpressionUUID->"ecb70777-d2bb-41e7-b249-0b5f5ed51d66"],
Cell[2248634, 42781, 284, 6, 30, "Input",ExpressionUUID->"0884ce52-d3dd-48aa-a1cc-b2fccef92966"],
Cell[CellGroupData[{
Cell[2248943, 42791, 7088, 175, 430, "Input",ExpressionUUID->"3d8caa4a-e329-447d-92fe-a2463acefc30"],
Cell[2256034, 42968, 117511, 2075, 332, "Output",ExpressionUUID->"c87b8ab0-bb03-4ef9-b701-e85abbded926"]
}, Open  ]],
Cell[2373560, 45046, 593, 15, 52, "Input",ExpressionUUID->"e8f7ed8b-7af6-40bd-be0b-3376b58c2be1"],
Cell[CellGroupData[{
Cell[2374178, 45065, 4637, 117, 325, "Input",ExpressionUUID->"9af44a9f-0bcf-4cfb-b50c-ec6354af8729"],
Cell[2378818, 45184, 54935, 1005, 325, "Output",ExpressionUUID->"691bba3f-88f7-478c-8362-57dfd07b0db5"]
}, Open  ]],
Cell[2433768, 46192, 601, 15, 52, "Input",ExpressionUUID->"f0ffb3cb-0211-496e-981a-d9dc6926a625"],
Cell[CellGroupData[{
Cell[2434394, 46211, 7236, 176, 472, "Input",ExpressionUUID->"268c9af6-6346-4aad-a405-8aa01a4e12db"],
Cell[2441633, 46389, 127449, 2240, 332, "Output",ExpressionUUID->"f9aa0df7-c660-4fe8-bfe9-037dbc0c98e2"]
}, Open  ]],
Cell[2569097, 48632, 595, 15, 52, "Input",ExpressionUUID->"a063cd9b-4583-4e4e-a4e5-6e105ac71ed3"],
Cell[CellGroupData[{
Cell[2569717, 48651, 4665, 118, 325, "Input",ExpressionUUID->"a97e7159-9454-4065-bb95-6cf35b455ac6"],
Cell[2574385, 48771, 58803, 1068, 325, "Output",ExpressionUUID->"b0290a0f-173b-4f5c-8254-848592487ef2"]
}, Open  ]],
Cell[2633203, 49842, 601, 15, 52, "Input",ExpressionUUID->"781e1714-914a-475a-bec7-3c06c55120f9"],
Cell[CellGroupData[{
Cell[2633829, 49861, 8281, 191, 430, "Input",ExpressionUUID->"025a056b-682b-4830-be6c-6359e4d0f323"],
Cell[2642113, 50054, 136953, 2393, 332, "Output",ExpressionUUID->"8ea309fa-731a-4e80-afe2-581a9389c2a7"]
}, Open  ]],
Cell[2779081, 52450, 597, 15, 52, "Input",ExpressionUUID->"368eaa77-4c0d-4dea-aaec-edb776e8fbac"],
Cell[CellGroupData[{
Cell[2779703, 52469, 4672, 118, 325, "Input",ExpressionUUID->"88b5f297-e507-4122-933e-7fe6b28a3431"],
Cell[2784378, 52589, 60569, 1097, 325, "Output",ExpressionUUID->"382dcf5a-79d5-408d-acd0-4dc27cc73c49"]
}, Open  ]],
Cell[2844962, 53689, 603, 15, 52, "Input",ExpressionUUID->"b9d41b6d-6f14-4b48-869d-1e2f98561bfe"],
Cell[CellGroupData[{
Cell[2845590, 53708, 8305, 192, 430, "Input",ExpressionUUID->"8ab1dd75-39eb-471a-a631-84e8f9ed862a"],
Cell[2853898, 53902, 138522, 2420, 332, "Output",ExpressionUUID->"418d9e9e-26f4-42cd-8d06-a129beda72af"]
}, Open  ]],
Cell[2992435, 56325, 595, 15, 52, "Input",ExpressionUUID->"2f70505f-8939-452a-ae76-71875b521487"],
Cell[CellGroupData[{
Cell[2993055, 56344, 4672, 118, 325, "Input",ExpressionUUID->"de020040-d931-4bcf-a435-4634c84b763c"],
Cell[2997730, 56464, 61214, 1108, 325, "Output",ExpressionUUID->"82eebf89-6a66-4294-a74f-a3aeafff7d93"]
}, Open  ]],
Cell[3058959, 57575, 603, 15, 52, "Input",ExpressionUUID->"d6a0e754-6cf7-4194-abfa-07cb5fdafb57"],
Cell[CellGroupData[{
Cell[3059587, 57594, 8411, 193, 430, "Input",ExpressionUUID->"2e93c11c-531a-43e7-bdc4-7c24f8c7e05b"],
Cell[3068001, 57789, 126868, 2228, 332, "Output",ExpressionUUID->"3b0f804a-dfb8-48e1-af42-844e7690884f"]
}, Open  ]],
Cell[3194884, 60020, 597, 15, 52, "Input",ExpressionUUID->"158ac736-4b47-4614-9712-55965e81b866"],
Cell[CellGroupData[{
Cell[3195506, 60039, 4725, 118, 325, "Input",ExpressionUUID->"4e2badbd-c7ab-4c43-ab1d-666d75968b76"],
Cell[3200234, 60159, 47587, 884, 325, "Output",ExpressionUUID->"589c0b34-38cf-4617-9ff6-fb60da2a5af1"]
}, Open  ]],
Cell[3247836, 61046, 605, 15, 52, "Input",ExpressionUUID->"e444002b-4141-43dc-89f1-7c18c808d8ac"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3248490, 61067, 198, 3, 53, "Subtitle",ExpressionUUID->"00ff2e95-e28f-44db-8101-7110726850e0"],
Cell[3248691, 61072, 11420, 325, 808, "Input",ExpressionUUID->"6c8da3e3-82a0-42da-b25d-2e815c2938d0"],
Cell[3260114, 61399, 9439, 273, 745, "Input",ExpressionUUID->"9fe2ef70-13fb-454c-b930-d7d1fbb80de9"],
Cell[3269556, 61674, 280, 6, 30, "Input",ExpressionUUID->"7afa628f-97d2-486a-8ab9-6fd40476cbb9"],
Cell[3269839, 61682, 221, 5, 30, "Input",ExpressionUUID->"14594e26-5f8a-4316-8cbc-3e05dbc85af6"]
}, Closed]],
Cell[CellGroupData[{
Cell[3270097, 61692, 356, 7, 53, "Subtitle",ExpressionUUID->"fb792a7c-f381-4779-a818-b3e4fb688e55"],
Cell[3270456, 61701, 459, 9, 52, "Input",ExpressionUUID->"4c5d5961-717d-44e2-afe2-88af450c060a"],
Cell[CellGroupData[{
Cell[3270940, 61714, 4345, 104, 199, "Input",ExpressionUUID->"45a3df58-5316-469f-a43a-302cb907a9f6"],
Cell[3275288, 61820, 78481, 1428, 334, "Output",ExpressionUUID->"8f7bb501-9518-4e07-94e5-ebde21050e56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3353806, 63253, 3692, 97, 199, "Input",ExpressionUUID->"f5e77aad-2cb8-40dc-8c8b-604c35195555"],
Cell[3357501, 63352, 80890, 1503, 334, "Output",ExpressionUUID->"c0dbe2fc-6410-460f-b8ca-512e759b4a2d"]
}, Open  ]],
Cell[3438406, 64858, 848, 23, 30, "Input",ExpressionUUID->"2a0b116c-0dd3-4acd-93ec-bdec144c4832"],
Cell[CellGroupData[{
Cell[3439279, 64885, 1008, 18, 30, "Input",ExpressionUUID->"d1eb5cbe-dd62-4b21-b443-1b9e289b0e33"],
Cell[3440290, 64905, 92558, 1693, 245, "Output",ExpressionUUID->"519aae49-48b9-476c-82dc-a3c75c1c4121"]
}, Open  ]],
Cell[3532863, 66601, 600, 14, 52, "Input",ExpressionUUID->"f220c509-ccfb-4a3e-9af3-f72fdb0c9953"],
Cell[CellGroupData[{
Cell[3533488, 66619, 2602, 62, 115, "Input",ExpressionUUID->"4c25ce42-efb4-4c47-8d82-9beb334d503a"],
Cell[3536093, 66683, 30151, 552, 285, "Output",ExpressionUUID->"00d87568-5ee7-4b24-a973-79345cf20653"]
}, Open  ]],
Cell[3566259, 67238, 608, 15, 52, "Input",ExpressionUUID->"c928ef1b-c4f6-42bc-bcaf-c4c84fbcfb9a"],
Cell[3566870, 67255, 175, 3, 30, "Input",ExpressionUUID->"8522c31e-3366-4b0f-b841-f69ee160884a"]
}, Closed]],
Cell[CellGroupData[{
Cell[3567082, 67263, 356, 7, 53, "Subtitle",ExpressionUUID->"e218d908-726c-46c7-bbcf-25694d8b4e22"],
Cell[3567441, 67272, 459, 9, 52, "Input",ExpressionUUID->"af98baf8-cda1-4cdf-bbb2-40a61d5ea2a9"],
Cell[CellGroupData[{
Cell[3567925, 67285, 4352, 105, 199, "Input",ExpressionUUID->"2288fb6a-69b7-4b2a-b6ee-fb8a2ee92054"],
Cell[3572280, 67392, 74503, 1364, 334, "Output",ExpressionUUID->"ae81f538-53dc-433b-960e-415ea0a47e30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3646820, 68761, 3576, 94, 199, "Input",ExpressionUUID->"53b83aca-4b87-4dee-8cc9-5b7f76a2fb67"],
Cell[3650399, 68857, 77230, 1443, 334, "Output",ExpressionUUID->"e4814613-5857-440e-847d-e2b11becf783"]
}, Open  ]],
Cell[3727644, 70303, 870, 23, 30, "Input",ExpressionUUID->"f770bff2-1227-4854-a4cd-5a6ad65ab904"],
Cell[CellGroupData[{
Cell[3728539, 70330, 957, 18, 30, "Input",ExpressionUUID->"2778d970-612b-4019-b123-cc3ed9fa412a"],
Cell[3729499, 70350, 87682, 1615, 245, "Output",ExpressionUUID->"5a2d64c3-8d62-48cb-87fb-1cfc930787c9"]
}, Open  ]],
Cell[3817196, 71968, 651, 15, 52, "Input",ExpressionUUID->"0d24b8f0-0e98-4125-b20d-871ec2f33dfd"],
Cell[CellGroupData[{
Cell[3817872, 71987, 2536, 63, 115, "Input",ExpressionUUID->"4317bb8e-9358-43bc-bc1d-191d5b8ffc1e"],
Cell[3820411, 72052, 26542, 494, 285, "Output",ExpressionUUID->"db16f247-e126-4935-b0fa-b229e978cb75"]
}, Open  ]],
Cell[3846968, 72549, 664, 15, 52, "Input",ExpressionUUID->"5d802398-f020-4389-88b0-f2563cca9f9c"]
}, Closed]],
Cell[CellGroupData[{
Cell[3847669, 72569, 489, 9, 85, "Subtitle",ExpressionUUID->"a14510e7-0df2-4c28-91b2-b0bd559d373a"],
Cell[3848161, 72580, 459, 9, 52, "Input",ExpressionUUID->"b7ba0189-608a-4cc9-a7fd-cc60feb0b608"],
Cell[CellGroupData[{
Cell[3848645, 72593, 4802, 112, 199, "Input",ExpressionUUID->"91195b8f-f0f8-4ad9-99ea-ac3922c7f56e"],
Cell[3853450, 72707, 66956, 1265, 317, "Output",ExpressionUUID->"10970ed1-9028-4ce6-b90c-d24ae52a9ad2"]
}, Open  ]],
Cell[3920421, 73975, 1010, 25, 30, "Input",ExpressionUUID->"746fac6e-02c9-4c4f-a2cc-e6b8db1828bc"],
Cell[CellGroupData[{
Cell[3921456, 74004, 1090, 20, 52, "Input",ExpressionUUID->"de8575c4-5107-45b8-9419-38ca0d4bf8c7"],
Cell[3922549, 74026, 73786, 1382, 244, "Output",ExpressionUUID->"c3755d38-4c25-4612-9ac7-3eb1d0d6e88b"]
}, Open  ]],
Cell[3996350, 75411, 755, 17, 52, "Input",ExpressionUUID->"c7a2ba89-41ba-458d-af51-e3d93dd89c57"],
Cell[CellGroupData[{
Cell[3997130, 75432, 2839, 66, 115, "Input",ExpressionUUID->"b839f804-aa42-4413-bb77-6e6d141970ab"],
Cell[3999972, 75500, 24088, 452, 285, "Output",ExpressionUUID->"293e1d30-26b4-4b33-badf-72fc19648b9f"]
}, Open  ]],
Cell[4024075, 75955, 705, 17, 52, "Input",ExpressionUUID->"6ea84ae9-20b3-4b99-96d7-3117d9c32deb"]
}, Closed]],
Cell[CellGroupData[{
Cell[4024817, 75977, 438, 8, 85, "Subtitle",ExpressionUUID->"44bb905e-0d19-408f-8202-a0f142d47781"],
Cell[4025258, 75987, 510, 10, 52, "Input",ExpressionUUID->"53bc77f2-db51-42db-ad35-70bbabc3148c"],
Cell[CellGroupData[{
Cell[4025793, 76001, 4784, 112, 199, "Input",ExpressionUUID->"4ebe5f1b-558e-43b0-9388-9fb45a9f7bb2"],
Cell[4030580, 76115, 66378, 1255, 317, "Output",ExpressionUUID->"596cd867-e70b-4bb8-ab42-43ac655cf6a0"]
}, Open  ]],
Cell[4096973, 77373, 959, 24, 30, "Input",ExpressionUUID->"dbd07b5a-1c61-4498-8365-d267b50242e8"],
Cell[CellGroupData[{
Cell[4097957, 77401, 1035, 19, 52, "Input",ExpressionUUID->"b274bde1-9c49-4f25-8276-ab59abe75b95"],
Cell[4098995, 77422, 71705, 1349, 244, "Output",ExpressionUUID->"0b810125-c78b-4600-9442-139fdfbee60a"]
}, Open  ]],
Cell[4170715, 78774, 757, 17, 52, "Input",ExpressionUUID->"0bfe79e0-59b7-469d-9038-9c19a905c47d"],
Cell[CellGroupData[{
Cell[4171497, 78795, 2550, 62, 115, "Input",ExpressionUUID->"be4eda7c-fa41-44e1-ad47-aa6d47befe25"],
Cell[4174050, 78859, 21357, 409, 285, "Output",ExpressionUUID->"a888f91a-2e69-49ea-bea2-8c37489e7f5a"]
}, Open  ]],
Cell[4195422, 79271, 763, 17, 52, "Input",ExpressionUUID->"09c0a962-9783-48f8-b4e9-78a2bbbff11a"]
}, Closed]]
}, Open  ]]
}
]
*)

